Class: CyberSourceMergedSpec::Account19

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/account19.rb

Overview

Account19 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(suffix: SKIP, prefix: SKIP, additional_properties: nil) ⇒ Account19

Returns a new instance of Account19.



42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 42

def initialize(suffix: SKIP, prefix: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @suffix = suffix unless suffix == SKIP
  @prefix = prefix unless prefix == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#prefixString

Bank Identification Number (BIN). This is the initial four to six numbers on a credit card account number.

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 19

def prefix
  @prefix
end

#suffixString

Last four digits of the customer’s payment account number.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 14

def suffix
  @suffix
end

Class Method Details

.from_element(root) ⇒ Object



72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 72

def self.from_element(root)
  suffix = XmlUtilities.from_element(root, 'suffix', String)
  prefix = XmlUtilities.from_element(root, 'prefix', String)

  new(suffix: suffix,
      prefix: prefix,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  suffix = hash.key?('suffix') ? hash['suffix'] : SKIP
  prefix = hash.key?('prefix') ? hash['prefix'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Account19.new(suffix: suffix,
                prefix: prefix,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['suffix'] = 'suffix'
  @_hash['prefix'] = 'prefix'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 30

def self.optionals
  %w[
    suffix
    prefix
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 100

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} suffix: #{@suffix.inspect}, prefix: #{@prefix.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} suffix: #{@suffix}, prefix: #{@prefix}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



81
82
83
84
85
86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/account19.rb', line 81

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'suffix', suffix)
  XmlUtilities.add_as_subelement(doc, root, 'prefix', prefix)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end