Class: CyberSourceMergedSpec::AccountFeatures2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/account_features2.rb

Overview

AccountFeatures2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(category: SKIP, additional_properties: nil) ⇒ AccountFeatures2

Returns a new instance of AccountFeatures2.



43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 43

def initialize(category: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @category = category unless category == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#categoryString

Card type category. Type of card used in the transaction. Possible values:

  • B: Business card.
  • O: Noncommercial card.
  • R: Corporate card.
  • S: Purchase card.
  • X: Visa B2B Virtual Payments
  • X1: Flexible Rate B2B Virtual Program
  • Blank: Purchase card not supported.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 22

def category
  @category
end

Class Method Details

.from_element(root) ⇒ Object



70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 70

def self.from_element(root)
  category = XmlUtilities.from_element(root, 'category', String)

  new(category: category,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  category = hash.key?('category') ? hash['category'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountFeatures2.new(category: category,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['category'] = 'category'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 32

def self.optionals
  %w[
    category
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



77
78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/account_features2.rb', line 77

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'category', category)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end