Class: CyberSourceMergedSpec::ActionDecisionManagerCaseException

Inherits:
APIException
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb

Overview

actionDecisionManagerCaseException class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ ActionDecisionManagerCaseException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



43
44
45
46
47
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 43

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#detailsArray[Detail]

Input request error.

Returns:



38
39
40
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 38

def details
  @details
end

#messageString

Input request error.

Returns:

  • (String)


34
35
36
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 34

def message
  @message
end

#reasonString

The reason of the status. Possible Values:

  • INVALID_DATA

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 30

def reason
  @reason
end

#statusString

The status of the submitted transaction. Possible values:

  • INVALID_REQUEST

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 24

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 18

def submit_time_utc
  @submit_time_utc
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



80
81
82
83
84
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 80

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\
  " reason: #{@reason.inspect}, message: #{@message.inspect}, details: #{@details.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
77
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc}, status: #{@status}, reason:"\
  " #{@reason}, message: #{@message}, details: #{@details}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/exceptions/action_decision_manager_case_exception.rb', line 52

def unbox(hash)
  return nil unless hash

  @submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  @status = hash.key?('status') ? hash['status'] : SKIP
  @reason = hash.key?('reason') ? hash['reason'] : SKIP
  @message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  @details = nil
  unless hash['details'].nil?
    @details = []
    hash['details'].each do |structure|
      @details << (Detail.from_hash(structure) if structure)
    end
  end

  @details = SKIP unless hash.key?('details')
end