Class: CyberSourceMergedSpec::ActionDecisionManagerCaseResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ActionDecisionManagerCaseResponse
- Defined in:
- lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb
Overview
ActionDecisionManagerCaseResponse Model.
Instance Attribute Summary collapse
-
#embedded ⇒ Embedded55
This object includes either a capture or reversal object.
-
#id ⇒ String
UUID uniquely generated for this comments.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, embedded: SKIP, additional_properties: nil) ⇒ ActionDecisionManagerCaseResponse
constructor
A new instance of ActionDecisionManagerCaseResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, embedded: SKIP, additional_properties: nil) ⇒ ActionDecisionManagerCaseResponse
Returns a new instance of ActionDecisionManagerCaseResponse.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 61 def initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, embedded: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @embedded = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#embedded ⇒ Embedded55
This object includes either a capture or reversal object. They each has the status of the action and link to the GET method to the following-on capture transaction or reversal transaction.
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 34 def @embedded end |
#id ⇒ String
UUID uniquely generated for this comments.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 14 def id @id end |
#status ⇒ String
The status of the submitted transaction. Possible values are:
ACCEPTEDREJECTED
28 29 30 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 28 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 22 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 99 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) = XmlUtilities.from_element(root, 'Embedded55', Embedded55) new(id: id, submit_time_utc: submit_time_utc, status: status, embedded: , additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP = Embedded55.from_hash(hash['_embedded']) if hash['_embedded'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ActionDecisionManagerCaseResponse.new(id: id, submit_time_utc: submit_time_utc, status: status, embedded: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['embedded'] = '_embedded' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
47 48 49 50 51 52 53 54 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 47 def self.optionals %w[ id submit_time_utc status embedded ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
134 135 136 137 138 139 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 134 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, submit_time_utc: #{@submit_time_utc.inspect}, status:"\ " #{@status.inspect}, embedded: #{@embedded.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
127 128 129 130 131 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 127 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " embedded: #{@embedded}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/cyber_source_merged_spec/models/action_decision_manager_case_response.rb', line 112 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'Embedded55', ) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |