Class: CyberSourceMergedSpec::Address1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/address1.rb

Overview

Address1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(with_apartment: SKIP, without_apartment: SKIP, additional_properties: nil) ⇒ Address1

Returns a new instance of Address1.



42
43
44
45
46
47
48
49
50
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 42

def initialize(with_apartment: SKIP, without_apartment: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @with_apartment = with_apartment unless with_apartment == SKIP
  @without_apartment = without_apartment unless without_apartment == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#with_apartmentString

First line of the standardized address, including apartment information.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 14

def with_apartment
  @with_apartment
end

#without_apartmentString

First line of the standardized address, without apartment information. Returned for U.S. and Canadian addresses.

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 19

def without_apartment
  @without_apartment
end

Class Method Details

.from_element(root) ⇒ Object



74
75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 74

def self.from_element(root)
  with_apartment = XmlUtilities.from_element(root, 'withApartment', String)
  without_apartment = XmlUtilities.from_element(root, 'withoutApartment',
                                                String)

  new(with_apartment: with_apartment,
      without_apartment: without_apartment,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  with_apartment = hash.key?('withApartment') ? hash['withApartment'] : SKIP
  without_apartment =
    hash.key?('withoutApartment') ? hash['withoutApartment'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Address1.new(with_apartment: with_apartment,
               without_apartment: without_apartment,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['with_apartment'] = 'withApartment'
  @_hash['without_apartment'] = 'withoutApartment'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 30

def self.optionals
  %w[
    with_apartment
    without_apartment
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} with_apartment: #{@with_apartment.inspect}, without_apartment:"\
  " #{@without_apartment.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} with_apartment: #{@with_apartment}, without_apartment:"\
  " #{@without_apartment}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/address1.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'withApartment', with_apartment)
  XmlUtilities.add_as_subelement(doc, root, 'withoutApartment',
                                 without_apartment)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end