Class: CyberSourceMergedSpec::AmountDetails29

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/amount_details29.rb

Overview

AmountDetails29 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_amount: SKIP, additional_properties: nil) ⇒ AmountDetails29

Returns a new instance of AmountDetails29.



64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 64

def initialize(total_amount: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total_amount = total_amount unless total_amount == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#total_amountString

Grand total for the order. This value cannot be negative. You can include a decimal point (.), but no other special characters. CyberSource truncates the amount to the correct number of decimal places. Note For CTV, FDCCompass, Paymentech processors, the maximum length for this field is 12. Important Some processors have specific requirements and limitations, such as maximum amounts and maximum field lengths. If your processor supports zero amount authorizations, you can set this field to 0 for the authorization to check if the card is lost or stolen.

Card Present

Required to include either this field or orderInformation.lineItems[].unitPrice for the order.

Required for creating a new invoice or payment link.

PIN Debit

Amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.

GPX

This field is optional for reversing an authorization or credit; however, for all other processors, these fields are required.

DCC with a Third-Party Provider

Set this field to the converted amount that was returned by the DCC provider. You must include either this field or the 1st line item in the order and the specific line-order amount in your request.

DCC for First Data

Not used.

Returns:

  • (String)


43
44
45
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 43

def total_amount
  @total_amount
end

Class Method Details

.from_element(root) ⇒ Object



91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 91

def self.from_element(root)
  total_amount = XmlUtilities.from_element(root, 'totalAmount', String)

  new(total_amount: total_amount,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 73

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_amount = hash.key?('totalAmount') ? hash['totalAmount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AmountDetails29.new(total_amount: total_amount,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



46
47
48
49
50
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 46

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_amount'] = 'totalAmount'
  @_hash
end

.nullablesObject

An array for nullable fields



60
61
62
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 60

def self.nullables
  []
end

.optionalsObject

An array for optional fields



53
54
55
56
57
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 53

def self.optionals
  %w[
    total_amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



116
117
118
119
120
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 116

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_amount: #{@total_amount.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



109
110
111
112
113
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 109

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_amount: #{@total_amount}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



98
99
100
101
102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/amount_details29.rb', line 98

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'totalAmount', total_amount)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end