Class: CyberSourceMergedSpec::AmountDetails3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/amount_details3.rb

Overview

AmountDetails3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(additional_amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ AmountDetails3

Returns a new instance of AmountDetails3.



79
80
81
82
83
84
85
86
87
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 79

def initialize(additional_amount: SKIP, currency: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @additional_amount = additional_amount unless additional_amount == SKIP
  @currency = currency unless currency == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#additional_amountString

Additional charges that have to be authorized against a lodging or auto-rental order. This value cannot be negative. You can include a decimal point (.), but no other special characters.

Returns:

  • (String)


17
18
19
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 17

def additional_amount
  @additional_amount
end

#currencyString

Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/cur rencies.pdf)

Used by

Authorization Required field. Authorization Reversal For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request.

PIN Debit

Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.

GPX

This field is optional for reversing an authorization or credit.

DCC for First Data

Your local currency.

Tax Calculation

Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.

Returns:

  • (String)


56
57
58
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 56

def currency
  @currency
end

Class Method Details

.from_element(root) ⇒ Object



111
112
113
114
115
116
117
118
119
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 111

def self.from_element(root)
  additional_amount = XmlUtilities.from_element(root, 'additionalAmount',
                                                String)
  currency = XmlUtilities.from_element(root, 'currency', String)

  new(additional_amount: additional_amount,
      currency: currency,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 90

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  additional_amount =
    hash.key?('additionalAmount') ? hash['additionalAmount'] : SKIP
  currency = hash.key?('currency') ? hash['currency'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AmountDetails3.new(additional_amount: additional_amount,
                     currency: currency,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 59

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['additional_amount'] = 'additionalAmount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



75
76
77
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 75

def self.nullables
  []
end

.optionalsObject

An array for optional fields



67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 67

def self.optionals
  %w[
    additional_amount
    currency
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



141
142
143
144
145
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 141

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} additional_amount: #{@additional_amount.inspect}, currency:"\
  " #{@currency.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



134
135
136
137
138
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 134

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} additional_amount: #{@additional_amount}, currency: #{@currency},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



121
122
123
124
125
126
127
128
129
130
131
# File 'lib/cyber_source_merged_spec/models/amount_details3.rb', line 121

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'additionalAmount',
                                 additional_amount)
  XmlUtilities.add_as_subelement(doc, root, 'currency', currency)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end