Class: CyberSourceMergedSpec::AmountDetails45

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/amount_details45.rb

Overview

AmountDetails45 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_amount:, additional_properties: nil) ⇒ AmountDetails45

Returns a new instance of AmountDetails45.



43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 43

def initialize(total_amount:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total_amount = total_amount
  @additional_properties = additional_properties
end

Instance Attribute Details

#total_amountString

Length: <=12. Up to 3 decimal places.
Type: String, with a non-negative double format. The total amount of the AFT reversal including all fees.

  1. an amount that is <= the totalAmount of the original AFT
  2. The amount of the transaction, inclusive of all fees assessed for the transaction, including currency conversion fees.
    Minimum Value: Field must be greater than zero: minimum value is the smallest amount in any given currency.
  3. Multiple successful reversals & refunds of the original AFT transaction are allowed but the sum of the transaction amounts must not total more than the original AFT totalAmount.

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 24

def total_amount
  @total_amount
end

Class Method Details

.from_element(root) ⇒ Object



70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 70

def self.from_element(root)
  total_amount = XmlUtilities.from_element(root, 'totalAmount', String)

  new(total_amount: total_amount,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_amount = hash.key?('totalAmount') ? hash['totalAmount'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AmountDetails45.new(total_amount: total_amount,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_amount'] = 'totalAmount'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 34

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_amount: #{@total_amount.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_amount: #{@total_amount}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



77
78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/amount_details45.rb', line 77

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'totalAmount', total_amount)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end