Class: CyberSourceMergedSpec::AmountDetails47

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/amount_details47.rb

Overview

AmountDetails47 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency:, billing_amount:, setup_fee: SKIP, additional_properties: nil) ⇒ AmountDetails47

Returns a new instance of AmountDetails47.



80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 80

def initialize(currency:, billing_amount:, setup_fee: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency = currency
  @billing_amount = billing_amount
  @setup_fee = setup_fee unless setup_fee == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_amountString

Billing amount for the billing period.

Returns:

  • (String)


53
54
55
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 53

def billing_amount
  @billing_amount
end

#currencyString

Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/cur rencies.pdf)

Used by

Authorization Required field. Authorization Reversal For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request.

PIN Debit

Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.

GPX

This field is optional for reversing an authorization or credit.

DCC for First Data

Your local currency.

Tax Calculation

Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.

Returns:

  • (String)


49
50
51
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 49

def currency
  @currency
end

#setup_feeString

Subscription setup fee

Returns:

  • (String)


57
58
59
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 57

def setup_fee
  @setup_fee
end

Class Method Details

.from_element(root) ⇒ Object



114
115
116
117
118
119
120
121
122
123
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 114

def self.from_element(root)
  currency = XmlUtilities.from_element(root, 'currency', String)
  billing_amount = XmlUtilities.from_element(root, 'billingAmount', String)
  setup_fee = XmlUtilities.from_element(root, 'setupFee', String)

  new(currency: currency,
      billing_amount: billing_amount,
      setup_fee: setup_fee,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 92

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  billing_amount = hash.key?('billingAmount') ? hash['billingAmount'] : nil
  setup_fee = hash.key?('setupFee') ? hash['setupFee'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AmountDetails47.new(currency: currency,
                      billing_amount: billing_amount,
                      setup_fee: setup_fee,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



60
61
62
63
64
65
66
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 60

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['billing_amount'] = 'billingAmount'
  @_hash['setup_fee'] = 'setupFee'
  @_hash
end

.nullablesObject

An array for nullable fields



76
77
78
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 76

def self.nullables
  []
end

.optionalsObject

An array for optional fields



69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 69

def self.optionals
  %w[
    setup_fee
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



145
146
147
148
149
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 145

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, billing_amount: #{@billing_amount.inspect},"\
  " setup_fee: #{@setup_fee.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



138
139
140
141
142
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 138

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, billing_amount: #{@billing_amount}, setup_fee:"\
  " #{@setup_fee}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



125
126
127
128
129
130
131
132
133
134
135
# File 'lib/cyber_source_merged_spec/models/amount_details47.rb', line 125

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'currency', currency)
  XmlUtilities.add_as_subelement(doc, root, 'billingAmount', billing_amount)
  XmlUtilities.add_as_subelement(doc, root, 'setupFee', setup_fee)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end