Class: CyberSourceMergedSpec::Avs
- Defined in:
- lib/cyber_source_merged_spec/models/avs.rb
Overview
Avs Model.
Instance Attribute Summary collapse
-
#code ⇒ String
AVS result code.
-
#code_raw ⇒ String
AVS result code sent directly from the processor.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) ⇒ Avs
constructor
A new instance of Avs.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) ⇒ Avs
Returns a new instance of Avs.
46 47 48 49 50 51 52 53 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 46 def initialize(code: SKIP, code_raw: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @code_raw = code_raw unless code_raw == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
AVS result code. Returned by authorization service.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 15 def code @code end |
#code_raw ⇒ String
AVS result code sent directly from the processor. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of AVS. Use for debugging purposes only. Returned by authorization service.
23 24 25 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 23 def code_raw @code_raw end |
Class Method Details
.from_element(root) ⇒ Object
76 77 78 79 80 81 82 83 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 76 def self.from_element(root) code = XmlUtilities.from_element(root, 'code', String) code_raw = XmlUtilities.from_element(root, 'codeRaw', String) new(code: code, code_raw: code_raw, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP code_raw = hash.key?('codeRaw') ? hash['codeRaw'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Avs.new(code: code, code_raw: code_raw, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['code_raw'] = 'codeRaw' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 34 def self.optionals %w[ code code_raw ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, code_raw: #{@code_raw.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, code_raw: #{@code_raw}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
85 86 87 88 89 90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/avs.rb', line 85 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'code', code) XmlUtilities.add_as_subelement(doc, root, 'codeRaw', code_raw) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |