Class: CyberSourceMergedSpec::Avs4
- Defined in:
- lib/cyber_source_merged_spec/models/avs4.rb
Overview
Avs4 Model.
Instance Attribute Summary collapse
-
#code ⇒ String
AVS result code.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, additional_properties: nil) ⇒ Avs4
constructor
A new instance of Avs4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, additional_properties: nil) ⇒ Avs4
Returns a new instance of Avs4.
42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 42 def initialize(code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
AVS result code. Code Description
- 'Y' Full Match
- 'A' Partial Match (street address only)
- 'Z' Partial Match (postal/zip only)
- 'N' Non-Match
- 'U' Unable to Verify
- 'R' Indeterminate Outcome (Retry)
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 21 def code @code end |
Class Method Details
.from_element(root) ⇒ Object
69 70 71 72 73 74 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 69 def self.from_element(root) code = XmlUtilities.from_element(root, 'code', String) new(code: code, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Avs4.new(code: code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 31 def self.optionals %w[ code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
76 77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/avs4.rb', line 76 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'code', code) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |