Class: CyberSourceMergedSpec::Bank11

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/bank11.rb

Overview

Bank11 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(swift_code: SKIP, account: SKIP, additional_properties: nil) ⇒ Bank11

Returns a new instance of Bank11.



45
46
47
48
49
50
51
52
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 45

def initialize(swift_code: SKIP, account: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @swift_code = swift_code unless swift_code == SKIP
  @account =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#accountAccount12

Bank’s SWIFT code. You can use this field only when scoring a direct debit transaction. Required only for crossborder transactions.

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 22

def 
  @account
end

#swift_codeString

Bank’s SWIFT code. You can use this field only when scoring a direct debit transaction. Required only for crossborder transactions.

Returns:

  • (String)


16
17
18
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 16

def swift_code
  @swift_code
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 75

def self.from_element(root)
  swift_code = XmlUtilities.from_element(root, 'swiftCode', String)
   = XmlUtilities.from_element(root, 'Account12', Account12)

  new(swift_code: swift_code,
      account: ,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  swift_code = hash.key?('swiftCode') ? hash['swiftCode'] : SKIP
   = Account12.from_hash(hash['account']) if hash['account']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Bank11.new(swift_code: swift_code,
             account: ,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['swift_code'] = 'swiftCode'
  @_hash['account'] = 'account'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
38
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 33

def self.optionals
  %w[
    swift_code
    account
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} swift_code: #{@swift_code.inspect}, account: #{@account.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} swift_code: #{@swift_code}, account: #{@account}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/bank11.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'swiftCode', swift_code)
  XmlUtilities.add_as_subelement(doc, root, 'Account12', )
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end