Class: CyberSourceMergedSpec::BankAccount1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/bank_account1.rb

Overview

BankAccount1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(number: SKIP, routing_number: SKIP, additional_properties: nil) ⇒ BankAccount1

Returns a new instance of BankAccount1.



47
48
49
50
51
52
53
54
55
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 47

def initialize(number: SKIP, routing_number: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @number = number unless number == SKIP
  @routing_number = routing_number unless routing_number == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#numberString

Account number. When processing encoded account numbers, use this field for the encoded account number.

Returns:

  • (String)


16
17
18
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 16

def number
  @number
end

#routing_numberString

Bank routing number. This is also called the transit number.

For details, see ecp_rdfi field description in the [Electronic Check

Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/EChe cks_SCMP_API/html/)

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 24

def routing_number
  @routing_number
end

Class Method Details

.from_element(root) ⇒ Object



78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 78

def self.from_element(root)
  number = XmlUtilities.from_element(root, 'number', String)
  routing_number = XmlUtilities.from_element(root, 'routingNumber', String)

  new(number: number,
      routing_number: routing_number,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  number = hash.key?('number') ? hash['number'] : SKIP
  routing_number = hash.key?('routingNumber') ? hash['routingNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BankAccount1.new(number: number,
                   routing_number: routing_number,
                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['number'] = 'number'
  @_hash['routing_number'] = 'routingNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 35

def self.optionals
  %w[
    number
    routing_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} number: #{@number.inspect}, routing_number: #{@routing_number.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} number: #{@number}, routing_number: #{@routing_number},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



87
88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/bank_account1.rb', line 87

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'number', number)
  XmlUtilities.add_as_subelement(doc, root, 'routingNumber', routing_number)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end