Class: CyberSourceMergedSpec::BankApplication
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::BankApplication
- Defined in:
- lib/cyber_source_merged_spec/models/bank_application.rb
Overview
BankApplication Model.
Instance Attribute Summary collapse
-
#address ⇒ String
Bank application address.
-
#name ⇒ String
Bank application name.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, address: SKIP, additional_properties: nil) ⇒ BankApplication
constructor
A new instance of BankApplication.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, address: SKIP, additional_properties: nil) ⇒ BankApplication
Returns a new instance of BankApplication.
41 42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 41 def initialize(name: SKIP, address: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @address = address unless address == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address ⇒ String
Bank application address. (e.g. com.mybank.app)
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 18 def address @address end |
#name ⇒ String
Bank application name.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 14 def name @name end |
Class Method Details
.from_element(root) ⇒ Object
71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 71 def self.from_element(root) name = XmlUtilities.from_element(root, 'name', String) address = XmlUtilities.from_element(root, 'address', String) new(name: name, address: address, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP address = hash.key?('address') ? hash['address'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankApplication.new(name: name, address: address, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['address'] = 'address' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 29 def self.optionals %w[ name address ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, address: #{@address.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, address: #{@address}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/bank_application.rb', line 80 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'name', name) XmlUtilities.add_as_subelement(doc, root, 'address', address) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |