Class: CyberSourceMergedSpec::BankTransferOptions4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::BankTransferOptions4
- Defined in:
- lib/cyber_source_merged_spec/models/bank_transfer_options4.rb
Overview
BankTransferOptions4 Model.
Instance Attribute Summary collapse
-
#sec_code ⇒ String
Specifies the authorization method for the transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(sec_code: SKIP, additional_properties: nil) ⇒ BankTransferOptions4
constructor
A new instance of BankTransferOptions4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(sec_code: SKIP, additional_properties: nil) ⇒ BankTransferOptions4
Returns a new instance of BankTransferOptions4.
47 48 49 50 51 52 53 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 47 def initialize(sec_code: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @sec_code = sec_code unless sec_code == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#sec_code ⇒ String
Specifies the authorization method for the transaction.
TeleCheck
Possible Values:
ARC: account receivable conversionCCD: corporate cash disbursementPOP: point of purchase conversionPPD: prearranged payment and deposit entryTEL: telephone-initiated entryWEB: internet-initiated entry
For details, see ecp_sec_code field description in the [Electronic
Check Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/EChe cks_SCMP_API/html/)
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 26 def sec_code @sec_code end |
Class Method Details
.from_element(root) ⇒ Object
74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 74 def self.from_element(root) sec_code = XmlUtilities.from_element(root, 'SECCode', String) new(sec_code: sec_code, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. sec_code = hash.key?('SECCode') ? hash['SECCode'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankTransferOptions4.new(sec_code: sec_code, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['sec_code'] = 'SECCode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 36 def self.optionals %w[ sec_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 98 def inspect class_name = self.class.name.split('::').last "<#{class_name} sec_code: #{@sec_code.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} sec_code: #{@sec_code}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/bank_transfer_options4.rb', line 81 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'SECCode', sec_code) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |