Class: CyberSourceMergedSpec::BillTo20

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/bill_to20.rb

Overview

BillTo20 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_name: SKIP, last_name: SKIP, address1: SKIP, locality: SKIP, administrative_area: SKIP, postal_code: SKIP, country: SKIP, email: SKIP, additional_properties: nil) ⇒ BillTo20

Returns a new instance of BillTo20.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 90

def initialize(first_name: SKIP, last_name: SKIP, address1: SKIP,
               locality: SKIP, administrative_area: SKIP, postal_code: SKIP,
               country: SKIP, email: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name unless first_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @address1 = address1 unless address1 == SKIP
  @locality = locality unless locality == SKIP
  @administrative_area = administrative_area unless administrative_area == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @country = country unless country == SKIP
  @email = email unless email == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#address1String

Payment card billing street address as it appears on the credit card issuer’s records.

Returns:

  • (String)


23
24
25
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 23

def address1
  @address1
end

#administrative_areaString

State or province of the billing address. Use the State, Province, and Territory Codes for the United States and Canada.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 33

def administrative_area
  @administrative_area
end

#countryString

Payment card billing country. Use the two-character ISO Standard Country Codes.

Returns:

  • (String)


51
52
53
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 51

def country
  @country
end

#emailString

Customer's email address, including the full domain name.

Returns:

  • (String)


55
56
57
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 55

def email
  @email
end

#first_nameString

Customer’s first name. This name must be the same as the name on the card.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 14

def first_name
  @first_name
end

#last_nameString

Customer’s last name. This name must be the same as the name on the card.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 18

def last_name
  @last_name
end

#localityString

Payment card billing city.

Returns:

  • (String)


27
28
29
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 27

def locality
  @locality
end

#postal_codeString

Postal code for the billing address. The postal code must consist of 5 to 9 digits. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3

Returns:

  • (String)


46
47
48
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 46

def postal_code
  @postal_code
end

Class Method Details

.from_element(root) ⇒ Object



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 141

def self.from_element(root)
  first_name = XmlUtilities.from_element(root, 'firstName', String)
  last_name = XmlUtilities.from_element(root, 'lastName', String)
  address1 = XmlUtilities.from_element(root, 'address1', String)
  locality = XmlUtilities.from_element(root, 'locality', String)
  administrative_area = XmlUtilities.from_element(root,
                                                  'administrativeArea',
                                                  String)
  postal_code = XmlUtilities.from_element(root, 'postalCode', String)
  country = XmlUtilities.from_element(root, 'country', String)
  email = XmlUtilities.from_element(root, 'email', String)

  new(first_name: first_name,
      last_name: last_name,
      address1: address1,
      locality: locality,
      administrative_area: administrative_area,
      postal_code: postal_code,
      country: country,
      email: email,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 108

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_name = hash.key?('firstName') ? hash['firstName'] : SKIP
  last_name = hash.key?('lastName') ? hash['lastName'] : SKIP
  address1 = hash.key?('address1') ? hash['address1'] : SKIP
  locality = hash.key?('locality') ? hash['locality'] : SKIP
  administrative_area =
    hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP
  postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP
  country = hash.key?('country') ? hash['country'] : SKIP
  email = hash.key?('email') ? hash['email'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BillTo20.new(first_name: first_name,
               last_name: last_name,
               address1: address1,
               locality: locality,
               administrative_area: administrative_area,
               postal_code: postal_code,
               country: country,
               email: email,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 58

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'firstName'
  @_hash['last_name'] = 'lastName'
  @_hash['address1'] = 'address1'
  @_hash['locality'] = 'locality'
  @_hash['administrative_area'] = 'administrativeArea'
  @_hash['postal_code'] = 'postalCode'
  @_hash['country'] = 'country'
  @_hash['email'] = 'email'
  @_hash
end

.nullablesObject

An array for nullable fields



86
87
88
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 86

def self.nullables
  []
end

.optionalsObject

An array for optional fields



72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 72

def self.optionals
  %w[
    first_name
    last_name
    address1
    locality
    administrative_area
    postal_code
    country
    email
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



192
193
194
195
196
197
198
199
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 192

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " address1: #{@address1.inspect}, locality: #{@locality.inspect}, administrative_area:"\
  " #{@administrative_area.inspect}, postal_code: #{@postal_code.inspect}, country:"\
  " #{@country.inspect}, email: #{@email.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



183
184
185
186
187
188
189
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 183

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, address1:"\
  " #{@address1}, locality: #{@locality}, administrative_area: #{@administrative_area},"\
  " postal_code: #{@postal_code}, country: #{@country}, email: #{@email},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/cyber_source_merged_spec/models/bill_to20.rb', line 164

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'firstName', first_name)
  XmlUtilities.add_as_subelement(doc, root, 'lastName', last_name)
  XmlUtilities.add_as_subelement(doc, root, 'address1', address1)
  XmlUtilities.add_as_subelement(doc, root, 'locality', locality)
  XmlUtilities.add_as_subelement(doc, root, 'administrativeArea',
                                 administrative_area)
  XmlUtilities.add_as_subelement(doc, root, 'postalCode', postal_code)
  XmlUtilities.add_as_subelement(doc, root, 'country', country)
  XmlUtilities.add_as_subelement(doc, root, 'email', email)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end