Class: CyberSourceMergedSpec::BillTo65

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/bill_to65.rb

Overview

BillTo65 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(address1:, administrative_area:, country:, first_name:, last_name:, email:, postal_code:, address2: SKIP, address3: SKIP, locality: SKIP, phone_number: SKIP, additional_properties: nil) ⇒ BillTo65

Returns a new instance of BillTo65.



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 444

def initialize(address1:, administrative_area:, country:, first_name:,
               last_name:, email:, postal_code:, address2: SKIP,
               address3: SKIP, locality: SKIP, phone_number: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @address1 = address1
  @address2 = address2 unless address2 == SKIP
  @address3 = address3 unless address3 == SKIP
  @administrative_area = administrative_area
  @country = country
  @locality = locality unless locality == SKIP
  @first_name = first_name
  @last_name = last_name
  @phone_number = phone_number unless phone_number == SKIP
  @email = email
  @postal_code = postal_code
  @additional_properties = additional_properties
end

Instance Attribute Details

#address1String

Payment card billing street address as it appears on the credit card issuer’s records.

SEPA

Required for Create Mandate and Import Mandate

Atos

This field must not contain colons (:).

CyberSource through VisaNet

Important When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, CyberSource through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, CyberSource through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

FDMS Nashville

When the street name is numeric, it must be sent in numeric format. For example, if the address is One First Street, it must be sent as 1 1st Street. Required if keyed; not used if swiped. String (20)

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

All other processors:

Optional. String (60)

For Payouts

This field may be sent only for FDC Compass. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Returns:

  • (String)


53
54
55
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 53

def address1
  @address1
end

#address2String

Used for additional address information. For example: Attention: Accounts Payable Optional field. For Payouts: This field may be sent only for FDC Compass.

Atos

This field must not contain colons (:).

CyberSource through VisaNet

Important When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, CyberSource through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, CyberSource through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

Chase Paymentech Solutions, FDC Compass, and TSYS Acquiring Solutions

This value is used for AVS.

FDMS Nashville

orderInformation.billTo.address1 and orderInformation.billTo.address2 together cannot exceed 20 characters. String (20)

All Other Processors

String (60)

Returns:

  • (String)


88
89
90
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 88

def address2
  @address2
end

#address3String

Additional address information (third line of the billing address)

Returns:

  • (String)


92
93
94
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 92

def address3
  @address3
end

#administrative_areaString

State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickr ef/states_and_provinces.pdf). For Payouts: This field may be sent only for FDC Compass.

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


127
128
129
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 127

def administrative_area
  @administrative_area
end

#countryString

Payment card billing country. Use the two-character [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/coun tries_alpha_list.pdf).

SEPA/BACS

Required for Create Mandate and Import Mandate

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


162
163
164
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 162

def country
  @country
end

#emailString

Customer's email address, including the full domain name.

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Invoicing

Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


361
362
363
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 361

def email
  @email
end

#first_nameString

Customer’s first name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

BACS

Required for Import Mandate

CyberSource Latin American Processing

Important For an authorization request, CyberSource Latin American Processing concatenates orderInformation.billTo.firstName and orderInformation.billTo.lastName. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.
Note CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


245
246
247
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 245

def first_name
  @first_name
end

#last_nameString

Customer’s last name. This name must be the same as the name on the card. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

BACS

Required for Import Mandate

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

CyberSource Latin American Processing

Important For an authorization request, CyberSource Latin American Processing concatenates orderInformation.billTo.firstName and orderInformation.billTo.lastName. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.
Note CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

OmniPay Direct

Optional field.

RBS WorldPay Atlanta

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


296
297
298
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 296

def last_name
  @last_name
end

#localityString

Payment card billing city.

SEPA

Required for Create Mandate and Import Mandate

Atos

This field must not contain colons (:).

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


196
197
198
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 196

def locality
  @locality
end

#phone_numberString

Customer’s phone number. It is recommended that you include the country code when the order is from outside the U.S.

Chase Paymentech Solutions

Optional field.

Credit Mutuel-CIC

Optional field.

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

For Payouts:

This field may be sent only for FDC Compass.

OmniPay Direct

Optional field.

SIX

Optional field.

TSYS Acquiring Solutions

Optional field.

Worldpay VAP

Optional field.

All other processors

Not used.

Returns:

  • (String)


327
328
329
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 327

def phone_number
  @phone_number
end

#postal_codeString

Postal code for the billing address. The postal code must consist of 5 to 9 digits. When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example 12345-6789 When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric] Example A1B 2C3 Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

SEPA

Required for Create Mandate and Import Mandate

For Payouts:

This field may be sent only for FDC Compass.

American Express Direct

Before sending the postal code to the processor, CyberSource removes all nonalphanumeric characters and, if the remaining value is longer than nine characters, truncates the value starting from the right side.

Atos

This field must not contain colons (:).

CyberSource through VisaNet

Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.

FDMS Nashville

Required if pointOfSaleInformation.entryMode=keyed and the address is in the U.S. or Canada. Optional if pointOfSaleInformation.entryMode=keyed and the address is not in the U.S. or Canada. Not used if swiped.

RBS WorldPay Atlanta:

For best card-present keyed rates, send the postal code if pointOfSaleInformation.entryMode=keyed.

TSYS Acquiring Solutions

Required when processingInformation.billPaymentOptions.billPayment=true and pointOfSaleInformation.entryMode=keyed.

All other processors:

Optional field.

Returns:

  • (String)


410
411
412
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 410

def postal_code
  @postal_code
end

Class Method Details

.from_element(root) ⇒ Object



505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 505

def self.from_element(root)
  address1 = XmlUtilities.from_element(root, 'address1', String)
  administrative_area = XmlUtilities.from_element(root,
                                                  'administrativeArea',
                                                  String)
  country = XmlUtilities.from_element(root, 'country', String)
  first_name = XmlUtilities.from_element(root, 'firstName', String)
  last_name = XmlUtilities.from_element(root, 'lastName', String)
  email = XmlUtilities.from_element(root, 'email', String)
  postal_code = XmlUtilities.from_element(root, 'postalCode', String)
  address2 = XmlUtilities.from_element(root, 'address2', String)
  address3 = XmlUtilities.from_element(root, 'address3', String)
  locality = XmlUtilities.from_element(root, 'locality', String)
  phone_number = XmlUtilities.from_element(root, 'phoneNumber', String)

  new(address1: address1,
      administrative_area: administrative_area,
      country: country,
      first_name: first_name,
      last_name: last_name,
      email: email,
      postal_code: postal_code,
      address2: address2,
      address3: address3,
      locality: locality,
      phone_number: phone_number,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 466

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  address1 = hash.key?('address1') ? hash['address1'] : nil
  administrative_area =
    hash.key?('administrativeArea') ? hash['administrativeArea'] : nil
  country = hash.key?('country') ? hash['country'] : nil
  first_name = hash.key?('firstName') ? hash['firstName'] : nil
  last_name = hash.key?('lastName') ? hash['lastName'] : nil
  email = hash.key?('email') ? hash['email'] : nil
  postal_code = hash.key?('postalCode') ? hash['postalCode'] : nil
  address2 = hash.key?('address2') ? hash['address2'] : SKIP
  address3 = hash.key?('address3') ? hash['address3'] : SKIP
  locality = hash.key?('locality') ? hash['locality'] : SKIP
  phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BillTo65.new(address1: address1,
               administrative_area: administrative_area,
               country: country,
               first_name: first_name,
               last_name: last_name,
               email: email,
               postal_code: postal_code,
               address2: address2,
               address3: address3,
               locality: locality,
               phone_number: phone_number,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 413

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address1'] = 'address1'
  @_hash['address2'] = 'address2'
  @_hash['address3'] = 'address3'
  @_hash['administrative_area'] = 'administrativeArea'
  @_hash['country'] = 'country'
  @_hash['locality'] = 'locality'
  @_hash['first_name'] = 'firstName'
  @_hash['last_name'] = 'lastName'
  @_hash['phone_number'] = 'phoneNumber'
  @_hash['email'] = 'email'
  @_hash['postal_code'] = 'postalCode'
  @_hash
end

.nullablesObject

An array for nullable fields



440
441
442
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 440

def self.nullables
  []
end

.optionalsObject

An array for optional fields



430
431
432
433
434
435
436
437
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 430

def self.optionals
  %w[
    address2
    address3
    locality
    phone_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



566
567
568
569
570
571
572
573
574
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 566

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address1: #{@address1.inspect}, address2: #{@address2.inspect}, address3:"\
  " #{@address3.inspect}, administrative_area: #{@administrative_area.inspect}, country:"\
  " #{@country.inspect}, locality: #{@locality.inspect}, first_name: #{@first_name.inspect},"\
  " last_name: #{@last_name.inspect}, phone_number: #{@phone_number.inspect}, email:"\
  " #{@email.inspect}, postal_code: #{@postal_code.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



556
557
558
559
560
561
562
563
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 556

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address1: #{@address1}, address2: #{@address2}, address3: #{@address3},"\
  " administrative_area: #{@administrative_area}, country: #{@country}, locality:"\
  " #{@locality}, first_name: #{@first_name}, last_name: #{@last_name}, phone_number:"\
  " #{@phone_number}, email: #{@email}, postal_code: #{@postal_code}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
# File 'lib/cyber_source_merged_spec/models/bill_to65.rb', line 534

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'address1', address1)
  XmlUtilities.add_as_subelement(doc, root, 'administrativeArea',
                                 administrative_area)
  XmlUtilities.add_as_subelement(doc, root, 'country', country)
  XmlUtilities.add_as_subelement(doc, root, 'firstName', first_name)
  XmlUtilities.add_as_subelement(doc, root, 'lastName', last_name)
  XmlUtilities.add_as_subelement(doc, root, 'email', email)
  XmlUtilities.add_as_subelement(doc, root, 'postalCode', postal_code)
  XmlUtilities.add_as_subelement(doc, root, 'address2', address2)
  XmlUtilities.add_as_subelement(doc, root, 'address3', address3)
  XmlUtilities.add_as_subelement(doc, root, 'locality', locality)
  XmlUtilities.add_as_subelement(doc, root, 'phoneNumber', phone_number)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end