Class: CyberSourceMergedSpec::BillingPeriod

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/billing_period.rb

Overview

Billing Frequency

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(length: SKIP, unit: SKIP, additional_properties: nil) ⇒ BillingPeriod

Returns a new instance of BillingPeriod.



48
49
50
51
52
53
54
55
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 48

def initialize(length: SKIP, unit: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @length = length unless length == SKIP
  @unit = unit unless unit == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#lengthString

Example:

  • If length=1 & unit=month then charge every month
  • If length=7 & unit=day then charge every 7th day

Returns:

  • (String)


16
17
18
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 16

def length
  @length
end

#unitString

Calendar unit values. possible values:

- `D` - day
- `M` - month
- `W` - week
- `Y` - year

Returns:

  • (String)


25
26
27
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 25

def unit
  @unit
end

Class Method Details

.from_element(root) ⇒ Object



78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 78

def self.from_element(root)
  length = XmlUtilities.from_element(root, 'length', String)
  unit = XmlUtilities.from_element(root, 'unit', String)

  new(length: length,
      unit: unit,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  length = hash.key?('length') ? hash['length'] : SKIP
  unit = hash.key?('unit') ? hash['unit'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BillingPeriod.new(length: length,
                    unit: unit,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



28
29
30
31
32
33
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 28

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['length'] = 'length'
  @_hash['unit'] = 'unit'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 36

def self.optionals
  %w[
    length
    unit
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} length: #{@length.inspect}, unit: #{@unit.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} length: #{@length}, unit: #{@unit}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



87
88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/billing_period.rb', line 87

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'length', length)
  XmlUtilities.add_as_subelement(doc, root, 'unit', unit)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end