Class: CyberSourceMergedSpec::BuyerInformation40

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/buyer_information40.rb

Overview

BuyerInformation40 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(merchant_customer_id: SKIP, additional_properties: nil) ⇒ BuyerInformation40

Returns a new instance of BuyerInformation40.



37
38
39
40
41
42
43
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 37

def initialize(merchant_customer_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @merchant_customer_id = merchant_customer_id unless merchant_customer_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#merchant_customer_idString

Optional customer’s account ID, tracking number, reward number, or other unique number that you assign to the customer for the purpose that you choose

Returns:

  • (String)


16
17
18
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 16

def merchant_customer_id
  @merchant_customer_id
end

Class Method Details

.from_element(root) ⇒ Object



65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 65

def self.from_element(root)
  merchant_customer_id = XmlUtilities.from_element(root,
                                                   'merchantCustomerId',
                                                   String)

  new(merchant_customer_id: merchant_customer_id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  merchant_customer_id =
    hash.key?('merchantCustomerId') ? hash['merchantCustomerId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  BuyerInformation40.new(merchant_customer_id: merchant_customer_id,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['merchant_customer_id'] = 'merchantCustomerId'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 26

def self.optionals
  %w[
    merchant_customer_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_customer_id: #{@merchant_customer_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_customer_id: #{@merchant_customer_id}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



74
75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/buyer_information40.rb', line 74

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'merchantCustomerId',
                                 merchant_customer_id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end