Class: CyberSourceMergedSpec::CaptureOptions1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/capture_options1.rb

Overview

CaptureOptions1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(final_capture: SKIP, additional_properties: nil) ⇒ CaptureOptions1

Returns a new instance of CaptureOptions1.



42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 42

def initialize(final_capture: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @final_capture = final_capture unless final_capture == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#final_captureString

Indicates whether you can make additional captures against the authorized payment. Set to true if you do not intend to capture additional payments against the authorization. Set to false if you intend to capture additional payments Possible Values:

  • true
  • false

Returns:

  • (String)


21
22
23
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 21

def final_capture
  @final_capture
end

Class Method Details

.from_element(root) ⇒ Object



69
70
71
72
73
74
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 69

def self.from_element(root)
  final_capture = XmlUtilities.from_element(root, 'finalCapture', String)

  new(final_capture: final_capture,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  final_capture = hash.key?('finalCapture') ? hash['finalCapture'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CaptureOptions1.new(final_capture: final_capture,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['final_capture'] = 'finalCapture'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 31

def self.optionals
  %w[
    final_capture
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} final_capture: #{@final_capture.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} final_capture: #{@final_capture}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/capture_options1.rb', line 76

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'finalCapture', final_capture)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end