Class: CyberSourceMergedSpec::Card126
- Defined in:
- lib/cyber_source_merged_spec/models/card126.rb
Overview
Card126 Model.
Instance Attribute Summary collapse
-
#balance ⇒ String
This field shows the available balance in the prepaid account.
-
#currency ⇒ String
This field indicates the 3-letter [ISO Standard Currency Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/curr encies.pdf) for the card currency.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(balance: SKIP, currency: SKIP, additional_properties: nil) ⇒ Card126
constructor
A new instance of Card126.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(balance: SKIP, currency: SKIP, additional_properties: nil) ⇒ Card126
Returns a new instance of Card126.
45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 45 def initialize(balance: SKIP, currency: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @balance = balance unless balance == SKIP @currency = currency unless currency == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#balance ⇒ String
This field shows the available balance in the prepaid account. Acquirers always receive the available balance in the transaction currency.
16 17 18 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 16 def balance @balance end |
#currency ⇒ String
This field indicates the 3-letter [ISO Standard Currency Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/curr encies.pdf) for the card currency.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 22 def currency @currency end |
Class Method Details
.from_element(root) ⇒ Object
75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 75 def self.from_element(root) balance = XmlUtilities.from_element(root, 'balance', String) currency = XmlUtilities.from_element(root, 'currency', String) new(balance: balance, currency: currency, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. balance = hash.key?('balance') ? hash['balance'] : SKIP currency = hash.key?('currency') ? hash['currency'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Card126.new(balance: balance, currency: currency, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['balance'] = 'balance' @_hash['currency'] = 'currency' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 33 def self.optionals %w[ balance currency ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} balance: #{@balance.inspect}, currency: #{@currency.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} balance: #{@balance}, currency: #{@currency}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cyber_source_merged_spec/models/card126.rb', line 84 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'balance', balance) XmlUtilities.add_as_subelement(doc, root, 'currency', currency) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |