Class: CyberSourceMergedSpec::CardVerification
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::CardVerification
- Defined in:
- lib/cyber_source_merged_spec/models/card_verification.rb
Overview
Contains card verification control flags for transaction-level verification settings.
Instance Attribute Summary collapse
-
#check_ani ⇒ String
Verification control flag to opt-in or opt-out of Address Name Inquiry (ANI) for a transaction.
-
#check_avs ⇒ String
Verification control flag to opt-in or opt-out of Address Verification Service (AVS) for a transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(check_avs: SKIP, check_ani: SKIP, additional_properties: nil) ⇒ CardVerification
constructor
A new instance of CardVerification.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(check_avs: SKIP, check_ani: SKIP, additional_properties: nil) ⇒ CardVerification
Returns a new instance of CardVerification.
60 61 62 63 64 65 66 67 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 60 def initialize(check_avs: SKIP, check_ani: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @check_avs = check_avs unless check_avs == SKIP @check_ani = check_ani unless check_ani == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#check_ani ⇒ String
Verification control flag to opt-in or opt-out of Address Name Inquiry (ANI) for a transaction. Possible values:
Y: Enable ANI verification for this transactionN: Disable ANI verification for this transaction
Used by
Authorization Optional field for controlling ANI verification at the transaction level.
API Ticket
ACCAPI-2156
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 37 def check_ani @check_ani end |
#check_avs ⇒ String
Verification control flag to opt-in or opt-out of Address Verification Service (AVS) for a transaction. Possible values:
Y: Enable AVS verification for this transactionN: Disable AVS verification for this transaction
Used by
Authorization Optional field for controlling AVS verification at the transaction level.
API Ticket
ACCAPI-2156
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 24 def check_avs @check_avs end |
Class Method Details
.from_element(root) ⇒ Object
90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 90 def self.from_element(root) check_avs = XmlUtilities.from_element(root, 'checkAVS', String) check_ani = XmlUtilities.from_element(root, 'checkANI', String) new(check_avs: check_avs, check_ani: check_ani, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. check_avs = hash.key?('checkAVS') ? hash['checkAVS'] : SKIP check_ani = hash.key?('checkANI') ? hash['checkANI'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CardVerification.new(check_avs: check_avs, check_ani: check_ani, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
40 41 42 43 44 45 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 40 def self.names @_hash = {} if @_hash.nil? @_hash['check_avs'] = 'checkAVS' @_hash['check_ani'] = 'checkANI' @_hash end |
.nullables ⇒ Object
An array for nullable fields
56 57 58 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 56 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 48 def self.optionals %w[ check_avs check_ani ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
118 119 120 121 122 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 118 def inspect class_name = self.class.name.split('::').last "<#{class_name} check_avs: #{@check_avs.inspect}, check_ani: #{@check_ani.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
111 112 113 114 115 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 111 def to_s class_name = self.class.name.split('::').last "<#{class_name} check_avs: #{@check_avs}, check_ani: #{@check_ani}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
99 100 101 102 103 104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/card_verification.rb', line 99 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'checkAVS', check_avs) XmlUtilities.add_as_subelement(doc, root, 'checkANI', check_ani) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |