Class: CyberSourceMergedSpec::CaseManagementCommentsRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::CaseManagementCommentsRequest
- Defined in:
- lib/cyber_source_merged_spec/models/case_management_comments_request.rb
Overview
CaseManagementCommentsRequest Model.
Instance Attribute Summary collapse
-
#comments ⇒ String
Comments to be added to case.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(comments:, additional_properties: nil) ⇒ CaseManagementCommentsRequest
constructor
A new instance of CaseManagementCommentsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(comments:, additional_properties: nil) ⇒ CaseManagementCommentsRequest
Returns a new instance of CaseManagementCommentsRequest.
33 34 35 36 37 38 39 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 33 def initialize(comments:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @comments = comments @additional_properties = additional_properties end |
Instance Attribute Details
#comments ⇒ String
Comments to be added to case.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 14 def comments @comments end |
Class Method Details
.from_element(root) ⇒ Object
60 61 62 63 64 65 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 60 def self.from_element(root) comments = XmlUtilities.from_element(root, 'comments', String) new(comments: comments, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. comments = hash.key?('comments') ? hash['comments'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CaseManagementCommentsRequest.new(comments: comments, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['comments'] = 'comments' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} comments: #{@comments.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} comments: #{@comments}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
67 68 69 70 71 72 73 74 75 |
# File 'lib/cyber_source_merged_spec/models/case_management_comments_request.rb', line 67 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'comments', comments) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |