Class: CyberSourceMergedSpec::CheckPayerAuthEnrollmentRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::CheckPayerAuthEnrollmentRequest
- Defined in:
- lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb
Overview
CheckPayerAuthEnrollmentRequest Model.
Instance Attribute Summary collapse
-
#acquirer_information ⇒ AcquirerInformation1
TODO: Write general description for this method.
-
#buyer_information ⇒ BuyerInformation38
TODO: Write general description for this method.
-
#client_reference_information ⇒ ClientReferenceInformation48
TODO: Write general description for this method.
-
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation4
This object contains recurring payment information.
-
#device_information ⇒ DeviceInformation14
TODO: Write general description for this method.
-
#merchant_defined_information ⇒ Array[MerchantDefinedInformation13]
This object contains recurring payment information.
-
#merchant_information ⇒ MerchantInformation19
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation37
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation34
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation57
TODO: Write general description for this method.
-
#recurring_payment_information ⇒ RecurringPaymentInformation
This object contains recurring payment information.
-
#risk_information ⇒ RiskInformation7
This object contains recurring payment information.
-
#token_information ⇒ TokenInformation6
TODO: Write general description for this method.
-
#travel_information ⇒ TravelInformation10
This object contains recurring payment information.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_reference_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, token_information: SKIP, buyer_information: SKIP, device_information: SKIP, merchant_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, consumer_authentication_information: SKIP, risk_information: SKIP, travel_information: SKIP, merchant_defined_information: SKIP, additional_properties: nil) ⇒ CheckPayerAuthEnrollmentRequest
constructor
A new instance of CheckPayerAuthEnrollmentRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_reference_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, token_information: SKIP, buyer_information: SKIP, device_information: SKIP, merchant_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, consumer_authentication_information: SKIP, risk_information: SKIP, travel_information: SKIP, merchant_defined_information: SKIP, additional_properties: nil) ⇒ CheckPayerAuthEnrollmentRequest
Returns a new instance of CheckPayerAuthEnrollmentRequest.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 114 def initialize(client_reference_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, token_information: SKIP, buyer_information: SKIP, device_information: SKIP, merchant_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, consumer_authentication_information: SKIP, risk_information: SKIP, travel_information: SKIP, merchant_defined_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless client_reference_information == SKIP @client_reference_information = client_reference_information end @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP @processing_information = processing_information unless processing_information == SKIP @token_information = token_information unless token_information == SKIP @buyer_information = buyer_information unless buyer_information == SKIP @device_information = device_information unless device_information == SKIP @merchant_information = merchant_information unless merchant_information == SKIP @acquirer_information = acquirer_information unless acquirer_information == SKIP unless recurring_payment_information == SKIP @recurring_payment_information = recurring_payment_information end unless consumer_authentication_information == SKIP @consumer_authentication_information = consumer_authentication_information end @risk_information = risk_information unless risk_information == SKIP @travel_information = travel_information unless travel_information == SKIP unless merchant_defined_information == SKIP @merchant_defined_information = merchant_defined_information end @additional_properties = additional_properties end |
Instance Attribute Details
#acquirer_information ⇒ AcquirerInformation1
TODO: Write general description for this method
46 47 48 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 46 def acquirer_information @acquirer_information end |
#buyer_information ⇒ BuyerInformation38
TODO: Write general description for this method
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 34 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation48
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 14 def client_reference_information @client_reference_information end |
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation4
This object contains recurring payment information.
54 55 56 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 54 def consumer_authentication_information @consumer_authentication_information end |
#device_information ⇒ DeviceInformation14
TODO: Write general description for this method
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 38 def device_information @device_information end |
#merchant_defined_information ⇒ Array[MerchantDefinedInformation13]
This object contains recurring payment information.
66 67 68 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 66 def merchant_defined_information @merchant_defined_information end |
#merchant_information ⇒ MerchantInformation19
TODO: Write general description for this method
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 42 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation37
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 18 def order_information @order_information end |
#payment_information ⇒ PaymentInformation34
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 22 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation57
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 26 def processing_information @processing_information end |
#recurring_payment_information ⇒ RecurringPaymentInformation
This object contains recurring payment information.
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 50 def recurring_payment_information @recurring_payment_information end |
#risk_information ⇒ RiskInformation7
This object contains recurring payment information.
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 58 def risk_information @risk_information end |
#token_information ⇒ TokenInformation6
TODO: Write general description for this method
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 30 def token_information @token_information end |
#travel_information ⇒ TravelInformation10
This object contains recurring payment information.
62 63 64 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 62 def travel_information @travel_information end |
Class Method Details
.from_element(root) ⇒ Object
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 226 def self.from_element(root) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation48', ClientReferenceInformation48 ) order_information = XmlUtilities.from_element(root, 'OrderInformation37', OrderInformation37) payment_information = XmlUtilities.from_element(root, 'PaymentInformation34', PaymentInformation34) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation57', ProcessingInformation57 ) token_information = XmlUtilities.from_element(root, 'TokenInformation6', TokenInformation6) buyer_information = XmlUtilities.from_element(root, 'BuyerInformation38', BuyerInformation38) device_information = XmlUtilities.from_element(root, 'DeviceInformation14', DeviceInformation14) merchant_information = XmlUtilities.from_element(root, 'MerchantInformation19', MerchantInformation19) acquirer_information = XmlUtilities.from_element(root, 'AcquirerInformation1', AcquirerInformation1) recurring_payment_information = XmlUtilities.from_element( root, 'RecurringPaymentInformation', RecurringPaymentInformation ) consumer_authentication_information = XmlUtilities.from_element( root, 'ConsumerAuthenticationInformation4', ConsumerAuthenticationInformation4 ) risk_information = XmlUtilities.from_element(root, 'RiskInformation7', RiskInformation7) travel_information = XmlUtilities.from_element(root, 'TravelInformation10', TravelInformation10) merchant_defined_information = XmlUtilities.from_element_to_array( root, 'MerchantDefinedInformation13', MerchantDefinedInformation13 ) new(client_reference_information: client_reference_information, order_information: order_information, payment_information: payment_information, processing_information: processing_information, token_information: token_information, buyer_information: buyer_information, device_information: device_information, merchant_information: merchant_information, acquirer_information: acquirer_information, recurring_payment_information: recurring_payment_information, consumer_authentication_information: consumer_authentication_information, risk_information: risk_information, travel_information: travel_information, merchant_defined_information: merchant_defined_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 157 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation48.from_hash(hash['clientReferenceInformation']) end order_information = OrderInformation37.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation34.from_hash(hash['paymentInformation']) if hash['paymentInformation'] processing_information = ProcessingInformation57.from_hash(hash['processingInformation']) if hash['processingInformation'] token_information = TokenInformation6.from_hash(hash['tokenInformation']) if hash['tokenInformation'] buyer_information = BuyerInformation38.from_hash(hash['buyerInformation']) if hash['buyerInformation'] device_information = DeviceInformation14.from_hash(hash['deviceInformation']) if hash['deviceInformation'] merchant_information = MerchantInformation19.from_hash(hash['merchantInformation']) if hash['merchantInformation'] acquirer_information = AcquirerInformation1.from_hash(hash['acquirerInformation']) if hash['acquirerInformation'] if hash['recurringPaymentInformation'] recurring_payment_information = RecurringPaymentInformation.from_hash(hash['recurringPaymentInformation']) end if hash['consumerAuthenticationInformation'] consumer_authentication_information = ConsumerAuthenticationInformation4.from_hash(hash['consumerAuthenticationInformation']) end risk_information = RiskInformation7.from_hash(hash['riskInformation']) if hash['riskInformation'] travel_information = TravelInformation10.from_hash(hash['travelInformation']) if hash['travelInformation'] # Parameter is an array, so we need to iterate through it merchant_defined_information = nil unless hash['merchantDefinedInformation'].nil? merchant_defined_information = [] hash['merchantDefinedInformation'].each do |structure| merchant_defined_information << (MerchantDefinedInformation13.from_hash(structure) if structure) end end merchant_defined_information = SKIP unless hash.key?('merchantDefinedInformation') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CheckPayerAuthEnrollmentRequest.new(client_reference_information: client_reference_information, order_information: order_information, payment_information: payment_information, processing_information: processing_information, token_information: token_information, buyer_information: buyer_information, device_information: device_information, merchant_information: merchant_information, acquirer_information: acquirer_information, recurring_payment_information: recurring_payment_information, consumer_authentication_information: consumer_authentication_information, risk_information: risk_information, travel_information: travel_information, merchant_defined_information: merchant_defined_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 69 def self.names @_hash = {} if @_hash.nil? @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['processing_information'] = 'processingInformation' @_hash['token_information'] = 'tokenInformation' @_hash['buyer_information'] = 'buyerInformation' @_hash['device_information'] = 'deviceInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['acquirer_information'] = 'acquirerInformation' @_hash['recurring_payment_information'] = 'recurringPaymentInformation' @_hash['consumer_authentication_information'] = 'consumerAuthenticationInformation' @_hash['risk_information'] = 'riskInformation' @_hash['travel_information'] = 'travelInformation' @_hash['merchant_defined_information'] = 'merchantDefinedInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
110 111 112 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 110 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 90 def self.optionals %w[ client_reference_information order_information payment_information processing_information token_information buyer_information device_information merchant_information acquirer_information recurring_payment_information consumer_authentication_information risk_information travel_information merchant_defined_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 342 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\ " order_information: #{@order_information.inspect}, payment_information:"\ " #{@payment_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, token_information: #{@token_information.inspect},"\ " buyer_information: #{@buyer_information.inspect}, device_information:"\ " #{@device_information.inspect}, merchant_information: #{@merchant_information.inspect},"\ " acquirer_information: #{@acquirer_information.inspect}, recurring_payment_information:"\ " #{@recurring_payment_information.inspect}, consumer_authentication_information:"\ " #{@consumer_authentication_information.inspect}, risk_information:"\ " #{@risk_information.inspect}, travel_information: #{@travel_information.inspect},"\ " merchant_defined_information: #{@merchant_defined_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 327 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information},"\ " order_information: #{@order_information}, payment_information: #{@payment_information},"\ " processing_information: #{@processing_information}, token_information:"\ " #{@token_information}, buyer_information: #{@buyer_information}, device_information:"\ " #{@device_information}, merchant_information: #{@merchant_information},"\ " acquirer_information: #{@acquirer_information}, recurring_payment_information:"\ " #{@recurring_payment_information}, consumer_authentication_information:"\ " #{@consumer_authentication_information}, risk_information: #{@risk_information},"\ " travel_information: #{@travel_information}, merchant_defined_information:"\ " #{@merchant_defined_information}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/cyber_source_merged_spec/models/check_payer_auth_enrollment_request.rb', line 287 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation48', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation37', order_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation34', payment_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation57', processing_information) XmlUtilities.add_as_subelement(doc, root, 'TokenInformation6', token_information) XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation38', buyer_information) XmlUtilities.add_as_subelement(doc, root, 'DeviceInformation14', device_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation19', merchant_information) XmlUtilities.add_as_subelement(doc, root, 'AcquirerInformation1', acquirer_information) XmlUtilities.add_as_subelement(doc, root, 'RecurringPaymentInformation', recurring_payment_information) XmlUtilities.add_as_subelement(doc, root, 'ConsumerAuthenticationInformation4', consumer_authentication_information) XmlUtilities.add_as_subelement(doc, root, 'RiskInformation7', risk_information) XmlUtilities.add_as_subelement(doc, root, 'TravelInformation10', travel_information) XmlUtilities.add_array_as_subelement(doc, root, 'MerchantDefinedInformation13', merchant_defined_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |