Class: CyberSourceMergedSpec::ClientReferenceInformation39
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ClientReferenceInformation39
- Defined in:
- lib/cyber_source_merged_spec/models/client_reference_information39.rb
Overview
ClientReferenceInformation39 Model.
Instance Attribute Summary collapse
-
#reconciliation_id ⇒ String
Reference number for the transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reconciliation_id: SKIP, additional_properties: nil) ⇒ ClientReferenceInformation39
constructor
A new instance of ClientReferenceInformation39.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reconciliation_id: SKIP, additional_properties: nil) ⇒ ClientReferenceInformation39
Returns a new instance of ClientReferenceInformation39.
39 40 41 42 43 44 45 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 39 def initialize(reconciliation_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 18 def reconciliation_id @reconciliation_id end |
Class Method Details
.from_element(root) ⇒ Object
67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 67 def self.from_element(root) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) new(reconciliation_id: reconciliation_id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ClientReferenceInformation39.new(reconciliation_id: reconciliation_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['reconciliation_id'] = 'reconciliationId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 28 def self.optionals %w[ reconciliation_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} reconciliation_id: #{@reconciliation_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} reconciliation_id: #{@reconciliation_id}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information39.rb', line 75 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |