Class: CyberSourceMergedSpec::CommentDecisionManagerCaseResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb

Overview

CommentDecisionManagerCaseResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, additional_properties: nil) ⇒ CommentDecisionManagerCaseResponse

Returns a new instance of CommentDecisionManagerCaseResponse.



52
53
54
55
56
57
58
59
60
61
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 52

def initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

UUID uniquely generated for this comments.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 14

def id
  @id
end

#statusString

Status of the comment creation. Possible values are:

  • COMPLETED

Returns:

  • (String)


27
28
29
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 27

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 22

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_element(root) ⇒ Object



87
88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 87

def self.from_element(root)
  id = XmlUtilities.from_element(root, 'id', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  status = XmlUtilities.from_element(root, 'status', String)

  new(id: id,
      submit_time_utc: submit_time_utc,
      status: status,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CommentDecisionManagerCaseResponse.new(id: id,
                                         submit_time_utc: submit_time_utc,
                                         status: status,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 48

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 39

def self.optionals
  %w[
    id
    submit_time_utc
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, submit_time_utc: #{@submit_time_utc.inspect}, status:"\
  " #{@status.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 112

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/comment_decision_manager_case_response.rb', line 98

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end