Class: CyberSourceMergedSpec::ConsumerAuthenticationInformation6

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb

Overview

ConsumerAuthenticationInformation6 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(access_token: SKIP, reference_id: SKIP, device_data_collection_url: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationInformation6

Returns a new instance of ConsumerAuthenticationInformation6.



52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 52

def initialize(access_token: SKIP, reference_id: SKIP,
               device_data_collection_url: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @access_token = access_token unless access_token == SKIP
  @reference_id = reference_id unless reference_id == SKIP
  unless device_data_collection_url == SKIP
    @device_data_collection_url =
      device_data_collection_url
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#access_tokenString

JSON Web Token (JWT) used to authenticate the consumer with the authentication provider, such as, CardinalCommerce or Rupay. Note - Max Length of this field is 2048 characters.

Returns:

  • (String)


16
17
18
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 16

def access_token
  @access_token
end

#device_data_collection_urlString

The deviceDataCollectionUrl is the location to send the Authentication JWT when invoking the Device Data collection process.

Returns:

  • (String)


27
28
29
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 27

def device_data_collection_url
  @device_data_collection_url
end

#reference_idString

This identifier represents cardinal has started device data collection session and this must be passed in Authentication JWT to Cardinal when invoking the deviceDataCollectionUrl.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 22

def reference_id
  @reference_id
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 90

def self.from_element(root)
  access_token = XmlUtilities.from_element(root, 'accessToken', String)
  reference_id = XmlUtilities.from_element(root, 'referenceId', String)
  device_data_collection_url = XmlUtilities.from_element(
    root, 'deviceDataCollectionUrl', String
  )

  new(access_token: access_token,
      reference_id: reference_id,
      device_data_collection_url: device_data_collection_url,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  access_token = hash.key?('accessToken') ? hash['accessToken'] : SKIP
  reference_id = hash.key?('referenceId') ? hash['referenceId'] : SKIP
  device_data_collection_url =
    hash.key?('deviceDataCollectionUrl') ? hash['deviceDataCollectionUrl'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsumerAuthenticationInformation6.new(access_token: access_token,
                                         reference_id: reference_id,
                                         device_data_collection_url: device_data_collection_url,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['access_token'] = 'accessToken'
  @_hash['reference_id'] = 'referenceId'
  @_hash['device_data_collection_url'] = 'deviceDataCollectionUrl'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 48

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 39

def self.optionals
  %w[
    access_token
    reference_id
    device_data_collection_url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



125
126
127
128
129
130
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 125

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token.inspect}, reference_id:"\
  " #{@reference_id.inspect}, device_data_collection_url:"\
  " #{@device_data_collection_url.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



117
118
119
120
121
122
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 117

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} access_token: #{@access_token}, reference_id: #{@reference_id},"\
  " device_data_collection_url: #{@device_data_collection_url}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information6.rb', line 103

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'accessToken', access_token)
  XmlUtilities.add_as_subelement(doc, root, 'referenceId', reference_id)
  XmlUtilities.add_as_subelement(doc, root, 'deviceDataCollectionUrl',
                                 device_data_collection_url)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end