Class: CyberSourceMergedSpec::ConsumerAuthenticationInformation9

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb

Overview

ConsumerAuthenticationInformation9 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(authentication_transaction_id:, authentication_transaction_context: SKIP, otp_token: SKIP, response_access_token: SKIP, signed_pares_status_reason: SKIP, signed_pares: SKIP, white_list_status: SKIP, credential_encrypted: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationInformation9

Returns a new instance of ConsumerAuthenticationInformation9.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 101

def initialize(authentication_transaction_id:,
               authentication_transaction_context: SKIP, otp_token: SKIP,
               response_access_token: SKIP,
               signed_pares_status_reason: SKIP, signed_pares: SKIP,
               white_list_status: SKIP, credential_encrypted: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @authentication_transaction_id = authentication_transaction_id
  unless authentication_transaction_context == SKIP
    @authentication_transaction_context =
      authentication_transaction_context
  end
  @otp_token = otp_token unless otp_token == SKIP
  @response_access_token = response_access_token unless response_access_token == SKIP
  unless signed_pares_status_reason == SKIP
    @signed_pares_status_reason =
      signed_pares_status_reason
  end
  @signed_pares = signed_pares unless signed_pares == SKIP
  @white_list_status = white_list_status unless white_list_status == SKIP
  @credential_encrypted = credential_encrypted unless credential_encrypted == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#authentication_transaction_contextString

Authentication transaction context is used as a unique identifier to link enroll and validate call.

Returns:

  • (String)


25
26
27
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 25

def authentication_transaction_context
  @authentication_transaction_context
end

#authentication_transaction_idString

Payer authentication transaction identifier passed to link the check enrollment and validate authentication messages.For Rupay,this is passed only in Re-Send OTP usecase. Note: Required for Standard integration, Rupay Seamless server to server integration for enroll service. Required for Hybrid integration for validate service.

Returns:

  • (String)


20
21
22
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 20

def authentication_transaction_id
  @authentication_transaction_id
end

#credential_encryptedString

A flag to indicate if the passed credential has been encrypted by the Merchant.

Returns:

  • (String)


66
67
68
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 66

def credential_encrypted
  @credential_encrypted
end

#otp_tokenString

OTP entered by the card holder.

Returns:

  • (String)


29
30
31
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 29

def otp_token
  @otp_token
end

#response_access_tokenString

JWT returned by the 3D Secure provider when the authentication is complete. Required for Hybrid integration if you use the Cybersource-generated access token. Note: Max. length of this field is 2048 characters.

Returns:

  • (String)


36
37
38
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 36

def response_access_token
  @response_access_token
end

#signed_paresString

Payer authentication result (PARes) message returned by the card-issuing bank. If you need to show proof of enrollment checking, you may need to decrypt and parse the string for the information required by the payment card company. For more information, see "Storing Payer Authentication Data," page 160. Important The value is in base64. You must remove all carriage returns and line feeds before adding the PARes to the request.

Returns:

  • (String)


53
54
55
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 53

def signed_pares
  @signed_pares
end

#signed_pares_status_reasonString

Provides additional information as to why the PAResStatus has a specific value.

Returns:

  • (String)


41
42
43
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 41

def signed_pares_status_reason
  @signed_pares_status_reason
end

#white_list_statusString

Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor. Possible Values: Y - 3DS Requestor is whitelisted by cardholder N - 3DS Requestor is not whitelisted by cardholder

Returns:

  • (String)


61
62
63
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 61

def white_list_status
  @white_list_status
end

Class Method Details

.from_element(root) ⇒ Object



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 166

def self.from_element(root)
  authentication_transaction_id = XmlUtilities.from_element(
    root, 'authenticationTransactionId', String
  )
  authentication_transaction_context = XmlUtilities.from_element(
    root, 'authenticationTransactionContext', String
  )
  otp_token = XmlUtilities.from_element(root, 'otpToken', String)
  response_access_token = XmlUtilities.from_element(root,
                                                    'responseAccessToken',
                                                    String)
  signed_pares_status_reason = XmlUtilities.from_element(
    root, 'signedParesStatusReason', String
  )
  signed_pares = XmlUtilities.from_element(root, 'signedPares', String)
  white_list_status = XmlUtilities.from_element(root, 'whiteListStatus',
                                                String)
  credential_encrypted = XmlUtilities.from_element(root,
                                                   'credentialEncrypted',
                                                   String)

  new(authentication_transaction_id: authentication_transaction_id,
      authentication_transaction_context: authentication_transaction_context,
      otp_token: otp_token,
      response_access_token: response_access_token,
      signed_pares_status_reason: signed_pares_status_reason,
      signed_pares: signed_pares,
      white_list_status: white_list_status,
      credential_encrypted: credential_encrypted,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 128

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  authentication_transaction_id =
    hash.key?('authenticationTransactionId') ? hash['authenticationTransactionId'] : nil
  authentication_transaction_context =
    hash.key?('authenticationTransactionContext') ? hash['authenticationTransactionContext'] : SKIP
  otp_token = hash.key?('otpToken') ? hash['otpToken'] : SKIP
  response_access_token =
    hash.key?('responseAccessToken') ? hash['responseAccessToken'] : SKIP
  signed_pares_status_reason =
    hash.key?('signedParesStatusReason') ? hash['signedParesStatusReason'] : SKIP
  signed_pares = hash.key?('signedPares') ? hash['signedPares'] : SKIP
  white_list_status =
    hash.key?('whiteListStatus') ? hash['whiteListStatus'] : SKIP
  credential_encrypted =
    hash.key?('credentialEncrypted') ? hash['credentialEncrypted'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ConsumerAuthenticationInformation9.new(authentication_transaction_id: authentication_transaction_id,
                                         authentication_transaction_context: authentication_transaction_context,
                                         otp_token: otp_token,
                                         response_access_token: response_access_token,
                                         signed_pares_status_reason: signed_pares_status_reason,
                                         signed_pares: signed_pares,
                                         white_list_status: white_list_status,
                                         credential_encrypted: credential_encrypted,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 69

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['authentication_transaction_id'] = 'authenticationTransactionId'
  @_hash['authentication_transaction_context'] =
    'authenticationTransactionContext'
  @_hash['otp_token'] = 'otpToken'
  @_hash['response_access_token'] = 'responseAccessToken'
  @_hash['signed_pares_status_reason'] = 'signedParesStatusReason'
  @_hash['signed_pares'] = 'signedPares'
  @_hash['white_list_status'] = 'whiteListStatus'
  @_hash['credential_encrypted'] = 'credentialEncrypted'
  @_hash
end

.nullablesObject

An array for nullable fields



97
98
99
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 97

def self.nullables
  []
end

.optionalsObject

An array for optional fields



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 84

def self.optionals
  %w[
    authentication_transaction_context
    otp_token
    response_access_token
    signed_pares_status_reason
    signed_pares
    white_list_status
    credential_encrypted
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



234
235
236
237
238
239
240
241
242
243
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 234

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} authentication_transaction_id: #{@authentication_transaction_id.inspect},"\
  " authentication_transaction_context: #{@authentication_transaction_context.inspect},"\
  " otp_token: #{@otp_token.inspect}, response_access_token:"\
  " #{@response_access_token.inspect}, signed_pares_status_reason:"\
  " #{@signed_pares_status_reason.inspect}, signed_pares: #{@signed_pares.inspect},"\
  " white_list_status: #{@white_list_status.inspect}, credential_encrypted:"\
  " #{@credential_encrypted.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



223
224
225
226
227
228
229
230
231
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 223

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} authentication_transaction_id: #{@authentication_transaction_id},"\
  " authentication_transaction_context: #{@authentication_transaction_context}, otp_token:"\
  " #{@otp_token}, response_access_token: #{@response_access_token},"\
  " signed_pares_status_reason: #{@signed_pares_status_reason}, signed_pares:"\
  " #{@signed_pares}, white_list_status: #{@white_list_status}, credential_encrypted:"\
  " #{@credential_encrypted}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information9.rb', line 198

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'authenticationTransactionId',
                                 authentication_transaction_id)
  XmlUtilities.add_as_subelement(doc, root,
                                 'authenticationTransactionContext',
                                 authentication_transaction_context)
  XmlUtilities.add_as_subelement(doc, root, 'otpToken', otp_token)
  XmlUtilities.add_as_subelement(doc, root, 'responseAccessToken',
                                 response_access_token)
  XmlUtilities.add_as_subelement(doc, root, 'signedParesStatusReason',
                                 signed_pares_status_reason)
  XmlUtilities.add_as_subelement(doc, root, 'signedPares', signed_pares)
  XmlUtilities.add_as_subelement(doc, root, 'whiteListStatus',
                                 white_list_status)
  XmlUtilities.add_as_subelement(doc, root, 'credentialEncrypted',
                                 credential_encrypted)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end