Class: CyberSourceMergedSpec::CreatePaymentRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::CreatePaymentRequest
- Defined in:
- lib/cyber_source_merged_spec/models/create_payment_request.rb
Overview
CreatePaymentRequest Model.
Instance Attribute Summary collapse
-
#acquirer_information ⇒ AcquirerInformation
This object is only needed when you are requesting both payment and DM services at same time.
-
#aggregator_information ⇒ AggregatorInformation
TODO: Write general description for this method.
-
#agreement_information ⇒ AgreementInformation
Processor Information.
-
#buyer_information ⇒ BuyerInformation
TODO: Write general description for this method.
-
#client_reference_information ⇒ ClientReferenceInformation
TODO: Write general description for this method.
-
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation
TODO: Write general description for this method.
-
#device_information ⇒ DeviceInformation
TODO: Write general description for this method.
-
#health_care_information ⇒ HealthCareInformation
The object containing the secure data that the merchant defines.
-
#hosted_payment_information ⇒ HostedPaymentInformation
This object contains recurring payment information.
-
#installment_information ⇒ InstallmentInformation
The object containing the secure data that the merchant defines.
-
#invoice_details ⇒ InvoiceDetails1
invoice Details.
-
#issuer_information ⇒ IssuerInformation
TODO: Write general description for this method.
-
#merchant_defined_information ⇒ Array[MerchantDefinedInformation]
The object containing the custom data that the merchant defines.
-
#merchant_defined_secure_information ⇒ MerchantDefinedSecureInformation
The object containing the secure data that the merchant defines.
-
#merchant_information ⇒ MerchantInformation
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation
TODO: Write general description for this method.
-
#point_of_sale_information ⇒ PointOfSaleInformation
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation
TODO: Write general description for this method.
-
#processor_information ⇒ ProcessorInformation
Processor Information.
-
#promotion_information ⇒ PromotionInformation
The object containing the secure data that the merchant defines.
-
#recipient_information ⇒ RecipientInformation
TODO: Write general description for this method.
-
#recurring_payment_information ⇒ RecurringPaymentInformation
This object contains recurring payment information.
-
#risk_information ⇒ RiskInformation
This object is only needed when you are requesting both payment and DM services at same time.
-
#sender_information ⇒ SenderInformation
TODO: Write general description for this method.
-
#token_information ⇒ TokenInformation
The object containing the secure data that the merchant defines.
-
#travel_information ⇒ TravelInformation
The object containing the secure data that the merchant defines.
-
#unscheduled_payment_information ⇒ UnscheduledPaymentInformation
This object contains recurring payment information.
-
#watchlist_screening_information ⇒ WatchlistScreeningInformation
This object contains recurring payment information.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_reference_information: SKIP, processing_information: SKIP, issuer_information: SKIP, payment_information: SKIP, order_information: SKIP, buyer_information: SKIP, sender_information: SKIP, recipient_information: SKIP, device_information: SKIP, merchant_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, point_of_sale_information: SKIP, merchant_defined_information: SKIP, merchant_defined_secure_information: SKIP, installment_information: SKIP, travel_information: SKIP, health_care_information: SKIP, promotion_information: SKIP, token_information: SKIP, invoice_details: SKIP, processor_information: SKIP, agreement_information: SKIP, risk_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, unscheduled_payment_information: SKIP, hosted_payment_information: SKIP, watchlist_screening_information: SKIP, additional_properties: nil) ⇒ CreatePaymentRequest
constructor
A new instance of CreatePaymentRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_reference_information: SKIP, processing_information: SKIP, issuer_information: SKIP, payment_information: SKIP, order_information: SKIP, buyer_information: SKIP, sender_information: SKIP, recipient_information: SKIP, device_information: SKIP, merchant_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, point_of_sale_information: SKIP, merchant_defined_information: SKIP, merchant_defined_secure_information: SKIP, installment_information: SKIP, travel_information: SKIP, health_care_information: SKIP, promotion_information: SKIP, token_information: SKIP, invoice_details: SKIP, processor_information: SKIP, agreement_information: SKIP, risk_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, unscheduled_payment_information: SKIP, hosted_payment_information: SKIP, watchlist_screening_information: SKIP, additional_properties: nil) ⇒ CreatePaymentRequest
Returns a new instance of CreatePaymentRequest.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 209 def initialize(client_reference_information: SKIP, processing_information: SKIP, issuer_information: SKIP, payment_information: SKIP, order_information: SKIP, buyer_information: SKIP, sender_information: SKIP, recipient_information: SKIP, device_information: SKIP, merchant_information: SKIP, aggregator_information: SKIP, consumer_authentication_information: SKIP, point_of_sale_information: SKIP, merchant_defined_information: SKIP, merchant_defined_secure_information: SKIP, installment_information: SKIP, travel_information: SKIP, health_care_information: SKIP, promotion_information: SKIP, token_information: SKIP, invoice_details: SKIP, processor_information: SKIP, agreement_information: SKIP, risk_information: SKIP, acquirer_information: SKIP, recurring_payment_information: SKIP, unscheduled_payment_information: SKIP, hosted_payment_information: SKIP, watchlist_screening_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless client_reference_information == SKIP @client_reference_information = client_reference_information end @processing_information = processing_information unless processing_information == SKIP @issuer_information = issuer_information unless issuer_information == SKIP @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP @buyer_information = buyer_information unless buyer_information == SKIP @sender_information = sender_information unless sender_information == SKIP @recipient_information = recipient_information unless recipient_information == SKIP @device_information = device_information unless device_information == SKIP @merchant_information = merchant_information unless merchant_information == SKIP @aggregator_information = aggregator_information unless aggregator_information == SKIP unless consumer_authentication_information == SKIP @consumer_authentication_information = consumer_authentication_information end unless point_of_sale_information == SKIP @point_of_sale_information = point_of_sale_information end unless merchant_defined_information == SKIP @merchant_defined_information = merchant_defined_information end unless merchant_defined_secure_information == SKIP @merchant_defined_secure_information = merchant_defined_secure_information end @installment_information = installment_information unless installment_information == SKIP @travel_information = travel_information unless travel_information == SKIP @health_care_information = health_care_information unless health_care_information == SKIP @promotion_information = promotion_information unless promotion_information == SKIP @token_information = token_information unless token_information == SKIP @invoice_details = invoice_details unless invoice_details == SKIP @processor_information = processor_information unless processor_information == SKIP @agreement_information = agreement_information unless agreement_information == SKIP @risk_information = risk_information unless risk_information == SKIP @acquirer_information = acquirer_information unless acquirer_information == SKIP unless recurring_payment_information == SKIP @recurring_payment_information = recurring_payment_information end unless unscheduled_payment_information == SKIP @unscheduled_payment_information = unscheduled_payment_information end unless hosted_payment_information == SKIP @hosted_payment_information = hosted_payment_information end unless watchlist_screening_information == SKIP @watchlist_screening_information = watchlist_screening_information end @additional_properties = additional_properties end |
Instance Attribute Details
#acquirer_information ⇒ AcquirerInformation
This object is only needed when you are requesting both payment and DM services at same time.
112 113 114 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 112 def acquirer_information @acquirer_information end |
#aggregator_information ⇒ AggregatorInformation
TODO: Write general description for this method
54 55 56 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 54 def aggregator_information @aggregator_information end |
#agreement_information ⇒ AgreementInformation
Processor Information
102 103 104 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 102 def agreement_information @agreement_information end |
#buyer_information ⇒ BuyerInformation
TODO: Write general description for this method
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 34 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 14 def client_reference_information @client_reference_information end |
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation
TODO: Write general description for this method
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 58 def consumer_authentication_information @consumer_authentication_information end |
#device_information ⇒ DeviceInformation
TODO: Write general description for this method
46 47 48 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 46 def device_information @device_information end |
#health_care_information ⇒ HealthCareInformation
The object containing the secure data that the merchant defines.
82 83 84 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 82 def health_care_information @health_care_information end |
#hosted_payment_information ⇒ HostedPaymentInformation
This object contains recurring payment information.
124 125 126 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 124 def hosted_payment_information @hosted_payment_information end |
#installment_information ⇒ InstallmentInformation
The object containing the secure data that the merchant defines.
74 75 76 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 74 def installment_information @installment_information end |
#invoice_details ⇒ InvoiceDetails1
invoice Details
94 95 96 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 94 def invoice_details @invoice_details end |
#issuer_information ⇒ IssuerInformation
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 22 def issuer_information @issuer_information end |
#merchant_defined_information ⇒ Array[MerchantDefinedInformation]
The object containing the custom data that the merchant defines.
66 67 68 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 66 def merchant_defined_information @merchant_defined_information end |
#merchant_defined_secure_information ⇒ MerchantDefinedSecureInformation
The object containing the secure data that the merchant defines.
70 71 72 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 70 def merchant_defined_secure_information @merchant_defined_secure_information end |
#merchant_information ⇒ MerchantInformation
TODO: Write general description for this method
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 50 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation
TODO: Write general description for this method
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 30 def order_information @order_information end |
#payment_information ⇒ PaymentInformation
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 26 def payment_information @payment_information end |
#point_of_sale_information ⇒ PointOfSaleInformation
TODO: Write general description for this method
62 63 64 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 62 def point_of_sale_information @point_of_sale_information end |
#processing_information ⇒ ProcessingInformation
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 18 def processing_information @processing_information end |
#processor_information ⇒ ProcessorInformation
Processor Information
98 99 100 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 98 def processor_information @processor_information end |
#promotion_information ⇒ PromotionInformation
The object containing the secure data that the merchant defines.
86 87 88 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 86 def promotion_information @promotion_information end |
#recipient_information ⇒ RecipientInformation
TODO: Write general description for this method
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 42 def recipient_information @recipient_information end |
#recurring_payment_information ⇒ RecurringPaymentInformation
This object contains recurring payment information.
116 117 118 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 116 def recurring_payment_information @recurring_payment_information end |
#risk_information ⇒ RiskInformation
This object is only needed when you are requesting both payment and DM services at same time.
107 108 109 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 107 def risk_information @risk_information end |
#sender_information ⇒ SenderInformation
TODO: Write general description for this method
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 38 def sender_information @sender_information end |
#token_information ⇒ TokenInformation
The object containing the secure data that the merchant defines.
90 91 92 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 90 def token_information @token_information end |
#travel_information ⇒ TravelInformation
The object containing the secure data that the merchant defines.
78 79 80 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 78 def travel_information @travel_information end |
#unscheduled_payment_information ⇒ UnscheduledPaymentInformation
This object contains recurring payment information.
120 121 122 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 120 def unscheduled_payment_information @unscheduled_payment_information end |
#watchlist_screening_information ⇒ WatchlistScreeningInformation
This object contains recurring payment information.
128 129 130 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 128 def watchlist_screening_information @watchlist_screening_information end |
Class Method Details
.from_element(root) ⇒ Object
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 411 def self.from_element(root) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation', ClientReferenceInformation ) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation', ProcessingInformation ) issuer_information = XmlUtilities.from_element(root, 'IssuerInformation', IssuerInformation) payment_information = XmlUtilities.from_element(root, 'PaymentInformation', PaymentInformation) order_information = XmlUtilities.from_element(root, 'OrderInformation', OrderInformation) buyer_information = XmlUtilities.from_element(root, 'BuyerInformation', BuyerInformation) sender_information = XmlUtilities.from_element(root, 'SenderInformation', SenderInformation) recipient_information = XmlUtilities.from_element(root, 'RecipientInformation', RecipientInformation) device_information = XmlUtilities.from_element(root, 'DeviceInformation', DeviceInformation) merchant_information = XmlUtilities.from_element(root, 'MerchantInformation', MerchantInformation) aggregator_information = XmlUtilities.from_element( root, 'AggregatorInformation', AggregatorInformation ) consumer_authentication_information = XmlUtilities.from_element( root, 'ConsumerAuthenticationInformation', ConsumerAuthenticationInformation ) point_of_sale_information = XmlUtilities.from_element( root, 'PointOfSaleInformation', PointOfSaleInformation ) merchant_defined_information = XmlUtilities.from_element_to_array( root, 'MerchantDefinedInformation', MerchantDefinedInformation ) merchant_defined_secure_information = XmlUtilities.from_element( root, 'MerchantDefinedSecureInformation', MerchantDefinedSecureInformation ) installment_information = XmlUtilities.from_element( root, 'InstallmentInformation', InstallmentInformation ) travel_information = XmlUtilities.from_element(root, 'TravelInformation', TravelInformation) health_care_information = XmlUtilities.from_element( root, 'HealthCareInformation', HealthCareInformation ) promotion_information = XmlUtilities.from_element(root, 'PromotionInformation', PromotionInformation) token_information = XmlUtilities.from_element(root, 'TokenInformation', TokenInformation) invoice_details = XmlUtilities.from_element(root, 'InvoiceDetails1', InvoiceDetails1) processor_information = XmlUtilities.from_element(root, 'ProcessorInformation', ProcessorInformation) agreement_information = XmlUtilities.from_element(root, 'AgreementInformation', AgreementInformation) risk_information = XmlUtilities.from_element(root, 'RiskInformation', RiskInformation) acquirer_information = XmlUtilities.from_element(root, 'AcquirerInformation', AcquirerInformation) recurring_payment_information = XmlUtilities.from_element( root, 'RecurringPaymentInformation', RecurringPaymentInformation ) unscheduled_payment_information = XmlUtilities.from_element( root, 'UnscheduledPaymentInformation', UnscheduledPaymentInformation ) hosted_payment_information = XmlUtilities.from_element( root, 'HostedPaymentInformation', HostedPaymentInformation ) watchlist_screening_information = XmlUtilities.from_element( root, 'WatchlistScreeningInformation', WatchlistScreeningInformation ) new(client_reference_information: client_reference_information, processing_information: processing_information, issuer_information: issuer_information, payment_information: payment_information, order_information: order_information, buyer_information: buyer_information, sender_information: sender_information, recipient_information: recipient_information, device_information: device_information, merchant_information: merchant_information, aggregator_information: aggregator_information, consumer_authentication_information: consumer_authentication_information, point_of_sale_information: point_of_sale_information, merchant_defined_information: merchant_defined_information, merchant_defined_secure_information: merchant_defined_secure_information, installment_information: installment_information, travel_information: travel_information, health_care_information: health_care_information, promotion_information: promotion_information, token_information: token_information, invoice_details: invoice_details, processor_information: processor_information, agreement_information: agreement_information, risk_information: risk_information, acquirer_information: acquirer_information, recurring_payment_information: recurring_payment_information, unscheduled_payment_information: unscheduled_payment_information, hosted_payment_information: hosted_payment_information, watchlist_screening_information: watchlist_screening_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 292 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation.from_hash(hash['clientReferenceInformation']) end processing_information = ProcessingInformation.from_hash(hash['processingInformation']) if hash['processingInformation'] issuer_information = IssuerInformation.from_hash(hash['issuerInformation']) if hash['issuerInformation'] payment_information = PaymentInformation.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation.from_hash(hash['orderInformation']) if hash['orderInformation'] buyer_information = BuyerInformation.from_hash(hash['buyerInformation']) if hash['buyerInformation'] sender_information = SenderInformation.from_hash(hash['senderInformation']) if hash['senderInformation'] recipient_information = RecipientInformation.from_hash(hash['recipientInformation']) if hash['recipientInformation'] device_information = DeviceInformation.from_hash(hash['deviceInformation']) if hash['deviceInformation'] merchant_information = MerchantInformation.from_hash(hash['merchantInformation']) if hash['merchantInformation'] aggregator_information = AggregatorInformation.from_hash(hash['aggregatorInformation']) if hash['aggregatorInformation'] if hash['consumerAuthenticationInformation'] consumer_authentication_information = ConsumerAuthenticationInformation.from_hash(hash['consumerAuthenticationInformation']) end if hash['pointOfSaleInformation'] point_of_sale_information = PointOfSaleInformation.from_hash(hash['pointOfSaleInformation']) end # Parameter is an array, so we need to iterate through it merchant_defined_information = nil unless hash['merchantDefinedInformation'].nil? merchant_defined_information = [] hash['merchantDefinedInformation'].each do |structure| merchant_defined_information << (MerchantDefinedInformation.from_hash(structure) if structure) end end merchant_defined_information = SKIP unless hash.key?('merchantDefinedInformation') if hash['merchantDefinedSecureInformation'] merchant_defined_secure_information = MerchantDefinedSecureInformation.from_hash(hash['merchantDefinedSecureInformation']) end installment_information = InstallmentInformation.from_hash(hash['installmentInformation']) if hash['installmentInformation'] travel_information = TravelInformation.from_hash(hash['travelInformation']) if hash['travelInformation'] health_care_information = HealthCareInformation.from_hash(hash['healthCareInformation']) if hash['healthCareInformation'] promotion_information = PromotionInformation.from_hash(hash['promotionInformation']) if hash['promotionInformation'] token_information = TokenInformation.from_hash(hash['tokenInformation']) if hash['tokenInformation'] invoice_details = InvoiceDetails1.from_hash(hash['invoiceDetails']) if hash['invoiceDetails'] processor_information = ProcessorInformation.from_hash(hash['processorInformation']) if hash['processorInformation'] agreement_information = AgreementInformation.from_hash(hash['agreementInformation']) if hash['agreementInformation'] risk_information = RiskInformation.from_hash(hash['riskInformation']) if hash['riskInformation'] acquirer_information = AcquirerInformation.from_hash(hash['acquirerInformation']) if hash['acquirerInformation'] if hash['recurringPaymentInformation'] recurring_payment_information = RecurringPaymentInformation.from_hash(hash['recurringPaymentInformation']) end if hash['unscheduledPaymentInformation'] unscheduled_payment_information = UnscheduledPaymentInformation.from_hash(hash['unscheduledPaymentInformation']) end if hash['hostedPaymentInformation'] hosted_payment_information = HostedPaymentInformation.from_hash(hash['hostedPaymentInformation']) end if hash['watchlistScreeningInformation'] watchlist_screening_information = WatchlistScreeningInformation.from_hash(hash['watchlistScreeningInformation']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CreatePaymentRequest.new(client_reference_information: client_reference_information, processing_information: processing_information, issuer_information: issuer_information, payment_information: payment_information, order_information: order_information, buyer_information: buyer_information, sender_information: sender_information, recipient_information: recipient_information, device_information: device_information, merchant_information: merchant_information, aggregator_information: aggregator_information, consumer_authentication_information: consumer_authentication_information, point_of_sale_information: point_of_sale_information, merchant_defined_information: merchant_defined_information, merchant_defined_secure_information: merchant_defined_secure_information, installment_information: installment_information, travel_information: travel_information, health_care_information: health_care_information, promotion_information: promotion_information, token_information: token_information, invoice_details: invoice_details, processor_information: processor_information, agreement_information: agreement_information, risk_information: risk_information, acquirer_information: acquirer_information, recurring_payment_information: recurring_payment_information, unscheduled_payment_information: unscheduled_payment_information, hosted_payment_information: hosted_payment_information, watchlist_screening_information: watchlist_screening_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 131 def self.names @_hash = {} if @_hash.nil? @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['processing_information'] = 'processingInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash['buyer_information'] = 'buyerInformation' @_hash['sender_information'] = 'senderInformation' @_hash['recipient_information'] = 'recipientInformation' @_hash['device_information'] = 'deviceInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['aggregator_information'] = 'aggregatorInformation' @_hash['consumer_authentication_information'] = 'consumerAuthenticationInformation' @_hash['point_of_sale_information'] = 'pointOfSaleInformation' @_hash['merchant_defined_information'] = 'merchantDefinedInformation' @_hash['merchant_defined_secure_information'] = 'merchantDefinedSecureInformation' @_hash['installment_information'] = 'installmentInformation' @_hash['travel_information'] = 'travelInformation' @_hash['health_care_information'] = 'healthCareInformation' @_hash['promotion_information'] = 'promotionInformation' @_hash['token_information'] = 'tokenInformation' @_hash['invoice_details'] = 'invoiceDetails' @_hash['processor_information'] = 'processorInformation' @_hash['agreement_information'] = 'agreementInformation' @_hash['risk_information'] = 'riskInformation' @_hash['acquirer_information'] = 'acquirerInformation' @_hash['recurring_payment_information'] = 'recurringPaymentInformation' @_hash['unscheduled_payment_information'] = 'unscheduledPaymentInformation' @_hash['hosted_payment_information'] = 'hostedPaymentInformation' @_hash['watchlist_screening_information'] = 'watchlistScreeningInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
205 206 207 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 205 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 170 def self.optionals %w[ client_reference_information processing_information issuer_information payment_information order_information buyer_information sender_information recipient_information device_information merchant_information aggregator_information consumer_authentication_information point_of_sale_information merchant_defined_information merchant_defined_secure_information installment_information travel_information health_care_information promotion_information token_information invoice_details processor_information agreement_information risk_information acquirer_information recurring_payment_information unscheduled_payment_information hosted_payment_information watchlist_screening_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 627 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\ " processing_information: #{@processing_information.inspect}, issuer_information:"\ " #{@issuer_information.inspect}, payment_information: #{@payment_information.inspect},"\ " order_information: #{@order_information.inspect}, buyer_information:"\ " #{@buyer_information.inspect}, sender_information: #{@sender_information.inspect},"\ " recipient_information: #{@recipient_information.inspect}, device_information:"\ " #{@device_information.inspect}, merchant_information: #{@merchant_information.inspect},"\ " aggregator_information: #{@aggregator_information.inspect},"\ " consumer_authentication_information: #{@consumer_authentication_information.inspect},"\ " point_of_sale_information: #{@point_of_sale_information.inspect},"\ " merchant_defined_information: #{@merchant_defined_information.inspect},"\ " merchant_defined_secure_information: #{@merchant_defined_secure_information.inspect},"\ " installment_information: #{@installment_information.inspect}, travel_information:"\ " #{@travel_information.inspect}, health_care_information:"\ " #{@health_care_information.inspect}, promotion_information:"\ " #{@promotion_information.inspect}, token_information: #{@token_information.inspect},"\ " invoice_details: #{@invoice_details.inspect}, processor_information:"\ " #{@processor_information.inspect}, agreement_information:"\ " #{@agreement_information.inspect}, risk_information: #{@risk_information.inspect},"\ " acquirer_information: #{@acquirer_information.inspect}, recurring_payment_information:"\ " #{@recurring_payment_information.inspect}, unscheduled_payment_information:"\ " #{@unscheduled_payment_information.inspect}, hosted_payment_information:"\ " #{@hosted_payment_information.inspect}, watchlist_screening_information:"\ " #{@watchlist_screening_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 601 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information},"\ " processing_information: #{@processing_information}, issuer_information:"\ " #{@issuer_information}, payment_information: #{@payment_information}, order_information:"\ " #{@order_information}, buyer_information: #{@buyer_information}, sender_information:"\ " #{@sender_information}, recipient_information: #{@recipient_information},"\ " device_information: #{@device_information}, merchant_information:"\ " #{@merchant_information}, aggregator_information: #{@aggregator_information},"\ " consumer_authentication_information: #{@consumer_authentication_information},"\ " point_of_sale_information: #{@point_of_sale_information}, merchant_defined_information:"\ " #{@merchant_defined_information}, merchant_defined_secure_information:"\ " #{@merchant_defined_secure_information}, installment_information:"\ " #{@installment_information}, travel_information: #{@travel_information},"\ " health_care_information: #{@health_care_information}, promotion_information:"\ " #{@promotion_information}, token_information: #{@token_information}, invoice_details:"\ " #{@invoice_details}, processor_information: #{@processor_information},"\ " agreement_information: #{@agreement_information}, risk_information: #{@risk_information},"\ " acquirer_information: #{@acquirer_information}, recurring_payment_information:"\ " #{@recurring_payment_information}, unscheduled_payment_information:"\ " #{@unscheduled_payment_information}, hosted_payment_information:"\ " #{@hosted_payment_information}, watchlist_screening_information:"\ " #{@watchlist_screening_information}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/cyber_source_merged_spec/models/create_payment_request.rb', line 530 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation', processing_information) XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation', issuer_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation', payment_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation', order_information) XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation', buyer_information) XmlUtilities.add_as_subelement(doc, root, 'SenderInformation', sender_information) XmlUtilities.add_as_subelement(doc, root, 'RecipientInformation', recipient_information) XmlUtilities.add_as_subelement(doc, root, 'DeviceInformation', device_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation', merchant_information) XmlUtilities.add_as_subelement(doc, root, 'AggregatorInformation', aggregator_information) XmlUtilities.add_as_subelement(doc, root, 'ConsumerAuthenticationInformation', consumer_authentication_information) XmlUtilities.add_as_subelement(doc, root, 'PointOfSaleInformation', point_of_sale_information) XmlUtilities.add_array_as_subelement(doc, root, 'MerchantDefinedInformation', merchant_defined_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantDefinedSecureInformation', merchant_defined_secure_information) XmlUtilities.add_as_subelement(doc, root, 'InstallmentInformation', installment_information) XmlUtilities.add_as_subelement(doc, root, 'TravelInformation', travel_information) XmlUtilities.add_as_subelement(doc, root, 'HealthCareInformation', health_care_information) XmlUtilities.add_as_subelement(doc, root, 'PromotionInformation', promotion_information) XmlUtilities.add_as_subelement(doc, root, 'TokenInformation', token_information) XmlUtilities.add_as_subelement(doc, root, 'InvoiceDetails1', invoice_details) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation', processor_information) XmlUtilities.add_as_subelement(doc, root, 'AgreementInformation', agreement_information) XmlUtilities.add_as_subelement(doc, root, 'RiskInformation', risk_information) XmlUtilities.add_as_subelement(doc, root, 'AcquirerInformation', acquirer_information) XmlUtilities.add_as_subelement(doc, root, 'RecurringPaymentInformation', recurring_payment_information) XmlUtilities.add_as_subelement(doc, root, 'UnscheduledPaymentInformation', unscheduled_payment_information) XmlUtilities.add_as_subelement(doc, root, 'HostedPaymentInformation', hosted_payment_information) XmlUtilities.add_as_subelement(doc, root, 'WatchlistScreeningInformation', watchlist_screening_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |