Class: CyberSourceMergedSpec::CreatePlanRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/create_plan_request.rb

Overview

CreatePlanRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(plan_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ CreatePlanRequest

Returns a new instance of CreatePlanRequest.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 41

def initialize(plan_information: SKIP, order_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @plan_information = plan_information unless plan_information == SKIP
  @order_information = order_information unless order_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#order_informationOrderInformation48

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 18

def order_information
  @order_information
end

#plan_informationPlanInformation

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 14

def plan_information
  @plan_information
end

Class Method Details

.from_element(root) ⇒ Object



74
75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 74

def self.from_element(root)
  plan_information = XmlUtilities.from_element(root, 'PlanInformation',
                                               PlanInformation)
  order_information = XmlUtilities.from_element(root, 'OrderInformation48',
                                                OrderInformation48)

  new(plan_information: plan_information,
      order_information: order_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  plan_information = PlanInformation.from_hash(hash['planInformation']) if
    hash['planInformation']
  order_information = OrderInformation48.from_hash(hash['orderInformation']) if
    hash['orderInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreatePlanRequest.new(plan_information: plan_information,
                        order_information: order_information,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['plan_information'] = 'planInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 29

def self.optionals
  %w[
    plan_information
    order_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} plan_information: #{@plan_information.inspect}, order_information:"\
  " #{@order_information.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} plan_information: #{@plan_information}, order_information:"\
  " #{@order_information}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/create_plan_request.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'PlanInformation',
                                 plan_information)
  XmlUtilities.add_as_subelement(doc, root, 'OrderInformation48',
                                 order_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end