Class: CyberSourceMergedSpec::CreditAmountDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/credit_amount_details.rb

Overview

CreditAmountDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(credit_amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ CreditAmountDetails

Returns a new instance of CreditAmountDetails.



77
78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 77

def initialize(credit_amount: SKIP, currency: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @credit_amount = credit_amount unless credit_amount == SKIP
  @currency = currency unless currency == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#credit_amountString

Amount that was credited to the cardholder’s account. Returned by PIN debit credit.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 15

def credit_amount
  @credit_amount
end

#currencyString

Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/cur rencies.pdf)

Used by

Authorization Required field. Authorization Reversal For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request.

PIN Debit

Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.

GPX

This field is optional for reversing an authorization or credit.

DCC for First Data

Your local currency.

Tax Calculation

Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.

Returns:

  • (String)


54
55
56
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 54

def currency
  @currency
end

Class Method Details

.from_element(root) ⇒ Object



108
109
110
111
112
113
114
115
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 108

def self.from_element(root)
  credit_amount = XmlUtilities.from_element(root, 'creditAmount', String)
  currency = XmlUtilities.from_element(root, 'currency', String)

  new(credit_amount: credit_amount,
      currency: currency,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 88

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  credit_amount = hash.key?('creditAmount') ? hash['creditAmount'] : SKIP
  currency = hash.key?('currency') ? hash['currency'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CreditAmountDetails.new(credit_amount: credit_amount,
                          currency: currency,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



57
58
59
60
61
62
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 57

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['credit_amount'] = 'creditAmount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



73
74
75
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 73

def self.nullables
  []
end

.optionalsObject

An array for optional fields



65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 65

def self.optionals
  %w[
    credit_amount
    currency
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



136
137
138
139
140
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 136

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} credit_amount: #{@credit_amount.inspect}, currency: #{@currency.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



129
130
131
132
133
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 129

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} credit_amount: #{@credit_amount}, currency: #{@currency},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



117
118
119
120
121
122
123
124
125
126
# File 'lib/cyber_source_merged_spec/models/credit_amount_details.rb', line 117

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'creditAmount', credit_amount)
  XmlUtilities.add_as_subelement(doc, root, 'currency', currency)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end