Class: CyberSourceMergedSpec::Customer50

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/customer50.rb

Overview

Customer50 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer_id:, additional_properties: nil) ⇒ Customer50

Returns a new instance of Customer50.



37
38
39
40
41
42
43
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 37

def initialize(customer_id:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer_id = customer_id
  @additional_properties = additional_properties
end

Instance Attribute Details

#customer_idString

Unique identifier for the legacy Secure Storage token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 18

def customer_id
  @customer_id
end

Class Method Details

.from_element(root) ⇒ Object



64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 64

def self.from_element(root)
  customer_id = XmlUtilities.from_element(root, 'customerId', String)

  new(customer_id: customer_id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 46

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer_id = hash.key?('customerId') ? hash['customerId'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Customer50.new(customer_id: customer_id,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer_id'] = 'customerId'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 28

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer_id: #{@customer_id}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/customer50.rb', line 71

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'customerId', customer_id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end