Class: CyberSourceMergedSpec::Detail102

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/detail102.rb

Overview

Detail102 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(field: SKIP, reason: SKIP, additional_properties: nil) ⇒ Detail102

Returns a new instance of Detail102.



60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 60

def initialize(field: SKIP, reason: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @field = field unless field == SKIP
  @reason = reason unless reason == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#fieldString

This is the flattened JSON object field name/path that is either missing or invalid.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 15

def field
  @field
end

#reasonString

Possible reasons for the error. Possible values:

  • AUTH_ALREADY_REVERSED
  • CONTACT_PROCESSOR
  • DEBIT_CARD_USAGE_LIMIT_EXCEEDED
  • EXCEEDS_AUTH_AMOUNT
  • EXCEEDS_CREDIT_LIMIT
  • EXPIRED_CARD
  • GENERAL_DECLINE
  • INSUFFICIENT_FUND
  • INVALID_CVN
  • INVALID_DATA
  • MISSING_AUTH
  • PARTIAL_APPROVAL
  • PROCESSOR_DECLINED
  • SERVER_ERROR
  • STOLEN_LOST_CARD
  • SUCCESS
  • UNAUTHORIZED_CARD

Returns:

  • (String)


37
38
39
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 37

def reason
  @reason
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 90

def self.from_element(root)
  field = XmlUtilities.from_element(root, 'field', String)
  reason = XmlUtilities.from_element(root, 'reason', String)

  new(field: field,
      reason: reason,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  field = hash.key?('field') ? hash['field'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Detail102.new(field: field,
                reason: reason,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 40

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['field'] = 'field'
  @_hash['reason'] = 'reason'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



48
49
50
51
52
53
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 48

def self.optionals
  %w[
    field
    reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



118
119
120
121
122
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 118

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} field: #{@field.inspect}, reason: #{@reason.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} field: #{@field}, reason: #{@reason}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



99
100
101
102
103
104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/detail102.rb', line 99

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'field', field)
  XmlUtilities.add_as_subelement(doc, root, 'reason', reason)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end