Class: CyberSourceMergedSpec::Detail73
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Detail73
- Defined in:
- lib/cyber_source_merged_spec/models/detail73.rb
Overview
Detail73 Model.
Instance Attribute Summary collapse
-
#location ⇒ String
Field name referred to for validation issues.
-
#message ⇒ String
Description or code of any error response.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(location: SKIP, message: SKIP, additional_properties: nil) ⇒ Detail73
constructor
A new instance of Detail73.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(location: SKIP, message: SKIP, additional_properties: nil) ⇒ Detail73
Returns a new instance of Detail73.
41 42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 41 def initialize(location: SKIP, message: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @location = location unless location == SKIP @message = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#location ⇒ String
Field name referred to for validation issues.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 14 def location @location end |
#message ⇒ String
Description or code of any error response.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 18 def @message end |
Class Method Details
.from_element(root) ⇒ Object
71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 71 def self.from_element(root) location = XmlUtilities.from_element(root, 'location', String) = XmlUtilities.from_element(root, 'message', String) new(location: location, message: , additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. location = hash.key?('location') ? hash['location'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Detail73.new(location: location, message: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['location'] = 'location' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 29 def self.optionals %w[ location message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} location: #{@location.inspect}, message: #{@message.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} location: #{@location}, message: #{@message}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/detail73.rb', line 80 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'location', location) XmlUtilities.add_as_subelement(doc, root, 'message', ) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |