Class: CyberSourceMergedSpec::DeviceInformation1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/device_information1.rb

Overview

DeviceInformation1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_type: SKIP, additional_properties: nil) ⇒ DeviceInformation1

Returns a new instance of DeviceInformation1.



54
55
56
57
58
59
60
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 54

def initialize(device_type: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @device_type = device_type unless device_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#device_typeString

Account Entry Device Type for Tap to More transactions. This field flows in ISO Field 34 DSID 02 Tag 89. Valid Values:

  • 1: Off-the-shelf mobile consumer Mastercard is introducing changes to support commercialization of Tap to More transactions. Acquirers globally must be prepared to send a value of 1 (Off-the-shelf mobile-consumer) in Field 34—Acceptance Environment Data (TLV Format), Dataset ID 02—Acceptance Environment Additional Data, Tag 89—Account Entry Device Type for Tap to More transactions. Visa will map this value to a value of 8 (Remote terminal) in Mastercard Data Element 61.10.

Mapping

  • SCMP API Field: customer_device_type
  • Simple Order API Field: billTo_deviceType
  • CCS: device.type
  • NRTF Key: customer_device_type Optional field.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 33

def device_type
  @device_type
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 81

def self.from_element(root)
  device_type = XmlUtilities.from_element(root, 'deviceType', String)

  new(device_type: device_type,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  device_type = hash.key?('deviceType') ? hash['deviceType'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceInformation1.new(device_type: device_type,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_type'] = 'deviceType'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 43

def self.optionals
  %w[
    device_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_type: #{@device_type.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_type: #{@device_type}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/device_information1.rb', line 88

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'deviceType', device_type)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end