Class: CyberSourceMergedSpec::DeviceInformation17

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/device_information17.rb

Overview

DeviceInformation17 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ip_address: SKIP, host_name: SKIP, additional_properties: nil) ⇒ DeviceInformation17

Returns a new instance of DeviceInformation17.



44
45
46
47
48
49
50
51
52
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 44

def initialize(ip_address: SKIP, host_name: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @ip_address = ip_address unless ip_address == SKIP
  @host_name = host_name unless host_name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#host_nameString

DNS resolved hostname from ipAddress.

Returns:

  • (String)


21
22
23
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 21

def host_name
  @host_name
end

#ip_addressString

IP address of the customer.

Used by

Authorization, Capture, and Credit Optional field.

Returns:

  • (String)


17
18
19
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 17

def ip_address
  @ip_address
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 75

def self.from_element(root)
  ip_address = XmlUtilities.from_element(root, 'ipAddress', String)
  host_name = XmlUtilities.from_element(root, 'hostName', String)

  new(ip_address: ip_address,
      host_name: host_name,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ip_address = hash.key?('ipAddress') ? hash['ipAddress'] : SKIP
  host_name = hash.key?('hostName') ? hash['hostName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceInformation17.new(ip_address: ip_address,
                          host_name: host_name,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ip_address'] = 'ipAddress'
  @_hash['host_name'] = 'hostName'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 32

def self.optionals
  %w[
    ip_address
    host_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ip_address: #{@ip_address.inspect}, host_name: #{@host_name.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ip_address: #{@ip_address}, host_name: #{@host_name},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/device_information17.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'ipAddress', ip_address)
  XmlUtilities.add_as_subelement(doc, root, 'hostName', host_name)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end