Class: CyberSourceMergedSpec::DeviceInformation3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/device_information3.rb

Overview

DeviceInformation3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(host_name: SKIP, ip_address: SKIP, user_agent: SKIP, additional_properties: nil) ⇒ DeviceInformation3

Returns a new instance of DeviceInformation3.



52
53
54
55
56
57
58
59
60
61
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 52

def initialize(host_name: SKIP, ip_address: SKIP, user_agent: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @host_name = host_name unless host_name == SKIP
  @ip_address = ip_address unless ip_address == SKIP
  @user_agent = user_agent unless user_agent == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#host_nameString

DNS resolved hostname from ipAddress.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 14

def host_name
  @host_name
end

#ip_addressString

IP address of the customer.

Used by

Authorization, Capture, and Credit Optional field.

Returns:

  • (String)


21
22
23
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 21

def ip_address
  @ip_address
end

#user_agentString

Customer’s browser as identified from the HTTP header data. For example, Mozilla is the value that identifies the Netscape browser.

Returns:

  • (String)


27
28
29
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 27

def user_agent
  @user_agent
end

Class Method Details

.from_element(root) ⇒ Object



86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 86

def self.from_element(root)
  host_name = XmlUtilities.from_element(root, 'hostName', String)
  ip_address = XmlUtilities.from_element(root, 'ipAddress', String)
  user_agent = XmlUtilities.from_element(root, 'userAgent', String)

  new(host_name: host_name,
      ip_address: ip_address,
      user_agent: user_agent,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  host_name = hash.key?('hostName') ? hash['hostName'] : SKIP
  ip_address = hash.key?('ipAddress') ? hash['ipAddress'] : SKIP
  user_agent = hash.key?('userAgent') ? hash['userAgent'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  DeviceInformation3.new(host_name: host_name,
                         ip_address: ip_address,
                         user_agent: user_agent,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['host_name'] = 'hostName'
  @_hash['ip_address'] = 'ipAddress'
  @_hash['user_agent'] = 'userAgent'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 48

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 39

def self.optionals
  %w[
    host_name
    ip_address
    user_agent
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} host_name: #{@host_name.inspect}, ip_address: #{@ip_address.inspect},"\
  " user_agent: #{@user_agent.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} host_name: #{@host_name}, ip_address: #{@ip_address}, user_agent:"\
  " #{@user_agent}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



97
98
99
100
101
102
103
104
105
106
107
# File 'lib/cyber_source_merged_spec/models/device_information3.rb', line 97

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'hostName', host_name)
  XmlUtilities.add_as_subelement(doc, root, 'ipAddress', ip_address)
  XmlUtilities.add_as_subelement(doc, root, 'userAgent', user_agent)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end