Class: CyberSourceMergedSpec::EWallet2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/e_wallet2.rb

Overview

EWallet2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(funding_source: SKIP, additional_properties: nil) ⇒ EWallet2

Returns a new instance of EWallet2.



38
39
40
41
42
43
44
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 38

def initialize(funding_source: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @funding_source = funding_source unless funding_source == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#funding_sourceString

Payment mode for the authorization or order transaction.  INSTANT_TRANSFER  MANUAL_BANK_TRANSFER  DELAYED_TRANSFER  ECHECK  UNRESTRICTED (default)—this value is available only when configured by PayPal for the merchant. INSTANT

Returns:

  • (String)


17
18
19
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 17

def funding_source
  @funding_source
end

Class Method Details

.from_element(root) ⇒ Object



65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 65

def self.from_element(root)
  funding_source = XmlUtilities.from_element(root, 'fundingSource', String)

  new(funding_source: funding_source,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  funding_source = hash.key?('fundingSource') ? hash['fundingSource'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  EWallet2.new(funding_source: funding_source,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['funding_source'] = 'fundingSource'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
30
31
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 27

def self.optionals
  %w[
    funding_source
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} funding_source: #{@funding_source.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} funding_source: #{@funding_source}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



72
73
74
75
76
77
78
79
80
# File 'lib/cyber_source_merged_spec/models/e_wallet2.rb', line 72

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'fundingSource', funding_source)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end