Class: CyberSourceMergedSpec::Embedded
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Embedded
- Defined in:
- lib/cyber_source_merged_spec/models/embedded.rb
Overview
Additional resources for the Customer.
Instance Attribute Summary collapse
-
#default_payment_instrument ⇒ DefaultPaymentInstrument1
TODO: Write general description for this method.
-
#default_shipping_address ⇒ DefaultShippingAddress1
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(default_payment_instrument: SKIP, default_shipping_address: SKIP, additional_properties: nil) ⇒ Embedded
constructor
A new instance of Embedded.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(default_payment_instrument: SKIP, default_shipping_address: SKIP, additional_properties: nil) ⇒ Embedded
Returns a new instance of Embedded.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 41 def initialize(default_payment_instrument: SKIP, default_shipping_address: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless default_payment_instrument == SKIP @default_payment_instrument = default_payment_instrument end @default_shipping_address = default_shipping_address unless default_shipping_address == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#default_payment_instrument ⇒ DefaultPaymentInstrument1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 14 def default_payment_instrument @default_payment_instrument end |
#default_shipping_address ⇒ DefaultShippingAddress1
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 18 def default_shipping_address @default_shipping_address end |
Class Method Details
.from_element(root) ⇒ Object
79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 79 def self.from_element(root) default_payment_instrument = XmlUtilities.from_element( root, 'defaultPaymentInstrument1', DefaultPaymentInstrument1 ) default_shipping_address = XmlUtilities.from_element( root, 'defaultShippingAddress1', DefaultShippingAddress1 ) new(default_payment_instrument: default_payment_instrument, default_shipping_address: default_shipping_address, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['defaultPaymentInstrument'] default_payment_instrument = DefaultPaymentInstrument1.from_hash(hash['defaultPaymentInstrument']) end if hash['defaultShippingAddress'] default_shipping_address = DefaultShippingAddress1.from_hash(hash['defaultShippingAddress']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Embedded.new(default_payment_instrument: default_payment_instrument, default_shipping_address: default_shipping_address, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['default_payment_instrument'] = 'defaultPaymentInstrument' @_hash['default_shipping_address'] = 'defaultShippingAddress' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 29 def self.optionals %w[ default_payment_instrument default_shipping_address ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 119 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} default_payment_instrument: #{@default_payment_instrument.inspect},"\ " default_shipping_address: #{@default_shipping_address.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
106 107 108 109 110 111 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 106 def to_s class_name = self.class.name.split('::').last "<#{class_name} default_payment_instrument: #{@default_payment_instrument},"\ " default_shipping_address: #{@default_shipping_address}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/embedded.rb', line 92 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'defaultPaymentInstrument1', default_payment_instrument) XmlUtilities.add_as_subelement(doc, root, 'defaultShippingAddress1', default_shipping_address) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |