Class: CyberSourceMergedSpec::Embedded1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/embedded1.rb

Overview

Additional resources for the Payment Instrument.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(instrument_identifier: SKIP, additional_properties: nil) ⇒ Embedded1

Returns a new instance of Embedded1.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 35

def initialize(instrument_identifier: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @instrument_identifier = instrument_identifier unless instrument_identifier == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#instrument_identifierTmsEmbeddedInstrumentIdentifier

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 14

def instrument_identifier
  @instrument_identifier
end

Class Method Details

.from_element(root) ⇒ Object



64
65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 64

def self.from_element(root)
  instrument_identifier = XmlUtilities.from_element(
    root, 'tmsEmbeddedInstrumentIdentifier',
    TmsEmbeddedInstrumentIdentifier
  )

  new(instrument_identifier: instrument_identifier,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  if hash['instrumentIdentifier']
    instrument_identifier = TmsEmbeddedInstrumentIdentifier.from_hash(hash['instrumentIdentifier'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Embedded1.new(instrument_identifier: instrument_identifier,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['instrument_identifier'] = 'instrumentIdentifier'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 24

def self.optionals
  %w[
    instrument_identifier
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} instrument_identifier: #{@instrument_identifier.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} instrument_identifier: #{@instrument_identifier}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/embedded1.rb', line 74

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root,
                                 'tmsEmbeddedInstrumentIdentifier',
                                 instrument_identifier)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end