Class: CyberSourceMergedSpec::Embedded41
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Embedded41
- Defined in:
- lib/cyber_source_merged_spec/models/embedded41.rb
Overview
Shipping Address Resources.
Instance Attribute Summary collapse
-
#shipping_addresses ⇒ Array[ShippingAddress12]
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shipping_addresses: SKIP, additional_properties: nil) ⇒ Embedded41
constructor
A new instance of Embedded41.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shipping_addresses: SKIP, additional_properties: nil) ⇒ Embedded41
Returns a new instance of Embedded41.
35 36 37 38 39 40 41 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 35 def initialize(shipping_addresses: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @shipping_addresses = shipping_addresses unless shipping_addresses == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#shipping_addresses ⇒ Array[ShippingAddress12]
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 14 def shipping_addresses @shipping_addresses end |
Class Method Details
.from_element(root) ⇒ Object
71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 71 def self.from_element(root) shipping_addresses = XmlUtilities.from_element_to_array( root, 'ShippingAddress12', ShippingAddress12 ) new(shipping_addresses: shipping_addresses, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it shipping_addresses = nil unless hash['shippingAddresses'].nil? shipping_addresses = [] hash['shippingAddresses'].each do |structure| shipping_addresses << (ShippingAddress12.from_hash(structure) if structure) end end shipping_addresses = SKIP unless hash.key?('shippingAddresses') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Embedded41.new(shipping_addresses: shipping_addresses, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['shipping_addresses'] = 'shippingAddresses' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 24 def self.optionals %w[ shipping_addresses ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} shipping_addresses: #{@shipping_addresses.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} shipping_addresses: #{@shipping_addresses}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/embedded41.rb', line 80 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_array_as_subelement(doc, root, 'ShippingAddress12', shipping_addresses) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |