Class: CyberSourceMergedSpec::Embedded55

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/embedded55.rb

Overview

This object includes either a capture or reversal object. They each has the status of the action and link to the GET method to the following-on capture transaction or reversal transaction.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(capture: SKIP, reversal: SKIP, additional_properties: nil) ⇒ Embedded55

Returns a new instance of Embedded55.



45
46
47
48
49
50
51
52
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 45

def initialize(capture: SKIP, reversal: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @capture = capture unless capture == SKIP
  @reversal = reversal unless reversal == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#captureCapture5

This object includes the status of the action and link to the GET method to the following-on capture transaction.

Returns:



17
18
19
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 17

def capture
  @capture
end

#reversalReversal5

This object includes the status of the action and link to the GET method to the following-on reversal transaction.

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 22

def reversal
  @reversal
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 75

def self.from_element(root)
  capture = XmlUtilities.from_element(root, 'Capture5', Capture5)
  reversal = XmlUtilities.from_element(root, 'Reversal5', Reversal5)

  new(capture: capture,
      reversal: reversal,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  capture = Capture5.from_hash(hash['capture']) if hash['capture']
  reversal = Reversal5.from_hash(hash['reversal']) if hash['reversal']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Embedded55.new(capture: capture,
                 reversal: reversal,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['capture'] = 'capture'
  @_hash['reversal'] = 'reversal'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



33
34
35
36
37
38
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 33

def self.optionals
  %w[
    capture
    reversal
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



103
104
105
106
107
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 103

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} capture: #{@capture.inspect}, reversal: #{@reversal.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 96

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} capture: #{@capture}, reversal: #{@reversal}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/embedded55.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Capture5', capture)
  XmlUtilities.add_as_subelement(doc, root, 'Reversal5', reversal)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end