Class: CyberSourceMergedSpec::Error

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/error.rb

Overview

Error Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ Error

Returns a new instance of Error.



66
67
68
69
70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/error.rb', line 66

def initialize(type: SKIP, message: SKIP, details: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @message = message unless message == SKIP
  @details = details unless details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailsArray[Detail43]

The detailed message related to the type.

Returns:



41
42
43
# File 'lib/cyber_source_merged_spec/models/error.rb', line 41

def details
  @details
end

#messageString

The detailed message related to the type.

Returns:

  • (String)


37
38
39
# File 'lib/cyber_source_merged_spec/models/error.rb', line 37

def message
  @message
end

#typeString

The type of error. Possible Values:

- invalidHeaders
- missingHeaders
- invalidFields
- missingFields
- unsupportedPaymentMethodModification
- invalidCombination
- forbidden
- notFound
- instrumentIdentifierDeletionError
- tokenIdConflict
- conflict
- notAvailable
- serverError
- notAttempted

A "notAttempted" error type is returned when the request cannot be processed because it depends on the existence of another token that does not exist. For example, creating a shipping address token is not attempted if the required customer token is missing.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/error.rb', line 33

def type
  @type
end

Class Method Details

.from_element(root) ⇒ Object



109
110
111
112
113
114
115
116
117
118
# File 'lib/cyber_source_merged_spec/models/error.rb', line 109

def self.from_element(root)
  type = XmlUtilities.from_element(root, 'type', String)
  message = XmlUtilities.from_element(root, 'message', String)
  details = XmlUtilities.from_element_to_array(root, 'Detail43', Detail43)

  new(type: type,
      message: message,
      details: details,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/cyber_source_merged_spec/models/error.rb', line 78

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  details = nil
  unless hash['details'].nil?
    details = []
    hash['details'].each do |structure|
      details << (Detail43.from_hash(structure) if structure)
    end
  end

  details = SKIP unless hash.key?('details')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Error.new(type: type,
            message: message,
            details: details,
            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



44
45
46
47
48
49
50
# File 'lib/cyber_source_merged_spec/models/error.rb', line 44

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['message'] = 'message'
  @_hash['details'] = 'details'
  @_hash
end

.nullablesObject

An array for nullable fields



62
63
64
# File 'lib/cyber_source_merged_spec/models/error.rb', line 62

def self.nullables
  []
end

.optionalsObject

An array for optional fields



53
54
55
56
57
58
59
# File 'lib/cyber_source_merged_spec/models/error.rb', line 53

def self.optionals
  %w[
    type
    message
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



140
141
142
143
144
# File 'lib/cyber_source_merged_spec/models/error.rb', line 140

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, message: #{@message.inspect}, details:"\
  " #{@details.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



133
134
135
136
137
# File 'lib/cyber_source_merged_spec/models/error.rb', line 133

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, message: #{@message}, details: #{@details},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



120
121
122
123
124
125
126
127
128
129
130
# File 'lib/cyber_source_merged_spec/models/error.rb', line 120

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'type', type)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_array_as_subelement(doc, root, 'Detail43', details)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end