Class: CyberSourceMergedSpec::ErrorInformation25

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/error_information25.rb

Overview

ErrorInformation25 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ ErrorInformation25

Returns a new instance of ErrorInformation25.



51
52
53
54
55
56
57
58
59
60
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 51

def initialize(reason: SKIP, message: SKIP, details: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @details = details unless details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailsArray[Detail]

The detail message related to the status and reason listed above.

Returns:



26
27
28
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 26

def details
  @details
end

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 22

def message
  @message
end

#reasonString

The reason of the status. Possible values are:

  • INVALID_MERCHANT_CONFIGURATION
  • CONSUMER_AUTHENTICATION_REQUIRED
  • CONSUMER_AUTHENTICATION_FAILED
  • AUTHENTICATION_FAILED

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 18

def reason
  @reason
end

Class Method Details

.from_element(root) ⇒ Object



94
95
96
97
98
99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 94

def self.from_element(root)
  reason = XmlUtilities.from_element(root, 'reason', String)
  message = XmlUtilities.from_element(root, 'message', String)
  details = XmlUtilities.from_element_to_array(root, 'Detail', Detail)

  new(reason: reason,
      message: message,
      details: details,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  details = nil
  unless hash['details'].nil?
    details = []
    hash['details'].each do |structure|
      details << (Detail.from_hash(structure) if structure)
    end
  end

  details = SKIP unless hash.key?('details')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ErrorInformation25.new(reason: reason,
                         message: message,
                         details: details,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash['details'] = 'details'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
41
42
43
44
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 38

def self.optionals
  %w[
    reason
    message
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



125
126
127
128
129
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 125

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason.inspect}, message: #{@message.inspect}, details:"\
  " #{@details.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



118
119
120
121
122
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 118

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason}, message: #{@message}, details: #{@details},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



105
106
107
108
109
110
111
112
113
114
115
# File 'lib/cyber_source_merged_spec/models/error_information25.rb', line 105

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'reason', reason)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_array_as_subelement(doc, root, 'Detail', details)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end