Class: CyberSourceMergedSpec::ErrorInformation28

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/error_information28.rb

Overview

ErrorInformation28 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ ErrorInformation28

Returns a new instance of ErrorInformation28.



52
53
54
55
56
57
58
59
60
61
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 52

def initialize(reason: SKIP, message: SKIP, details: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @details = details unless details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailsArray[Detail]

The detail message related to the status and reason listed above.

Returns:



27
28
29
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 27

def details
  @details
end

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


23
24
25
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 23

def message
  @message
end

#reasonString

The reason of the status. Value can be

  • CUSTOMER_WATCHLIST_MATCH
  • ADDRESS_COUNTRY_WATCHLIST_MATCH
  • EMAIL_COUNTRY_WATCHLIST_MATCH
  • IP_COUNTRY_WATCHLIST_MATCH
  • INVALID_MERCHANT_CONFIGURATION

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 19

def reason
  @reason
end

Class Method Details

.from_element(root) ⇒ Object



95
96
97
98
99
100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 95

def self.from_element(root)
  reason = XmlUtilities.from_element(root, 'reason', String)
  message = XmlUtilities.from_element(root, 'message', String)
  details = XmlUtilities.from_element_to_array(root, 'Detail', Detail)

  new(reason: reason,
      message: message,
      details: details,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 64

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  details = nil
  unless hash['details'].nil?
    details = []
    hash['details'].each do |structure|
      details << (Detail.from_hash(structure) if structure)
    end
  end

  details = SKIP unless hash.key?('details')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ErrorInformation28.new(reason: reason,
                         message: message,
                         details: details,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash['details'] = 'details'
  @_hash
end

.nullablesObject

An array for nullable fields



48
49
50
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 48

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 39

def self.optionals
  %w[
    reason
    message
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



126
127
128
129
130
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 126

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason.inspect}, message: #{@message.inspect}, details:"\
  " #{@details.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason}, message: #{@message}, details: #{@details},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/error_information28.rb', line 106

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'reason', reason)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_array_as_subelement(doc, root, 'Detail', details)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end