Class: CyberSourceMergedSpec::ErrorInformation29
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ErrorInformation29
- Defined in:
- lib/cyber_source_merged_spec/models/error_information29.rb
Overview
ErrorInformation29 Model.
Instance Attribute Summary collapse
-
#details ⇒ Array[Detail]
The detail message related to the status and reason listed above.
-
#message ⇒ String
The detail message related to the status and reason listed above.
-
#reason ⇒ String
The reason of the status.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ ErrorInformation29
constructor
A new instance of ErrorInformation29.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ ErrorInformation29
Returns a new instance of ErrorInformation29.
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 62 def initialize(reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reason = reason unless reason == SKIP @message = unless == SKIP @details = details unless details == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#details ⇒ Array[Detail]
The detail message related to the status and reason listed above.
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 37 def details @details end |
#message ⇒ String
The detail message related to the status and reason listed above.
33 34 35 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 33 def @message end |
#reason ⇒ String
The reason of the status. Possible values:
- EXPIRED_CARD
- PROCESSOR_DECLINED
- STOLEN_LOST_CARD
- UNAUTHORIZED_CARD
- CVN_NOT_MATCH
- INVALID_CVN
- BLOCKED_BY_CARDHOLDER
- BLACKLISTED_CUSTOMER
- INVALID_ACCOUNT
- GENERAL_DECLINE
- RISK_CONTROL_DECLINE
- PROCESSOR_RISK_CONTROL_DECLINE
- ALLOWABLE_PIN_RETRIES_EXCEEDED
- PROCESSOR_ERROR
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 29 def reason @reason end |
Class Method Details
.from_element(root) ⇒ Object
105 106 107 108 109 110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 105 def self.from_element(root) reason = XmlUtilities.from_element(root, 'reason', String) = XmlUtilities.from_element(root, 'message', String) details = XmlUtilities.from_element_to_array(root, 'Detail', Detail) new(reason: reason, message: , details: details, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reason = hash.key?('reason') ? hash['reason'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Parameter is an array, so we need to iterate through it details = nil unless hash['details'].nil? details = [] hash['details'].each do |structure| details << (Detail.from_hash(structure) if structure) end end details = SKIP unless hash.key?('details') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ErrorInformation29.new(reason: reason, message: , details: details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 40 def self.names @_hash = {} if @_hash.nil? @_hash['reason'] = 'reason' @_hash['message'] = 'message' @_hash['details'] = 'details' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 58 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 49 def self.optionals %w[ reason message details ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
136 137 138 139 140 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 136 def inspect class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason.inspect}, message: #{@message.inspect}, details:"\ " #{@details.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
129 130 131 132 133 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 129 def to_s class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason}, message: #{@message}, details: #{@details},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/cyber_source_merged_spec/models/error_information29.rb', line 116 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'reason', reason) XmlUtilities.add_as_subelement(doc, root, 'message', ) XmlUtilities.add_array_as_subelement(doc, root, 'Detail', details) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |