Class: CyberSourceMergedSpec::File
- Defined in:
- lib/cyber_source_merged_spec/models/file.rb
Overview
File Model.
Instance Attribute Summary collapse
-
#file_id ⇒ String
Unique identifier for each file.
-
#href ⇒ String
Unique identifier for each file.
-
#method ⇒ String
Unique identifier for each file.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(file_id: SKIP, href: SKIP, method: SKIP, additional_properties: nil) ⇒ File
constructor
A new instance of File.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(file_id: SKIP, href: SKIP, method: SKIP, additional_properties: nil) ⇒ File
Returns a new instance of File.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 47 def initialize(file_id: SKIP, href: SKIP, method: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @file_id = file_id unless file_id == SKIP @href = href unless href == SKIP @method = method unless method == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#file_id ⇒ String
Unique identifier for each file
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 14 def file_id @file_id end |
#href ⇒ String
Unique identifier for each file
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 18 def href @href end |
#method ⇒ String
Unique identifier for each file
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 22 def method @method end |
Class Method Details
.from_element(root) ⇒ Object
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 81 def self.from_element(root) file_id = XmlUtilities.from_element(root, 'fileId', String) href = XmlUtilities.from_element(root, 'href', String) method = XmlUtilities.from_element(root, 'method', String) new(file_id: file_id, href: href, method: method, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. file_id = hash.key?('fileId') ? hash['fileId'] : SKIP href = hash.key?('href') ? hash['href'] : SKIP method = hash.key?('method') ? hash['method'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. File.new(file_id: file_id, href: href, method: method, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['file_id'] = 'fileId' @_hash['href'] = 'href' @_hash['method'] = 'method' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 34 def self.optionals %w[ file_id href method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 112 def inspect class_name = self.class.name.split('::').last "<#{class_name} file_id: #{@file_id.inspect}, href: #{@href.inspect}, method:"\ " #{@method.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} file_id: #{@file_id}, href: #{@href}, method: #{@method},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/file.rb', line 92 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'fileId', file_id) XmlUtilities.add_as_subelement(doc, root, 'href', href) XmlUtilities.add_as_subelement(doc, root, 'method', method) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |