Class: CyberSourceMergedSpec::FraudMarkingActionRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::FraudMarkingActionRequest
- Defined in:
- lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb
Overview
FraudMarkingActionRequest Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation49
TODO: Write general description for this method.
-
#risk_information ⇒ RiskInformation9
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(risk_information:, client_reference_information: SKIP, additional_properties: nil) ⇒ FraudMarkingActionRequest
constructor
A new instance of FraudMarkingActionRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(risk_information:, client_reference_information: SKIP, additional_properties: nil) ⇒ FraudMarkingActionRequest
Returns a new instance of FraudMarkingActionRequest.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 40 def initialize(risk_information:, client_reference_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @risk_information = risk_information unless client_reference_information == SKIP @client_reference_information = client_reference_information end @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation49
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 18 def client_reference_information @client_reference_information end |
#risk_information ⇒ RiskInformation9
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 14 def risk_information @risk_information end |
Class Method Details
.from_element(root) ⇒ Object
77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 77 def self.from_element(root) risk_information = XmlUtilities.from_element(root, 'RiskInformation9', RiskInformation9) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation49', ClientReferenceInformation49 ) new(risk_information: risk_information, client_reference_information: client_reference_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. risk_information = RiskInformation9.from_hash(hash['riskInformation']) if hash['riskInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation49.from_hash(hash['clientReferenceInformation']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FraudMarkingActionRequest.new(risk_information: risk_information, client_reference_information: client_reference_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['risk_information'] = 'riskInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 29 def self.optionals %w[ client_reference_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} risk_information: #{@risk_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 104 def to_s class_name = self.class.name.split('::').last "<#{class_name} risk_information: #{@risk_information}, client_reference_information:"\ " #{@client_reference_information}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_action_request.rb', line 90 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'RiskInformation9', risk_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation49', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |