Class: CyberSourceMergedSpec::GenerateCaptureContextException

Inherits:
APIException
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb

Overview

generateCaptureContextException class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ GenerateCaptureContextException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



23
24
25
26
27
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 23

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 18

def links
  @links
end

#response_statusResponseStatus

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 14

def response_status
  @response_status
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



47
48
49
50
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 47

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} response_status: #{@response_status.inspect}, links: #{@links.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



41
42
43
44
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 41

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} response_status: #{@response_status}, links: #{@links}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



32
33
34
35
36
37
38
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 32

def unbox(hash)
  return nil unless hash

  @response_status = ResponseStatus.from_hash(hash['responseStatus']) if
    hash['responseStatus']
  @links = Links211.from_hash(hash['_links']) if hash['_links']
end