Class: CyberSourceMergedSpec::GetAllSubscriptionsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb

Overview

GetAllSubscriptionsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, submit_time_utc: SKIP, total_count: SKIP, subscriptions: SKIP, additional_properties: nil) ⇒ GetAllSubscriptionsResponse

Returns a new instance of GetAllSubscriptionsResponse.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 57

def initialize(links: SKIP, submit_time_utc: SKIP, total_count: SKIP,
               subscriptions: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @total_count = total_count unless total_count == SKIP
  @subscriptions = subscriptions unless subscriptions == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 14

def links
  @links
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 22

def submit_time_utc
  @submit_time_utc
end

#subscriptionsArray[Subscription]

total number of subscriptions created

Returns:



30
31
32
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 30

def subscriptions
  @subscriptions
end

#total_countInteger

total number of subscriptions created

Returns:

  • (Integer)


26
27
28
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 26

def total_count
  @total_count
end

Class Method Details

.from_element(root) ⇒ Object



104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 104

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links227', Links227)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  total_count = XmlUtilities.from_element(root, 'totalCount', Integer)
  subscriptions = XmlUtilities.from_element_to_array(root, 'Subscription',
                                                     Subscription)

  new(links: links,
      submit_time_utc: submit_time_utc,
      total_count: total_count,
      subscriptions: subscriptions,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links227.from_hash(hash['_links']) if hash['_links']
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  total_count = hash.key?('totalCount') ? hash['totalCount'] : SKIP
  # Parameter is an array, so we need to iterate through it
  subscriptions = nil
  unless hash['subscriptions'].nil?
    subscriptions = []
    hash['subscriptions'].each do |structure|
      subscriptions << (Subscription.from_hash(structure) if structure)
    end
  end

  subscriptions = SKIP unless hash.key?('subscriptions')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetAllSubscriptionsResponse.new(links: links,
                                  submit_time_utc: submit_time_utc,
                                  total_count: total_count,
                                  subscriptions: subscriptions,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['total_count'] = 'totalCount'
  @_hash['subscriptions'] = 'subscriptions'
  @_hash
end

.nullablesObject

An array for nullable fields



53
54
55
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 53

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
48
49
50
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 43

def self.optionals
  %w[
    links
    submit_time_utc
    total_count
    subscriptions
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



142
143
144
145
146
147
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 142

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, submit_time_utc: #{@submit_time_utc.inspect},"\
  " total_count: #{@total_count.inspect}, subscriptions: #{@subscriptions.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



134
135
136
137
138
139
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 134

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, submit_time_utc: #{@submit_time_utc}, total_count:"\
  " #{@total_count}, subscriptions: #{@subscriptions}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/cyber_source_merged_spec/models/get_all_subscriptions_response.rb', line 118

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links227', links)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'totalCount', total_count)
  XmlUtilities.add_array_as_subelement(doc, root, 'Subscription',
                                       subscriptions)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end