Class: CyberSourceMergedSpec::GetSubscriptionCodeResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::GetSubscriptionCodeResponse
- Defined in:
- lib/cyber_source_merged_spec/models/get_subscription_code_response.rb
Overview
GetSubscriptionCodeResponse Model.
Instance Attribute Summary collapse
-
#code ⇒ String
Subscription code.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, submit_time_utc: SKIP, additional_properties: nil) ⇒ GetSubscriptionCodeResponse
constructor
A new instance of GetSubscriptionCodeResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, submit_time_utc: SKIP, additional_properties: nil) ⇒ GetSubscriptionCodeResponse
Returns a new instance of GetSubscriptionCodeResponse.
45 46 47 48 49 50 51 52 53 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 45 def initialize(code: SKIP, submit_time_utc: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
Subscription code.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 14 def code @code end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 22 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 77 def self.from_element(root) code = XmlUtilities.from_element(root, 'code', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) new(code: code, submit_time_utc: submit_time_utc, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetSubscriptionCodeResponse.new(code: code, submit_time_utc: submit_time_utc, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 33 def self.optionals %w[ code submit_time_utc ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
106 107 108 109 110 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 106 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, submit_time_utc: #{@submit_time_utc.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, submit_time_utc: #{@submit_time_utc},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/get_subscription_code_response.rb', line 86 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'code', code) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |