Class: CyberSourceMergedSpec::GetSubscriptionResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/get_subscription_response.rb

Overview

GetSubscriptionResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, plan_information: SKIP, subscription_information: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, reactivation_information: SKIP, additional_properties: nil) ⇒ GetSubscriptionResponse

Returns a new instance of GetSubscriptionResponse.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 115

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP,
               plan_information: SKIP, subscription_information: SKIP,
               payment_information: SKIP, order_information: SKIP,
               client_reference_information: SKIP,
               reactivation_information: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @plan_information = plan_information unless plan_information == SKIP
  @subscription_information = subscription_information unless subscription_information == SKIP
  @payment_information = payment_information unless payment_information == SKIP
  @order_information = order_information unless order_information == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @reactivation_information = reactivation_information unless reactivation_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation3

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.



70
71
72
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 70

def client_reference_information
  @client_reference_information
end

#idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 14

def links
  @links
end

#order_informationOrderInformation53

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:



62
63
64
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 62

def order_information
  @order_information
end

#payment_informationPaymentInformation40

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.



54
55
56
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 54

def payment_information
  @payment_information
end

#plan_informationPlanInformation9

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:



38
39
40
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 38

def plan_information
  @plan_information
end

#reactivation_informationReactivationInformation

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.



78
79
80
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 78

def reactivation_information
  @reactivation_information
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

#subscription_informationSubscriptionInformation2

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.



46
47
48
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 46

def subscription_information
  @subscription_information
end

Class Method Details

.from_element(root) ⇒ Object



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 183

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links235', Links235)
  id = XmlUtilities.from_element(root, 'id', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  plan_information = XmlUtilities.from_element(root, 'PlanInformation9',
                                               PlanInformation9)
  subscription_information = XmlUtilities.from_element(
    root, 'SubscriptionInformation2', SubscriptionInformation2
  )
  payment_information = XmlUtilities.from_element(root,
                                                  'PaymentInformation40',
                                                  PaymentInformation40)
  order_information = XmlUtilities.from_element(root, 'OrderInformation53',
                                                OrderInformation53)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation3',
    ClientReferenceInformation3
  )
  reactivation_information = XmlUtilities.from_element(
    root, 'ReactivationInformation', ReactivationInformation
  )

  new(links: links,
      id: id,
      submit_time_utc: submit_time_utc,
      plan_information: plan_information,
      subscription_information: subscription_information,
      payment_information: payment_information,
      order_information: order_information,
      client_reference_information: client_reference_information,
      reactivation_information: reactivation_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 139

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links235.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  plan_information = PlanInformation9.from_hash(hash['planInformation']) if
    hash['planInformation']
  if hash['subscriptionInformation']
    subscription_information = SubscriptionInformation2.from_hash(hash['subscriptionInformation'])
  end
  payment_information = PaymentInformation40.from_hash(hash['paymentInformation']) if
    hash['paymentInformation']
  order_information = OrderInformation53.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation'])
  end
  if hash['reactivationInformation']
    reactivation_information = ReactivationInformation.from_hash(hash['reactivationInformation'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetSubscriptionResponse.new(links: links,
                              id: id,
                              submit_time_utc: submit_time_utc,
                              plan_information: plan_information,
                              subscription_information: subscription_information,
                              payment_information: payment_information,
                              order_information: order_information,
                              client_reference_information: client_reference_information,
                              reactivation_information: reactivation_information,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 81

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['plan_information'] = 'planInformation'
  @_hash['subscription_information'] = 'subscriptionInformation'
  @_hash['payment_information'] = 'paymentInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['reactivation_information'] = 'reactivationInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



111
112
113
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 111

def self.nullables
  []
end

.optionalsObject

An array for optional fields



96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 96

def self.optionals
  %w[
    links
    id
    submit_time_utc
    plan_information
    subscription_information
    payment_information
    order_information
    client_reference_information
    reactivation_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



254
255
256
257
258
259
260
261
262
263
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 254

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, plan_information: #{@plan_information.inspect},"\
  " subscription_information: #{@subscription_information.inspect}, payment_information:"\
  " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\
  " client_reference_information: #{@client_reference_information.inspect},"\
  " reactivation_information: #{@reactivation_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



243
244
245
246
247
248
249
250
251
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 243

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc},"\
  " plan_information: #{@plan_information}, subscription_information:"\
  " #{@subscription_information}, payment_information: #{@payment_information},"\
  " order_information: #{@order_information}, client_reference_information:"\
  " #{@client_reference_information}, reactivation_information: #{@reactivation_information},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/cyber_source_merged_spec/models/get_subscription_response.rb', line 217

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links235', links)
  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'PlanInformation9',
                                 plan_information)
  XmlUtilities.add_as_subelement(doc, root, 'SubscriptionInformation2',
                                 subscription_information)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation40',
                                 payment_information)
  XmlUtilities.add_as_subelement(doc, root, 'OrderInformation53',
                                 order_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation3',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'ReactivationInformation',
                                 reactivation_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end