Class: CyberSourceMergedSpec::GetSubscriptionResponse1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/get_subscription_response1.rb

Overview

GetSubscriptionResponse1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, buyer_information: SKIP, payment_instrument: SKIP, shipping_address: SKIP, additional_properties: nil) ⇒ GetSubscriptionResponse1

Returns a new instance of GetSubscriptionResponse1.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 53

def initialize(links: SKIP, buyer_information: SKIP,
               payment_instrument: SKIP, shipping_address: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @buyer_information = buyer_information unless buyer_information == SKIP
  @payment_instrument = payment_instrument unless payment_instrument == SKIP
  @shipping_address = shipping_address unless shipping_address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#buyer_informationBuyerInformation43

Customer information used during Follow-On Transaction.

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 18

def buyer_information
  @buyer_information
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 14

def links
  @links
end

#payment_instrumentPaymentInstrument25

Payment instrument used during Follow-On Transaction.

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 22

def payment_instrument
  @payment_instrument
end

#shipping_addressShippingAddress21

Shipping address used during Follow-On Transaction.

Returns:



26
27
28
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 26

def shipping_address
  @shipping_address
end

Class Method Details

.from_element(root) ⇒ Object



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 94

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links241', Links241)
  buyer_information = XmlUtilities.from_element(root, 'BuyerInformation43',
                                                BuyerInformation43)
  payment_instrument = XmlUtilities.from_element(root,
                                                 'PaymentInstrument25',
                                                 PaymentInstrument25)
  shipping_address = XmlUtilities.from_element(root, 'ShippingAddress21',
                                               ShippingAddress21)

  new(links: links,
      buyer_information: buyer_information,
      payment_instrument: payment_instrument,
      shipping_address: shipping_address,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links241.from_hash(hash['_links']) if hash['_links']
  buyer_information = BuyerInformation43.from_hash(hash['buyerInformation']) if
    hash['buyerInformation']
  payment_instrument = PaymentInstrument25.from_hash(hash['paymentInstrument']) if
    hash['paymentInstrument']
  shipping_address = ShippingAddress21.from_hash(hash['shippingAddress']) if
    hash['shippingAddress']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  GetSubscriptionResponse1.new(links: links,
                               buyer_information: buyer_information,
                               payment_instrument: payment_instrument,
                               shipping_address: shipping_address,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['buyer_information'] = 'buyerInformation'
  @_hash['payment_instrument'] = 'paymentInstrument'
  @_hash['shipping_address'] = 'shippingAddress'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 39

def self.optionals
  %w[
    links
    buyer_information
    payment_instrument
    shipping_address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



136
137
138
139
140
141
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 136

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, buyer_information: #{@buyer_information.inspect},"\
  " payment_instrument: #{@payment_instrument.inspect}, shipping_address:"\
  " #{@shipping_address.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



128
129
130
131
132
133
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 128

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, buyer_information: #{@buyer_information},"\
  " payment_instrument: #{@payment_instrument}, shipping_address: #{@shipping_address},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/cyber_source_merged_spec/models/get_subscription_response1.rb', line 111

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links241', links)
  XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation43',
                                 buyer_information)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentInstrument25',
                                 payment_instrument)
  XmlUtilities.add_as_subelement(doc, root, 'ShippingAddress21',
                                 shipping_address)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end