Class: CyberSourceMergedSpec::GetTokenizedCardResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::GetTokenizedCardResponse
- Defined in:
- lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb
Overview
GetTokenizedCardResponse Model.
Instance Attribute Summary collapse
-
#links ⇒ Links39
TODO: Write general description for this method.
-
#tokenized_card ⇒ TokenizedCard9
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ GetTokenizedCardResponse
constructor
A new instance of GetTokenizedCardResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ GetTokenizedCardResponse
Returns a new instance of GetTokenizedCardResponse.
41 42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 41 def initialize(links: SKIP, tokenized_card: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @tokenized_card = tokenized_card unless tokenized_card == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#links ⇒ Links39
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 14 def links @links end |
#tokenized_card ⇒ TokenizedCard9
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 18 def tokenized_card @tokenized_card end |
Class Method Details
.from_element(root) ⇒ Object
72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 72 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links39', Links39) tokenized_card = XmlUtilities.from_element(root, 'TokenizedCard9', TokenizedCard9) new(links: links, tokenized_card: tokenized_card, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links39.from_hash(hash['_links']) if hash['_links'] tokenized_card = TokenizedCard9.from_hash(hash['tokenizedCard']) if hash['tokenizedCard'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetTokenizedCardResponse.new(links: links, tokenized_card: tokenized_card, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['tokenized_card'] = 'tokenizedCard' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 29 def self.optionals %w[ links tokenized_card ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, tokenized_card: #{@tokenized_card.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, tokenized_card: #{@tokenized_card},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/get_tokenized_card_response.rb', line 82 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links39', links) XmlUtilities.add_as_subelement(doc, root, 'TokenizedCard9', tokenized_card) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |