Class: CyberSourceMergedSpec::HeaderStyle

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/header_style.rb

Overview

HeaderStyle Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(font_color: SKIP, background_color: SKIP, additional_properties: nil) ⇒ HeaderStyle

Returns a new instance of HeaderStyle.



43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 43

def initialize(font_color: SKIP, background_color: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @font_color = font_color unless font_color == SKIP
  @background_color = background_color unless background_color == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#background_colorString

The invoice background color. The format is a valid hexadecimal code prefixed with #, such as #ffffff for white.

Returns:

  • (String)


20
21
22
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 20

def background_color
  @background_color
end

#font_colorString

The invoice font color. The format is a valid hexadecimal code prefixed with #, such as #000000 for black.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 15

def font_color
  @font_color
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 75

def self.from_element(root)
  font_color = XmlUtilities.from_element(root, 'fontColor', String)
  background_color = XmlUtilities.from_element(root, 'backgroundColor',
                                               String)

  new(font_color: font_color,
      background_color: background_color,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  font_color = hash.key?('fontColor') ? hash['fontColor'] : SKIP
  background_color =
    hash.key?('backgroundColor') ? hash['backgroundColor'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  HeaderStyle.new(font_color: font_color,
                  background_color: background_color,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['font_color'] = 'fontColor'
  @_hash['background_color'] = 'backgroundColor'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 31

def self.optionals
  %w[
    font_color
    background_color
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} font_color: #{@font_color.inspect}, background_color:"\
  " #{@background_color.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} font_color: #{@font_color}, background_color: #{@background_color},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/header_style.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'fontColor', font_color)
  XmlUtilities.add_as_subelement(doc, root, 'backgroundColor',
                                 background_color)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end