Class: CyberSourceMergedSpec::Initiator1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Initiator1
- Defined in:
- lib/cyber_source_merged_spec/models/initiator1.rb
Overview
Initiator1 Model.
Instance Attribute Summary collapse
-
#stored_credential_used ⇒ TrueClass | FalseClass
Indicates to an issuing bank whether a merchant-initiated transaction came from a card that was already stored on file.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(stored_credential_used: SKIP, additional_properties: nil) ⇒ Initiator1
constructor
A new instance of Initiator1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(stored_credential_used: SKIP, additional_properties: nil) ⇒ Initiator1
Returns a new instance of Initiator1.
41 42 43 44 45 46 47 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 41 def initialize(stored_credential_used: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @stored_credential_used = stored_credential_used unless stored_credential_used == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#stored_credential_used ⇒ TrueClass | FalseClass
Indicates to an issuing bank whether a merchant-initiated transaction came from a card that was already stored on file. Possible values:
- true means the merchant-initiated transaction came from a card that was already stored on file.
- false means the merchant-initiated transaction came from a card that was not stored on file.
20 21 22 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 20 def stored_credential_used @stored_credential_used end |
Class Method Details
.from_element(root) ⇒ Object
69 70 71 72 73 74 75 76 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 69 def self.from_element(root) stored_credential_used = XmlUtilities.from_element(root, 'storedCredentialUsed', TrueClass) new(stored_credential_used: stored_credential_used, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. stored_credential_used = hash.key?('storedCredentialUsed') ? hash['storedCredentialUsed'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Initiator1.new(stored_credential_used: stored_credential_used, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['stored_credential_used'] = 'storedCredentialUsed' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 30 def self.optionals %w[ stored_credential_used ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} stored_credential_used: #{@stored_credential_used.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 90 def to_s class_name = self.class.name.split('::').last "<#{class_name} stored_credential_used: #{@stored_credential_used}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/cyber_source_merged_spec/models/initiator1.rb', line 78 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'storedCredentialUsed', stored_credential_used) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |