Class: CyberSourceMergedSpec::Initiator2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/initiator2.rb

Overview

Initiator2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(merchant_initiated_transaction: SKIP, additional_properties: nil) ⇒ Initiator2

Returns a new instance of Initiator2.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 36

def initialize(merchant_initiated_transaction: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless merchant_initiated_transaction == SKIP
    @merchant_initiated_transaction =
      merchant_initiated_transaction
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#merchant_initiated_transactionMerchantInitiatedTransaction1

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 14

def merchant_initiated_transaction
  @merchant_initiated_transaction
end

Class Method Details

.from_element(root) ⇒ Object



69
70
71
72
73
74
75
76
77
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 69

def self.from_element(root)
  merchant_initiated_transaction = XmlUtilities.from_element(
    root, 'MerchantInitiatedTransaction1',
    MerchantInitiatedTransaction1
  )

  new(merchant_initiated_transaction: merchant_initiated_transaction,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  if hash['merchantInitiatedTransaction']
    merchant_initiated_transaction = MerchantInitiatedTransaction1.from_hash(hash['merchantInitiatedTransaction'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Initiator2.new(merchant_initiated_transaction: merchant_initiated_transaction,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
22
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['merchant_initiated_transaction'] =
    'merchantInitiatedTransaction'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 25

def self.optionals
  %w[
    merchant_initiated_transaction
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_initiated_transaction: #{@merchant_initiated_transaction.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_initiated_transaction: #{@merchant_initiated_transaction},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/initiator2.rb', line 79

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'MerchantInitiatedTransaction1',
                                 merchant_initiated_transaction)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end