Class: CyberSourceMergedSpec::InstallmentInformation10
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::InstallmentInformation10
- Defined in:
- lib/cyber_source_merged_spec/models/installment_information10.rb
Overview
InstallmentInformation10 Model.
Instance Attribute Summary collapse
-
#identifier ⇒ String
Standing Instruction/Installment identifier.
-
#number_of_installments ⇒ String
Number of Installments.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number_of_installments: SKIP, identifier: SKIP, additional_properties: nil) ⇒ InstallmentInformation10
constructor
A new instance of InstallmentInformation10.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number_of_installments: SKIP, identifier: SKIP, additional_properties: nil) ⇒ InstallmentInformation10
Returns a new instance of InstallmentInformation10.
41 42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 41 def initialize(number_of_installments: SKIP, identifier: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number_of_installments = number_of_installments unless number_of_installments == SKIP @identifier = identifier unless identifier == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#identifier ⇒ String
Standing Instruction/Installment identifier.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 18 def identifier @identifier end |
#number_of_installments ⇒ String
Number of Installments.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 14 def number_of_installments @number_of_installments end |
Class Method Details
.from_element(root) ⇒ Object
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 73 def self.from_element(root) number_of_installments = XmlUtilities.from_element(root, 'numberOfInstallments', String) identifier = XmlUtilities.from_element(root, 'identifier', String) new(number_of_installments: number_of_installments, identifier: identifier, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number_of_installments = hash.key?('numberOfInstallments') ? hash['numberOfInstallments'] : SKIP identifier = hash.key?('identifier') ? hash['identifier'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstallmentInformation10.new(number_of_installments: number_of_installments, identifier: identifier, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['number_of_installments'] = 'numberOfInstallments' @_hash['identifier'] = 'identifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 29 def self.optionals %w[ number_of_installments identifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} number_of_installments: #{@number_of_installments.inspect}, identifier:"\ " #{@identifier.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} number_of_installments: #{@number_of_installments}, identifier:"\ " #{@identifier}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/installment_information10.rb', line 84 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'numberOfInstallments', number_of_installments) XmlUtilities.add_as_subelement(doc, root, 'identifier', identifier) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |