Class: CyberSourceMergedSpec::InstrumentIdentifier35
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::InstrumentIdentifier35
- Defined in:
- lib/cyber_source_merged_spec/models/instrument_identifier35.rb
Overview
A GET link to the instrument identifier used in the AFT
Instance Attribute Summary collapse
-
#href ⇒ String
This is the endpoint of the resource that was created by the successful request.
-
#method ⇒ String
methodrefers to the HTTP method that you can send to theselfendpoint to retrieve details of the resource.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(href: SKIP, method: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier35
constructor
A new instance of InstrumentIdentifier35.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(href: SKIP, method: SKIP, additional_properties: nil) ⇒ InstrumentIdentifier35
Returns a new instance of InstrumentIdentifier35.
43 44 45 46 47 48 49 50 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 43 def initialize(href: SKIP, method: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @href = href unless href == SKIP @method = method unless method == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#href ⇒ String
This is the endpoint of the resource that was created by the successful request.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 15 def href @href end |
#method ⇒ String
method refers to the HTTP method that you can send to the self
endpoint to retrieve details of the resource.
20 21 22 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 20 def method @method end |
Class Method Details
.from_element(root) ⇒ Object
73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 73 def self.from_element(root) href = XmlUtilities.from_element(root, 'href', String) method = XmlUtilities.from_element(root, 'method', String) new(href: href, method: method, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. href = hash.key?('href') ? hash['href'] : SKIP method = hash.key?('method') ? hash['method'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstrumentIdentifier35.new(href: href, method: method, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['href'] = 'href' @_hash['method'] = 'method' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 31 def self.optionals %w[ href method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} href: #{@href.inspect}, method: #{@method.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} href: #{@href}, method: #{@method}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/instrument_identifier35.rb', line 82 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'href', href) XmlUtilities.add_as_subelement(doc, root, 'method', method) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |