Class: CyberSourceMergedSpec::IntimateBillingAgreement
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::IntimateBillingAgreement
- Defined in:
- lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb
Overview
IntimateBillingAgreement Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation
TODO: Write general description for this method.
-
#installment_information ⇒ InstallmentInformation4
TODO: Write general description for this method.
-
#merchant_information ⇒ MerchantInformation12
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation20
TODO: Write general description for this method.
-
#payment_information ⇒ PaymentInformation16
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(client_reference_information: SKIP, installment_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, additional_properties: nil) ⇒ IntimateBillingAgreement
constructor
A new instance of IntimateBillingAgreement.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(client_reference_information: SKIP, installment_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, additional_properties: nil) ⇒ IntimateBillingAgreement
Returns a new instance of IntimateBillingAgreement.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 59 def initialize(client_reference_information: SKIP, installment_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless client_reference_information == SKIP @client_reference_information = client_reference_information end @installment_information = installment_information unless installment_information == SKIP @merchant_information = merchant_information unless merchant_information == SKIP @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 14 def client_reference_information @client_reference_information end |
#installment_information ⇒ InstallmentInformation4
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 18 def installment_information @installment_information end |
#merchant_information ⇒ MerchantInformation12
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 22 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation20
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 26 def order_information @order_information end |
#payment_information ⇒ PaymentInformation16
TODO: Write general description for this method
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 30 def payment_information @payment_information end |
Class Method Details
.from_element(root) ⇒ Object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 110 def self.from_element(root) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation', ClientReferenceInformation ) installment_information = XmlUtilities.from_element( root, 'InstallmentInformation4', InstallmentInformation4 ) merchant_information = XmlUtilities.from_element(root, 'MerchantInformation12', MerchantInformation12) order_information = XmlUtilities.from_element(root, 'OrderInformation20', OrderInformation20) payment_information = XmlUtilities.from_element(root, 'PaymentInformation16', PaymentInformation16) new(client_reference_information: client_reference_information, installment_information: installment_information, merchant_information: merchant_information, order_information: order_information, payment_information: payment_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 78 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation.from_hash(hash['clientReferenceInformation']) end installment_information = InstallmentInformation4.from_hash(hash['installmentInformation']) if hash['installmentInformation'] merchant_information = MerchantInformation12.from_hash(hash['merchantInformation']) if hash['merchantInformation'] order_information = OrderInformation20.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation16.from_hash(hash['paymentInformation']) if hash['paymentInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IntimateBillingAgreement.new(client_reference_information: client_reference_information, installment_information: installment_information, merchant_information: merchant_information, order_information: order_information, payment_information: payment_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['installment_information'] = 'installmentInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 44 def self.optionals %w[ client_reference_information installment_information merchant_information order_information payment_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
164 165 166 167 168 169 170 171 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 164 def inspect class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\ " installment_information: #{@installment_information.inspect}, merchant_information:"\ " #{@merchant_information.inspect}, order_information: #{@order_information.inspect},"\ " payment_information: #{@payment_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
155 156 157 158 159 160 161 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 155 def to_s class_name = self.class.name.split('::').last "<#{class_name} client_reference_information: #{@client_reference_information},"\ " installment_information: #{@installment_information}, merchant_information:"\ " #{@merchant_information}, order_information: #{@order_information}, payment_information:"\ " #{@payment_information}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/cyber_source_merged_spec/models/intimate_billing_agreement.rb', line 135 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'InstallmentInformation4', installment_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation12', merchant_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation20', order_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation16', payment_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |