Class: CyberSourceMergedSpec::Invoice
- Defined in:
- lib/cyber_source_merged_spec/models/invoice.rb
Overview
Invoice Model.
Instance Attribute Summary collapse
-
#barcode_number ⇒ String
Barcode Number.
-
#expiration_date ⇒ String
Expiration Date.
-
#number ⇒ String
Invoice Number.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number: SKIP, barcode_number: SKIP, expiration_date: SKIP, additional_properties: nil) ⇒ Invoice
constructor
A new instance of Invoice.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number: SKIP, barcode_number: SKIP, expiration_date: SKIP, additional_properties: nil) ⇒ Invoice
Returns a new instance of Invoice.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 47 def initialize(number: SKIP, barcode_number: SKIP, expiration_date: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number = number unless number == SKIP @barcode_number = unless == SKIP @expiration_date = expiration_date unless expiration_date == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#barcode_number ⇒ String
Barcode Number.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 18 def @barcode_number end |
#expiration_date ⇒ String
Expiration Date.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 22 def expiration_date @expiration_date end |
#number ⇒ String
Invoice Number.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 14 def number @number end |
Class Method Details
.from_element(root) ⇒ Object
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 82 def self.from_element(root) number = XmlUtilities.from_element(root, 'number', String) = XmlUtilities.from_element(root, 'barcodeNumber', String) expiration_date = XmlUtilities.from_element(root, 'expirationDate', String) new(number: number, barcode_number: , expiration_date: expiration_date, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number = hash.key?('number') ? hash['number'] : SKIP = hash.key?('barcodeNumber') ? hash['barcodeNumber'] : SKIP expiration_date = hash.key?('expirationDate') ? hash['expirationDate'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Invoice.new(number: number, barcode_number: , expiration_date: expiration_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['number'] = 'number' @_hash['barcode_number'] = 'barcodeNumber' @_hash['expiration_date'] = 'expirationDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 34 def self.optionals %w[ number barcode_number expiration_date ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 120 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} number: #{@number.inspect}, barcode_number: #{@barcode_number.inspect},"\ " expiration_date: #{@expiration_date.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} number: #{@number}, barcode_number: #{@barcode_number}, expiration_date:"\ " #{@expiration_date}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/invoice.rb', line 94 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'number', number) XmlUtilities.add_as_subelement(doc, root, 'barcodeNumber', ) XmlUtilities.add_as_subelement(doc, root, 'expirationDate', expiration_date) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |