Class: CyberSourceMergedSpec::InvoiceDetails15

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/invoice_details15.rb

Overview

InvoiceDetails15 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(cost_center: SKIP, product_description: SKIP, additional_properties: nil) ⇒ InvoiceDetails15

Returns a new instance of InvoiceDetails15.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 41

def initialize(cost_center: SKIP, product_description: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cost_center = cost_center unless cost_center == SKIP
  @product_description = product_description unless product_description == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cost_centerString

Cost centre of the merchant.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 14

def cost_center
  @cost_center
end

#product_descriptionString

Brief description of item.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 18

def product_description
  @product_description
end

Class Method Details

.from_element(root) ⇒ Object



73
74
75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 73

def self.from_element(root)
  cost_center = XmlUtilities.from_element(root, 'costCenter', String)
  product_description = XmlUtilities.from_element(root,
                                                  'productDescription',
                                                  String)

  new(cost_center: cost_center,
      product_description: product_description,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  cost_center = hash.key?('costCenter') ? hash['costCenter'] : SKIP
  product_description =
    hash.key?('productDescription') ? hash['productDescription'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvoiceDetails15.new(cost_center: cost_center,
                       product_description: product_description,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cost_center'] = 'costCenter'
  @_hash['product_description'] = 'productDescription'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 29

def self.optionals
  %w[
    cost_center
    product_description
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cost_center: #{@cost_center.inspect}, product_description:"\
  " #{@product_description.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cost_center: #{@cost_center}, product_description: #{@product_description},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/invoice_details15.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'costCenter', cost_center)
  XmlUtilities.add_as_subelement(doc, root, 'productDescription',
                                 product_description)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end