Class: CyberSourceMergedSpec::InvoiceDetails19

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/invoice_details19.rb

Overview

InvoiceDetails19 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sales_slip_number: SKIP, additional_properties: nil) ⇒ InvoiceDetails19

Returns a new instance of InvoiceDetails19.



50
51
52
53
54
55
56
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 50

def initialize(sales_slip_number: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @sales_slip_number = sales_slip_number unless sales_slip_number == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#sales_slip_numberInteger

Transaction identifier that is generated. You have the option of printing the sales slip number on the receipt. This field is supported only on Cybersource through Visanet and JCN gateway. Optional field.

Card Present processing message

If you included this field in the request, the returned value is the value that you sent in the request. If you did not include this field in the request, the system generated this value for you. The difference between this reply field and the processorInformation.systemTraceAuditNumber field is that the system generates the system trace audit number (STAN), and you must print the receipt number on the receipt; whereas you can generate the sales slip number, and you can choose to print the sales slip number on the receipt.

Returns:

  • (Integer)


29
30
31
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 29

def sales_slip_number
  @sales_slip_number
end

Class Method Details

.from_element(root) ⇒ Object



78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 78

def self.from_element(root)
  sales_slip_number = XmlUtilities.from_element(root, 'salesSlipNumber',
                                                Integer)

  new(sales_slip_number: sales_slip_number,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sales_slip_number =
    hash.key?('salesSlipNumber') ? hash['salesSlipNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvoiceDetails19.new(sales_slip_number: sales_slip_number,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 32

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sales_slip_number'] = 'salesSlipNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 39

def self.optionals
  %w[
    sales_slip_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sales_slip_number: #{@sales_slip_number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sales_slip_number: #{@sales_slip_number}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/invoice_details19.rb', line 86

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'salesSlipNumber',
                                 sales_slip_number)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end