Class: CyberSourceMergedSpec::InvoiceDetails5
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::InvoiceDetails5
- Defined in:
- lib/cyber_source_merged_spec/models/invoice_details5.rb
Overview
InvoiceDetails5 Model.
Instance Attribute Summary collapse
-
#level3_transmission_status ⇒ String
Indicates whether CyberSource sent the Level III information to the processor.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(level3_transmission_status: SKIP, additional_properties: nil) ⇒ InvoiceDetails5
constructor
A new instance of InvoiceDetails5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(level3_transmission_status: SKIP, additional_properties: nil) ⇒ InvoiceDetails5
Returns a new instance of InvoiceDetails5.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 43 def initialize(level3_transmission_status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless level3_transmission_status == SKIP @level3_transmission_status = level3_transmission_status end @additional_properties = additional_properties end |
Instance Attribute Details
#level3_transmission_status ⇒ String
Indicates whether CyberSource sent the Level III information to the processor. The possible values are: If your account is not enabled for Level III data or if you did not include the purchasing level field in your request, CyberSource does not include the Level III data in the request sent to the processor. Possible values:
- Y for true
- N for false
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 22 def level3_transmission_status @level3_transmission_status end |
Class Method Details
.from_element(root) ⇒ Object
74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 74 def self.from_element(root) level3_transmission_status = XmlUtilities.from_element( root, 'level3TransmissionStatus', String ) new(level3_transmission_status: level3_transmission_status, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. level3_transmission_status = hash.key?('level3TransmissionStatus') ? hash['level3TransmissionStatus'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InvoiceDetails5.new(level3_transmission_status: level3_transmission_status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['level3_transmission_status'] = 'level3TransmissionStatus' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 32 def self.optionals %w[ level3_transmission_status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} level3_transmission_status: #{@level3_transmission_status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} level3_transmission_status: #{@level3_transmission_status},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/invoice_details5.rb', line 83 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'level3TransmissionStatus', level3_transmission_status) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |