Class: CyberSourceMergedSpec::InvoiceInformation2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/invoice_information2.rb

Overview

InvoiceInformation2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(due_date: SKIP, expiration_date: SKIP, additional_properties: nil) ⇒ InvoiceInformation2

Returns a new instance of InvoiceInformation2.



43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 43

def initialize(due_date: SKIP, expiration_date: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @due_date = due_date unless due_date == SKIP
  @expiration_date = expiration_date unless expiration_date == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#due_dateDate

The invoice due date. This field is required for creating an invoice. Format: YYYY-MM-DD, where YYYY = year, MM = month, and DD = day

Returns:

  • (Date)


15
16
17
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 15

def due_date
  @due_date
end

#expiration_dateDate

Define an expiration date for the link. Format: YYYY-MM-DD, where YYYY = year, MM = month, and DD = day

Returns:

  • (Date)


20
21
22
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 20

def expiration_date
  @expiration_date
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 75

def self.from_element(root)
  due_date = XmlUtilities.from_element(root, 'dueDate', String)
  expiration_date = XmlUtilities.from_element(root, 'expirationDate',
                                              String)

  new(due_date: due_date,
      expiration_date: expiration_date,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  due_date = hash.key?('dueDate') ? hash['dueDate'] : SKIP
  expiration_date =
    hash.key?('expirationDate') ? hash['expirationDate'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvoiceInformation2.new(due_date: due_date,
                          expiration_date: expiration_date,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['due_date'] = 'dueDate'
  @_hash['expiration_date'] = 'expirationDate'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 31

def self.optionals
  %w[
    due_date
    expiration_date
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} due_date: #{@due_date.inspect}, expiration_date:"\
  " #{@expiration_date.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} due_date: #{@due_date}, expiration_date: #{@expiration_date},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/invoice_information2.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'dueDate', due_date)
  XmlUtilities.add_as_subelement(doc, root, 'expirationDate',
                                 expiration_date)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end