Class: CyberSourceMergedSpec::InvoicingV2InvoiceSettingsGet200Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::InvoicingV2InvoiceSettingsGet200Response
- Defined in:
- lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb
Overview
InvoicingV2InvoiceSettingsGet200Response Model.
Instance Attribute Summary collapse
-
#invoice_settings_information ⇒ InvoiceSettingsInformation1
Time of request in UTC.
-
#merchant_information ⇒ MerchantInformation27
Time of request in UTC.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(submit_time_utc: SKIP, invoice_settings_information: SKIP, merchant_information: SKIP, additional_properties: nil) ⇒ InvoicingV2InvoiceSettingsGet200Response
constructor
A new instance of InvoicingV2InvoiceSettingsGet200Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(submit_time_utc: SKIP, invoice_settings_information: SKIP, merchant_information: SKIP, additional_properties: nil) ⇒ InvoicingV2InvoiceSettingsGet200Response
Returns a new instance of InvoicingV2InvoiceSettingsGet200Response.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 59 def initialize(submit_time_utc: SKIP, invoice_settings_information: SKIP, merchant_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP unless invoice_settings_information == SKIP @invoice_settings_information = invoice_settings_information end @merchant_information = merchant_information unless merchant_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#invoice_settings_information ⇒ InvoiceSettingsInformation1
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 26 def invoice_settings_information @invoice_settings_information end |
#merchant_information ⇒ MerchantInformation27
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 34 def merchant_information @merchant_information end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 18 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 100 def self.from_element(root) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) invoice_settings_information = XmlUtilities.from_element( root, 'InvoiceSettingsInformation1', InvoiceSettingsInformation1 ) merchant_information = XmlUtilities.from_element(root, 'MerchantInformation27', MerchantInformation27) new(submit_time_utc: submit_time_utc, invoice_settings_information: invoice_settings_information, merchant_information: merchant_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 74 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP if hash['invoiceSettingsInformation'] invoice_settings_information = InvoiceSettingsInformation1.from_hash(hash['invoiceSettingsInformation']) end merchant_information = MerchantInformation27.from_hash(hash['merchantInformation']) if hash['merchantInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InvoicingV2InvoiceSettingsGet200Response.new(submit_time_utc: submit_time_utc, invoice_settings_information: invoice_settings_information, merchant_information: merchant_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['invoice_settings_information'] = 'invoiceSettingsInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 46 def self.optionals %w[ submit_time_utc invoice_settings_information merchant_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
140 141 142 143 144 145 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 140 def inspect class_name = self.class.name.split('::').last "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, invoice_settings_information:"\ " #{@invoice_settings_information.inspect}, merchant_information:"\ " #{@merchant_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
132 133 134 135 136 137 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 132 def to_s class_name = self.class.name.split('::').last "<#{class_name} submit_time_utc: #{@submit_time_utc}, invoice_settings_information:"\ " #{@invoice_settings_information}, merchant_information: #{@merchant_information},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoice_settings_get200_response.rb', line 116 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'InvoiceSettingsInformation1', invoice_settings_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation27', merchant_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |