Class: CyberSourceMergedSpec::InvoicingV2InvoicesAllGet200Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb

Overview

InvoicingV2InvoicesAllGet200Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, submit_time_utc: SKIP, total_invoices: SKIP, invoices: SKIP, additional_properties: nil) ⇒ InvoicingV2InvoicesAllGet200Response

Returns a new instance of InvoicingV2InvoicesAllGet200Response.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 65

def initialize(links: SKIP, submit_time_utc: SKIP, total_invoices: SKIP,
               invoices: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @total_invoices = total_invoices unless total_invoices == SKIP
  @invoices = invoices unless invoices == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#invoicesArray[Invoice1]

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:



38
39
40
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 38

def invoices
  @invoices
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 14

def links
  @links
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 22

def submit_time_utc
  @submit_time_utc
end

#total_invoicesInteger

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (Integer)


30
31
32
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 30

def total_invoices
  @total_invoices
end

Class Method Details

.from_element(root) ⇒ Object



112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 112

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links251', Links251)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  total_invoices = XmlUtilities.from_element(root, 'totalInvoices', Integer)
  invoices = XmlUtilities.from_element_to_array(root, 'Invoice1', Invoice1)

  new(links: links,
      submit_time_utc: submit_time_utc,
      total_invoices: total_invoices,
      invoices: invoices,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 78

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links251.from_hash(hash['_links']) if hash['_links']
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  total_invoices = hash.key?('totalInvoices') ? hash['totalInvoices'] : SKIP
  # Parameter is an array, so we need to iterate through it
  invoices = nil
  unless hash['invoices'].nil?
    invoices = []
    hash['invoices'].each do |structure|
      invoices << (Invoice1.from_hash(structure) if structure)
    end
  end

  invoices = SKIP unless hash.key?('invoices')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvoicingV2InvoicesAllGet200Response.new(links: links,
                                           submit_time_utc: submit_time_utc,
                                           total_invoices: total_invoices,
                                           invoices: invoices,
                                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['total_invoices'] = 'totalInvoices'
  @_hash['invoices'] = 'invoices'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



51
52
53
54
55
56
57
58
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 51

def self.optionals
  %w[
    links
    submit_time_utc
    total_invoices
    invoices
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



148
149
150
151
152
153
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 148

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, submit_time_utc: #{@submit_time_utc.inspect},"\
  " total_invoices: #{@total_invoices.inspect}, invoices: #{@invoices.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



140
141
142
143
144
145
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 140

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, submit_time_utc: #{@submit_time_utc}, total_invoices:"\
  " #{@total_invoices}, invoices: #{@invoices}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_all_get200_response.rb', line 125

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links251', links)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'totalInvoices', total_invoices)
  XmlUtilities.add_array_as_subelement(doc, root, 'Invoice1', invoices)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end