Class: CyberSourceMergedSpec::InvoicingV2InvoicesCancel200Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::InvoicingV2InvoicesCancel200Response
- Defined in:
- lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb
Overview
InvoicingV2InvoicesCancel200Response Model.
Instance Attribute Summary collapse
-
#customer_information ⇒ CustomerInformation
Contains all of the customer-related fields for the invoice.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#invoice_information ⇒ InvoiceInformation1
Contains all of the invoice-specific fields, such as the invoice number and due date.
-
#links ⇒ Links251
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation61
Contains all of the order-related fields, such as the amount and line item details.
-
#processing_information ⇒ ProcessingInformation72
Contains processing information, such as collection details.
-
#status ⇒ String
The status of the invoice.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, customer_information: SKIP, processing_information: SKIP, invoice_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ InvoicingV2InvoicesCancel200Response
constructor
A new instance of InvoicingV2InvoicesCancel200Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, customer_information: SKIP, processing_information: SKIP, invoice_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ InvoicingV2InvoicesCancel200Response
Returns a new instance of InvoicingV2InvoicesCancel200Response.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 95 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, customer_information: SKIP, processing_information: SKIP, invoice_information: SKIP, order_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @customer_information = customer_information unless customer_information == SKIP @processing_information = processing_information unless processing_information == SKIP @invoice_information = invoice_information unless invoice_information == SKIP @order_information = order_information unless order_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#customer_information ⇒ CustomerInformation
Contains all of the customer-related fields for the invoice.
46 47 48 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 46 def customer_information @customer_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 22 def id @id end |
#invoice_information ⇒ InvoiceInformation1
Contains all of the invoice-specific fields, such as the invoice number and due date.
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 55 def invoice_information @invoice_information end |
#links ⇒ Links251
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 14 def links @links end |
#order_information ⇒ OrderInformation61
Contains all of the order-related fields, such as the amount and line item details.
60 61 62 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 60 def order_information @order_information end |
#processing_information ⇒ ProcessingInformation72
Contains processing information, such as collection details.
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 50 def processing_information @processing_information end |
#status ⇒ String
The status of the invoice. Possible values:
- DRAFT
- CREATED
- SENT
- PARTIAL
- PAID
- CANCELED
- PENDING
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 42 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 151 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links251', Links251) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) customer_information = XmlUtilities.from_element(root, 'CustomerInformation', CustomerInformation) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation72', ProcessingInformation72 ) invoice_information = XmlUtilities.from_element(root, 'InvoiceInformation1', InvoiceInformation1) order_information = XmlUtilities.from_element(root, 'OrderInformation61', OrderInformation61) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, customer_information: customer_information, processing_information: processing_information, invoice_information: invoice_information, order_information: order_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 114 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links251.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP customer_information = CustomerInformation.from_hash(hash['customerInformation']) if hash['customerInformation'] processing_information = ProcessingInformation72.from_hash(hash['processingInformation']) if hash['processingInformation'] invoice_information = InvoiceInformation1.from_hash(hash['invoiceInformation']) if hash['invoiceInformation'] order_information = OrderInformation61.from_hash(hash['orderInformation']) if hash['orderInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InvoicingV2InvoicesCancel200Response.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, customer_information: customer_information, processing_information: processing_information, invoice_information: invoice_information, order_information: order_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 63 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['customer_information'] = 'customerInformation' @_hash['processing_information'] = 'processingInformation' @_hash['invoice_information'] = 'invoiceInformation' @_hash['order_information'] = 'orderInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
91 92 93 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 91 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 77 def self.optionals %w[ links id submit_time_utc status customer_information processing_information invoice_information order_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
212 213 214 215 216 217 218 219 220 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 212 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, customer_information:"\ " #{@customer_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, invoice_information: #{@invoice_information.inspect},"\ " order_information: #{@order_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
202 203 204 205 206 207 208 209 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 202 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, customer_information: #{@customer_information}, processing_information:"\ " #{@processing_information}, invoice_information: #{@invoice_information},"\ " order_information: #{@order_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_cancel200_response.rb', line 179 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links251', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'CustomerInformation', customer_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation72', processing_information) XmlUtilities.add_as_subelement(doc, root, 'InvoiceInformation1', invoice_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation61', order_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |