Class: CyberSourceMergedSpec::InvoicingV2InvoicesPost202Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb

Overview

InvoicingV2InvoicesPost202Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(submit_time_utc: SKIP, status: SKIP, reason: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ InvoicingV2InvoicesPost202Response

Returns a new instance of InvoicingV2InvoicesPost202Response.



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 73

def initialize(submit_time_utc: SKIP, status: SKIP, reason: SKIP,
               message: SKIP, details: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @details = details unless details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailsArray[Detail]

The detail message related to the status and reason listed above.

Returns:



44
45
46
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 44

def details
  @details
end

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


40
41
42
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 40

def message
  @message
end

#reasonString

The reason of the status. Possible values:

  • ACCEPTED

Returns:

  • (String)


36
37
38
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 36

def reason
  @reason
end

#statusString

The status of the invoice. Possible values:

  • DRAFT
  • CREATED
  • SENT
  • PARTIAL
  • PAID
  • CANCELED
  • PENDING

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 30

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 18

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_element(root) ⇒ Object



123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 123

def self.from_element(root)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  status = XmlUtilities.from_element(root, 'status', String)
  reason = XmlUtilities.from_element(root, 'reason', String)
  message = XmlUtilities.from_element(root, 'message', String)
  details = XmlUtilities.from_element_to_array(root, 'Detail', Detail)

  new(submit_time_utc: submit_time_utc,
      status: status,
      reason: reason,
      message: message,
      details: details,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 87

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  details = nil
  unless hash['details'].nil?
    details = []
    hash['details'].each do |structure|
      details << (Detail.from_hash(structure) if structure)
    end
  end

  details = SKIP unless hash.key?('details')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InvoicingV2InvoicesPost202Response.new(submit_time_utc: submit_time_utc,
                                         status: status,
                                         reason: reason,
                                         message: message,
                                         details: details,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



47
48
49
50
51
52
53
54
55
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 47

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash['details'] = 'details'
  @_hash
end

.nullablesObject

An array for nullable fields



69
70
71
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 69

def self.nullables
  []
end

.optionalsObject

An array for optional fields



58
59
60
61
62
63
64
65
66
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 58

def self.optionals
  %w[
    submit_time_utc
    status
    reason
    message
    details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



162
163
164
165
166
167
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 162

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\
  " reason: #{@reason.inspect}, message: #{@message.inspect}, details: #{@details.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



154
155
156
157
158
159
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 154

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc}, status: #{@status}, reason:"\
  " #{@reason}, message: #{@message}, details: #{@details}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/cyber_source_merged_spec/models/invoicing_v2_invoices_post202_response.rb', line 138

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'reason', reason)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_array_as_subelement(doc, root, 'Detail', details)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end