Class: CyberSourceMergedSpec::InvoicingV2InvoicesSend400ResponseException

Inherits:
APIException
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb

Overview

invoicingV2InvoicesSend400Response class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ InvoicingV2InvoicesSend400ResponseException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



47
48
49
50
51
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 47

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#detailsArray[Detail]

The detail message related to the status and reason listed above.

Returns:



42
43
44
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 42

def details
  @details
end

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


38
39
40
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 38

def message
  @message
end

#reasonString

The reason of the status. Possible values:

  • DUPLICATE_RECORD
  • ACTION_NOT_ALLOWED
  • VALIDATION_ERRORS
  • INVALID_IMAGE
  • INVALID_TRANSIENT_TOKEN

Returns:

  • (String)


34
35
36
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 34

def reason
  @reason
end

#statusString

The status of the invoice. Possible values:

- BADREQUEST

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 24

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 18

def submit_time_utc
  @submit_time_utc
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\
  " reason: #{@reason.inspect}, message: #{@message.inspect}, details: #{@details.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



77
78
79
80
81
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 77

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} submit_time_utc: #{@submit_time_utc}, status: #{@status}, reason:"\
  " #{@reason}, message: #{@message}, details: #{@details}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/cyber_source_merged_spec/exceptions/invoicing_v2_invoices_send400_response_exception.rb', line 56

def unbox(hash)
  return nil unless hash

  @submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  @status = hash.key?('status') ? hash['status'] : SKIP
  @reason = hash.key?('reason') ? hash['reason'] : SKIP
  @message = hash.key?('message') ? hash['message'] : SKIP
  # Parameter is an array, so we need to iterate through it
  @details = nil
  unless hash['details'].nil?
    @details = []
    hash['details'].each do |structure|
      @details << (Detail.from_hash(structure) if structure)
    end
  end

  @details = SKIP unless hash.key?('details')
end