Class: CyberSourceMergedSpec::IssuerInformation1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::IssuerInformation1
- Defined in:
- lib/cyber_source_merged_spec/models/issuer_information1.rb
Overview
IssuerInformation1 Model.
Instance Attribute Summary collapse
-
#exemption_data_raw ⇒ String
Payer authentication exemption indicator for Carte Bancaire exemptions.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(exemption_data_raw: SKIP, additional_properties: nil) ⇒ IssuerInformation1
constructor
A new instance of IssuerInformation1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(exemption_data_raw: SKIP, additional_properties: nil) ⇒ IssuerInformation1
Returns a new instance of IssuerInformation1.
40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 40 def initialize(exemption_data_raw: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @exemption_data_raw = exemption_data_raw unless exemption_data_raw == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#exemption_data_raw ⇒ String
Payer authentication exemption indicator for Carte Bancaire exemptions.
This is used with unbundled authentication and authorizations calls, for
example: "low fraud merchant program".
The value for this field maps to the value returned in the payer
authentication API response field -
consumerAuthenticationInformation.exemptionDataRaw.
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 19 def exemption_data_raw @exemption_data_raw end |
Class Method Details
.from_element(root) ⇒ Object
68 69 70 71 72 73 74 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 68 def self.from_element(root) exemption_data_raw = XmlUtilities.from_element(root, 'exemptionDataRaw', String) new(exemption_data_raw: exemption_data_raw, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. exemption_data_raw = hash.key?('exemptionDataRaw') ? hash['exemptionDataRaw'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IssuerInformation1.new(exemption_data_raw: exemption_data_raw, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['exemption_data_raw'] = 'exemptionDataRaw' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 29 def self.optionals %w[ exemption_data_raw ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} exemption_data_raw: #{@exemption_data_raw.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} exemption_data_raw: #{@exemption_data_raw}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/cyber_source_merged_spec/models/issuer_information1.rb', line 76 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'exemptionDataRaw', exemption_data_raw) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |