Class: CyberSourceMergedSpec::LineItem13

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/line_item13.rb

Overview

LineItem13 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(unit_price: SKIP, additional_properties: nil) ⇒ LineItem13

Returns a new instance of LineItem13.



36
37
38
39
40
41
42
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 36

def initialize(unit_price: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @unit_price = unit_price unless unit_price == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#unit_priceString

Per-item price of the product. If line items are present in the request, the unit price is a mandatory field.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 15

def unit_price
  @unit_price
end

Class Method Details

.from_element(root) ⇒ Object



63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 63

def self.from_element(root)
  unit_price = XmlUtilities.from_element(root, 'unitPrice', String)

  new(unit_price: unit_price,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  unit_price = hash.key?('unitPrice') ? hash['unitPrice'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LineItem13.new(unit_price: unit_price,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['unit_price'] = 'unitPrice'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 25

def self.optionals
  %w[
    unit_price
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} unit_price: #{@unit_price.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} unit_price: #{@unit_price}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



70
71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/line_item13.rb', line 70

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'unitPrice', unit_price)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end