Class: CyberSourceMergedSpec::Links13
- Defined in:
- lib/cyber_source_merged_spec/models/links13.rb
Overview
Links13 Model.
Instance Attribute Summary collapse
-
#mself ⇒ Self
TODO: Write general description for this method.
-
#revoke_agreement ⇒ RevokeAgreement
TODO: Write general description for this method.
-
#status ⇒ Status
TODO: Write general description for this method.
-
#update_agreement ⇒ UpdateAgreement
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, update_agreement: SKIP, revoke_agreement: SKIP, status: SKIP, additional_properties: nil) ⇒ Links13
constructor
A new instance of Links13.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, update_agreement: SKIP, revoke_agreement: SKIP, status: SKIP, additional_properties: nil) ⇒ Links13
Returns a new instance of Links13.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 53 def initialize(mself: SKIP, update_agreement: SKIP, revoke_agreement: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @update_agreement = update_agreement unless update_agreement == SKIP @revoke_agreement = revoke_agreement unless revoke_agreement == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mself ⇒ Self
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 14 def mself @mself end |
#revoke_agreement ⇒ RevokeAgreement
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 22 def revoke_agreement @revoke_agreement end |
#status ⇒ Status
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 26 def status @status end |
#update_agreement ⇒ UpdateAgreement
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 18 def update_agreement @update_agreement end |
Class Method Details
.from_element(root) ⇒ Object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 92 def self.from_element(root) mself = XmlUtilities.from_element(root, 'Self', Self) update_agreement = XmlUtilities.from_element(root, 'UpdateAgreement', UpdateAgreement) revoke_agreement = XmlUtilities.from_element(root, 'RevokeAgreement', RevokeAgreement) status = XmlUtilities.from_element(root, 'Status', Status) new(mself: mself, update_agreement: update_agreement, revoke_agreement: revoke_agreement, status: status, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self.from_hash(hash['self']) if hash['self'] update_agreement = UpdateAgreement.from_hash(hash['updateAgreement']) if hash['updateAgreement'] revoke_agreement = RevokeAgreement.from_hash(hash['revokeAgreement']) if hash['revokeAgreement'] status = Status.from_hash(hash['status']) if hash['status'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links13.new(mself: mself, update_agreement: update_agreement, revoke_agreement: revoke_agreement, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['update_agreement'] = 'updateAgreement' @_hash['revoke_agreement'] = 'revokeAgreement' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 39 def self.optionals %w[ mself update_agreement revoke_agreement status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
131 132 133 134 135 136 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 131 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, update_agreement: #{@update_agreement.inspect},"\ " revoke_agreement: #{@revoke_agreement.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
123 124 125 126 127 128 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 123 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, update_agreement: #{@update_agreement}, revoke_agreement:"\ " #{@revoke_agreement}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/cyber_source_merged_spec/models/links13.rb', line 107 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Self', mself) XmlUtilities.add_as_subelement(doc, root, 'UpdateAgreement', update_agreement) XmlUtilities.add_as_subelement(doc, root, 'RevokeAgreement', revoke_agreement) XmlUtilities.add_as_subelement(doc, root, 'Status', status) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |