Class: CyberSourceMergedSpec::Links227

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/links227.rb

Overview

Links227 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mself: SKIP, mnext: SKIP, previous: SKIP, additional_properties: nil) ⇒ Links227

Returns a new instance of Links227.



47
48
49
50
51
52
53
54
55
56
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 47

def initialize(mself: SKIP, mnext: SKIP, previous: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mself = mself unless mself == SKIP
  @mnext = mnext unless mnext == SKIP
  @previous = previous unless previous == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#mnextNext4

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 18

def mnext
  @mnext
end

#mselfSelf

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 14

def mself
  @mself
end

#previousPrevious

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 22

def previous
  @previous
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 81

def self.from_element(root)
  mself = XmlUtilities.from_element(root, 'Self', Self)
  mnext = XmlUtilities.from_element(root, 'Next4', Next4)
  previous = XmlUtilities.from_element(root, 'Previous', Previous)

  new(mself: mself,
      mnext: mnext,
      previous: previous,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mself = Self.from_hash(hash['self']) if hash['self']
  mnext = Next4.from_hash(hash['next']) if hash['next']
  previous = Previous.from_hash(hash['previous']) if hash['previous']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Links227.new(mself: mself,
               mnext: mnext,
               previous: previous,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mself'] = 'self'
  @_hash['mnext'] = 'next'
  @_hash['previous'] = 'previous'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 34

def self.optionals
  %w[
    mself
    mnext
    previous
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself.inspect}, mnext: #{@mnext.inspect}, previous:"\
  " #{@previous.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself}, mnext: #{@mnext}, previous: #{@previous},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/links227.rb', line 92

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Self', mself)
  XmlUtilities.add_as_subelement(doc, root, 'Next4', mnext)
  XmlUtilities.add_as_subelement(doc, root, 'Previous', previous)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end