Class: CyberSourceMergedSpec::Links235

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/links235.rb

Overview

Links235 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mself: SKIP, cancel: SKIP, suspend: SKIP, activate: SKIP, additional_properties: nil) ⇒ Links235

Returns a new instance of Links235.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 53

def initialize(mself: SKIP, cancel: SKIP, suspend: SKIP, activate: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mself = mself unless mself == SKIP
  @cancel = cancel unless cancel == SKIP
  @suspend = suspend unless suspend == SKIP
  @activate = activate unless activate == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#activateActivate

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 26

def activate
  @activate
end

#cancelCancel

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 18

def cancel
  @cancel
end

#mselfSelf

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 14

def mself
  @mself
end

#suspendSuspend

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 22

def suspend
  @suspend
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 90

def self.from_element(root)
  mself = XmlUtilities.from_element(root, 'Self', Self)
  cancel = XmlUtilities.from_element(root, 'Cancel', Cancel)
  suspend = XmlUtilities.from_element(root, 'Suspend', Suspend)
  activate = XmlUtilities.from_element(root, 'Activate', Activate)

  new(mself: mself,
      cancel: cancel,
      suspend: suspend,
      activate: activate,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mself = Self.from_hash(hash['self']) if hash['self']
  cancel = Cancel.from_hash(hash['cancel']) if hash['cancel']
  suspend = Suspend.from_hash(hash['suspend']) if hash['suspend']
  activate = Activate.from_hash(hash['activate']) if hash['activate']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Links235.new(mself: mself,
               cancel: cancel,
               suspend: suspend,
               activate: activate,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mself'] = 'self'
  @_hash['cancel'] = 'cancel'
  @_hash['suspend'] = 'suspend'
  @_hash['activate'] = 'activate'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 39

def self.optionals
  %w[
    mself
    cancel
    suspend
    activate
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



124
125
126
127
128
129
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 124

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself.inspect}, cancel: #{@cancel.inspect}, suspend:"\
  " #{@suspend.inspect}, activate: #{@activate.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



117
118
119
120
121
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 117

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself}, cancel: #{@cancel}, suspend: #{@suspend}, activate:"\
  " #{@activate}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/cyber_source_merged_spec/models/links235.rb', line 103

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Self', mself)
  XmlUtilities.add_as_subelement(doc, root, 'Cancel', cancel)
  XmlUtilities.add_as_subelement(doc, root, 'Suspend', suspend)
  XmlUtilities.add_as_subelement(doc, root, 'Activate', activate)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end