Class: CyberSourceMergedSpec::Links244
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Links244
- Defined in:
- lib/cyber_source_merged_spec/models/links244.rb
Overview
Links244 Model.
Instance Attribute Summary collapse
-
#mself ⇒ Self
TODO: Write general description for this method.
-
#update ⇒ Update
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, update: SKIP, additional_properties: nil) ⇒ Links244
constructor
A new instance of Links244.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, update: SKIP, additional_properties: nil) ⇒ Links244
Returns a new instance of Links244.
41 42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 41 def initialize(mself: SKIP, update: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @update = update unless update == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mself ⇒ Self
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 14 def mself @mself end |
#update ⇒ Update
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 18 def update @update end |
Class Method Details
.from_element(root) ⇒ Object
71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 71 def self.from_element(root) mself = XmlUtilities.from_element(root, 'Self', Self) update = XmlUtilities.from_element(root, 'Update', Update) new(mself: mself, update: update, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self.from_hash(hash['self']) if hash['self'] update = Update.from_hash(hash['update']) if hash['update'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links244.new(mself: mself, update: update, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['update'] = 'update' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 29 def self.optionals %w[ mself update ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, update: #{@update.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, update: #{@update}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/links244.rb', line 80 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Self', mself) XmlUtilities.add_as_subelement(doc, root, 'Update', update) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |