Class: CyberSourceMergedSpec::Links245

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/links245.rb

Overview

Links245 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mself: SKIP, related_transactions: SKIP, additional_properties: nil) ⇒ Links245

Returns a new instance of Links245.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 41

def initialize(mself: SKIP, related_transactions: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mself = mself unless mself == SKIP
  @related_transactions = related_transactions unless related_transactions == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#mselfSelf

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 14

def mself
  @mself
end

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 18

def related_transactions
  @related_transactions
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 81

def self.from_element(root)
  mself = XmlUtilities.from_element(root, 'Self', Self)
  related_transactions = XmlUtilities.from_element_to_array(
    root, 'RelatedTransaction', RelatedTransaction
  )

  new(mself: mself,
      related_transactions: related_transactions,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mself = Self.from_hash(hash['self']) if hash['self']
  # Parameter is an array, so we need to iterate through it
  related_transactions = nil
  unless hash['relatedTransactions'].nil?
    related_transactions = []
    hash['relatedTransactions'].each do |structure|
      related_transactions << (RelatedTransaction.from_hash(structure) if structure)
    end
  end

  related_transactions = SKIP unless hash.key?('relatedTransactions')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Links245.new(mself: mself,
               related_transactions: related_transactions,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mself'] = 'self'
  @_hash['related_transactions'] = 'relatedTransactions'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 29

def self.optionals
  %w[
    mself
    related_transactions
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself.inspect}, related_transactions:"\
  " #{@related_transactions.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself}, related_transactions: #{@related_transactions},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/links245.rb', line 92

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Self', mself)
  XmlUtilities.add_array_as_subelement(doc, root, 'RelatedTransaction',
                                       related_transactions)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end