Class: CyberSourceMergedSpec::Links250

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/links250.rb

Overview

Links250 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(mself: SKIP, files: SKIP, additional_properties: nil) ⇒ Links250

Returns a new instance of Links250.



41
42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 41

def initialize(mself: SKIP, files: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @mself = mself unless mself == SKIP
  @files = files unless files == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#filesArray[File]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 18

def files
  @files
end

#mselfSelf17

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 14

def mself
  @mself
end

Class Method Details

.from_element(root) ⇒ Object



80
81
82
83
84
85
86
87
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 80

def self.from_element(root)
  mself = XmlUtilities.from_element(root, 'Self17', Self17)
  files = XmlUtilities.from_element_to_array(root, 'File', File)

  new(mself: mself,
      files: files,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  mself = Self17.from_hash(hash['self']) if hash['self']
  # Parameter is an array, so we need to iterate through it
  files = nil
  unless hash['files'].nil?
    files = []
    hash['files'].each do |structure|
      files << (File.from_hash(structure) if structure)
    end
  end

  files = SKIP unless hash.key?('files')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Links250.new(mself: mself,
               files: files,
               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['mself'] = 'self'
  @_hash['files'] = 'files'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 29

def self.optionals
  %w[
    mself
    files
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



108
109
110
111
112
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 108

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself.inspect}, files: #{@files.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



101
102
103
104
105
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 101

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} mself: #{@mself}, files: #{@files}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



89
90
91
92
93
94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/links250.rb', line 89

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Self17', mself)
  XmlUtilities.add_array_as_subelement(doc, root, 'File', files)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end