Class: CyberSourceMergedSpec::Links54

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/links54.rb

Overview

Links54 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(customer: SKIP, payment_instruments: SKIP, instrument_identifier: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ Links54

Returns a new instance of Links54.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 53

def initialize(customer: SKIP, payment_instruments: SKIP,
               instrument_identifier: SKIP, tokenized_card: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @customer = customer unless customer == SKIP
  @payment_instruments = payment_instruments unless payment_instruments == SKIP
  @instrument_identifier = instrument_identifier unless instrument_identifier == SKIP
  @tokenized_card = tokenized_card unless tokenized_card == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#customerCustomer19

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 14

def customer
  @customer
end

#instrument_identifierInstrumentIdentifier13

TODO: Write general description for this method



22
23
24
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 22

def instrument_identifier
  @instrument_identifier
end

#payment_instrumentsPaymentInstruments4

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 18

def payment_instruments
  @payment_instruments
end

#tokenized_cardTokenizedCard12

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 26

def tokenized_card
  @tokenized_card
end

Class Method Details

.from_element(root) ⇒ Object



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 93

def self.from_element(root)
  customer = XmlUtilities.from_element(root, 'Customer19', Customer19)
  payment_instruments = XmlUtilities.from_element(root,
                                                  'PaymentInstruments4',
                                                  PaymentInstruments4)
  instrument_identifier = XmlUtilities.from_element(
    root, 'InstrumentIdentifier13', InstrumentIdentifier13
  )
  tokenized_card = XmlUtilities.from_element(root, 'TokenizedCard12',
                                             TokenizedCard12)

  new(customer: customer,
      payment_instruments: payment_instruments,
      instrument_identifier: instrument_identifier,
      tokenized_card: tokenized_card,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  customer = Customer19.from_hash(hash['customer']) if hash['customer']
  payment_instruments = PaymentInstruments4.from_hash(hash['paymentInstruments']) if
    hash['paymentInstruments']
  instrument_identifier = InstrumentIdentifier13.from_hash(hash['instrumentIdentifier']) if
    hash['instrumentIdentifier']
  tokenized_card = TokenizedCard12.from_hash(hash['tokenizedCard']) if hash['tokenizedCard']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Links54.new(customer: customer,
              payment_instruments: payment_instruments,
              instrument_identifier: instrument_identifier,
              tokenized_card: tokenized_card,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['customer'] = 'customer'
  @_hash['payment_instruments'] = 'paymentInstruments'
  @_hash['instrument_identifier'] = 'instrumentIdentifier'
  @_hash['tokenized_card'] = 'tokenizedCard'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 39

def self.optionals
  %w[
    customer
    payment_instruments
    instrument_identifier
    tokenized_card
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



136
137
138
139
140
141
142
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 136

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} customer: #{@customer.inspect}, payment_instruments:"\
  " #{@payment_instruments.inspect}, instrument_identifier: #{@instrument_identifier.inspect},"\
  " tokenized_card: #{@tokenized_card.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



128
129
130
131
132
133
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 128

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} customer: #{@customer}, payment_instruments: #{@payment_instruments},"\
  " instrument_identifier: #{@instrument_identifier}, tokenized_card: #{@tokenized_card},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/cyber_source_merged_spec/models/links54.rb', line 111

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Customer19', customer)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentInstruments4',
                                 payment_instruments)
  XmlUtilities.add_as_subelement(doc, root, 'InstrumentIdentifier13',
                                 instrument_identifier)
  XmlUtilities.add_as_subelement(doc, root, 'TokenizedCard12',
                                 tokenized_card)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end