Class: CyberSourceMergedSpec::Mandate
- Defined in:
- lib/cyber_source_merged_spec/models/mandate.rb
Overview
Mandate Model.
Instance Attribute Summary collapse
-
#clearing_date ⇒ String
This is the date on which the SEPA DD should be executed.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(clearing_date: SKIP, additional_properties: nil) ⇒ Mandate
constructor
A new instance of Mandate.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(clearing_date: SKIP, additional_properties: nil) ⇒ Mandate
Returns a new instance of Mandate.
36 37 38 39 40 41 42 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 36 def initialize(clearing_date: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @clearing_date = clearing_date unless clearing_date == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#clearing_date ⇒ String
This is the date on which the SEPA DD should be executed. Debit date: the day on which the payer's account is debited.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 15 def clearing_date @clearing_date end |
Class Method Details
.from_element(root) ⇒ Object
63 64 65 66 67 68 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 63 def self.from_element(root) clearing_date = XmlUtilities.from_element(root, 'clearingDate', String) new(clearing_date: clearing_date, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. clearing_date = hash.key?('clearingDate') ? hash['clearingDate'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Mandate.new(clearing_date: clearing_date, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['clearing_date'] = 'clearingDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 25 def self.optionals %w[ clearing_date ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} clearing_date: #{@clearing_date.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} clearing_date: #{@clearing_date}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
70 71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/mandate.rb', line 70 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'clearingDate', clearing_date) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |