Class: CyberSourceMergedSpec::MerchantDescriptor34

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_descriptor34.rb

Overview

MerchantDescriptor34 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, url: SKIP, additional_properties: nil) ⇒ MerchantDescriptor34

Returns a new instance of MerchantDescriptor34.



60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 60

def initialize(name: SKIP, url: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @url = url unless url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

Your merchant name. Note For Paymentech processor using Cybersource Payouts, the maximum data length is 22.

PIN debit

Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. When you do not include this value in your PIN debit request, the merchant name from your account is used. Important This value must consist of English characters. Optional field for PIN debit credit or PIN debit purchase requests.

Airline processing

Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. Note Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field. Important This value must consist of English characters. Required for captures and credits.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 33

def name
  @name
end

#urlString

Address of company's website provided by merchant

Returns:

  • (String)


37
38
39
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 37

def url
  @url
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 90

def self.from_element(root)
  name = XmlUtilities.from_element(root, 'name', String)
  url = XmlUtilities.from_element(root, 'url', String)

  new(name: name,
      url: url,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  url = hash.key?('url') ? hash['url'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantDescriptor34.new(name: name,
                           url: url,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 40

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



56
57
58
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 56

def self.nullables
  []
end

.optionalsObject

An array for optional fields



48
49
50
51
52
53
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 48

def self.optionals
  %w[
    name
    url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



118
119
120
121
122
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 118

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, url: #{@url.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, url: #{@url}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



99
100
101
102
103
104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor34.rb', line 99

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'name', name)
  XmlUtilities.add_as_subelement(doc, root, 'url', url)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end