Class: CyberSourceMergedSpec::MerchantDescriptor39

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_descriptor39.rb

Overview

MerchantDescriptor39 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, additional_properties: nil) ⇒ MerchantDescriptor39

Returns a new instance of MerchantDescriptor39.



54
55
56
57
58
59
60
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 54

def initialize(name: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

Your merchant name. Note For Paymentech processor using Cybersource Payouts, the maximum data length is 22.

PIN debit

Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. When you do not include this value in your PIN debit request, the merchant name from your account is used. Important This value must consist of English characters. Optional field for PIN debit credit or PIN debit purchase requests.

Airline processing

Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed. Note Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field. Important This value must consist of English characters. Required for captures and credits.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 33

def name
  @name
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 81

def self.from_element(root)
  name = XmlUtilities.from_element(root, 'name', String)

  new(name: name,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantDescriptor39.new(name: name,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 43

def self.optionals
  %w[
    name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/merchant_descriptor39.rb', line 88

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'name', name)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end