Class: CyberSourceMergedSpec::MerchantInformation15

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_information15.rb

Overview

MerchantInformation15 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(merchant_descriptor: SKIP, cancel_url: SKIP, success_url: SKIP, failure_url: SKIP, note_to_buyer: SKIP, additional_properties: nil) ⇒ MerchantInformation15

Returns a new instance of MerchantInformation15.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 62

def initialize(merchant_descriptor: SKIP, cancel_url: SKIP,
               success_url: SKIP, failure_url: SKIP, note_to_buyer: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @merchant_descriptor = merchant_descriptor unless merchant_descriptor == SKIP
  @cancel_url = cancel_url unless cancel_url == SKIP
  @success_url = success_url unless success_url == SKIP
  @failure_url = failure_url unless failure_url == SKIP
  @note_to_buyer = note_to_buyer unless note_to_buyer == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cancel_urlString

customer would be redirected to this url based on the decision of the transaction

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 19

def cancel_url
  @cancel_url
end

#failure_urlString

customer would be redirected to this url based on the decision of the transaction

Returns:

  • (String)


29
30
31
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 29

def failure_url
  @failure_url
end

#merchant_descriptorMerchantDescriptor

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 14

def merchant_descriptor
  @merchant_descriptor
end

#note_to_buyerString

Free-form text field.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 33

def note_to_buyer
  @note_to_buyer
end

#success_urlString

customer would be redirected to this url based on the decision of the transaction

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 24

def success_url
  @success_url
end

Class Method Details

.from_element(root) ⇒ Object



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 104

def self.from_element(root)
  merchant_descriptor = XmlUtilities.from_element(root,
                                                  'MerchantDescriptor',
                                                  MerchantDescriptor)
  cancel_url = XmlUtilities.from_element(root, 'cancelUrl', String)
  success_url = XmlUtilities.from_element(root, 'successUrl', String)
  failure_url = XmlUtilities.from_element(root, 'failureUrl', String)
  note_to_buyer = XmlUtilities.from_element(root, 'noteToBuyer', String)

  new(merchant_descriptor: merchant_descriptor,
      cancel_url: cancel_url,
      success_url: success_url,
      failure_url: failure_url,
      note_to_buyer: note_to_buyer,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  merchant_descriptor = MerchantDescriptor.from_hash(hash['merchantDescriptor']) if
    hash['merchantDescriptor']
  cancel_url = hash.key?('cancelUrl') ? hash['cancelUrl'] : SKIP
  success_url = hash.key?('successUrl') ? hash['successUrl'] : SKIP
  failure_url = hash.key?('failureUrl') ? hash['failureUrl'] : SKIP
  note_to_buyer = hash.key?('noteToBuyer') ? hash['noteToBuyer'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantInformation15.new(merchant_descriptor: merchant_descriptor,
                            cancel_url: cancel_url,
                            success_url: success_url,
                            failure_url: failure_url,
                            note_to_buyer: note_to_buyer,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
41
42
43
44
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['merchant_descriptor'] = 'merchantDescriptor'
  @_hash['cancel_url'] = 'cancelUrl'
  @_hash['success_url'] = 'successUrl'
  @_hash['failure_url'] = 'failureUrl'
  @_hash['note_to_buyer'] = 'noteToBuyer'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 58

def self.nullables
  []
end

.optionalsObject

An array for optional fields



47
48
49
50
51
52
53
54
55
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 47

def self.optionals
  %w[
    merchant_descriptor
    cancel_url
    success_url
    failure_url
    note_to_buyer
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



145
146
147
148
149
150
151
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 145

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_descriptor: #{@merchant_descriptor.inspect}, cancel_url:"\
  " #{@cancel_url.inspect}, success_url: #{@success_url.inspect}, failure_url:"\
  " #{@failure_url.inspect}, note_to_buyer: #{@note_to_buyer.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



137
138
139
140
141
142
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 137

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_descriptor: #{@merchant_descriptor}, cancel_url: #{@cancel_url},"\
  " success_url: #{@success_url}, failure_url: #{@failure_url}, note_to_buyer:"\
  " #{@note_to_buyer}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/cyber_source_merged_spec/models/merchant_information15.rb', line 121

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'MerchantDescriptor',
                                 merchant_descriptor)
  XmlUtilities.add_as_subelement(doc, root, 'cancelUrl', cancel_url)
  XmlUtilities.add_as_subelement(doc, root, 'successUrl', success_url)
  XmlUtilities.add_as_subelement(doc, root, 'failureUrl', failure_url)
  XmlUtilities.add_as_subelement(doc, root, 'noteToBuyer', note_to_buyer)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end