Class: CyberSourceMergedSpec::MerchantInformation18

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_information18.rb

Overview

MerchantInformation18 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(merchant_descriptor: SKIP, additional_properties: nil) ⇒ MerchantInformation18

Returns a new instance of MerchantInformation18.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 35

def initialize(merchant_descriptor: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @merchant_descriptor = merchant_descriptor unless merchant_descriptor == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#merchant_descriptorMerchantDescriptor11

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 14

def merchant_descriptor
  @merchant_descriptor
end

Class Method Details

.from_element(root) ⇒ Object



63
64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 63

def self.from_element(root)
  merchant_descriptor = XmlUtilities.from_element(root,
                                                  'MerchantDescriptor11',
                                                  MerchantDescriptor11)

  new(merchant_descriptor: merchant_descriptor,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  merchant_descriptor = MerchantDescriptor11.from_hash(hash['merchantDescriptor']) if
    hash['merchantDescriptor']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantInformation18.new(merchant_descriptor: merchant_descriptor,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['merchant_descriptor'] = 'merchantDescriptor'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 24

def self.optionals
  %w[
    merchant_descriptor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_descriptor: #{@merchant_descriptor.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} merchant_descriptor: #{@merchant_descriptor}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



72
73
74
75
76
77
78
79
80
81
# File 'lib/cyber_source_merged_spec/models/merchant_information18.rb', line 72

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'MerchantDescriptor11',
                                 merchant_descriptor)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end