Class: CyberSourceMergedSpec::MerchantInformation2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_information2.rb

Overview

MerchantInformation2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transaction_local_date_time: SKIP, additional_properties: nil) ⇒ MerchantInformation2

Returns a new instance of MerchantInformation2.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 54

def initialize(transaction_local_date_time: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless transaction_local_date_time == SKIP
    @transaction_local_date_time =
      transaction_local_date_time
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#transaction_local_date_timeString

Date and time at your physical location. Format: YYYYMMDDhhmmss, where:

  • YYYY = year
  • MM = month
  • DD = day
  • hh = hour
  • mm = minutes
  • ss = seconds

Used by

Authorization Required for these processors:

  • American Express Direct

                                    - American Express Direct
    
  • Credit Mutuel-CIC

  • FDC Nashville Global

  • SIX Optional for all other processors.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 33

def transaction_local_date_time
  @transaction_local_date_time
end

Class Method Details

.from_element(root) ⇒ Object



86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 86

def self.from_element(root)
  transaction_local_date_time = XmlUtilities.from_element(
    root, 'transactionLocalDateTime', String
  )

  new(transaction_local_date_time: transaction_local_date_time,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transaction_local_date_time =
    hash.key?('transactionLocalDateTime') ? hash['transactionLocalDateTime'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantInformation2.new(transaction_local_date_time: transaction_local_date_time,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 36

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transaction_local_date_time'] = 'transactionLocalDateTime'
  @_hash
end

.nullablesObject

An array for nullable fields



50
51
52
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 50

def self.nullables
  []
end

.optionalsObject

An array for optional fields



43
44
45
46
47
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 43

def self.optionals
  %w[
    transaction_local_date_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_local_date_time: #{@transaction_local_date_time.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_local_date_time: #{@transaction_local_date_time},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



95
96
97
98
99
100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/merchant_information2.rb', line 95

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'transactionLocalDateTime',
                                 transaction_local_date_time)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end