Class: CyberSourceMergedSpec::MerchantInformation25

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_information25.rb

Overview

MerchantInformation25 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reseller_id: SKIP, additional_properties: nil) ⇒ MerchantInformation25

Returns a new instance of MerchantInformation25.



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 39

def initialize(reseller_id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reseller_id = reseller_id unless reseller_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reseller_idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 18

def reseller_id
  @reseller_id
end

Class Method Details

.from_element(root) ⇒ Object



66
67
68
69
70
71
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 66

def self.from_element(root)
  reseller_id = XmlUtilities.from_element(root, 'resellerId', String)

  new(reseller_id: reseller_id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reseller_id = hash.key?('resellerId') ? hash['resellerId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantInformation25.new(reseller_id: reseller_id,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reseller_id'] = 'resellerId'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 28

def self.optionals
  %w[
    reseller_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reseller_id: #{@reseller_id.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reseller_id: #{@reseller_id}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



73
74
75
76
77
78
79
80
81
# File 'lib/cyber_source_merged_spec/models/merchant_information25.rb', line 73

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'resellerId', reseller_id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end