Class: CyberSourceMergedSpec::MerchantInformation27
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::MerchantInformation27
- Defined in:
- lib/cyber_source_merged_spec/models/merchant_information27.rb
Overview
MerchantInformation27 Model.
Instance Attribute Summary collapse
-
#address_details ⇒ AddressDetails
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, phone: SKIP, address_details: SKIP, additional_properties: nil) ⇒ MerchantInformation27
constructor
A new instance of MerchantInformation27.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, phone: SKIP, address_details: SKIP, additional_properties: nil) ⇒ MerchantInformation27
Returns a new instance of MerchantInformation27.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 47 def initialize(name: SKIP, phone: SKIP, address_details: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @phone = phone unless phone == SKIP @address_details = address_details unless address_details == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#address_details ⇒ AddressDetails
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 22 def address_details @address_details end |
#name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 14 def name @name end |
#phone ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 18 def phone @phone end |
Class Method Details
.from_element(root) ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 81 def self.from_element(root) name = XmlUtilities.from_element(root, 'name', String) phone = XmlUtilities.from_element(root, 'phone', String) address_details = XmlUtilities.from_element(root, 'AddressDetails', AddressDetails) new(name: name, phone: phone, address_details: address_details, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP phone = hash.key?('phone') ? hash['phone'] : SKIP address_details = AddressDetails.from_hash(hash['addressDetails']) if hash['addressDetails'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantInformation27.new(name: name, phone: phone, address_details: address_details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['phone'] = 'phone' @_hash['address_details'] = 'addressDetails' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 34 def self.optionals %w[ name phone address_details ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, phone: #{@phone.inspect}, address_details:"\ " #{@address_details.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
107 108 109 110 111 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 107 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, phone: #{@phone}, address_details: #{@address_details},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/cyber_source_merged_spec/models/merchant_information27.rb', line 93 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'name', name) XmlUtilities.add_as_subelement(doc, root, 'phone', phone) XmlUtilities.add_as_subelement(doc, root, 'AddressDetails', address_details) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |