Class: CyberSourceMergedSpec::MerchantInformation8

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/merchant_information8.rb

Overview

MerchantInformation8 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transaction_local_date_time: SKIP, additional_properties: nil) ⇒ MerchantInformation8

Returns a new instance of MerchantInformation8.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 37

def initialize(transaction_local_date_time: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless transaction_local_date_time == SKIP
    @transaction_local_date_time =
      transaction_local_date_time
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#transaction_local_date_timeString

Local Time of the transaction Set the timestamp for the exchange rate by ISO 8601 UTC format. Format: “YYYYMMdd’T’HHmmss’Z’” (20151103T123456Z)

Returns:

  • (String)


16
17
18
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 16

def transaction_local_date_time
  @transaction_local_date_time
end

Class Method Details

.from_element(root) ⇒ Object



69
70
71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 69

def self.from_element(root)
  transaction_local_date_time = XmlUtilities.from_element(
    root, 'transactionLocalDateTime', String
  )

  new(transaction_local_date_time: transaction_local_date_time,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transaction_local_date_time =
    hash.key?('transactionLocalDateTime') ? hash['transactionLocalDateTime'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MerchantInformation8.new(transaction_local_date_time: transaction_local_date_time,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transaction_local_date_time'] = 'transactionLocalDateTime'
  @_hash
end

.nullablesObject

An array for nullable fields



33
34
35
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 33

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
29
30
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 26

def self.optionals
  %w[
    transaction_local_date_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_local_date_time: #{@transaction_local_date_time.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_local_date_time: #{@transaction_local_date_time},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



78
79
80
81
82
83
84
85
86
87
# File 'lib/cyber_source_merged_spec/models/merchant_information8.rb', line 78

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'transactionLocalDateTime',
                                 transaction_local_date_time)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end