Class: CyberSourceMergedSpec::MitReversalRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/mit_reversal_request.rb

Overview

MitReversalRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_reference_information: SKIP, reversal_information: SKIP, processing_information: SKIP, order_information: SKIP, point_of_sale_information: SKIP, device_information: SKIP, processor_information: SKIP, additional_properties: nil) ⇒ MitReversalRequest

Returns a new instance of MitReversalRequest.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 71

def initialize(client_reference_information: SKIP,
               reversal_information: SKIP, processing_information: SKIP,
               order_information: SKIP, point_of_sale_information: SKIP,
               device_information: SKIP, processor_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @reversal_information = reversal_information unless reversal_information == SKIP
  @processing_information = processing_information unless processing_information == SKIP
  @order_information = order_information unless order_information == SKIP
  unless point_of_sale_information == SKIP
    @point_of_sale_information =
      point_of_sale_information
  end
  @device_information = device_information unless device_information == SKIP
  @processor_information = processor_information unless processor_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 14

def client_reference_information
  @client_reference_information
end

#device_informationDeviceInformation1

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 34

def device_information
  @device_information
end

#order_informationOrderInformation4

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 26

def order_information
  @order_information
end

#point_of_sale_informationPointOfSaleInformation2

TODO: Write general description for this method



30
31
32
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 30

def point_of_sale_information
  @point_of_sale_information
end

#processing_informationProcessingInformation3

TODO: Write general description for this method



22
23
24
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 22

def processing_information
  @processing_information
end

#processor_informationProcessorInformation5

TODO: Write general description for this method



38
39
40
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 38

def processor_information
  @processor_information
end

#reversal_informationReversalInformation

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 18

def reversal_information
  @reversal_information
end

Class Method Details

.from_element(root) ⇒ Object



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 135

def self.from_element(root)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation',
    ClientReferenceInformation
  )
  reversal_information = XmlUtilities.from_element(root,
                                                   'ReversalInformation',
                                                   ReversalInformation)
  processing_information = XmlUtilities.from_element(
    root, 'ProcessingInformation3', ProcessingInformation3
  )
  order_information = XmlUtilities.from_element(root, 'OrderInformation4',
                                                OrderInformation4)
  point_of_sale_information = XmlUtilities.from_element(
    root, 'PointOfSaleInformation2', PointOfSaleInformation2
  )
  device_information = XmlUtilities.from_element(root, 'DeviceInformation1',
                                                 DeviceInformation1)
  processor_information = XmlUtilities.from_element(root,
                                                    'ProcessorInformation5',
                                                    ProcessorInformation5)

  new(client_reference_information: client_reference_information,
      reversal_information: reversal_information,
      processing_information: processing_information,
      order_information: order_information,
      point_of_sale_information: point_of_sale_information,
      device_information: device_information,
      processor_information: processor_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 96

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation.from_hash(hash['clientReferenceInformation'])
  end
  reversal_information = ReversalInformation.from_hash(hash['reversalInformation']) if
    hash['reversalInformation']
  processing_information = ProcessingInformation3.from_hash(hash['processingInformation']) if
    hash['processingInformation']
  order_information = OrderInformation4.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  if hash['pointOfSaleInformation']
    point_of_sale_information = PointOfSaleInformation2.from_hash(hash['pointOfSaleInformation'])
  end
  device_information = DeviceInformation1.from_hash(hash['deviceInformation']) if
    hash['deviceInformation']
  processor_information = ProcessorInformation5.from_hash(hash['processorInformation']) if
    hash['processorInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MitReversalRequest.new(client_reference_information: client_reference_information,
                         reversal_information: reversal_information,
                         processing_information: processing_information,
                         order_information: order_information,
                         point_of_sale_information: point_of_sale_information,
                         device_information: device_information,
                         processor_information: processor_information,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['reversal_information'] = 'reversalInformation'
  @_hash['processing_information'] = 'processingInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash['point_of_sale_information'] = 'pointOfSaleInformation'
  @_hash['device_information'] = 'deviceInformation'
  @_hash['processor_information'] = 'processorInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



67
68
69
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 67

def self.nullables
  []
end

.optionalsObject

An array for optional fields



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 54

def self.optionals
  %w[
    client_reference_information
    reversal_information
    processing_information
    order_information
    point_of_sale_information
    device_information
    processor_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



202
203
204
205
206
207
208
209
210
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 202

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\
  " reversal_information: #{@reversal_information.inspect}, processing_information:"\
  " #{@processing_information.inspect}, order_information: #{@order_information.inspect},"\
  " point_of_sale_information: #{@point_of_sale_information.inspect}, device_information:"\
  " #{@device_information.inspect}, processor_information: #{@processor_information.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



191
192
193
194
195
196
197
198
199
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 191

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information},"\
  " reversal_information: #{@reversal_information}, processing_information:"\
  " #{@processing_information}, order_information: #{@order_information},"\
  " point_of_sale_information: #{@point_of_sale_information}, device_information:"\
  " #{@device_information}, processor_information: #{@processor_information},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/cyber_source_merged_spec/models/mit_reversal_request.rb', line 167

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'ReversalInformation',
                                 reversal_information)
  XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation3',
                                 processing_information)
  XmlUtilities.add_as_subelement(doc, root, 'OrderInformation4',
                                 order_information)
  XmlUtilities.add_as_subelement(doc, root, 'PointOfSaleInformation2',
                                 point_of_sale_information)
  XmlUtilities.add_as_subelement(doc, root, 'DeviceInformation1',
                                 device_information)
  XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation5',
                                 processor_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end