Class: CyberSourceMergedSpec::Network

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/network.rb

Overview

Network Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(economically_related_txn_id: SKIP, additional_properties: nil) ⇒ Network

Returns a new instance of Network.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/network.rb', line 35

def initialize(economically_related_txn_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless economically_related_txn_id == SKIP
    @economically_related_txn_id =
      economically_related_txn_id
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

Indicates the economically related transaction id

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/network.rb', line 14

def economically_related_txn_id
  @economically_related_txn_id
end

Class Method Details

.from_element(root) ⇒ Object



67
68
69
70
71
72
73
74
# File 'lib/cyber_source_merged_spec/models/network.rb', line 67

def self.from_element(root)
  economically_related_txn_id = XmlUtilities.from_element(
    root, 'economicallyRelatedTxnId', String
  )

  new(economically_related_txn_id: economically_related_txn_id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/cyber_source_merged_spec/models/network.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  economically_related_txn_id =
    hash.key?('economicallyRelatedTxnId') ? hash['economicallyRelatedTxnId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Network.new(economically_related_txn_id: economically_related_txn_id,
              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/network.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['economically_related_txn_id'] = 'economicallyRelatedTxnId'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/network.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/network.rb', line 24

def self.optionals
  %w[
    economically_related_txn_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/network.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} economically_related_txn_id: #{@economically_related_txn_id.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/network.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} economically_related_txn_id: #{@economically_related_txn_id},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



76
77
78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/network.rb', line 76

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'economicallyRelatedTxnId',
                                 economically_related_txn_id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end