Class: CyberSourceMergedSpec::Network45

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/network45.rb

Overview

Network45 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, additional_properties: nil) ⇒ Network45

Returns a new instance of Network45.



38
39
40
41
42
43
44
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 38

def initialize(id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

This field contains a code that identifies the network. Please refer [Network ID and Sharing Group Code](https://developer.visa.com/request_response_codes#network_id_and_sha ring_group_code)

Returns:

  • (String)


17
18
19
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 17

def id
  @id
end

Class Method Details

.from_element(root) ⇒ Object



65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 65

def self.from_element(root)
  id = XmlUtilities.from_element(root, 'id', String)

  new(id: id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Network45.new(id: id,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



20
21
22
23
24
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 20

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



27
28
29
30
31
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 27

def self.optionals
  %w[
    id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



72
73
74
75
76
77
78
79
80
# File 'lib/cyber_source_merged_spec/models/network45.rb', line 72

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end