Class: CyberSourceMergedSpec::Note

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/note.rb

Overview

Note Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(time: SKIP, added_by: SKIP, comments: SKIP, additional_properties: nil) ⇒ Note

Returns a new instance of Note.



48
49
50
51
52
53
54
55
56
57
# File 'lib/cyber_source_merged_spec/models/note.rb', line 48

def initialize(time: SKIP, added_by: SKIP, comments: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @time = time unless time == SKIP
  @added_by = added_by unless added_by == SKIP
  @comments = comments unless comments == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#added_byString

Note added by reviewer

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/note.rb', line 19

def added_by
  @added_by
end

#commentsString

Comments given by the reviewer

Returns:

  • (String)


23
24
25
# File 'lib/cyber_source_merged_spec/models/note.rb', line 23

def comments
  @comments
end

#timeDateTime

Time of the note added by reviewer

Returns:

  • (DateTime)


15
16
17
# File 'lib/cyber_source_merged_spec/models/note.rb', line 15

def time
  @time
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/note.rb', line 90

def self.from_element(root)
  time = XmlUtilities.from_attribute(root, 'Date', String,
                                     datetime_format: 'rfc3339')
  added_by = XmlUtilities.from_attribute(root, 'AddedBy', String)
  comments = XmlUtilities.from_attribute(root, 'Comment', String)

  new(time: time,
      added_by: added_by,
      comments: comments,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/note.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  time = if hash.key?('time')
           (DateTimeHelper.from_rfc3339(hash['time']) if hash['time'])
         else
           SKIP
         end
  added_by = hash.key?('addedBy') ? hash['addedBy'] : SKIP
  comments = hash.key?('comments') ? hash['comments'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Note.new(time: time,
           added_by: added_by,
           comments: comments,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/note.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['time'] = 'time'
  @_hash['added_by'] = 'addedBy'
  @_hash['comments'] = 'comments'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/cyber_source_merged_spec/models/note.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/note.rb', line 35

def self.optionals
  %w[
    time
    added_by
    comments
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



123
124
125
126
127
# File 'lib/cyber_source_merged_spec/models/note.rb', line 123

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} time: #{@time.inspect}, added_by: #{@added_by.inspect}, comments:"\
  " #{@comments.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_timeObject



86
87
88
# File 'lib/cyber_source_merged_spec/models/note.rb', line 86

def to_custom_time
  DateTimeHelper.to_rfc3339(time)
end

#to_sObject

Provides a human-readable string representation of the object.



116
117
118
119
120
# File 'lib/cyber_source_merged_spec/models/note.rb', line 116

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} time: #{@time}, added_by: #{@added_by}, comments: #{@comments},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/cyber_source_merged_spec/models/note.rb', line 102

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_attribute(root, 'Date', time,
                                datetime_format: 'rfc3339')
  XmlUtilities.add_as_attribute(root, 'AddedBy', added_by)
  XmlUtilities.add_as_attribute(root, 'Comment', comments)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end