Class: CyberSourceMergedSpec::OrderInformation20

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/order_information20.rb

Overview

OrderInformation20 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_details: SKIP, invoice_details: SKIP, bill_to: SKIP, additional_properties: nil) ⇒ OrderInformation20

Returns a new instance of OrderInformation20.



47
48
49
50
51
52
53
54
55
56
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 47

def initialize(amount_details: SKIP, invoice_details: SKIP, bill_to: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount_details = amount_details unless amount_details == SKIP
  @invoice_details = invoice_details unless invoice_details == SKIP
  @bill_to = bill_to unless bill_to == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_detailsAmountDetails23

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 14

def amount_details
  @amount_details
end

#bill_toBillTo7

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 22

def bill_to
  @bill_to
end

#invoice_detailsInvoiceDetails12

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 18

def invoice_details
  @invoice_details
end

Class Method Details

.from_element(root) ⇒ Object



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 82

def self.from_element(root)
  amount_details = XmlUtilities.from_element(root, 'AmountDetails23',
                                             AmountDetails23)
  invoice_details = XmlUtilities.from_element(root, 'InvoiceDetails12',
                                              InvoiceDetails12)
  bill_to = XmlUtilities.from_element(root, 'BillTo7', BillTo7)

  new(amount_details: amount_details,
      invoice_details: invoice_details,
      bill_to: bill_to,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_details = AmountDetails23.from_hash(hash['amountDetails']) if hash['amountDetails']
  invoice_details = InvoiceDetails12.from_hash(hash['invoiceDetails']) if
    hash['invoiceDetails']
  bill_to = BillTo7.from_hash(hash['billTo']) if hash['billTo']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrderInformation20.new(amount_details: amount_details,
                         invoice_details: invoice_details,
                         bill_to: bill_to,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount_details'] = 'amountDetails'
  @_hash['invoice_details'] = 'invoiceDetails'
  @_hash['bill_to'] = 'billTo'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 34

def self.optionals
  %w[
    amount_details
    invoice_details
    bill_to
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details.inspect}, invoice_details:"\
  " #{@invoice_details.inspect}, bill_to: #{@bill_to.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



110
111
112
113
114
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 110

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details}, invoice_details: #{@invoice_details},"\
  " bill_to: #{@bill_to}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/cyber_source_merged_spec/models/order_information20.rb', line 95

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'AmountDetails23',
                                 amount_details)
  XmlUtilities.add_as_subelement(doc, root, 'InvoiceDetails12',
                                 invoice_details)
  XmlUtilities.add_as_subelement(doc, root, 'BillTo7', bill_to)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end