Class: CyberSourceMergedSpec::OrderInformation22

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/order_information22.rb

Overview

OrderInformation22 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(bill_to: SKIP, ship_to: SKIP, additional_properties: nil) ⇒ OrderInformation22

Returns a new instance of OrderInformation22.



41
42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 41

def initialize(bill_to: SKIP, ship_to: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @bill_to = bill_to unless bill_to == SKIP
  @ship_to = ship_to unless ship_to == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bill_toBillTo9

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 14

def bill_to
  @bill_to
end

#ship_toShipTo7

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 18

def ship_to
  @ship_to
end

Class Method Details

.from_element(root) ⇒ Object



71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 71

def self.from_element(root)
  bill_to = XmlUtilities.from_element(root, 'BillTo9', BillTo9)
  ship_to = XmlUtilities.from_element(root, 'ShipTo7', ShipTo7)

  new(bill_to: bill_to,
      ship_to: ship_to,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  bill_to = BillTo9.from_hash(hash['billTo']) if hash['billTo']
  ship_to = ShipTo7.from_hash(hash['shipTo']) if hash['shipTo']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrderInformation22.new(bill_to: bill_to,
                         ship_to: ship_to,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['bill_to'] = 'billTo'
  @_hash['ship_to'] = 'shipTo'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 29

def self.optionals
  %w[
    bill_to
    ship_to
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} bill_to: #{@bill_to.inspect}, ship_to: #{@ship_to.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} bill_to: #{@bill_to}, ship_to: #{@ship_to}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/order_information22.rb', line 80

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'BillTo9', bill_to)
  XmlUtilities.add_as_subelement(doc, root, 'ShipTo7', ship_to)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end