Class: CyberSourceMergedSpec::OrderInformation33

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/order_information33.rb

Overview

OrderInformation33 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_details: SKIP, bill_to: SKIP, additional_properties: nil) ⇒ OrderInformation33

Returns a new instance of OrderInformation33.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 41

def initialize(amount_details: SKIP, bill_to: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount_details = amount_details unless amount_details == SKIP
  @bill_to = bill_to unless bill_to == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_detailsAmountDetails34

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 14

def amount_details
  @amount_details
end

#bill_toBillTo20

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 18

def bill_to
  @bill_to
end

Class Method Details

.from_element(root) ⇒ Object



72
73
74
75
76
77
78
79
80
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 72

def self.from_element(root)
  amount_details = XmlUtilities.from_element(root, 'AmountDetails34',
                                             AmountDetails34)
  bill_to = XmlUtilities.from_element(root, 'BillTo20', BillTo20)

  new(amount_details: amount_details,
      bill_to: bill_to,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_details = AmountDetails34.from_hash(hash['amountDetails']) if hash['amountDetails']
  bill_to = BillTo20.from_hash(hash['billTo']) if hash['billTo']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrderInformation33.new(amount_details: amount_details,
                         bill_to: bill_to,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount_details'] = 'amountDetails'
  @_hash['bill_to'] = 'billTo'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 29

def self.optionals
  %w[
    amount_details
    bill_to
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details.inspect}, bill_to: #{@bill_to.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details}, bill_to: #{@bill_to},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/order_information33.rb', line 82

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'AmountDetails34',
                                 amount_details)
  XmlUtilities.add_as_subelement(doc, root, 'BillTo20', bill_to)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end