Class: CyberSourceMergedSpec::OrderInformation4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::OrderInformation4
- Defined in:
- lib/cyber_source_merged_spec/models/order_information4.rb
Overview
OrderInformation4 Model.
Instance Attribute Summary collapse
-
#amount_details ⇒ AmountDetails6
TODO: Write general description for this method.
-
#line_items ⇒ Array[LineItem1]
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount_details: SKIP, line_items: SKIP, additional_properties: nil) ⇒ OrderInformation4
constructor
A new instance of OrderInformation4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount_details: SKIP, line_items: SKIP, additional_properties: nil) ⇒ OrderInformation4
Returns a new instance of OrderInformation4.
41 42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 41 def initialize(amount_details: SKIP, line_items: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount_details = amount_details unless amount_details == SKIP @line_items = line_items unless line_items == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount_details ⇒ AmountDetails6
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 14 def amount_details @amount_details end |
#line_items ⇒ Array[LineItem1]
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 18 def line_items @line_items end |
Class Method Details
.from_element(root) ⇒ Object
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 81 def self.from_element(root) amount_details = XmlUtilities.from_element(root, 'AmountDetails6', AmountDetails6) line_items = XmlUtilities.from_element_to_array(root, 'LineItem1', LineItem1) new(amount_details: amount_details, line_items: line_items, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount_details = AmountDetails6.from_hash(hash['amountDetails']) if hash['amountDetails'] # Parameter is an array, so we need to iterate through it line_items = nil unless hash['lineItems'].nil? line_items = [] hash['lineItems'].each do |structure| line_items << (LineItem1.from_hash(structure) if structure) end end line_items = SKIP unless hash.key?('lineItems') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderInformation4.new(amount_details: amount_details, line_items: line_items, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['amount_details'] = 'amountDetails' @_hash['line_items'] = 'lineItems' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 29 def self.optionals %w[ amount_details line_items ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 112 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details.inspect}, line_items:"\ " #{@line_items.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details}, line_items: #{@line_items},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/order_information4.rb', line 92 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'AmountDetails6', amount_details) XmlUtilities.add_array_as_subelement(doc, root, 'LineItem1', line_items) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |