Class: CyberSourceMergedSpec::OrderInformation42
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::OrderInformation42
- Defined in:
- lib/cyber_source_merged_spec/models/order_information42.rb
Overview
OrderInformation42 Model.
Instance Attribute Summary collapse
-
#bill_to ⇒ BillTo68
TODO: Write general description for this method.
-
#line_items ⇒ Array[LineItem15]
TODO: Write general description for this method.
-
#ship_to ⇒ ShipTo31
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bill_to: SKIP, ship_to: SKIP, line_items: SKIP, additional_properties: nil) ⇒ OrderInformation42
constructor
A new instance of OrderInformation42.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bill_to: SKIP, ship_to: SKIP, line_items: SKIP, additional_properties: nil) ⇒ OrderInformation42
Returns a new instance of OrderInformation42.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 47 def initialize(bill_to: SKIP, ship_to: SKIP, line_items: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bill_to = bill_to unless bill_to == SKIP @ship_to = ship_to unless ship_to == SKIP @line_items = line_items unless line_items == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bill_to ⇒ BillTo68
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 14 def bill_to @bill_to end |
#line_items ⇒ Array[LineItem15]
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 22 def line_items @line_items end |
#ship_to ⇒ ShipTo31
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 18 def ship_to @ship_to end |
Class Method Details
.from_element(root) ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 90 def self.from_element(root) bill_to = XmlUtilities.from_element(root, 'BillTo68', BillTo68) ship_to = XmlUtilities.from_element(root, 'ShipTo31', ShipTo31) line_items = XmlUtilities.from_element_to_array(root, 'LineItem15', LineItem15) new(bill_to: bill_to, ship_to: ship_to, line_items: line_items, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bill_to = BillTo68.from_hash(hash['billTo']) if hash['billTo'] ship_to = ShipTo31.from_hash(hash['shipTo']) if hash['shipTo'] # Parameter is an array, so we need to iterate through it line_items = nil unless hash['lineItems'].nil? line_items = [] hash['lineItems'].each do |structure| line_items << (LineItem15.from_hash(structure) if structure) end end line_items = SKIP unless hash.key?('lineItems') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderInformation42.new(bill_to: bill_to, ship_to: ship_to, line_items: line_items, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['bill_to'] = 'billTo' @_hash['ship_to'] = 'shipTo' @_hash['line_items'] = 'lineItems' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 34 def self.optionals %w[ bill_to ship_to line_items ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
122 123 124 125 126 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 122 def inspect class_name = self.class.name.split('::').last "<#{class_name} bill_to: #{@bill_to.inspect}, ship_to: #{@ship_to.inspect}, line_items:"\ " #{@line_items.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 119 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} bill_to: #{@bill_to}, ship_to: #{@ship_to}, line_items: #{@line_items},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/order_information42.rb', line 102 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'BillTo68', bill_to) XmlUtilities.add_as_subelement(doc, root, 'ShipTo31', ship_to) XmlUtilities.add_array_as_subelement(doc, root, 'LineItem15', line_items) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |