Class: CyberSourceMergedSpec::OrderInformation47
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::OrderInformation47
- Defined in:
- lib/cyber_source_merged_spec/models/order_information47.rb
Overview
OrderInformation47 Model.
Instance Attribute Summary collapse
-
#amount_details ⇒ AmountDetails46
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount_details:, additional_properties: nil) ⇒ OrderInformation47
constructor
A new instance of OrderInformation47.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount_details:, additional_properties: nil) ⇒ OrderInformation47
Returns a new instance of OrderInformation47.
33 34 35 36 37 38 39 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 33 def initialize(amount_details:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount_details = amount_details @additional_properties = additional_properties end |
Instance Attribute Details
#amount_details ⇒ AmountDetails46
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 14 def amount_details @amount_details end |
Class Method Details
.from_element(root) ⇒ Object
60 61 62 63 64 65 66 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 60 def self.from_element(root) amount_details = XmlUtilities.from_element(root, 'AmountDetails46', AmountDetails46) new(amount_details: amount_details, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount_details = AmountDetails46.from_hash(hash['amountDetails']) if hash['amountDetails'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderInformation47.new(amount_details: amount_details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['amount_details'] = 'amountDetails' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/cyber_source_merged_spec/models/order_information47.rb', line 68 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'AmountDetails46', amount_details) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |