Class: CyberSourceMergedSpec::OrderInformation48

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/order_information48.rb

Overview

OrderInformation48 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_details: SKIP, additional_properties: nil) ⇒ OrderInformation48

Returns a new instance of OrderInformation48.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 35

def initialize(amount_details: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount_details = amount_details unless amount_details == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_detailsAmountDetails47

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 14

def amount_details
  @amount_details
end

Class Method Details

.from_element(root) ⇒ Object



62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 62

def self.from_element(root)
  amount_details = XmlUtilities.from_element(root, 'AmountDetails47',
                                             AmountDetails47)

  new(amount_details: amount_details,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_details = AmountDetails47.from_hash(hash['amountDetails']) if hash['amountDetails']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OrderInformation48.new(amount_details: amount_details,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount_details'] = 'amountDetails'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 24

def self.optionals
  %w[
    amount_details
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/order_information48.rb', line 70

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'AmountDetails47',
                                 amount_details)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end