Class: CyberSourceMergedSpec::OrderInformation8
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::OrderInformation8
- Defined in:
- lib/cyber_source_merged_spec/models/order_information8.rb
Overview
OrderInformation8 Model.
Instance Attribute Summary collapse
-
#amount_details ⇒ AmountDetails9
TODO: Write general description for this method.
-
#bill_to ⇒ BillTo2
TODO: Write general description for this method.
-
#digital_currency ⇒ DigitalCurrency
Digital currency information for the order.
-
#invoice_details ⇒ InvoiceDetails4
TODO: Write general description for this method.
-
#line_items ⇒ Array[LineItem4]
TODO: Write general description for this method.
-
#ship_to ⇒ ShipTo2
TODO: Write general description for this method.
-
#shipping_details ⇒ ShippingDetails2
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount_details: SKIP, bill_to: SKIP, ship_to: SKIP, line_items: SKIP, invoice_details: SKIP, shipping_details: SKIP, digital_currency: SKIP, additional_properties: nil) ⇒ OrderInformation8
constructor
A new instance of OrderInformation8.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount_details: SKIP, bill_to: SKIP, ship_to: SKIP, line_items: SKIP, invoice_details: SKIP, shipping_details: SKIP, digital_currency: SKIP, additional_properties: nil) ⇒ OrderInformation8
Returns a new instance of OrderInformation8.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 71 def initialize(amount_details: SKIP, bill_to: SKIP, ship_to: SKIP, line_items: SKIP, invoice_details: SKIP, shipping_details: SKIP, digital_currency: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount_details = amount_details unless amount_details == SKIP @bill_to = bill_to unless bill_to == SKIP @ship_to = ship_to unless ship_to == SKIP @line_items = line_items unless line_items == SKIP @invoice_details = invoice_details unless invoice_details == SKIP @shipping_details = shipping_details unless shipping_details == SKIP @digital_currency = digital_currency unless digital_currency == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#amount_details ⇒ AmountDetails9
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 14 def amount_details @amount_details end |
#bill_to ⇒ BillTo2
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 18 def bill_to @bill_to end |
#digital_currency ⇒ DigitalCurrency
Digital currency information for the order.
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 38 def digital_currency @digital_currency end |
#invoice_details ⇒ InvoiceDetails4
TODO: Write general description for this method
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 30 def invoice_details @invoice_details end |
#line_items ⇒ Array[LineItem4]
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 26 def line_items @line_items end |
#ship_to ⇒ ShipTo2
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 22 def ship_to @ship_to end |
#shipping_details ⇒ ShippingDetails2
TODO: Write general description for this method
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 34 def shipping_details @shipping_details end |
Class Method Details
.from_element(root) ⇒ Object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 131 def self.from_element(root) amount_details = XmlUtilities.from_element(root, 'AmountDetails9', AmountDetails9) bill_to = XmlUtilities.from_element(root, 'BillTo2', BillTo2) ship_to = XmlUtilities.from_element(root, 'ShipTo2', ShipTo2) line_items = XmlUtilities.from_element_to_array(root, 'LineItem4', LineItem4) invoice_details = XmlUtilities.from_element(root, 'InvoiceDetails4', InvoiceDetails4) shipping_details = XmlUtilities.from_element(root, 'ShippingDetails2', ShippingDetails2) digital_currency = XmlUtilities.from_element(root, 'DigitalCurrency', DigitalCurrency) new(amount_details: amount_details, bill_to: bill_to, ship_to: ship_to, line_items: line_items, invoice_details: invoice_details, shipping_details: shipping_details, digital_currency: digital_currency, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount_details = AmountDetails9.from_hash(hash['amountDetails']) if hash['amountDetails'] bill_to = BillTo2.from_hash(hash['billTo']) if hash['billTo'] ship_to = ShipTo2.from_hash(hash['shipTo']) if hash['shipTo'] # Parameter is an array, so we need to iterate through it line_items = nil unless hash['lineItems'].nil? line_items = [] hash['lineItems'].each do |structure| line_items << (LineItem4.from_hash(structure) if structure) end end line_items = SKIP unless hash.key?('lineItems') invoice_details = InvoiceDetails4.from_hash(hash['invoiceDetails']) if hash['invoiceDetails'] shipping_details = ShippingDetails2.from_hash(hash['shippingDetails']) if hash['shippingDetails'] digital_currency = DigitalCurrency.from_hash(hash['digitalCurrency']) if hash['digitalCurrency'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderInformation8.new(amount_details: amount_details, bill_to: bill_to, ship_to: ship_to, line_items: line_items, invoice_details: invoice_details, shipping_details: shipping_details, digital_currency: digital_currency, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['amount_details'] = 'amountDetails' @_hash['bill_to'] = 'billTo' @_hash['ship_to'] = 'shipTo' @_hash['line_items'] = 'lineItems' @_hash['invoice_details'] = 'invoiceDetails' @_hash['shipping_details'] = 'shippingDetails' @_hash['digital_currency'] = 'digitalCurrency' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 54 def self.optionals %w[ amount_details bill_to ship_to line_items invoice_details shipping_details digital_currency ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
185 186 187 188 189 190 191 192 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 185 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details.inspect}, bill_to: #{@bill_to.inspect},"\ " ship_to: #{@ship_to.inspect}, line_items: #{@line_items.inspect}, invoice_details:"\ " #{@invoice_details.inspect}, shipping_details: #{@shipping_details.inspect},"\ " digital_currency: #{@digital_currency.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
176 177 178 179 180 181 182 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 176 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details}, bill_to: #{@bill_to}, ship_to:"\ " #{@ship_to}, line_items: #{@line_items}, invoice_details: #{@invoice_details},"\ " shipping_details: #{@shipping_details}, digital_currency: #{@digital_currency},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/cyber_source_merged_spec/models/order_information8.rb', line 155 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'AmountDetails9', amount_details) XmlUtilities.add_as_subelement(doc, root, 'BillTo2', bill_to) XmlUtilities.add_as_subelement(doc, root, 'ShipTo2', ship_to) XmlUtilities.add_array_as_subelement(doc, root, 'LineItem4', line_items) XmlUtilities.add_as_subelement(doc, root, 'InvoiceDetails4', invoice_details) XmlUtilities.add_as_subelement(doc, root, 'ShippingDetails2', shipping_details) XmlUtilities.add_as_subelement(doc, root, 'DigitalCurrency', digital_currency) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |