Class: CyberSourceMergedSpec::Partner33

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/partner33.rb

Overview

Partner33 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(solution_id: SKIP, third_party_certification_number: SKIP, additional_properties: nil) ⇒ Partner33

Returns a new instance of Partner33.



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 56

def initialize(solution_id: SKIP, third_party_certification_number: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @solution_id = solution_id unless solution_id == SKIP
  unless third_party_certification_number == SKIP
    @third_party_certification_number =
      third_party_certification_number
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#solution_idString

Identifier for the partner that is integrated to CyberSource. Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 18

def solution_id
  @solution_id
end

#third_party_certification_numberString

Value that identifies the application vendor and application version for a third party gateway. CyberSource provides you with this value during testing and validation. This field is supported only on CyberSource through VisaNet.

Used by

Authorization, Authorization Reversal, Capture, Credit, Incremental Authorization, and Void Optional field.

PIN debit

Required field for PIN debit credit, PIN debit purchase, or PIN debit reversal request.

Returns:

  • (String)


32
33
34
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 32

def third_party_certification_number
  @third_party_certification_number
end

Class Method Details

.from_element(root) ⇒ Object



91
92
93
94
95
96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 91

def self.from_element(root)
  solution_id = XmlUtilities.from_element(root, 'solutionId', String)
  third_party_certification_number = XmlUtilities.from_element(
    root, 'thirdPartyCertificationNumber', String
  )

  new(solution_id: solution_id,
      third_party_certification_number: third_party_certification_number,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 70

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP
  third_party_certification_number =
    hash.key?('thirdPartyCertificationNumber') ? hash['thirdPartyCertificationNumber'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Partner33.new(solution_id: solution_id,
                third_party_certification_number: third_party_certification_number,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 35

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['solution_id'] = 'solutionId'
  @_hash['third_party_certification_number'] =
    'thirdPartyCertificationNumber'
  @_hash
end

.nullablesObject

An array for nullable fields



52
53
54
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 52

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 44

def self.optionals
  %w[
    solution_id
    third_party_certification_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



122
123
124
125
126
127
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 122

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} solution_id: #{@solution_id.inspect}, third_party_certification_number:"\
  " #{@third_party_certification_number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



115
116
117
118
119
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 115

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} solution_id: #{@solution_id}, third_party_certification_number:"\
  " #{@third_party_certification_number}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/cyber_source_merged_spec/models/partner33.rb', line 102

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'solutionId', solution_id)
  XmlUtilities.add_as_subelement(doc, root, 'thirdPartyCertificationNumber',
                                 third_party_certification_number)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end