Class: CyberSourceMergedSpec::Partner38

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/partner38.rb

Overview

Partner38 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner38

Returns a new instance of Partner38.



50
51
52
53
54
55
56
57
58
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 50

def initialize(developer_id: SKIP, solution_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @developer_id = developer_id unless developer_id == SKIP
  @solution_id = solution_id unless solution_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#developer_idString

Identifier for the developer that integrated a partner solution with Cybersource. Send this value with all requests that are sent through a partner solution built by that developer. Cybersource assigns the ID to the developer. Note A developerId set to 999 means the submitted developer ID is incorrect.

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 19

def developer_id
  @developer_id
end

#solution_idString

Identifier for the partner that integrated with Cybersource. Send this value with all requests sent through the partner solution. Cybersource assigns the ID to the partner. Note A solutionId set to 999 means the submitted solutionId is incorrect.

Returns:

  • (String)


27
28
29
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 27

def solution_id
  @solution_id
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 81

def self.from_element(root)
  developer_id = XmlUtilities.from_element(root, 'developerId', String)
  solution_id = XmlUtilities.from_element(root, 'solutionId', String)

  new(developer_id: developer_id,
      solution_id: solution_id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  developer_id = hash.key?('developerId') ? hash['developerId'] : SKIP
  solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Partner38.new(developer_id: developer_id,
                solution_id: solution_id,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
35
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['developer_id'] = 'developerId'
  @_hash['solution_id'] = 'solutionId'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
41
42
43
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 38

def self.optionals
  %w[
    developer_id
    solution_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



109
110
111
112
113
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 109

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} developer_id: #{@developer_id.inspect}, solution_id:"\
  " #{@solution_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 102

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} developer_id: #{@developer_id}, solution_id: #{@solution_id},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



90
91
92
93
94
95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/partner38.rb', line 90

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'developerId', developer_id)
  XmlUtilities.add_as_subelement(doc, root, 'solutionId', solution_id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end