Class: CyberSourceMergedSpec::PassiveRule
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PassiveRule
- Defined in:
- lib/cyber_source_merged_spec/models/passive_rule.rb
Overview
Names of one or more rules that were processed, and the decisions made by the rules.
Instance Attribute Summary collapse
-
#decision ⇒ String
Summarizes the result for the rule according to the setting that you chose in the Profile Editor.
-
#name ⇒ String
Description of the rule as it appears in the Profile Editor.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, decision: SKIP, additional_properties: nil) ⇒ PassiveRule
constructor
A new instance of PassiveRule.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, decision: SKIP, additional_properties: nil) ⇒ PassiveRule
Returns a new instance of PassiveRule.
48 49 50 51 52 53 54 55 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 48 def initialize(name: SKIP, decision: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @decision = decision unless decision == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#decision ⇒ String
Summarizes the result for the rule according to the setting that you chose in the Profile Editor. This field can contain one of the following values:
IGNOREREVIEWREJECTACCEPT
25 26 27 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 25 def decision @decision end |
#name ⇒ String
Description of the rule as it appears in the Profile Editor.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 15 def name @name end |
Class Method Details
.from_element(root) ⇒ Object
78 79 80 81 82 83 84 85 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 78 def self.from_element(root) name = XmlUtilities.from_element(root, 'name', String) decision = XmlUtilities.from_element(root, 'decision', String) new(name: name, decision: decision, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP decision = hash.key?('decision') ? hash['decision'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PassiveRule.new(name: name, decision: decision, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['decision'] = 'decision' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 36 def self.optionals %w[ name decision ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
106 107 108 109 110 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 106 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, decision: #{@decision.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, decision: #{@decision}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
87 88 89 90 91 92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/passive_rule.rb', line 87 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'name', name) XmlUtilities.add_as_subelement(doc, root, 'decision', decision) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |