Class: CyberSourceMergedSpec::PatchInstrumentIdentifierResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PatchInstrumentIdentifierResponse
- Defined in:
- lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb
Overview
PatchInstrumentIdentifierResponse Model.
Instance Attribute Summary collapse
-
#bank_account ⇒ BankAccount1
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#bill_to ⇒ BillTo16
This information is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#card ⇒ Card14
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#embedded ⇒ Embedded2
This information is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#id ⇒ String
The Id of the Instrument Identifier Token.
-
#issuer ⇒ Issuer4
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#links ⇒ Links21
TODO: Write general description for this method.
-
#metadata ⇒ Metadata3
This information is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#object ⇒ String
The type.
-
#point_of_sale_information ⇒ TmsPointOfSaleInformation
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#processing_information ⇒ ProcessingInformation29
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#source ⇒ String
Source of the card details.
-
#state ⇒ String
Issuers state for the card number.
-
#token_provisioning_information ⇒ TokenProvisioningInformation
Source of the card details.
-
#tokenized_card ⇒ Tmsv2TokenizedCard
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
-
#type ⇒ String
The type of Instrument Identifier.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, object: SKIP, state: SKIP, type: SKIP, source: SKIP, token_provisioning_information: SKIP, card: SKIP, point_of_sale_information: SKIP, bank_account: SKIP, tokenized_card: SKIP, issuer: SKIP, processing_information: SKIP, bill_to: SKIP, metadata: SKIP, embedded: SKIP, additional_properties: nil) ⇒ PatchInstrumentIdentifierResponse
constructor
A new instance of PatchInstrumentIdentifierResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, object: SKIP, state: SKIP, type: SKIP, source: SKIP, token_provisioning_information: SKIP, card: SKIP, point_of_sale_information: SKIP, bank_account: SKIP, tokenized_card: SKIP, issuer: SKIP, processing_information: SKIP, bill_to: SKIP, metadata: SKIP, embedded: SKIP, additional_properties: nil) ⇒ PatchInstrumentIdentifierResponse
Returns a new instance of PatchInstrumentIdentifierResponse.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 153 def initialize(links: SKIP, id: SKIP, object: SKIP, state: SKIP, type: SKIP, source: SKIP, token_provisioning_information: SKIP, card: SKIP, point_of_sale_information: SKIP, bank_account: SKIP, tokenized_card: SKIP, issuer: SKIP, processing_information: SKIP, bill_to: SKIP, metadata: SKIP, embedded: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @object = object unless object == SKIP @state = state unless state == SKIP @type = type unless type == SKIP @source = source unless source == SKIP unless token_provisioning_information == SKIP @token_provisioning_information = token_provisioning_information end @card = card unless card == SKIP unless point_of_sale_information == SKIP @point_of_sale_information = point_of_sale_information end @bank_account = bank_account unless bank_account == SKIP @tokenized_card = tokenized_card unless tokenized_card == SKIP @issuer = issuer unless issuer == SKIP @processing_information = processing_information unless processing_information == SKIP @bill_to = bill_to unless bill_to == SKIP @metadata = unless == SKIP @embedded = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bank_account ⇒ BankAccount1
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
68 69 70 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 68 def bank_account @bank_account end |
#bill_to ⇒ BillTo16
This information is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
91 92 93 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 91 def bill_to @bill_to end |
#card ⇒ Card14
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
56 57 58 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 56 def card @card end |
#embedded ⇒ Embedded2
This information is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
101 102 103 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 101 def @embedded end |
#id ⇒ String
The Id of the Instrument Identifier Token.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 18 def id @id end |
#issuer ⇒ Issuer4
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
80 81 82 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 80 def issuer @issuer end |
#links ⇒ Links21
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 14 def links @links end |
#metadata ⇒ Metadata3
This information is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
96 97 98 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 96 def @metadata end |
#object ⇒ String
The type. Possible Values:
- instrumentIdentifier
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 24 def object @object end |
#point_of_sale_information ⇒ TmsPointOfSaleInformation
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
62 63 64 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 62 def point_of_sale_information @point_of_sale_information end |
#processing_information ⇒ ProcessingInformation29
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
86 87 88 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 86 def processing_information @processing_information end |
#source ⇒ String
Source of the card details. Possible Values:
- CONTACTLESS_TAP
44 45 46 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 44 def source @source end |
#state ⇒ String
Issuers state for the card number. Possible Values:
- ACTIVE
- CLOSED : The account has been closed.
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 31 def state @state end |
#token_provisioning_information ⇒ TokenProvisioningInformation
Source of the card details. Possible Values:
- CONTACTLESS_TAP
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 50 def token_provisioning_information @token_provisioning_information end |
#tokenized_card ⇒ Tmsv2TokenizedCard
The expirationMonth, expirationYear and securityCode is sent to the issuer as part of network token enrollment and is not stored under the Instrument Identifier.
74 75 76 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 74 def tokenized_card @tokenized_card end |
#type ⇒ String
The type of Instrument Identifier. Possible Values:
- enrollable card
- enrollable token
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 38 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 242 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links21', Links21) id = XmlUtilities.from_element(root, 'id', String) object = XmlUtilities.from_element(root, 'object', String) state = XmlUtilities.from_element(root, 'state', String) type = XmlUtilities.from_element(root, 'type', String) source = XmlUtilities.from_element(root, 'source', String) token_provisioning_information = XmlUtilities.from_element( root, 'TokenProvisioningInformation', TokenProvisioningInformation ) card = XmlUtilities.from_element(root, 'Card14', Card14) point_of_sale_information = XmlUtilities.from_element( root, 'tmsPointOfSaleInformation', TmsPointOfSaleInformation ) bank_account = XmlUtilities.from_element(root, 'BankAccount1', BankAccount1) tokenized_card = XmlUtilities.from_element(root, 'tmsv2TokenizedCard', Tmsv2TokenizedCard) issuer = XmlUtilities.from_element(root, 'Issuer4', Issuer4) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation29', ProcessingInformation29 ) bill_to = XmlUtilities.from_element(root, 'BillTo16', BillTo16) = XmlUtilities.from_element(root, 'Metadata3', Metadata3) = XmlUtilities.from_element(root, 'Embedded2', Embedded2) new(links: links, id: id, object: object, state: state, type: type, source: source, token_provisioning_information: token_provisioning_information, card: card, point_of_sale_information: point_of_sale_information, bank_account: bank_account, tokenized_card: tokenized_card, issuer: issuer, processing_information: processing_information, bill_to: bill_to, metadata: , embedded: , additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 188 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links21.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP object = hash.key?('object') ? hash['object'] : SKIP state = hash.key?('state') ? hash['state'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP source = hash.key?('source') ? hash['source'] : SKIP if hash['tokenProvisioningInformation'] token_provisioning_information = TokenProvisioningInformation.from_hash(hash['tokenProvisioningInformation']) end card = Card14.from_hash(hash['card']) if hash['card'] if hash['pointOfSaleInformation'] point_of_sale_information = TmsPointOfSaleInformation.from_hash(hash['pointOfSaleInformation']) end bank_account = BankAccount1.from_hash(hash['bankAccount']) if hash['bankAccount'] tokenized_card = Tmsv2TokenizedCard.from_hash(hash['tokenizedCard']) if hash['tokenizedCard'] issuer = Issuer4.from_hash(hash['issuer']) if hash['issuer'] processing_information = ProcessingInformation29.from_hash(hash['processingInformation']) if hash['processingInformation'] bill_to = BillTo16.from_hash(hash['billTo']) if hash['billTo'] = Metadata3.from_hash(hash['metadata']) if hash['metadata'] = Embedded2.from_hash(hash['_embedded']) if hash['_embedded'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PatchInstrumentIdentifierResponse.new(links: links, id: id, object: object, state: state, type: type, source: source, token_provisioning_information: token_provisioning_information, card: card, point_of_sale_information: point_of_sale_information, bank_account: bank_account, tokenized_card: tokenized_card, issuer: issuer, processing_information: processing_information, bill_to: bill_to, metadata: , embedded: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 104 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['object'] = 'object' @_hash['state'] = 'state' @_hash['type'] = 'type' @_hash['source'] = 'source' @_hash['token_provisioning_information'] = 'tokenProvisioningInformation' @_hash['card'] = 'card' @_hash['point_of_sale_information'] = 'pointOfSaleInformation' @_hash['bank_account'] = 'bankAccount' @_hash['tokenized_card'] = 'tokenizedCard' @_hash['issuer'] = 'issuer' @_hash['processing_information'] = 'processingInformation' @_hash['bill_to'] = 'billTo' @_hash['metadata'] = 'metadata' @_hash['embedded'] = '_embedded' @_hash end |
.nullables ⇒ Object
An array for nullable fields
149 150 151 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 149 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 127 def self.optionals %w[ links id object state type source token_provisioning_information card point_of_sale_information bank_account tokenized_card issuer processing_information bill_to metadata embedded ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 330 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, object: #{@object.inspect},"\ " state: #{@state.inspect}, type: #{@type.inspect}, source: #{@source.inspect},"\ " token_provisioning_information: #{@token_provisioning_information.inspect}, card:"\ " #{@card.inspect}, point_of_sale_information: #{@point_of_sale_information.inspect},"\ " bank_account: #{@bank_account.inspect}, tokenized_card: #{@tokenized_card.inspect},"\ " issuer: #{@issuer.inspect}, processing_information: #{@processing_information.inspect},"\ " bill_to: #{@bill_to.inspect}, metadata: #{@metadata.inspect}, embedded:"\ " #{@embedded.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
318 319 320 321 322 323 324 325 326 327 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 318 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, object: #{@object}, state: #{@state}, type:"\ " #{@type}, source: #{@source}, token_provisioning_information:"\ " #{@token_provisioning_information}, card: #{@card}, point_of_sale_information:"\ " #{@point_of_sale_information}, bank_account: #{@bank_account}, tokenized_card:"\ " #{@tokenized_card}, issuer: #{@issuer}, processing_information:"\ " #{@processing_information}, bill_to: #{@bill_to}, metadata: #{@metadata}, embedded:"\ " #{@embedded}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/cyber_source_merged_spec/models/patch_instrument_identifier_response.rb', line 288 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links21', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'object', object) XmlUtilities.add_as_subelement(doc, root, 'state', state) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'source', source) XmlUtilities.add_as_subelement(doc, root, 'TokenProvisioningInformation', token_provisioning_information) XmlUtilities.add_as_subelement(doc, root, 'Card14', card) XmlUtilities.add_as_subelement(doc, root, 'tmsPointOfSaleInformation', point_of_sale_information) XmlUtilities.add_as_subelement(doc, root, 'BankAccount1', bank_account) XmlUtilities.add_as_subelement(doc, root, 'tmsv2TokenizedCard', tokenized_card) XmlUtilities.add_as_subelement(doc, root, 'Issuer4', issuer) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation29', processing_information) XmlUtilities.add_as_subelement(doc, root, 'BillTo16', bill_to) XmlUtilities.add_as_subelement(doc, root, 'Metadata3', ) XmlUtilities.add_as_subelement(doc, root, 'Embedded2', ) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |