Class: CyberSourceMergedSpec::PaymentAccountInformation2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payment_account_information2.rb

Overview

PaymentAccountInformation2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card: SKIP, features: SKIP, network: SKIP, additional_properties: nil) ⇒ PaymentAccountInformation2

Returns a new instance of PaymentAccountInformation2.



47
48
49
50
51
52
53
54
55
56
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 47

def initialize(card: SKIP, features: SKIP, network: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @card = card unless card == SKIP
  @features = features unless features == SKIP
  @network = network unless network == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cardCard16

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 14

def card
  @card
end

#featuresFeatures

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 18

def features
  @features
end

#networkNetwork17

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 22

def network
  @network
end

Class Method Details

.from_element(root) ⇒ Object



81
82
83
84
85
86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 81

def self.from_element(root)
  card = XmlUtilities.from_element(root, 'Card16', Card16)
  features = XmlUtilities.from_element(root, 'Features', Features)
  network = XmlUtilities.from_element(root, 'Network17', Network17)

  new(card: card,
      features: features,
      network: network,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card = Card16.from_hash(hash['card']) if hash['card']
  features = Features.from_hash(hash['features']) if hash['features']
  network = Network17.from_hash(hash['network']) if hash['network']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentAccountInformation2.new(card: card,
                                 features: features,
                                 network: network,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['card'] = 'card'
  @_hash['features'] = 'features'
  @_hash['network'] = 'network'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 34

def self.optionals
  %w[
    card
    features
    network
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card.inspect}, features: #{@features.inspect}, network:"\
  " #{@network.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card}, features: #{@features}, network: #{@network},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/payment_account_information2.rb', line 92

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Card16', card)
  XmlUtilities.add_as_subelement(doc, root, 'Features', features)
  XmlUtilities.add_as_subelement(doc, root, 'Network17', network)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end