Class: CyberSourceMergedSpec::PaymentInformation15
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentInformation15
- Defined in:
- lib/cyber_source_merged_spec/models/payment_information15.rb
Overview
PaymentInformation15 Model.
Instance Attribute Summary collapse
-
#bank ⇒ Bank6
TODO: Write general description for this method.
-
#customer ⇒ Customer10
TODO: Write general description for this method.
-
#e_wallet ⇒ EWallet5
TODO: Write general description for this method.
-
#payment_type ⇒ PaymentType12
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_type: SKIP, e_wallet: SKIP, customer: SKIP, bank: SKIP, additional_properties: nil) ⇒ PaymentInformation15
constructor
A new instance of PaymentInformation15.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_type: SKIP, e_wallet: SKIP, customer: SKIP, bank: SKIP, additional_properties: nil) ⇒ PaymentInformation15
Returns a new instance of PaymentInformation15.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 53 def initialize(payment_type: SKIP, e_wallet: SKIP, customer: SKIP, bank: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_type = payment_type unless payment_type == SKIP @e_wallet = e_wallet unless e_wallet == SKIP @customer = customer unless customer == SKIP @bank = bank unless bank == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bank ⇒ Bank6
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 26 def bank @bank end |
#customer ⇒ Customer10
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 22 def customer @customer end |
#e_wallet ⇒ EWallet5
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 18 def e_wallet @e_wallet end |
#payment_type ⇒ PaymentType12
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 14 def payment_type @payment_type end |
Class Method Details
.from_element(root) ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 90 def self.from_element(root) payment_type = XmlUtilities.from_element(root, 'PaymentType12', PaymentType12) e_wallet = XmlUtilities.from_element(root, 'EWallet5', EWallet5) customer = XmlUtilities.from_element(root, 'Customer10', Customer10) bank = XmlUtilities.from_element(root, 'Bank6', Bank6) new(payment_type: payment_type, e_wallet: e_wallet, customer: customer, bank: bank, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_type = PaymentType12.from_hash(hash['paymentType']) if hash['paymentType'] e_wallet = EWallet5.from_hash(hash['eWallet']) if hash['eWallet'] customer = Customer10.from_hash(hash['customer']) if hash['customer'] bank = Bank6.from_hash(hash['bank']) if hash['bank'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInformation15.new(payment_type: payment_type, e_wallet: e_wallet, customer: customer, bank: bank, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['payment_type'] = 'paymentType' @_hash['e_wallet'] = 'eWallet' @_hash['customer'] = 'customer' @_hash['bank'] = 'bank' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 39 def self.optionals %w[ payment_type e_wallet customer bank ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_type: #{@payment_type.inspect}, e_wallet: #{@e_wallet.inspect},"\ " customer: #{@customer.inspect}, bank: #{@bank.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
118 119 120 121 122 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 118 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_type: #{@payment_type}, e_wallet: #{@e_wallet}, customer:"\ " #{@customer}, bank: #{@bank}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/cyber_source_merged_spec/models/payment_information15.rb', line 104 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'PaymentType12', payment_type) XmlUtilities.add_as_subelement(doc, root, 'EWallet5', e_wallet) XmlUtilities.add_as_subelement(doc, root, 'Customer10', customer) XmlUtilities.add_as_subelement(doc, root, 'Bank6', bank) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |