Class: CyberSourceMergedSpec::PaymentInformation20
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentInformation20
- Defined in:
- lib/cyber_source_merged_spec/models/payment_information20.rb
Overview
PaymentInformation20 Model.
Instance Attribute Summary collapse
-
#e_wallet ⇒ EWallet7
TODO: Write general description for this method.
-
#payment_type ⇒ PaymentType1
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_type: SKIP, e_wallet: SKIP, additional_properties: nil) ⇒ PaymentInformation20
constructor
A new instance of PaymentInformation20.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_type: SKIP, e_wallet: SKIP, additional_properties: nil) ⇒ PaymentInformation20
Returns a new instance of PaymentInformation20.
41 42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 41 def initialize(payment_type: SKIP, e_wallet: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payment_type = payment_type unless payment_type == SKIP @e_wallet = e_wallet unless e_wallet == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#e_wallet ⇒ EWallet7
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 18 def e_wallet @e_wallet end |
#payment_type ⇒ PaymentType1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 14 def payment_type @payment_type end |
Class Method Details
.from_element(root) ⇒ Object
72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 72 def self.from_element(root) payment_type = XmlUtilities.from_element(root, 'PaymentType1', PaymentType1) e_wallet = XmlUtilities.from_element(root, 'EWallet7', EWallet7) new(payment_type: payment_type, e_wallet: e_wallet, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_type = PaymentType1.from_hash(hash['paymentType']) if hash['paymentType'] e_wallet = EWallet7.from_hash(hash['eWallet']) if hash['eWallet'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInformation20.new(payment_type: payment_type, e_wallet: e_wallet, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['payment_type'] = 'paymentType' @_hash['e_wallet'] = 'eWallet' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 29 def self.optionals %w[ payment_type e_wallet ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_type: #{@payment_type.inspect}, e_wallet: #{@e_wallet.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_type: #{@payment_type}, e_wallet: #{@e_wallet},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/payment_information20.rb', line 82 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'PaymentType1', payment_type) XmlUtilities.add_as_subelement(doc, root, 'EWallet7', e_wallet) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |