Class: CyberSourceMergedSpec::PaymentInformation29

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payment_information29.rb

Overview

PaymentInformation29 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(payment_type: SKIP, tokenized_payment_method: SKIP, additional_properties: nil) ⇒ PaymentInformation29

Returns a new instance of PaymentInformation29.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 41

def initialize(payment_type: SKIP, tokenized_payment_method: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @payment_type = payment_type unless payment_type == SKIP
  @tokenized_payment_method = tokenized_payment_method unless tokenized_payment_method == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#payment_typePaymentType11

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 14

def payment_type
  @payment_type
end

#tokenized_payment_methodTokenizedPaymentMethod

TODO: Write general description for this method



18
19
20
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 18

def tokenized_payment_method
  @tokenized_payment_method
end

Class Method Details

.from_element(root) ⇒ Object



73
74
75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 73

def self.from_element(root)
  payment_type = XmlUtilities.from_element(root, 'PaymentType11',
                                           PaymentType11)
  tokenized_payment_method = XmlUtilities.from_element(
    root, 'TokenizedPaymentMethod', TokenizedPaymentMethod
  )

  new(payment_type: payment_type,
      tokenized_payment_method: tokenized_payment_method,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  payment_type = PaymentType11.from_hash(hash['paymentType']) if hash['paymentType']
  tokenized_payment_method = TokenizedPaymentMethod.from_hash(hash['tokenizedPaymentMethod']) if
    hash['tokenizedPaymentMethod']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInformation29.new(payment_type: payment_type,
                           tokenized_payment_method: tokenized_payment_method,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['payment_type'] = 'paymentType'
  @_hash['tokenized_payment_method'] = 'tokenizedPaymentMethod'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 29

def self.optionals
  %w[
    payment_type
    tokenized_payment_method
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_type: #{@payment_type.inspect}, tokenized_payment_method:"\
  " #{@tokenized_payment_method.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} payment_type: #{@payment_type}, tokenized_payment_method:"\
  " #{@tokenized_payment_method}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/payment_information29.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'PaymentType11', payment_type)
  XmlUtilities.add_as_subelement(doc, root, 'TokenizedPaymentMethod',
                                 tokenized_payment_method)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end