Class: CyberSourceMergedSpec::PaymentInformation35

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payment_information35.rb

Overview

PaymentInformation35 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card: SKIP, tokenized_card: SKIP, fluid_data: SKIP, customer: SKIP, additional_properties: nil) ⇒ PaymentInformation35

Returns a new instance of PaymentInformation35.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 53

def initialize(card: SKIP, tokenized_card: SKIP, fluid_data: SKIP,
               customer: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @card = card unless card == SKIP
  @tokenized_card = tokenized_card unless tokenized_card == SKIP
  @fluid_data = fluid_data unless fluid_data == SKIP
  @customer = customer unless customer == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cardCard123

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 14

def card
  @card
end

#customerCustomer51

TODO: Write general description for this method

Returns:



26
27
28
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 26

def customer
  @customer
end

#fluid_dataFluidData

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 22

def fluid_data
  @fluid_data
end

#tokenized_cardTokenizedCard17

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 18

def tokenized_card
  @tokenized_card
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 90

def self.from_element(root)
  card = XmlUtilities.from_element(root, 'Card123', Card123)
  tokenized_card = XmlUtilities.from_element(root, 'TokenizedCard17',
                                             TokenizedCard17)
  fluid_data = XmlUtilities.from_element(root, 'FluidData', FluidData)
  customer = XmlUtilities.from_element(root, 'Customer51', Customer51)

  new(card: card,
      tokenized_card: tokenized_card,
      fluid_data: fluid_data,
      customer: customer,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card = Card123.from_hash(hash['card']) if hash['card']
  tokenized_card = TokenizedCard17.from_hash(hash['tokenizedCard']) if hash['tokenizedCard']
  fluid_data = FluidData.from_hash(hash['fluidData']) if hash['fluidData']
  customer = Customer51.from_hash(hash['customer']) if hash['customer']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInformation35.new(card: card,
                           tokenized_card: tokenized_card,
                           fluid_data: fluid_data,
                           customer: customer,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['card'] = 'card'
  @_hash['tokenized_card'] = 'tokenizedCard'
  @_hash['fluid_data'] = 'fluidData'
  @_hash['customer'] = 'customer'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 39

def self.optionals
  %w[
    card
    tokenized_card
    fluid_data
    customer
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



126
127
128
129
130
131
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 126

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card.inspect}, tokenized_card: #{@tokenized_card.inspect},"\
  " fluid_data: #{@fluid_data.inspect}, customer: #{@customer.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card}, tokenized_card: #{@tokenized_card}, fluid_data:"\
  " #{@fluid_data}, customer: #{@customer}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/payment_information35.rb', line 104

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Card123', card)
  XmlUtilities.add_as_subelement(doc, root, 'TokenizedCard17',
                                 tokenized_card)
  XmlUtilities.add_as_subelement(doc, root, 'FluidData', fluid_data)
  XmlUtilities.add_as_subelement(doc, root, 'Customer51', customer)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end