Class: CyberSourceMergedSpec::PaymentInformation36

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payment_information36.rb

Overview

Contains the payment data for updating in List Management.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card: SKIP, bank: SKIP, additional_properties: nil) ⇒ PaymentInformation36

Returns a new instance of PaymentInformation36.



41
42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 41

def initialize(card: SKIP, bank: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @card = card unless card == SKIP
  @bank = bank unless bank == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#bankBank14

Customer's bank account details

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 18

def bank
  @bank
end

#cardCard124

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 14

def card
  @card
end

Class Method Details

.from_element(root) ⇒ Object



71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 71

def self.from_element(root)
  card = XmlUtilities.from_element(root, 'Card124', Card124)
  bank = XmlUtilities.from_element(root, 'Bank14', Bank14)

  new(card: card,
      bank: bank,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card = Card124.from_hash(hash['card']) if hash['card']
  bank = Bank14.from_hash(hash['bank']) if hash['bank']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInformation36.new(card: card,
                           bank: bank,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['card'] = 'card'
  @_hash['bank'] = 'bank'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 29

def self.optionals
  %w[
    card
    bank
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card.inspect}, bank: #{@bank.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} card: #{@card}, bank: #{@bank}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/payment_information36.rb', line 80

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Card124', card)
  XmlUtilities.add_as_subelement(doc, root, 'Bank14', bank)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end