Class: CyberSourceMergedSpec::PaymentInstrument23

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payment_instrument23.rb

Overview

PaymentInstrument23 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, additional_properties: nil) ⇒ PaymentInstrument23

Returns a new instance of PaymentInstrument23.



48
49
50
51
52
53
54
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 48

def initialize(id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

Unique identifier for the Payment Instrument token used in the transaction. When you include this value in your request, many of the fields that are normally required become optional. If you intend on using more than one token, please take note of the following conditions:

  • In case a Payment Instrument token is accompanied by an Instrument Identifier token, the card number from the Instrument Identifier token will take precedence over the Payment Instrument token.
  • The Customer token and the Payment Instrument token are mutually exclusive. If both are present, you will receive an error. For more information on TMS, please see our originator-facing documentation. Conditional: If the card and customer object information is incomplete, this field becomes mandatory to retrieve missing information.

Returns:

  • (String)


27
28
29
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 27

def id
  @id
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 75

def self.from_element(root)
  id = XmlUtilities.from_element(root, 'id', String)

  new(id: id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentInstrument23.new(id: id,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 30

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 37

def self.optionals
  %w[
    id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



82
83
84
85
86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/payment_instrument23.rb', line 82

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end