Class: CyberSourceMergedSpec::PaymentType19

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payment_type19.rb

Overview

PaymentType19 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, method: SKIP, additional_properties: nil) ⇒ PaymentType19

Returns a new instance of PaymentType19.



61
62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 61

def initialize(name: SKIP, method: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @method = method unless method == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#methodMethod19

A Payment Type is an agreed means for a payee to receive legal tender from a payer. The way one pays for a commercial financial transaction. Examples: Card, Bank Transfer, Digital, Direct Debit. Possible values:

  • CARD (use this for a PIN debit transaction)
  • CHECK (use this for all eCheck payment transactions - ECP Debit, ECP Follow-on Credit, ECP StandAlone Credit)
  • bankTransfer (use for Online Bank Transafer for methods such as P24, iDeal, Estonia Bank, KCP)
  • localCard (KCP Local card via Altpay)
  • carrierBilling (KCP Carrier Billing via Altpay)

Returns:



38
39
40
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 38

def method
  @method
end

#nameString

A Payment Type is an agreed means for a payee to receive legal tender from a payer. The way one pays for a commercial financial transaction. Examples: Card, Bank Transfer, Digital, Direct Debit. Possible values:

  • CARD (use this for a PIN debit transaction)
  • CHECK (use this for all eCheck payment transactions - ECP Debit, ECP Follow-on Credit, ECP StandAlone Credit)
  • bankTransfer (use for Online Bank Transafer for methods such as P24, iDeal, Estonia Bank, KCP)
  • localCard (KCP Local card via Altpay)
  • carrierBilling (KCP Carrier Billing via Altpay)

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 24

def name
  @name
end

Class Method Details

.from_element(root) ⇒ Object



91
92
93
94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 91

def self.from_element(root)
  name = XmlUtilities.from_element(root, 'name', String)
  method = XmlUtilities.from_element(root, 'Method19', Method19)

  new(name: name,
      method: method,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 71

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  method = Method19.from_hash(hash['method']) if hash['method']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PaymentType19.new(name: name,
                    method: method,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 41

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['method'] = 'method'
  @_hash
end

.nullablesObject

An array for nullable fields



57
58
59
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 57

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 49

def self.optionals
  %w[
    name
    method
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, method: #{@method.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



112
113
114
115
116
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 112

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, method: #{@method}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



100
101
102
103
104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/payment_type19.rb', line 100

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'name', name)
  XmlUtilities.add_as_subelement(doc, root, 'Method19', method)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end