Class: CyberSourceMergedSpec::PayoutOptions1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PayoutOptions1
- Defined in:
- lib/cyber_source_merged_spec/models/payout_options1.rb
Overview
PayoutOptions1 Model.
Instance Attribute Summary collapse
-
#payout_inquiry ⇒ String
If true then provide attributes related to fund transfer/payouts.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payout_inquiry: SKIP, additional_properties: nil) ⇒ PayoutOptions1
constructor
A new instance of PayoutOptions1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payout_inquiry: SKIP, additional_properties: nil) ⇒ PayoutOptions1
Returns a new instance of PayoutOptions1.
40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 40 def initialize(payout_inquiry: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @payout_inquiry = payout_inquiry unless payout_inquiry == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#payout_inquiry ⇒ String
If true then provide attributes related to fund transfer/payouts. If payout information not found then response will have standard account lookup. Possible values:
truefalse
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 19 def payout_inquiry @payout_inquiry end |
Class Method Details
.from_element(root) ⇒ Object
67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 67 def self.from_element(root) payout_inquiry = XmlUtilities.from_element(root, 'payoutInquiry', String) new(payout_inquiry: payout_inquiry, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payout_inquiry = hash.key?('payoutInquiry') ? hash['payoutInquiry'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PayoutOptions1.new(payout_inquiry: payout_inquiry, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['payout_inquiry'] = 'payoutInquiry' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 29 def self.optionals %w[ payout_inquiry ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} payout_inquiry: #{@payout_inquiry.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} payout_inquiry: #{@payout_inquiry}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/payout_options1.rb', line 74 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'payoutInquiry', payout_inquiry) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |