Class: CyberSourceMergedSpec::PayoutsOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/payouts_options.rb

Overview

PayoutsOptions Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(acquirer_merchant_id: SKIP, acquirer_bin: SKIP, retrieval_reference_number: SKIP, account_funding_reference_id: SKIP, deferred_date_time: SKIP, additional_properties: nil) ⇒ PayoutsOptions

Returns a new instance of PayoutsOptions.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 91

def initialize(acquirer_merchant_id: SKIP, acquirer_bin: SKIP,
               retrieval_reference_number: SKIP,
               account_funding_reference_id: SKIP, deferred_date_time: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @acquirer_merchant_id = acquirer_merchant_id unless acquirer_merchant_id == SKIP
  @acquirer_bin = acquirer_bin unless acquirer_bin == SKIP
  unless retrieval_reference_number == SKIP
    @retrieval_reference_number =
      retrieval_reference_number
  end
  unless  == SKIP
    @account_funding_reference_id =
      
  end
  @deferred_date_time = deferred_date_time unless deferred_date_time == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_funding_reference_idString

Visa (maxLength of 15) or MasterCard (maxLength of 40) generated transaction identifier (TID) that is unique for each original authorization and financial request.

  • Applicable only for CTV for Payouts.

Returns:

  • (String)


51
52
53
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 51

def 
  @account_funding_reference_id
end

#acquirer_binString

This code identifies the financial institution acting as the acquirer of this customer transaction. The acquirer is the member or system user that signed the merchant or ADM or dispensed cash. This number is usually Visa-assigned.

  • Applicable only for CTV for Payouts.

Returns:

  • (String)


32
33
34
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 32

def acquirer_bin
  @acquirer_bin
end

#acquirer_merchant_idString

This field identifies the card acceptor for defining the point of service terminal in both local and interchange environments. An acquirer-assigned code identifying the card acceptor for the transaction. Depending on the acquirer and merchant billing and reporting requirements, the code can represent a merchant, a specific merchant location, or a specific merchant location terminal. Acquiring Institution Identification Code uniquely identifies the merchant. The value from the original is required in any subsequent messages, including reversals, chargebacks, and representments.

  • Applicable only for CTV for Payouts.

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 24

def acquirer_merchant_id
  @acquirer_merchant_id
end

#deferred_date_timeString

Visa Platform Connect

Contains date and time value indicating scheduled deferred OCT. Format is : 'yyyyMMddHHmm', where 'YYYY' = year 'MM' = month 'DD' = day 'hh' = hour 'mm' = minutes

Returns:

  • (String)


62
63
64
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 62

def deferred_date_time
  @deferred_date_time
end

#retrieval_reference_numberString

This field contains a number that is used with other data elements as a key to identify and track all messages related to a given cardholder transaction; that is, to a given transaction set. Format:

Positions 1-4: The `yddd` equivalent of the date, where `y` = 0-9 and

ddd = 001 – 366. Positions 5-12: A unique identification number generated by the merchant

  • Applicable only for CTV for Payouts.

Returns:

  • (String)


44
45
46
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 44

def retrieval_reference_number
  @retrieval_reference_number
end

Class Method Details

.from_element(root) ⇒ Object



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 143

def self.from_element(root)
  acquirer_merchant_id = XmlUtilities.from_element(root,
                                                   'acquirerMerchantId',
                                                   String)
  acquirer_bin = XmlUtilities.from_element(root, 'acquirerBin', String)
  retrieval_reference_number = XmlUtilities.from_element(
    root, 'retrievalReferenceNumber', String
  )
   = XmlUtilities.from_element(
    root, 'accountFundingReferenceId', String
  )
  deferred_date_time = XmlUtilities.from_element(root, 'deferredDateTime',
                                                 String)

  new(acquirer_merchant_id: acquirer_merchant_id,
      acquirer_bin: acquirer_bin,
      retrieval_reference_number: retrieval_reference_number,
      account_funding_reference_id: ,
      deferred_date_time: deferred_date_time,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 113

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  acquirer_merchant_id =
    hash.key?('acquirerMerchantId') ? hash['acquirerMerchantId'] : SKIP
  acquirer_bin = hash.key?('acquirerBin') ? hash['acquirerBin'] : SKIP
  retrieval_reference_number =
    hash.key?('retrievalReferenceNumber') ? hash['retrievalReferenceNumber'] : SKIP
   =
    hash.key?('accountFundingReferenceId') ? hash['accountFundingReferenceId'] : SKIP
  deferred_date_time =
    hash.key?('deferredDateTime') ? hash['deferredDateTime'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PayoutsOptions.new(acquirer_merchant_id: acquirer_merchant_id,
                     acquirer_bin: acquirer_bin,
                     retrieval_reference_number: retrieval_reference_number,
                     account_funding_reference_id: ,
                     deferred_date_time: deferred_date_time,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 65

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['acquirer_merchant_id'] = 'acquirerMerchantId'
  @_hash['acquirer_bin'] = 'acquirerBin'
  @_hash['retrieval_reference_number'] = 'retrievalReferenceNumber'
  @_hash['account_funding_reference_id'] = 'accountFundingReferenceId'
  @_hash['deferred_date_time'] = 'deferredDateTime'
  @_hash
end

.nullablesObject

An array for nullable fields



87
88
89
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 87

def self.nullables
  []
end

.optionalsObject

An array for optional fields



76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 76

def self.optionals
  %w[
    acquirer_merchant_id
    acquirer_bin
    retrieval_reference_number
    account_funding_reference_id
    deferred_date_time
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



193
194
195
196
197
198
199
200
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 193

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} acquirer_merchant_id: #{@acquirer_merchant_id.inspect}, acquirer_bin:"\
  " #{@acquirer_bin.inspect}, retrieval_reference_number:"\
  " #{@retrieval_reference_number.inspect}, account_funding_reference_id:"\
  " #{@account_funding_reference_id.inspect}, deferred_date_time:"\
  " #{@deferred_date_time.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



184
185
186
187
188
189
190
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 184

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} acquirer_merchant_id: #{@acquirer_merchant_id}, acquirer_bin:"\
  " #{@acquirer_bin}, retrieval_reference_number: #{@retrieval_reference_number},"\
  " account_funding_reference_id: #{@account_funding_reference_id}, deferred_date_time:"\
  " #{@deferred_date_time}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/cyber_source_merged_spec/models/payouts_options.rb', line 165

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'acquirerMerchantId',
                                 acquirer_merchant_id)
  XmlUtilities.add_as_subelement(doc, root, 'acquirerBin', acquirer_bin)
  XmlUtilities.add_as_subelement(doc, root, 'retrievalReferenceNumber',
                                 retrieval_reference_number)
  XmlUtilities.add_as_subelement(doc, root, 'accountFundingReferenceId',
                                 )
  XmlUtilities.add_as_subelement(doc, root, 'deferredDateTime',
                                 deferred_date_time)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end