Class: CyberSourceMergedSpec::PersonalIdentification2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/personal_identification2.rb

Overview

PersonalIdentification2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, additional_properties: nil) ⇒ PersonalIdentification2

Returns a new instance of PersonalIdentification2.



50
51
52
53
54
55
56
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 50

def initialize(id: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idString

The value of the identification type. This field is supported only on the following processors.

ComercioLatino

Set this field to the Cadastro de Pessoas Fisicas (CPF).

CyberSource Latin American Processing

Supported for Redecard in Brazil. Set this field to the Cadastro de Pessoas Fisicas (CPF), which is required for AVS for Redecard in Brazil. Note CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.
If type = PASSPORT, this is the cardholder's passport number. Recommended for Discover ProtectBuy.

Returns:

  • (String)


29
30
31
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 29

def id
  @id
end

Class Method Details

.from_element(root) ⇒ Object



77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 77

def self.from_element(root)
  id = XmlUtilities.from_element(root, 'id', String)

  new(id: id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PersonalIdentification2.new(id: id,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 32

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash
end

.nullablesObject

An array for nullable fields



46
47
48
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 46

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 39

def self.optionals
  %w[
    id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/personal_identification2.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end