Class: CyberSourceMergedSpec::PlanInformation11

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/plan_information11.rb

Overview

PlanInformation11 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(billing_cycles: SKIP, additional_properties: nil) ⇒ PlanInformation11

Returns a new instance of PlanInformation11.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 35

def initialize(billing_cycles: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @billing_cycles = billing_cycles unless billing_cycles == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_cyclesBillingCycles

Number of times customer is going to be billed

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 14

def billing_cycles
  @billing_cycles
end

Class Method Details

.from_element(root) ⇒ Object



62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 62

def self.from_element(root)
  billing_cycles = XmlUtilities.from_element(root, 'BillingCycles',
                                             BillingCycles)

  new(billing_cycles: billing_cycles,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  billing_cycles = BillingCycles.from_hash(hash['billingCycles']) if hash['billingCycles']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PlanInformation11.new(billing_cycles: billing_cycles,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['billing_cycles'] = 'billingCycles'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 24

def self.optionals
  %w[
    billing_cycles
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} billing_cycles: #{@billing_cycles.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} billing_cycles: #{@billing_cycles}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



70
71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/plan_information11.rb', line 70

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'BillingCycles', billing_cycles)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end