Class: CyberSourceMergedSpec::PlanInformation8

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/plan_information8.rb

Overview

PlanInformation8 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(billing_period: SKIP, billing_cycles: SKIP, additional_properties: nil) ⇒ PlanInformation8

Returns a new instance of PlanInformation8.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 41

def initialize(billing_period: SKIP, billing_cycles: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @billing_period = billing_period unless billing_period == SKIP
  @billing_cycles = billing_cycles unless billing_cycles == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_cyclesBillingCycles

Number of times customer is going to be billed

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 18

def billing_cycles
  @billing_cycles
end

#billing_periodBillingPeriod

Billing Frequency

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 14

def billing_period
  @billing_period
end

Class Method Details

.from_element(root) ⇒ Object



72
73
74
75
76
77
78
79
80
81
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 72

def self.from_element(root)
  billing_period = XmlUtilities.from_element(root, 'BillingPeriod',
                                             BillingPeriod)
  billing_cycles = XmlUtilities.from_element(root, 'BillingCycles',
                                             BillingCycles)

  new(billing_period: billing_period,
      billing_cycles: billing_cycles,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  billing_period = BillingPeriod.from_hash(hash['billingPeriod']) if hash['billingPeriod']
  billing_cycles = BillingCycles.from_hash(hash['billingCycles']) if hash['billingCycles']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PlanInformation8.new(billing_period: billing_period,
                       billing_cycles: billing_cycles,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['billing_period'] = 'billingPeriod'
  @_hash['billing_cycles'] = 'billingCycles'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 29

def self.optionals
  %w[
    billing_period
    billing_cycles
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} billing_period: #{@billing_period.inspect}, billing_cycles:"\
  " #{@billing_cycles.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} billing_period: #{@billing_period}, billing_cycles: #{@billing_cycles},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/plan_information8.rb', line 83

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'BillingPeriod', billing_period)
  XmlUtilities.add_as_subelement(doc, root, 'BillingCycles', billing_cycles)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end