Class: CyberSourceMergedSpec::PointOfSaleInformation7

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/point_of_sale_information7.rb

Overview

PointOfSaleInformation7 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(terminal_id: SKIP, encrypted_key_id: SKIP, additional_properties: nil) ⇒ PointOfSaleInformation7

Returns a new instance of PointOfSaleInformation7.



97
98
99
100
101
102
103
104
105
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 97

def initialize(terminal_id: SKIP, encrypted_key_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @terminal_id = terminal_id unless terminal_id == SKIP
  @encrypted_key_id = encrypted_key_id unless encrypted_key_id == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#encrypted_key_idString

Identifies the Zone PIN Key (ZPK) used for Online PIN processing by providing the 10‑digit Key Set Identifier (KSI). This value indicates that the PIN block is encrypted under a ZPK and enables the Payment Security Service (PSS) to perform the correct ZPK→ZPK PIN translation during card‑present EMV PIN transactions.

Returns:

  • (String)


74
75
76
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 74

def encrypted_key_id
  @encrypted_key_id
end

#terminal_idString

Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.

CyberSource through VisaNet

A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support. When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.

FDC Nashville Global

To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.

For Payouts

This field is applicable for CyberSource through VisaNet.

GPX

Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support. When you do not include this field in a request, the default value that is defined in your account is used. Optional for authorizations.

Used by

Authorization Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.

  • American Express Direct
  • Credit Mutuel-CIC
  • FDC Nashville Global
  • SIX
  • Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include pointOfSaleInformation.catLevel.
  • FDMS Nashville: The default value that is defined in your account is used.
  • GPX
  • OmniPay Direct: Optional field. For the following processors, this field is not used.
  • GPN
  • JCN Gateway
  • RBS WorldPay Atlanta
  • TSYS Acquiring Solutions
  • Worldpay VAP

Card Present reply

Terminal identifier assigned by the acquirer. This value must be printed on the receipt.

Returns:

  • (String)


65
66
67
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 65

def terminal_id
  @terminal_id
end

Class Method Details

.from_element(root) ⇒ Object



129
130
131
132
133
134
135
136
137
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 129

def self.from_element(root)
  terminal_id = XmlUtilities.from_element(root, 'terminalId', String)
  encrypted_key_id = XmlUtilities.from_element(root, 'encryptedKeyId',
                                               String)

  new(terminal_id: terminal_id,
      encrypted_key_id: encrypted_key_id,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 108

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  terminal_id = hash.key?('terminalId') ? hash['terminalId'] : SKIP
  encrypted_key_id =
    hash.key?('encryptedKeyId') ? hash['encryptedKeyId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PointOfSaleInformation7.new(terminal_id: terminal_id,
                              encrypted_key_id: encrypted_key_id,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 77

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['terminal_id'] = 'terminalId'
  @_hash['encrypted_key_id'] = 'encryptedKeyId'
  @_hash
end

.nullablesObject

An array for nullable fields



93
94
95
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 93

def self.nullables
  []
end

.optionalsObject

An array for optional fields



85
86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 85

def self.optionals
  %w[
    terminal_id
    encrypted_key_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



159
160
161
162
163
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 159

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} terminal_id: #{@terminal_id.inspect}, encrypted_key_id:"\
  " #{@encrypted_key_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



152
153
154
155
156
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 152

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} terminal_id: #{@terminal_id}, encrypted_key_id: #{@encrypted_key_id},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



139
140
141
142
143
144
145
146
147
148
149
# File 'lib/cyber_source_merged_spec/models/point_of_sale_information7.rb', line 139

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'terminalId', terminal_id)
  XmlUtilities.add_as_subelement(doc, root, 'encryptedKeyId',
                                 encrypted_key_id)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end