Class: CyberSourceMergedSpec::PostTokenPaymentCredentialsV3Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PostTokenPaymentCredentialsV3Response
- Defined in:
- lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb
Overview
PostTokenPaymentCredentialsV3Response Model.
Instance Attribute Summary collapse
-
#card ⇒ Card28
TODO: Write general description for this method.
-
#links ⇒ Links54
TODO: Write general description for this method.
-
#tokenized_card ⇒ TokenizedCard13
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, card: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ PostTokenPaymentCredentialsV3Response
constructor
A new instance of PostTokenPaymentCredentialsV3Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, card: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ PostTokenPaymentCredentialsV3Response
Returns a new instance of PostTokenPaymentCredentialsV3Response.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 47 def initialize(links: SKIP, card: SKIP, tokenized_card: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @card = card unless card == SKIP @tokenized_card = tokenized_card unless tokenized_card == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#card ⇒ Card28
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 18 def card @card end |
#links ⇒ Links54
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 14 def links @links end |
#tokenized_card ⇒ TokenizedCard13
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 22 def tokenized_card @tokenized_card end |
Class Method Details
.from_element(root) ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 81 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links54', Links54) card = XmlUtilities.from_element(root, 'Card28', Card28) tokenized_card = XmlUtilities.from_element(root, 'TokenizedCard13', TokenizedCard13) new(links: links, card: card, tokenized_card: tokenized_card, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links54.from_hash(hash['_links']) if hash['_links'] card = Card28.from_hash(hash['card']) if hash['card'] tokenized_card = TokenizedCard13.from_hash(hash['tokenizedCard']) if hash['tokenizedCard'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PostTokenPaymentCredentialsV3Response.new(links: links, card: card, tokenized_card: tokenized_card, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['card'] = 'card' @_hash['tokenized_card'] = 'tokenizedCard' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 34 def self.optionals %w[ links card tokenized_card ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
114 115 116 117 118 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 114 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, card: #{@card.inspect}, tokenized_card:"\ " #{@tokenized_card.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
107 108 109 110 111 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 107 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, card: #{@card}, tokenized_card: #{@tokenized_card},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/cyber_source_merged_spec/models/post_token_payment_credentials_v3_response.rb', line 93 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links54', links) XmlUtilities.add_as_subelement(doc, root, 'Card28', card) XmlUtilities.add_as_subelement(doc, root, 'TokenizedCard13', tokenized_card) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |