Class: CyberSourceMergedSpec::PostTokenizeRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/post_tokenize_request.rb

Overview

PostTokenizeRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(processing_information: SKIP, token_information: SKIP, additional_properties: nil) ⇒ PostTokenizeRequest

Returns a new instance of PostTokenizeRequest.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 41

def initialize(processing_information: SKIP, token_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @processing_information = processing_information unless processing_information == SKIP
  @token_information = token_information unless token_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#processing_informationProcessingInformation28

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 14

def processing_information
  @processing_information
end

#token_informationTokenInformation4

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 18

def token_information
  @token_information
end

Class Method Details

.from_element(root) ⇒ Object



74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 74

def self.from_element(root)
  processing_information = XmlUtilities.from_element(
    root, 'ProcessingInformation28', ProcessingInformation28
  )
  token_information = XmlUtilities.from_element(root, 'TokenInformation4',
                                                TokenInformation4)

  new(processing_information: processing_information,
      token_information: token_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  processing_information = ProcessingInformation28.from_hash(hash['processingInformation']) if
    hash['processingInformation']
  token_information = TokenInformation4.from_hash(hash['tokenInformation']) if
    hash['tokenInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PostTokenizeRequest.new(processing_information: processing_information,
                          token_information: token_information,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['processing_information'] = 'processingInformation'
  @_hash['token_information'] = 'tokenInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 29

def self.optionals
  %w[
    processing_information
    token_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



107
108
109
110
111
112
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 107

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} processing_information: #{@processing_information.inspect},"\
  " token_information: #{@token_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 100

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} processing_information: #{@processing_information}, token_information:"\
  " #{@token_information}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/post_tokenize_request.rb', line 86

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation28',
                                 processing_information)
  XmlUtilities.add_as_subelement(doc, root, 'TokenInformation4',
                                 token_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end