Class: CyberSourceMergedSpec::ProcessingInfOauthOrizationOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb

Overview

ProcessingInfOauthOrizationOptions Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(auth_type: SKIP, pan_return_indicator: SKIP, verbal_auth_code: SKIP, verbal_auth_transaction_id: SKIP, auth_indicator: SKIP, partial_auth_indicator: SKIP, extend_auth_indicator: SKIP, balance_inquiry: SKIP, ignore_avs_result: false, decline_avs_flags: SKIP, decline_ani_flags: SKIP, ignore_cv_result: false, initiator: SKIP, bill_payment: SKIP, bill_payment_type: SKIP, redemption_inquiry: SKIP, transportation_mode: SKIP, aggregated_auth_indicator: SKIP, debt_recovery_indicator: SKIP, deferred_auth_indicator: SKIP, cash_advance_indicator: SKIP, split_payment_transaction: SKIP, card_verification_indicator: SKIP, transaction_mode: SKIP, aft_indicator: SKIP, service_type: SKIP, balance_update: SKIP, money_load: SKIP, additional_properties: nil) ⇒ ProcessingInfOauthOrizationOptions

Returns a new instance of ProcessingInfOauthOrizationOptions.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 602

def initialize(auth_type: SKIP, pan_return_indicator: SKIP,
               verbal_auth_code: SKIP, verbal_auth_transaction_id: SKIP,
               auth_indicator: SKIP, partial_auth_indicator: SKIP,
               extend_auth_indicator: SKIP, balance_inquiry: SKIP,
               ignore_avs_result: false, decline_avs_flags: SKIP,
               decline_ani_flags: SKIP, ignore_cv_result: false,
               initiator: SKIP, bill_payment: SKIP, bill_payment_type: SKIP,
               redemption_inquiry: SKIP, transportation_mode: SKIP,
               aggregated_auth_indicator: SKIP,
               debt_recovery_indicator: SKIP, deferred_auth_indicator: SKIP,
               cash_advance_indicator: SKIP,
               split_payment_transaction: SKIP,
               card_verification_indicator: SKIP, transaction_mode: SKIP,
               aft_indicator: SKIP, service_type: SKIP,
               balance_update: SKIP, money_load: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @auth_type = auth_type unless auth_type == SKIP
  @pan_return_indicator = pan_return_indicator unless pan_return_indicator == SKIP
  @verbal_auth_code = verbal_auth_code unless verbal_auth_code == SKIP
  unless verbal_auth_transaction_id == SKIP
    @verbal_auth_transaction_id =
      verbal_auth_transaction_id
  end
  @auth_indicator = auth_indicator unless auth_indicator == SKIP
  @partial_auth_indicator = partial_auth_indicator unless partial_auth_indicator == SKIP
  @extend_auth_indicator = extend_auth_indicator unless extend_auth_indicator == SKIP
  @balance_inquiry = balance_inquiry unless balance_inquiry == SKIP
  @ignore_avs_result = ignore_avs_result unless ignore_avs_result == SKIP
  @decline_avs_flags = decline_avs_flags unless decline_avs_flags == SKIP
  @decline_ani_flags = decline_ani_flags unless decline_ani_flags == SKIP
  @ignore_cv_result = ignore_cv_result unless ignore_cv_result == SKIP
  @initiator = initiator unless initiator == SKIP
  @bill_payment = bill_payment unless bill_payment == SKIP
  @bill_payment_type = bill_payment_type unless bill_payment_type == SKIP
  @redemption_inquiry = redemption_inquiry unless redemption_inquiry == SKIP
  @transportation_mode = transportation_mode unless transportation_mode == SKIP
  unless aggregated_auth_indicator == SKIP
    @aggregated_auth_indicator =
      aggregated_auth_indicator
  end
  @debt_recovery_indicator = debt_recovery_indicator unless debt_recovery_indicator == SKIP
  @deferred_auth_indicator = deferred_auth_indicator unless deferred_auth_indicator == SKIP
  @cash_advance_indicator = cash_advance_indicator unless cash_advance_indicator == SKIP
  unless split_payment_transaction == SKIP
    @split_payment_transaction =
      split_payment_transaction
  end
  unless card_verification_indicator == SKIP
    @card_verification_indicator =
      card_verification_indicator
  end
  @transaction_mode = transaction_mode unless transaction_mode == SKIP
  @aft_indicator = aft_indicator unless aft_indicator == SKIP
  @service_type = service_type unless service_type == SKIP
  @balance_update = balance_update unless balance_update == SKIP
  @money_load = money_load unless money_load == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#aft_indicatorTrueClass | FalseClass

Indicates whether the transaction is an Account Funding Transaction (AFT).

This field is mandatory for Account Funding Transactions (AFT). Possible values:

- `true` (This is an AFT transaction)
- `false` (default value) (This is not an AFT transaction)

Returns:

  • (TrueClass | FalseClass)


489
490
491
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 489

def aft_indicator
  @aft_indicator
end

#aggregated_auth_indicatorString

Indicates if transaction is an aggregated auth Possible values:

  • true
  • false

Returns:

  • (String)


426
427
428
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 426

def aggregated_auth_indicator
  @aggregated_auth_indicator
end

#auth_indicatorString

Flag that specifies the purpose of the authorization. Possible values:

  • 0: Preauthorization
  • 1: Final authorization To set the default for this field, contact CyberSource Customer Support.

Barclays and Elavon

The default for Barclays and Elavon is 1 (final authorization). To change the default for this field, contact CyberSource Customer Support.

CyberSource through VisaNet

When the value for this field is 0, it corresponds to the following data in the TC 33 capture file:

  • Record: CP01 TCR0
  • Position: 164
  • Field: Additional Authorization Indicators When the value for this field is 1, it does not correspond to any data in the TC 33 capture file.

Returns:

  • (String)


89
90
91
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 89

def auth_indicator
  @auth_indicator
end

#auth_typeString

Authorization type. Possible values:

  • AUTOCAPTURE: automatic capture.
  • STANDARDCAPTURE: standard capture.
  • VERBAL: forced capture. Include it in the payment request for a forced capture. Include it in the capture request for a verbal payment.

Asia, Middle East, and Africa Gateway; Cielo; Comercio Latino; and

CyberSource Latin American Processing Set this field to AUTOCAPTURE and include it in a bundled request to indicate that you are requesting an automatic capture. If your account is configured to enable automatic captures, set this field to STANDARDCAPTURE and include it in a standard authorization or bundled request to indicate that you are overriding an automatic capture.

Forced Capture

Set this field to VERBAL and include it in the authorization request to indicate that you are performing a forced capture; therefore, you receive the authorization code outside the CyberSource system.

Verbal Authorization

Set this field to VERBAL and include it in the capture request to indicate that the request is for a verbal authorization.

for PayPal ptsV2CreateOrderPost400Response

Set this field to 'AUTHORIZE' or 'CAPTURE' depending on whether you want to invoke delayed capture or sale respectively.

Returns:

  • (String)


35
36
37
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 35

def auth_type
  @auth_type
end

#balance_inquiryTrueClass | FalseClass

Flag that indicates whether to return balance information. Possible values:

  • true: Return balance information.
  • false: Do not return balance information.

Used by

Authorization Required for a balance inquiry; otherwise, not used.

PIN debit

Required for a balance inquiry request of a PIN debit purchase; otherwise, not used.

Returns:

  • (TrueClass | FalseClass)


133
134
135
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 133

def balance_inquiry
  @balance_inquiry
end

#balance_updateTrueClass | FalseClass

Merchant to inform Cybersource whether a transaction is Money load with Balance Update. Possible values:

- `true` (This is a Money load with balance update transaction)
- `false` (default value) (This is not a Money load with balance update

transaction)

Returns:

  • (TrueClass | FalseClass)


519
520
521
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 519

def balance_update
  @balance_update
end

#bill_paymentTrueClass | FalseClass

Indicates payment for bill or payment towards existing contractual loan. Possible values:

  • true: Bill payment or loan payment.
  • false (default): Not a bill payment or loan payment. Optional request field.

Returns:

  • (TrueClass | FalseClass)


356
357
358
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 356

def bill_payment
  @bill_payment
end

#bill_payment_typeString

Reason for the payment. Possible values:

  • 001: Public utilities / Utility payment
  • 002: Government services
  • 003: Cellular / Mobile phone top-up
  • 004: Coupon payment
  • 005: Installment based repayment
  • 006: Billing payment
  • 007: Tax payment
  • 008: Tax payment refunds The value for this field corresponds to the following data in the TC 33A capture file (applicable to Brazil):
  • Record: CP07 TCR0
  • Position: 48-50
  • Field: Bill Payment Transaction Type Identifier The value for this field corresponds to the following data in the TC 33A capture file (applicable to Installment) based Repayment):
  • Record: CP01 TCR6
  • Position: 154-156
  • Field: Bill Payment Transaction Type Identifier This field is supported for
  1. Bill payments in Brazil with Mastercard on CyberSource through VisaNet.
  2. Installment based repayment transactions on Cybersource through VisaNet.

Returns:

  • (String)


384
385
386
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 384

def bill_payment_type
  @bill_payment_type
end

#card_verification_indicatorTrueClass | FalseClass

This API field will indicate whether a card verification check is being performed during the transaction Possible values:

- `true`
- `false` (default value)

Returns:

  • (TrueClass | FalseClass)


472
473
474
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 472

def card_verification_indicator
  @card_verification_indicator
end

#cash_advance_indicatorTrueClass | FalseClass

This API field enables the merchant to indicate that a given transaction is Cash Advance. Cash advance or Cash disbursement functionality allows a merchant to dispense cash at a point of sale. It provides the ability of a POS system to act like an ATM. These terminals are typically seen in bank branches where customers can use their card and withdraw cash or at merchant locations where ATMs are sparse. Possible values:

- `true` (Cash advance is supported)
- `false` (default: cash advance is not supported)

Returns:

  • (TrueClass | FalseClass)


455
456
457
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 455

def cash_advance_indicator
  @cash_advance_indicator
end

#debt_recovery_indicatorString

Indicates if transaction is a debt recovery request Possible values:

  • true
  • false

Returns:

  • (String)


433
434
435
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 433

def debt_recovery_indicator
  @debt_recovery_indicator
end

#decline_ani_flagsArray[DeclineAniFlag]

User-defined list of ANI (Address Name Inquiry) codes that will cause the system to decline a transaction. Address Name Inquiry is a Verification suite product which checks whether the name shared in the transaction matches with the one stored at the issuing bank. This field replicates the same behavior as AVS (which uses DAVSNO flag), but for ANI verification using the DANINO flag. Important:

  • By default, no ANI codes cause declines (empty/null)
  • Merchant specifies which ANI codes should trigger declines
  • When triggered, returns reason code 217 with reply flag DANINO
  • Use space to separate values in the list
  • To receive declines for the ANI code N, include the value N in the list

ANI Result Codes

ANI Code Description
Y Match: Full name match with issuing bank records
O Partial match: Partial name match with issuing bank records
N No match: Name does not match issuing bank records
U Unverified: ANI verification not performed or not supported
R Retry: System should retry the ANI check

Reply Flag When Triggered

When a transaction's ANI result matches one of the codes in this list, the system returns:

  • Reason Code: 217
  • Reply Flag: DANINO
  • Description: Decline. The authorization request was approved by the issuing bank but was flagged because it did not pass the Address Name Inquiry (ANI) check.
  • Possible Action: Review the order for the possibility of fraud.

Used by

Authorization Optional field for controlling ANI-based declines.

API Ticket

ACCAPI-2138

Returns:



320
321
322
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 320

def decline_ani_flags
  @decline_ani_flags
end

#decline_avs_flagsArray[String]

Comma-separated list of AVS flags that cause the reply flag DAVSNO to be returned. Important To receive declines for the AVS code N, you must include the value N in the comma-separated list.

AVS Codes for Cielo 3.0 and CyberSource Latin American Processing

Note CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this section is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.

AVS Code Description
D Partial match: postal code and address match.
E Not supported: AVS is not supported for this card type. or Invalid:
the acquirer returned an unrecognized value for the AVS response.
F Partial match: postal code matches, but CPF and address do not match.*
G Not supported: AVS not supported or not verified.
I No match: AVS information is not available.
K Partial match: CPF matches, but postal code and address do not match.*
L Partial match: postal code and CPF match, but address does not match.*
N No match: postal code, CPF, and address do not match.*
O Partial match: CPF and address match, but postal code does not match.*
R Not supported: your implementation does not support AVS or System
unavailable.
T Partial match: address matches, but postal code and CPF do not match.*
V Match: postal code, CPF, and address match.*
* CPF (Cadastro de Pessoas Fisicas) is required only for Redecard in
Brazil.

AVS Codes for All Other Processors

Note The list of AVS codes for all other processors follows these descriptions of the processor-specific information for these codes.

American Express Cards

For American Express cards only, you can receive Visa and CyberSource AVS codes in addition to the American Express AVS codes. Note For CyberSource through VisaNet, the American Express AVS codes are converted to Visa AVS codes before they are returned to you. As a result, you will not receive American Express AVS codes for the American Express card type.

American Express Card codes: F, H, K, L, O, T, V

Domestic and International Visa Cards

The international and domestic alphabetic AVS codes are the Visa standard AVS codes. CyberSource maps the standard AVS return codes for other types of payment cards, including American Express cards, to the Visa standard AVS codes. AVS is considered either domestic or international, depending on the location of the bank that issued the customer's payment card:

  • When the bank is in the U.S., the AVS is domestic.
  • When the bank is outside the U.S., the AVS is international. You should be prepared to handle both domestic and international AVS result codes:
  • For international cards, you can receive domestic AVS codes in addition to the international AVS codes.
  • For domestic cards, you can receive international AVS codes in addition to the domestic AVS codes. International Visa Codes: B, C, D, G, I, M, P Domestic Visa Codes: A, E,N, R, S, U, W, X, Y, Z

CyberSource Codes

The numeric AVS codes are created by CyberSource and are not standard Visa codes. These AVS codes can be returned for any card type. CyberSource Codes: 1, 2, 3, 4

Table of AVS Codes for All Other Processors

AVS Code Description
A Partial match: street address matches, but 5-digit and 9-digit postal
codes do not match.
B Partial match: street address matches, but postal code is not verified.
Returned only for Visa cards not issued in the U.S.
C No match: street address and postal code do not match. Returned only
for Visa cards not issued in the U.S.
D & M Match: street address and postal code match. Returned only for Visa
cards not issued in the U.S.
E Invalid: AVS data is invalid or AVS is not allowed for this card type.
F Partial match: card member’s name does not match, but billing postal
code matches.
G Not supported: issuing bank outside the U.S. does not support AVS.
H Partial match: card member’s name does not match, but street address
and postal code match. Returned only for the American Express card type.
I No match: address not verified. Returned only for Visa cards not issued
in the U.S.
K Partial match: card member’s name matches, but billing address and

billing postal code do not match. Returned only for the American Express card type.| |L|Partial match: card member’s name and billing postal code match, but billing address does not match. Returned only for the American Express card type.| |M|See the entry for D & M.| |N|No match: one of the following: street address and postal code do not match or (American Express card type only) card member’s name, street address, and postal code do not match.| |O|Partial match: card member’s name and billing address match, but billing postal code does not match. Returned only for the American Express card type.| |P|Partial match: postal code matches, but street address not verified. Returned only for Visa cards not issued in the U.S.| |R|System unavailable.| |S|Not supported: issuing bank in the U.S. does not support AVS.| |T|Partial match: card member’s name does not match, but street address matches. Returned only for the American Express card type.| |U|System unavailable: address information unavailable for one of these reasons: The U.S. bank does not support AVS outside the U.S. or The AVS in a U.S. bank is not functioning properly.| |V|Match: card member’s name, billing address, and billing postal code match. Returned only for the American Express card type.| |W|Partial match: street address does not match, but 9-digit postal code matches.| |X|Match: street address and 9-digit postal code match.| |Y|Match: street address and 5-digit postal code match.| |Z|Partial match: street address does not match, but 5-digit postal code matches.| |1|Not supported: one of the following: AVS is not supported for this processor or card type or AVS is disabled for your CyberSource account. To enable AVS, contact CyberSource Customer Support.| |2|Unrecognized: the processor returned an unrecognized value for the AVS response.| |3|Match: address is confirmed. Returned only for PayPal Express Checkout.| |4|No match: address is not confirmed. Returned only for PayPal Express Checkout.| |5|No match: no AVS code was returned by the processor.|

Returns:

  • (Array[String])


281
282
283
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 281

def decline_avs_flags
  @decline_avs_flags
end

#deferred_auth_indicatorTrueClass | FalseClass

Flag that indicates whether the authorization request was delayed because connectivity was interrupted. Possible values:

- `true` (Deferred authorization)
- `false` (default: Not a deferred authorization)

Returns:

  • (TrueClass | FalseClass)


441
442
443
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 441

def deferred_auth_indicator
  @deferred_auth_indicator
end

#extend_auth_indicatorString

Indicates Authorization extension transaction. Extension transaction is used to prolong the settlement period by one additional settlement cycle period. Possible values:

  • true: Transaction is an Authorization Extension transaction.
  • false: Transaction is not an Authorization Extension transaction.

Returns:

  • (String)


120
121
122
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 120

def extend_auth_indicator
  @extend_auth_indicator
end

#ignore_avs_resultTrueClass | FalseClass

Flag for a sale request that indicates whether to allow the capture service to run even when the authorization receives an AVS decline, as indicated by a reply flag value of DAVSNO. Possible values:

  • true: Ignore the results of AVS checking and run the capture service.
  • false (default): If the authorization receives an AVS decline, do not run the capture service. When the value of this field is true, the list in the processingInformation.authorizationOptions.declineAvsFlags field is ignored.

Used by

Authorization Optional field. String (3)

Returns:

  • (TrueClass | FalseClass)


150
151
152
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 150

def ignore_avs_result
  @ignore_avs_result
end

#ignore_cv_resultTrueClass | FalseClass

Flag for a sale request that indicates whether to allow the capture service to run even when the authorization receives a CVN decline, as indicated by an processorInformation.cardVerification.resultCode value of D or N. Possible values:

  • true: Ignore the results of CVN checking and run the capture service.
  • false (default): If the authorization receives a CVN decline, do not run the capture service.

Used by

Authorization Optional field.

Returns:

  • (TrueClass | FalseClass)


334
335
336
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 334

def ignore_cv_result
  @ignore_cv_result
end

#initiatorInitiator

Flag for a sale request that indicates whether to allow the capture service to run even when the authorization receives a CVN decline, as indicated by an processorInformation.cardVerification.resultCode value of D or N. Possible values:

  • true: Ignore the results of CVN checking and run the capture service.
  • false (default): If the authorization receives a CVN decline, do not run the capture service.

Used by

Authorization Optional field.

Returns:



348
349
350
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 348

def initiator
  @initiator
end

#money_loadTrueClass | FalseClass

Merchant to inform Cybersource whether a transaction is Money load with Money load only. Possible values:

- `true` (This is a money load transaction)
- `false` (default value) (This is not a money load transaction)

Returns:

  • (TrueClass | FalseClass)


527
528
529
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 527

def money_load
  @money_load
end

#pan_return_indicatorString

Visa Platform Connect

The field contains the PAN translation indicator for American Express Contactless Transaction. Valid value is  1- Expresspay Translation, PAN request 2- Expresspay Translation, PAN and Expiry date request

Returns:

  • (String)


43
44
45
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 43

def pan_return_indicator
  @pan_return_indicator
end

#partial_auth_indicatorTrueClass | FalseClass

Flag that indicates whether the transaction is enabled for partial authorization. When the request includes this field, this value overrides the information in your account. Possible values:

  • true: Enable the transaction for partial authorization.
  • false: Do not enable the transaction for partial authorization.

PIN debit

Required field for partial authorizations that use PIN debit purchase; otherwise, not used.

Used by

Authorization Optional field.

CyberSource through VisaNet

To set the default for this field, contact CyberSource Customer Support. The value for this field corresponds to the following data in the TC 33 capture file5:

  • Record: CP01 TCR0
  • Position: 164
  • Field: Additional Authorization Indicators

Returns:

  • (TrueClass | FalseClass)


111
112
113
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 111

def partial_auth_indicator
  @partial_auth_indicator
end

#redemption_inquiryTrueClass | FalseClass

Flag that indicates the payment request is a redemption inquiry. Possible values:

- `true`
- `false`

Returns:

  • (TrueClass | FalseClass)


391
392
393
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 391

def redemption_inquiry
  @redemption_inquiry
end

#service_typeString

Field is used for back-to-back funding transaction and can be defined as a payment flow that automatically transfers funds through a real-time funding or a live-load. This type of transaction can also be connected to a purchase. In back-to-back funding of general purpose card that is used to make a purchase, two separate accounts are involved:

  • account one is used to make the purchase
  • account two is used to automatically fund or reimburse account one Possible values:
  • 0B = back to back funding transaction
  • 00 = normal transaction
  • 01 = originator hold
  • 02 = Visa deferred OCT hold, default interval
  • 03 = Visa deferred OCT hold, user-defined interval
  • 09 = Cancel pending deferred OCT request
  • 0I = Visa Direct custom program 1
  • 0Q = uery the status of the deferred OCT
  • A0 = Alias Directory 2

Returns:

  • (String)


510
511
512
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 510

def service_type
  @service_type
end

#split_payment_transactionTrueClass | FalseClass

Visa Platform Connect

Indicates split payment transaction. A split payment allows the use of two payment methods for a single transaction. Possible values:

- `true` (split payment transaction is supported)
- `false` (default: split payment transaction is not supported)

Returns:

  • (TrueClass | FalseClass)


464
465
466
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 464

def split_payment_transaction
  @split_payment_transaction
end

#transaction_modeString

Transaction mode identifier. Identifies the specific channel from which the transaction originates. Possible values:

  • M – Mobile Order
  • T – Telephone Order

Returns:

  • (String)


480
481
482
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 480

def transaction_mode
  @transaction_mode
end

#transportation_modeString

Type of transportation mode : Possible Values:

  • 00 = Unknown
  • 01 = Urban bus
  • 02 = Interurban bus
  • 03=Lighttrainmasstransit(Underground Metro LTR)
  • 04 = Train
  • 05 = Commuter train
  • 06 = Water-borne vehicle
  • 07 = Toll
  • 08 = Parking
  • 09 = Taxi
  • 10 = High-speed train
  • 11 = Rural bus
  • 12 = Express commuter train
  • 13 = Para transit
  • 14 = Self drive vehicle
  • 15 = Coach
  • 16 = Locomotive
  • 17 = Powered motor coach
  • 18 = Trailer
  • 19 = Regional train
  • 20 = Inter-city
  • 21 = Funicular train
  • 22 = Cable car

Returns:

  • (String)


419
420
421
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 419

def transportation_mode
  @transportation_mode
end

#verbal_auth_codeString

Authorization code.

Forced Capture

Use this field to send the authorization code you received from a payment that you authorized outside the CyberSource system.

PIN debit

Authorization code that is returned by the processor. Returned by PIN debit purchase.

Verbal Authorization

Use this field in CAPTURE API to send the verbally received authorization code.

Returns:

  • (String)


57
58
59
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 57

def verbal_auth_code
  @verbal_auth_code
end

#verbal_auth_transaction_idString

Transaction ID (TID).

FDMS South

This field is required for verbal authorizations and forced captures with the American Express card type to comply with the CAPN requirements:

  • Forced capture: Obtain the value for this field from the authorization response.
  • Verbal authorization: You cannot obtain a value for this field so CyberSource uses the default value of 000000000000000 (15 zeros).

Returns:

  • (String)


70
71
72
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 70

def verbal_auth_transaction_id
  @verbal_auth_transaction_id
end

Class Method Details

.from_element(root) ⇒ Object



755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 755

def self.from_element(root)
  auth_type = XmlUtilities.from_element(root, 'authType', String)
  pan_return_indicator = XmlUtilities.from_element(root,
                                                   'panReturnIndicator',
                                                   String)
  verbal_auth_code = XmlUtilities.from_element(root, 'verbalAuthCode',
                                               String)
  verbal_auth_transaction_id = XmlUtilities.from_element(
    root, 'verbalAuthTransactionId', String
  )
  auth_indicator = XmlUtilities.from_element(root, 'authIndicator', String)
  partial_auth_indicator = XmlUtilities.from_element(root,
                                                     'partialAuthIndicator',
                                                     TrueClass)
  extend_auth_indicator = XmlUtilities.from_element(root,
                                                    'extendAuthIndicator',
                                                    String)
  balance_inquiry = XmlUtilities.from_element(root, 'balanceInquiry',
                                              TrueClass)
  ignore_avs_result = XmlUtilities.from_element(root, 'ignoreAvsResult',
                                                TrueClass)
  decline_avs_flags = XmlUtilities.from_element_to_array(root,
                                                         'declineAvsFlags',
                                                         String)
  decline_ani_flags = XmlUtilities.from_element_to_array(root,
                                                         'declineAniFlags',
                                                         String)
  ignore_cv_result = XmlUtilities.from_element(root, 'ignoreCvResult',
                                               TrueClass)
  initiator = XmlUtilities.from_element(root, 'Initiator', Initiator)
  bill_payment = XmlUtilities.from_element(root, 'billPayment', TrueClass)
  bill_payment_type = XmlUtilities.from_element(root, 'billPaymentType',
                                                String)
  redemption_inquiry = XmlUtilities.from_element(root, 'redemptionInquiry',
                                                 TrueClass)
  transportation_mode = XmlUtilities.from_element(root,
                                                  'transportationMode',
                                                  String)
  aggregated_auth_indicator = XmlUtilities.from_element(
    root, 'aggregatedAuthIndicator', String
  )
  debt_recovery_indicator = XmlUtilities.from_element(
    root, 'debtRecoveryIndicator', String
  )
  deferred_auth_indicator = XmlUtilities.from_element(
    root, 'deferredAuthIndicator', TrueClass
  )
  cash_advance_indicator = XmlUtilities.from_element(root,
                                                     'cashAdvanceIndicator',
                                                     TrueClass)
  split_payment_transaction = XmlUtilities.from_element(
    root, 'splitPaymentTransaction', TrueClass
  )
  card_verification_indicator = XmlUtilities.from_element(
    root, 'cardVerificationIndicator', TrueClass
  )
  transaction_mode = XmlUtilities.from_element(root, 'transactionMode',
                                               String)
  aft_indicator = XmlUtilities.from_element(root, 'aftIndicator', TrueClass)
  service_type = XmlUtilities.from_element(root, 'serviceType', String)
  balance_update = XmlUtilities.from_element(root, 'balanceUpdate',
                                             TrueClass)
  money_load = XmlUtilities.from_element(root, 'moneyLoad', TrueClass)

  new(auth_type: auth_type,
      pan_return_indicator: pan_return_indicator,
      verbal_auth_code: verbal_auth_code,
      verbal_auth_transaction_id: verbal_auth_transaction_id,
      auth_indicator: auth_indicator,
      partial_auth_indicator: partial_auth_indicator,
      extend_auth_indicator: extend_auth_indicator,
      balance_inquiry: balance_inquiry,
      ignore_avs_result: ignore_avs_result,
      decline_avs_flags: decline_avs_flags,
      decline_ani_flags: decline_ani_flags,
      ignore_cv_result: ignore_cv_result,
      initiator: initiator,
      bill_payment: bill_payment,
      bill_payment_type: bill_payment_type,
      redemption_inquiry: redemption_inquiry,
      transportation_mode: transportation_mode,
      aggregated_auth_indicator: aggregated_auth_indicator,
      debt_recovery_indicator: debt_recovery_indicator,
      deferred_auth_indicator: deferred_auth_indicator,
      cash_advance_indicator: cash_advance_indicator,
      split_payment_transaction: split_payment_transaction,
      card_verification_indicator: card_verification_indicator,
      transaction_mode: transaction_mode,
      aft_indicator: aft_indicator,
      service_type: service_type,
      balance_update: balance_update,
      money_load: money_load,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 665

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  auth_type = hash.key?('authType') ? hash['authType'] : SKIP
  pan_return_indicator =
    hash.key?('panReturnIndicator') ? hash['panReturnIndicator'] : SKIP
  verbal_auth_code =
    hash.key?('verbalAuthCode') ? hash['verbalAuthCode'] : SKIP
  verbal_auth_transaction_id =
    hash.key?('verbalAuthTransactionId') ? hash['verbalAuthTransactionId'] : SKIP
  auth_indicator = hash.key?('authIndicator') ? hash['authIndicator'] : SKIP
  partial_auth_indicator =
    hash.key?('partialAuthIndicator') ? hash['partialAuthIndicator'] : SKIP
  extend_auth_indicator =
    hash.key?('extendAuthIndicator') ? hash['extendAuthIndicator'] : SKIP
  balance_inquiry =
    hash.key?('balanceInquiry') ? hash['balanceInquiry'] : SKIP
  ignore_avs_result = hash['ignoreAvsResult'] ||= false
  decline_avs_flags =
    hash.key?('declineAvsFlags') ? hash['declineAvsFlags'] : SKIP
  decline_ani_flags =
    hash.key?('declineAniFlags') ? hash['declineAniFlags'] : SKIP
  ignore_cv_result = hash['ignoreCvResult'] ||= false
  initiator = Initiator.from_hash(hash['initiator']) if hash['initiator']
  bill_payment = hash.key?('billPayment') ? hash['billPayment'] : SKIP
  bill_payment_type =
    hash.key?('billPaymentType') ? hash['billPaymentType'] : SKIP
  redemption_inquiry =
    hash.key?('redemptionInquiry') ? hash['redemptionInquiry'] : SKIP
  transportation_mode =
    hash.key?('transportationMode') ? hash['transportationMode'] : SKIP
  aggregated_auth_indicator =
    hash.key?('aggregatedAuthIndicator') ? hash['aggregatedAuthIndicator'] : SKIP
  debt_recovery_indicator =
    hash.key?('debtRecoveryIndicator') ? hash['debtRecoveryIndicator'] : SKIP
  deferred_auth_indicator =
    hash.key?('deferredAuthIndicator') ? hash['deferredAuthIndicator'] : SKIP
  cash_advance_indicator =
    hash.key?('cashAdvanceIndicator') ? hash['cashAdvanceIndicator'] : SKIP
  split_payment_transaction =
    hash.key?('splitPaymentTransaction') ? hash['splitPaymentTransaction'] : SKIP
  card_verification_indicator =
    hash.key?('cardVerificationIndicator') ? hash['cardVerificationIndicator'] : SKIP
  transaction_mode =
    hash.key?('transactionMode') ? hash['transactionMode'] : SKIP
  aft_indicator = hash.key?('aftIndicator') ? hash['aftIndicator'] : SKIP
  service_type = hash.key?('serviceType') ? hash['serviceType'] : SKIP
  balance_update = hash.key?('balanceUpdate') ? hash['balanceUpdate'] : SKIP
  money_load = hash.key?('moneyLoad') ? hash['moneyLoad'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInfOauthOrizationOptions.new(auth_type: auth_type,
                                         pan_return_indicator: pan_return_indicator,
                                         verbal_auth_code: verbal_auth_code,
                                         verbal_auth_transaction_id: verbal_auth_transaction_id,
                                         auth_indicator: auth_indicator,
                                         partial_auth_indicator: partial_auth_indicator,
                                         extend_auth_indicator: extend_auth_indicator,
                                         balance_inquiry: balance_inquiry,
                                         ignore_avs_result: ignore_avs_result,
                                         decline_avs_flags: decline_avs_flags,
                                         decline_ani_flags: decline_ani_flags,
                                         ignore_cv_result: ignore_cv_result,
                                         initiator: initiator,
                                         bill_payment: bill_payment,
                                         bill_payment_type: bill_payment_type,
                                         redemption_inquiry: redemption_inquiry,
                                         transportation_mode: transportation_mode,
                                         aggregated_auth_indicator: aggregated_auth_indicator,
                                         debt_recovery_indicator: debt_recovery_indicator,
                                         deferred_auth_indicator: deferred_auth_indicator,
                                         cash_advance_indicator: cash_advance_indicator,
                                         split_payment_transaction: split_payment_transaction,
                                         card_verification_indicator: card_verification_indicator,
                                         transaction_mode: transaction_mode,
                                         aft_indicator: aft_indicator,
                                         service_type: service_type,
                                         balance_update: balance_update,
                                         money_load: money_load,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 530

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['auth_type'] = 'authType'
  @_hash['pan_return_indicator'] = 'panReturnIndicator'
  @_hash['verbal_auth_code'] = 'verbalAuthCode'
  @_hash['verbal_auth_transaction_id'] = 'verbalAuthTransactionId'
  @_hash['auth_indicator'] = 'authIndicator'
  @_hash['partial_auth_indicator'] = 'partialAuthIndicator'
  @_hash['extend_auth_indicator'] = 'extendAuthIndicator'
  @_hash['balance_inquiry'] = 'balanceInquiry'
  @_hash['ignore_avs_result'] = 'ignoreAvsResult'
  @_hash['decline_avs_flags'] = 'declineAvsFlags'
  @_hash['decline_ani_flags'] = 'declineAniFlags'
  @_hash['ignore_cv_result'] = 'ignoreCvResult'
  @_hash['initiator'] = 'initiator'
  @_hash['bill_payment'] = 'billPayment'
  @_hash['bill_payment_type'] = 'billPaymentType'
  @_hash['redemption_inquiry'] = 'redemptionInquiry'
  @_hash['transportation_mode'] = 'transportationMode'
  @_hash['aggregated_auth_indicator'] = 'aggregatedAuthIndicator'
  @_hash['debt_recovery_indicator'] = 'debtRecoveryIndicator'
  @_hash['deferred_auth_indicator'] = 'deferredAuthIndicator'
  @_hash['cash_advance_indicator'] = 'cashAdvanceIndicator'
  @_hash['split_payment_transaction'] = 'splitPaymentTransaction'
  @_hash['card_verification_indicator'] = 'cardVerificationIndicator'
  @_hash['transaction_mode'] = 'transactionMode'
  @_hash['aft_indicator'] = 'aftIndicator'
  @_hash['service_type'] = 'serviceType'
  @_hash['balance_update'] = 'balanceUpdate'
  @_hash['money_load'] = 'moneyLoad'
  @_hash
end

.nullablesObject

An array for nullable fields



598
599
600
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 598

def self.nullables
  []
end

.optionalsObject

An array for optional fields



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 564

def self.optionals
  %w[
    auth_type
    pan_return_indicator
    verbal_auth_code
    verbal_auth_transaction_id
    auth_indicator
    partial_auth_indicator
    extend_auth_indicator
    balance_inquiry
    ignore_avs_result
    decline_avs_flags
    decline_ani_flags
    ignore_cv_result
    initiator
    bill_payment
    bill_payment_type
    redemption_inquiry
    transportation_mode
    aggregated_auth_indicator
    debt_recovery_indicator
    deferred_auth_indicator
    cash_advance_indicator
    split_payment_transaction
    card_verification_indicator
    transaction_mode
    aft_indicator
    service_type
    balance_update
    money_load
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 929

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} auth_type: #{@auth_type.inspect}, pan_return_indicator:"\
  " #{@pan_return_indicator.inspect}, verbal_auth_code: #{@verbal_auth_code.inspect},"\
  " verbal_auth_transaction_id: #{@verbal_auth_transaction_id.inspect}, auth_indicator:"\
  " #{@auth_indicator.inspect}, partial_auth_indicator: #{@partial_auth_indicator.inspect},"\
  " extend_auth_indicator: #{@extend_auth_indicator.inspect}, balance_inquiry:"\
  " #{@balance_inquiry.inspect}, ignore_avs_result: #{@ignore_avs_result.inspect},"\
  " decline_avs_flags: #{@decline_avs_flags.inspect}, decline_ani_flags:"\
  " #{@decline_ani_flags.inspect}, ignore_cv_result: #{@ignore_cv_result.inspect}, initiator:"\
  " #{@initiator.inspect}, bill_payment: #{@bill_payment.inspect}, bill_payment_type:"\
  " #{@bill_payment_type.inspect}, redemption_inquiry: #{@redemption_inquiry.inspect},"\
  " transportation_mode: #{@transportation_mode.inspect}, aggregated_auth_indicator:"\
  " #{@aggregated_auth_indicator.inspect}, debt_recovery_indicator:"\
  " #{@debt_recovery_indicator.inspect}, deferred_auth_indicator:"\
  " #{@deferred_auth_indicator.inspect}, cash_advance_indicator:"\
  " #{@cash_advance_indicator.inspect}, split_payment_transaction:"\
  " #{@split_payment_transaction.inspect}, card_verification_indicator:"\
  " #{@card_verification_indicator.inspect}, transaction_mode: #{@transaction_mode.inspect},"\
  " aft_indicator: #{@aft_indicator.inspect}, service_type: #{@service_type.inspect},"\
  " balance_update: #{@balance_update.inspect}, money_load: #{@money_load.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 908

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} auth_type: #{@auth_type}, pan_return_indicator: #{@pan_return_indicator},"\
  " verbal_auth_code: #{@verbal_auth_code}, verbal_auth_transaction_id:"\
  " #{@verbal_auth_transaction_id}, auth_indicator: #{@auth_indicator},"\
  " partial_auth_indicator: #{@partial_auth_indicator}, extend_auth_indicator:"\
  " #{@extend_auth_indicator}, balance_inquiry: #{@balance_inquiry}, ignore_avs_result:"\
  " #{@ignore_avs_result}, decline_avs_flags: #{@decline_avs_flags}, decline_ani_flags:"\
  " #{@decline_ani_flags}, ignore_cv_result: #{@ignore_cv_result}, initiator: #{@initiator},"\
  " bill_payment: #{@bill_payment}, bill_payment_type: #{@bill_payment_type},"\
  " redemption_inquiry: #{@redemption_inquiry}, transportation_mode: #{@transportation_mode},"\
  " aggregated_auth_indicator: #{@aggregated_auth_indicator}, debt_recovery_indicator:"\
  " #{@debt_recovery_indicator}, deferred_auth_indicator: #{@deferred_auth_indicator},"\
  " cash_advance_indicator: #{@cash_advance_indicator}, split_payment_transaction:"\
  " #{@split_payment_transaction}, card_verification_indicator:"\
  " #{@card_verification_indicator}, transaction_mode: #{@transaction_mode}, aft_indicator:"\
  " #{@aft_indicator}, service_type: #{@service_type}, balance_update: #{@balance_update},"\
  " money_load: #{@money_load}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
# File 'lib/cyber_source_merged_spec/models/processing_inf_oauth_orization_options.rb', line 850

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'authType', auth_type)
  XmlUtilities.add_as_subelement(doc, root, 'panReturnIndicator',
                                 pan_return_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'verbalAuthCode',
                                 verbal_auth_code)
  XmlUtilities.add_as_subelement(doc, root, 'verbalAuthTransactionId',
                                 verbal_auth_transaction_id)
  XmlUtilities.add_as_subelement(doc, root, 'authIndicator', auth_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'partialAuthIndicator',
                                 partial_auth_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'extendAuthIndicator',
                                 extend_auth_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'balanceInquiry',
                                 balance_inquiry)
  XmlUtilities.add_as_subelement(doc, root, 'ignoreAvsResult',
                                 ignore_avs_result)
  XmlUtilities.add_array_as_subelement(doc, root, 'declineAvsFlags',
                                       decline_avs_flags)
  XmlUtilities.add_array_as_subelement(doc, root, 'declineAniFlags',
                                       decline_ani_flags)
  XmlUtilities.add_as_subelement(doc, root, 'ignoreCvResult',
                                 ignore_cv_result)
  XmlUtilities.add_as_subelement(doc, root, 'Initiator', initiator)
  XmlUtilities.add_as_subelement(doc, root, 'billPayment', bill_payment)
  XmlUtilities.add_as_subelement(doc, root, 'billPaymentType',
                                 bill_payment_type)
  XmlUtilities.add_as_subelement(doc, root, 'redemptionInquiry',
                                 redemption_inquiry)
  XmlUtilities.add_as_subelement(doc, root, 'transportationMode',
                                 transportation_mode)
  XmlUtilities.add_as_subelement(doc, root, 'aggregatedAuthIndicator',
                                 aggregated_auth_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'debtRecoveryIndicator',
                                 debt_recovery_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'deferredAuthIndicator',
                                 deferred_auth_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'cashAdvanceIndicator',
                                 cash_advance_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'splitPaymentTransaction',
                                 split_payment_transaction)
  XmlUtilities.add_as_subelement(doc, root, 'cardVerificationIndicator',
                                 card_verification_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'transactionMode',
                                 transaction_mode)
  XmlUtilities.add_as_subelement(doc, root, 'aftIndicator', aft_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'serviceType', service_type)
  XmlUtilities.add_as_subelement(doc, root, 'balanceUpdate', balance_update)
  XmlUtilities.add_as_subelement(doc, root, 'moneyLoad', money_load)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end