Class: CyberSourceMergedSpec::ProcessingInformation11

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processing_information11.rb

Overview

ProcessingInformation11 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(action_list: SKIP, action_token_types: SKIP, commerce_indicator: SKIP, processor_id: SKIP, payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, purchase_level: SKIP, industry_data_type: SKIP, wallet_type: SKIP, national_net_domestic_data: SKIP, network_routing_order: SKIP, recurring_options: SKIP, bank_transfer_options: SKIP, purchase_options: SKIP, electronic_benefits_transfer: SKIP, loan_options: SKIP, japan_payment_options: SKIP, refund_options: SKIP, merchant_verification_value: SKIP, transaction_type_indicator: SKIP, additional_properties: nil) ⇒ ProcessingInformation11

Returns a new instance of ProcessingInformation11.



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 627

def initialize(action_list: SKIP, action_token_types: SKIP,
               commerce_indicator: SKIP, processor_id: SKIP,
               payment_solution: SKIP, reconciliation_id: SKIP,
               link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP,
               purchase_level: SKIP, industry_data_type: SKIP,
               wallet_type: SKIP, national_net_domestic_data: SKIP,
               network_routing_order: SKIP, recurring_options: SKIP,
               bank_transfer_options: SKIP, purchase_options: SKIP,
               electronic_benefits_transfer: SKIP, loan_options: SKIP,
               japan_payment_options: SKIP, refund_options: SKIP,
               merchant_verification_value: SKIP,
               transaction_type_indicator: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @action_list = action_list unless action_list == SKIP
  @action_token_types = action_token_types unless action_token_types == SKIP
  @commerce_indicator = commerce_indicator unless commerce_indicator == SKIP
  @processor_id = processor_id unless processor_id == SKIP
  @payment_solution = payment_solution unless payment_solution == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @link_id = link_id unless link_id == SKIP
  @report_group = report_group unless report_group == SKIP
  @visa_checkout_id = visa_checkout_id unless visa_checkout_id == SKIP
  @purchase_level = purchase_level unless purchase_level == SKIP
  @industry_data_type = industry_data_type unless industry_data_type == SKIP
  @wallet_type = wallet_type unless wallet_type == SKIP
  unless national_net_domestic_data == SKIP
    @national_net_domestic_data =
      national_net_domestic_data
  end
  @network_routing_order = network_routing_order unless network_routing_order == SKIP
  @recurring_options = recurring_options unless recurring_options == SKIP
  @bank_transfer_options = bank_transfer_options unless bank_transfer_options == SKIP
  @purchase_options = purchase_options unless purchase_options == SKIP
  unless electronic_benefits_transfer == SKIP
    @electronic_benefits_transfer =
      electronic_benefits_transfer
  end
  @loan_options = loan_options unless loan_options == SKIP
  @japan_payment_options = japan_payment_options unless japan_payment_options == SKIP
  @refund_options = refund_options unless refund_options == SKIP
  unless merchant_verification_value == SKIP
    @merchant_verification_value =
      merchant_verification_value
  end
  unless transaction_type_indicator == SKIP
    @transaction_type_indicator =
      transaction_type_indicator
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#action_listArray[String]

Array of actions (one or more) to be included in the payment to invoke bundled services along with Standalone Credit. Possible values are one or more of follows:

  • DECISION_SKIP: Use this when you want to skip Decision Manager service(s).

Returns:

  • (Array[String])


18
19
20
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 18

def action_list
  @action_list
end

#action_token_typesArray[String]

CyberSource tokens types you are performing a create on. If not supplied the default token type for the merchants token vault will be used. Valid values:

  • customer
  • paymentInstrument
  • instrumentIdentifier
  • shippingAddress

Returns:

  • (Array[String])


29
30
31
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 29

def action_token_types
  @action_token_types
end

#bank_transfer_optionsBankTransferOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.



332
333
334
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 332

def bank_transfer_options
  @bank_transfer_options
end

#commerce_indicatorString

Type of transaction. Some payment card companies use this information when determining discount rates.

Used by

Authorization Required payer authentication transactions; otherwise, optional. Credit Required for standalone credits on Chase Paymentech solutions; otherwise, optional. The list of valid values in this field depends on your processor.

Ingenico ePayments

When you omit this field for Ingenico ePayments, the processor uses the default transaction type they have on file for you instead of the default value

Card Present

You must set this field to retail. This field is required for a card-present transaction. Note that this should ONLY be used when the cardholder and card are present at the time of the transaction. For all keyed transactions originated from a POS terminal where the cardholder and card are not present, commerceIndicator should be submitted as “moto"

Returns:

  • (String)


53
54
55
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 53

def commerce_indicator
  @commerce_indicator
end

#electronic_benefits_transferElectronicBenefitsTransfer1

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.



406
407
408
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 406

def electronic_benefits_transfer
  @electronic_benefits_transfer
end

#industry_data_typeString

Indicates that the transaction includes industry-specific data. Possible Values:

  • airline
  • restaurant
  • lodging
  • auto_rental
  • transit
  • healthcare_medical
  • healthcare_transit
  • transit

Card Present, Airlines and Auto Rental

You must set this field to airline in order for airline data to be sent to the processor. For example, if this field is not set to airline or is not included in the request, no airline data is sent to the processor. You must set this field to restaurant in order for restaurant data to be sent to the processor. When this field is not set to restaurant or is not included in the request, no restaurant data is sent to the processor. You must set this field to auto_rental in order for auto rental data to be sent to the processor. For example, if this field is not set to auto_rental or is not included in the request, no auto rental data is sent to the processor. Restaurant data is supported only on CyberSource through VisaNet.

Returns:

  • (String)


148
149
150
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 148

def industry_data_type
  @industry_data_type
end

#japan_payment_optionsJapanPaymentOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.



480
481
482
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 480

def japan_payment_options
  @japan_payment_options
end

Value that links the current authorization request to the original authorization request or previous declined Merchant Initiated Debt Recovery Transactions . Set this value to the ID that was returned in the reply message from the original authorization request or previous declined Merchant Initiated Debt Recovery Transactions. This value is used for:

  • Partial authorizations
  • Split shipments
  • Merchant Initiated Debt Recovery Transactions for Visa Platform Connect and China Union Pay merchants

Returns:

  • (String)


106
107
108
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 106

def link_id
  @link_id
end

#loan_optionsLoanOptions

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



443
444
445
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 443

def loan_options
  @loan_options
end

#merchant_verification_valueString

The override value of the Merchant Verification Value (MVV) received by various card brands. MVV refers to the value assigned by the card brand/network to identify participation in select merchant programs. Sample value for Visa: 101010

Returns:

  • (String)


524
525
526
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 524

def merchant_verification_value
  @merchant_verification_value
end

#national_net_domestic_dataString

Supplementary domestic transaction information provided by the acquirer for National Net Settlement Service (NNSS) transactions. NNSS is a settlement service that Visa provides. For transactions on CyberSource through VisaNet in countries that subscribe to NNSS: VisaNet clears transactions; VisaNet transfers funds to the acquirer after deducting processing fees and interchange fees. VisaNet settles transactions in the local pricing currency through a local financial institution. This field is supported only on CyberSource through VisaNet for domestic data in Colombia

Returns:

  • (String)


221
222
223
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 221

def national_net_domestic_data
  @national_net_domestic_data
end

#network_routing_orderString

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:

  • (String)


258
259
260
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 258

def network_routing_order
  @network_routing_order
end

#payment_solutionString

Type of digital payment solution for the transaction. Possible Values:

  • visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, see payment_solution field description in [Visa Checkout Using the REST API.](https://developer.cybersource.com/content/dam/docs/cybs/en-us/apifie lds/reference/all/rest/api-fields.pdf)
  • 001: Apple Pay.
  • 004: Cybersource In-App Solution.
  • 005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.
  • 006: Android Pay.
  • 007: Chase Pay.
  • 008: Samsung Pay.
  • 012: Google Pay.
  • 013: Cybersource P2PE Decryption
  • 014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.
  • 027: Click to Pay.

Returns:

  • (String)


85
86
87
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 85

def payment_solution
  @payment_solution
end

#processor_idString

Value that identifies the processor/acquirer to use for the transaction. This value is supported only for CyberSource through VisaNet. Contact CyberSource Customer Support to get the value for this field.

Returns:

  • (String)


60
61
62
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 60

def processor_id
  @processor_id
end

#purchase_levelString

Set this field to 3 to indicate that the request includes Level III data.

Returns:

  • (String)


121
122
123
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 121

def purchase_level
  @purchase_level
end

#purchase_optionsPurchaseOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



369
370
371
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 369

def purchase_options
  @purchase_options
end

#reconciliation_idString

Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request.

  • For Payouts: max length for FDCCompass is String (22).

Returns:

  • (String)


92
93
94
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 92

def reconciliation_id
  @reconciliation_id
end

#recurring_optionsRecurringOptions1

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



295
296
297
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 295

def recurring_options
  @recurring_options
end

#refund_optionsRefundOptions2

On PIN Debit Gateways: This U.S.-only field is optionally used by participants (merchants and acquirers) to specify the network access priority. VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the sharing group code. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference. If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.

PIN debit

Priority order of the networks through which he transaction will be routed. Set this value to a series of one-character network codes in your preferred order. This is a list of the network codes:

Network Code
Accel E
AFFN U
Alaska Option 3
CU24 C
Interlink G
Maestro 8
NETS P
NYCE F
Pulse H
Shazam 7
Star M
Visa V

For example, if the Star network is your first preference and Pulse is your second preference, set this field to a value of MH. When you do not include this value in your PIN debit request, the list of network codes from your account is used. Note This field is supported only for businesses located in the U.S. Optional field for PIN debit credit or PIN debit purchase.

Returns:



517
518
519
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 517

def refund_options
  @refund_options
end

#report_groupString

Attribute that lets you define custom grouping for your processor reports. This field is supported only for Worldpay VAP.

Returns:

  • (String)


111
112
113
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 111

def report_group
  @report_group
end

#transaction_type_indicatorString

This field is used identify the type of payment transaction taking place. This field is applicable for MasterCard transactions only. Possible values:

  • 201- Mastercard Rebate
  • 202- rePower Load Value
  • 203- Gaming Re-pay
  • 204- General Person-to-Person
  • 205- General Transfer to Own Account
  • 206- Agent Cash Out
  • 207- Payment of Own Credit Card Bill
  • 208- Business Disbursement
  • 209- Government/Non-Profit Disbursement
  • 210- Rapid Merchant Settlement
  • 211- Cash in at ATM (Usage limited to specific countries)
  • 212- Cash in at Point of Sale (Usage limited to specific countries)
  • 213- General Business to Business Transfer
  • 214- Mastercard Merchant Presented QR
  • 215- Mastercard Merchant Presented QR Refund Payment
  • 216- Utility Payments (for Brazil domestic use only)
  • 217- Government Services (for Brazil domestic use only)
  • 218- Mobile phone top-ups (for Brazil domestic use only)
  • 219- Coupon booklet payments (for Brazil domestic use only)
  • 220- General Person-to-Person Transfer
  • 221- Person-to-Person Transfer to Card Account
  • 222- General Transfer to Own Account
  • 223- Agent Cash Out
  • 224- Payment of Own Credit Card Bill
  • 225- Business Disbursement
  • 226- Transfer to Own Staged Digital Wallet Account
  • 227- Transfer to Own Debit or Prepaid Account
  • 228- General Business-to-Business Transfer
  • 229- Installment-based repayment
  • 230- Mastercard ATM Cash Pick-Up Transaction
  • 231- Cryptocurrency
  • 232- High-risk Securities

Returns:

  • (String)


562
563
564
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 562

def transaction_type_indicator
  @transaction_type_indicator
end

#visa_checkout_idString

Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.

Returns:

  • (String)


117
118
119
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 117

def visa_checkout_id
  @visa_checkout_id
end

#wallet_typeString

This field carries the wallet type in authorization requests and credit requests. Possible value are:

  • 101: Masterpass remote payment. The customer created the wallet by manually interacting with a customer-controlled device such as a computer, tablet, or phone. This value is supported only for Masterpass transactions on Chase Paymentech Solutions and CyberSource through VisaNet.
  • 102: Masterpass remote near field communication (NFC) payment. The customer created the wallet by tapping a PayPass card or customer-controlled device at a contactless card reader. This value is supported only for card-present Masterpass transactions on CyberSource through VisaNet.
  • 103: Masterpass Apple Pay payment. The payment was made with a combination of Masterpass and Apple Pay. This value is supported only for Masterpass Apple Pay transactions on CyberSource through VisaNet.
  • 216: Masterpass Google Pay payment. The payment was made with a combination of Masterpass and Google Pay. This value is supported only for Masterpass Google Pay transactions on CyberSource through VisaNet.
  • 217: Masterpass Samsung Pay payment. The payment was made with a combination of Masterpass and Samsung Pay. This value is supported only for Masterpass Samsung Pay transactions on CyberSource through VisaNet.
  • SDW: Staged digital wallet. An issuer or operator created the wallet. This value is supported only for Masterpass transactions on Chase Paymentech Solutions.
  • VCIND: Visa Checkout payment. This value is supported only on CyberSource through VisaNet, FDC Compass, FDC Nashville Global, FDI Australia, and TSYS Acquiring Solutions. See Getting Started with Visa Checkout. For Visa Checkout transactions, the way CyberSource processes the value for this field depends on the processor. See the Visa Checkout section below. For all other values, this field is a passthrough; therefore, CyberSource does not verify the value or modify it in any way before sending it to the processor. Masterpass (101, 102, 103, 216, and 217): The Masterpass platform generates the wallet type value and passes it to you along with the customer’s checkout information. Visa Checkout: This field is optional for Visa Checkout authorizations on FDI Australia. For all other processors, this field is required for Visa Checkout authorizations. For Visa Checkout transactions on the following processors, CyberSource sends the value that the processor expects for this field:FDC Compass,FDC Nashville Global,FDI Australia,TSYS Acquiring Solutions For all other processors, this field is a passthrough; therefore, CyberSource does not verify the value or modify it in any way before sending it to the processor. For incremental authorizations, this field is supported only for Mastercard and the supported values are 101 and 102. Payment card companies can introduce new values without notice. Your order management system should be able to process new values without problems. CyberSource through VisaNet When the value for this field is 101, 102, 103, 216, or 217, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR6, Position: 88-90, Field: Mastercard Wallet Identifier. When the value for this field is VCIND, it corresponds to the following data in the TC 33 capture file5: Record: CP01 TCR8, Position: 72-76, Field: Agent Unique ID.

Returns:

  • (String)


207
208
209
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 207

def wallet_type
  @wallet_type
end

Class Method Details

.from_element(root) ⇒ Object



759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 759

def self.from_element(root)
  action_list = XmlUtilities.from_element_to_array(root, 'actionList',
                                                   String)
  action_token_types = XmlUtilities.from_element_to_array(
    root, 'actionTokenTypes', String
  )
  commerce_indicator = XmlUtilities.from_element(root, 'commerceIndicator',
                                                 String)
  processor_id = XmlUtilities.from_element(root, 'processorId', String)
  payment_solution = XmlUtilities.from_element(root, 'paymentSolution',
                                               String)
  reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId',
                                                String)
  link_id = XmlUtilities.from_element(root, 'linkId', String)
  report_group = XmlUtilities.from_element(root, 'reportGroup', String)
  visa_checkout_id = XmlUtilities.from_element(root, 'visaCheckoutId',
                                               String)
  purchase_level = XmlUtilities.from_element(root, 'purchaseLevel', String)
  industry_data_type = XmlUtilities.from_element(root, 'industryDataType',
                                                 String)
  wallet_type = XmlUtilities.from_element(root, 'walletType', String)
  national_net_domestic_data = XmlUtilities.from_element(
    root, 'nationalNetDomesticData', String
  )
  network_routing_order = XmlUtilities.from_element(root,
                                                    'networkRoutingOrder',
                                                    String)
  recurring_options = XmlUtilities.from_element(root, 'RecurringOptions1',
                                                RecurringOptions1)
  bank_transfer_options = XmlUtilities.from_element(root,
                                                    'BankTransferOptions2',
                                                    BankTransferOptions2)
  purchase_options = XmlUtilities.from_element(root, 'PurchaseOptions2',
                                               PurchaseOptions2)
  electronic_benefits_transfer = XmlUtilities.from_element(
    root, 'ElectronicBenefitsTransfer1',
    ElectronicBenefitsTransfer1
  )
  loan_options = XmlUtilities.from_element(root, 'LoanOptions', LoanOptions)
  japan_payment_options = XmlUtilities.from_element(root,
                                                    'JapanPaymentOptions2',
                                                    JapanPaymentOptions2)
  refund_options = XmlUtilities.from_element(root, 'RefundOptions2',
                                             RefundOptions2)
  merchant_verification_value = XmlUtilities.from_element(
    root, 'merchantVerificationValue', String
  )
  transaction_type_indicator = XmlUtilities.from_element(
    root, 'transactionTypeIndicator', String
  )

  new(action_list: action_list,
      action_token_types: action_token_types,
      commerce_indicator: commerce_indicator,
      processor_id: processor_id,
      payment_solution: payment_solution,
      reconciliation_id: reconciliation_id,
      link_id: link_id,
      report_group: report_group,
      visa_checkout_id: visa_checkout_id,
      purchase_level: purchase_level,
      industry_data_type: industry_data_type,
      wallet_type: wallet_type,
      national_net_domestic_data: national_net_domestic_data,
      network_routing_order: network_routing_order,
      recurring_options: recurring_options,
      bank_transfer_options: bank_transfer_options,
      purchase_options: purchase_options,
      electronic_benefits_transfer: electronic_benefits_transfer,
      loan_options: loan_options,
      japan_payment_options: japan_payment_options,
      refund_options: refund_options,
      merchant_verification_value: merchant_verification_value,
      transaction_type_indicator: transaction_type_indicator,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 681

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  action_list = hash.key?('actionList') ? hash['actionList'] : SKIP
  action_token_types =
    hash.key?('actionTokenTypes') ? hash['actionTokenTypes'] : SKIP
  commerce_indicator =
    hash.key?('commerceIndicator') ? hash['commerceIndicator'] : SKIP
  processor_id = hash.key?('processorId') ? hash['processorId'] : SKIP
  payment_solution =
    hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  link_id = hash.key?('linkId') ? hash['linkId'] : SKIP
  report_group = hash.key?('reportGroup') ? hash['reportGroup'] : SKIP
  visa_checkout_id =
    hash.key?('visaCheckoutId') ? hash['visaCheckoutId'] : SKIP
  purchase_level = hash.key?('purchaseLevel') ? hash['purchaseLevel'] : SKIP
  industry_data_type =
    hash.key?('industryDataType') ? hash['industryDataType'] : SKIP
  wallet_type = hash.key?('walletType') ? hash['walletType'] : SKIP
  national_net_domestic_data =
    hash.key?('nationalNetDomesticData') ? hash['nationalNetDomesticData'] : SKIP
  network_routing_order =
    hash.key?('networkRoutingOrder') ? hash['networkRoutingOrder'] : SKIP
  recurring_options = RecurringOptions1.from_hash(hash['recurringOptions']) if
    hash['recurringOptions']
  bank_transfer_options = BankTransferOptions2.from_hash(hash['bankTransferOptions']) if
    hash['bankTransferOptions']
  purchase_options = PurchaseOptions2.from_hash(hash['purchaseOptions']) if
    hash['purchaseOptions']
  if hash['electronicBenefitsTransfer']
    electronic_benefits_transfer = ElectronicBenefitsTransfer1.from_hash(hash['electronicBenefitsTransfer'])
  end
  loan_options = LoanOptions.from_hash(hash['loanOptions']) if hash['loanOptions']
  japan_payment_options = JapanPaymentOptions2.from_hash(hash['japanPaymentOptions']) if
    hash['japanPaymentOptions']
  refund_options = RefundOptions2.from_hash(hash['refundOptions']) if hash['refundOptions']
  merchant_verification_value =
    hash.key?('merchantVerificationValue') ? hash['merchantVerificationValue'] : SKIP
  transaction_type_indicator =
    hash.key?('transactionTypeIndicator') ? hash['transactionTypeIndicator'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation11.new(action_list: action_list,
                              action_token_types: action_token_types,
                              commerce_indicator: commerce_indicator,
                              processor_id: processor_id,
                              payment_solution: payment_solution,
                              reconciliation_id: reconciliation_id,
                              link_id: link_id,
                              report_group: report_group,
                              visa_checkout_id: visa_checkout_id,
                              purchase_level: purchase_level,
                              industry_data_type: industry_data_type,
                              wallet_type: wallet_type,
                              national_net_domestic_data: national_net_domestic_data,
                              network_routing_order: network_routing_order,
                              recurring_options: recurring_options,
                              bank_transfer_options: bank_transfer_options,
                              purchase_options: purchase_options,
                              electronic_benefits_transfer: electronic_benefits_transfer,
                              loan_options: loan_options,
                              japan_payment_options: japan_payment_options,
                              refund_options: refund_options,
                              merchant_verification_value: merchant_verification_value,
                              transaction_type_indicator: transaction_type_indicator,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 565

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['action_list'] = 'actionList'
  @_hash['action_token_types'] = 'actionTokenTypes'
  @_hash['commerce_indicator'] = 'commerceIndicator'
  @_hash['processor_id'] = 'processorId'
  @_hash['payment_solution'] = 'paymentSolution'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['link_id'] = 'linkId'
  @_hash['report_group'] = 'reportGroup'
  @_hash['visa_checkout_id'] = 'visaCheckoutId'
  @_hash['purchase_level'] = 'purchaseLevel'
  @_hash['industry_data_type'] = 'industryDataType'
  @_hash['wallet_type'] = 'walletType'
  @_hash['national_net_domestic_data'] = 'nationalNetDomesticData'
  @_hash['network_routing_order'] = 'networkRoutingOrder'
  @_hash['recurring_options'] = 'recurringOptions'
  @_hash['bank_transfer_options'] = 'bankTransferOptions'
  @_hash['purchase_options'] = 'purchaseOptions'
  @_hash['electronic_benefits_transfer'] = 'electronicBenefitsTransfer'
  @_hash['loan_options'] = 'loanOptions'
  @_hash['japan_payment_options'] = 'japanPaymentOptions'
  @_hash['refund_options'] = 'refundOptions'
  @_hash['merchant_verification_value'] = 'merchantVerificationValue'
  @_hash['transaction_type_indicator'] = 'transactionTypeIndicator'
  @_hash
end

.nullablesObject

An array for nullable fields



623
624
625
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 623

def self.nullables
  []
end

.optionalsObject

An array for optional fields



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 594

def self.optionals
  %w[
    action_list
    action_token_types
    commerce_indicator
    processor_id
    payment_solution
    reconciliation_id
    link_id
    report_group
    visa_checkout_id
    purchase_level
    industry_data_type
    wallet_type
    national_net_domestic_data
    network_routing_order
    recurring_options
    bank_transfer_options
    purchase_options
    electronic_benefits_transfer
    loan_options
    japan_payment_options
    refund_options
    merchant_verification_value
    transaction_type_indicator
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 903

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list.inspect}, action_token_types:"\
  " #{@action_token_types.inspect}, commerce_indicator: #{@commerce_indicator.inspect},"\
  " processor_id: #{@processor_id.inspect}, payment_solution: #{@payment_solution.inspect},"\
  " reconciliation_id: #{@reconciliation_id.inspect}, link_id: #{@link_id.inspect},"\
  " report_group: #{@report_group.inspect}, visa_checkout_id: #{@visa_checkout_id.inspect},"\
  " purchase_level: #{@purchase_level.inspect}, industry_data_type:"\
  " #{@industry_data_type.inspect}, wallet_type: #{@wallet_type.inspect},"\
  " national_net_domestic_data: #{@national_net_domestic_data.inspect}, network_routing_order:"\
  " #{@network_routing_order.inspect}, recurring_options: #{@recurring_options.inspect},"\
  " bank_transfer_options: #{@bank_transfer_options.inspect}, purchase_options:"\
  " #{@purchase_options.inspect}, electronic_benefits_transfer:"\
  " #{@electronic_benefits_transfer.inspect}, loan_options: #{@loan_options.inspect},"\
  " japan_payment_options: #{@japan_payment_options.inspect}, refund_options:"\
  " #{@refund_options.inspect}, merchant_verification_value:"\
  " #{@merchant_verification_value.inspect}, transaction_type_indicator:"\
  " #{@transaction_type_indicator.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 885

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list}, action_token_types: #{@action_token_types},"\
  " commerce_indicator: #{@commerce_indicator}, processor_id: #{@processor_id},"\
  " payment_solution: #{@payment_solution}, reconciliation_id: #{@reconciliation_id}, link_id:"\
  " #{@link_id}, report_group: #{@report_group}, visa_checkout_id: #{@visa_checkout_id},"\
  " purchase_level: #{@purchase_level}, industry_data_type: #{@industry_data_type},"\
  " wallet_type: #{@wallet_type}, national_net_domestic_data: #{@national_net_domestic_data},"\
  " network_routing_order: #{@network_routing_order}, recurring_options:"\
  " #{@recurring_options}, bank_transfer_options: #{@bank_transfer_options}, purchase_options:"\
  " #{@purchase_options}, electronic_benefits_transfer: #{@electronic_benefits_transfer},"\
  " loan_options: #{@loan_options}, japan_payment_options: #{@japan_payment_options},"\
  " refund_options: #{@refund_options}, merchant_verification_value:"\
  " #{@merchant_verification_value}, transaction_type_indicator:"\
  " #{@transaction_type_indicator}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
# File 'lib/cyber_source_merged_spec/models/processing_information11.rb', line 836

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'actionList', action_list)
  XmlUtilities.add_array_as_subelement(doc, root, 'actionTokenTypes',
                                       action_token_types)
  XmlUtilities.add_as_subelement(doc, root, 'commerceIndicator',
                                 commerce_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'processorId', processor_id)
  XmlUtilities.add_as_subelement(doc, root, 'paymentSolution',
                                 payment_solution)
  XmlUtilities.add_as_subelement(doc, root, 'reconciliationId',
                                 reconciliation_id)
  XmlUtilities.add_as_subelement(doc, root, 'linkId', link_id)
  XmlUtilities.add_as_subelement(doc, root, 'reportGroup', report_group)
  XmlUtilities.add_as_subelement(doc, root, 'visaCheckoutId',
                                 visa_checkout_id)
  XmlUtilities.add_as_subelement(doc, root, 'purchaseLevel', purchase_level)
  XmlUtilities.add_as_subelement(doc, root, 'industryDataType',
                                 industry_data_type)
  XmlUtilities.add_as_subelement(doc, root, 'walletType', wallet_type)
  XmlUtilities.add_as_subelement(doc, root, 'nationalNetDomesticData',
                                 national_net_domestic_data)
  XmlUtilities.add_as_subelement(doc, root, 'networkRoutingOrder',
                                 network_routing_order)
  XmlUtilities.add_as_subelement(doc, root, 'RecurringOptions1',
                                 recurring_options)
  XmlUtilities.add_as_subelement(doc, root, 'BankTransferOptions2',
                                 bank_transfer_options)
  XmlUtilities.add_as_subelement(doc, root, 'PurchaseOptions2',
                                 purchase_options)
  XmlUtilities.add_as_subelement(doc, root, 'ElectronicBenefitsTransfer1',
                                 electronic_benefits_transfer)
  XmlUtilities.add_as_subelement(doc, root, 'LoanOptions', loan_options)
  XmlUtilities.add_as_subelement(doc, root, 'JapanPaymentOptions2',
                                 japan_payment_options)
  XmlUtilities.add_as_subelement(doc, root, 'RefundOptions2',
                                 refund_options)
  XmlUtilities.add_as_subelement(doc, root, 'merchantVerificationValue',
                                 merchant_verification_value)
  XmlUtilities.add_as_subelement(doc, root, 'transactionTypeIndicator',
                                 transaction_type_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end