Class: CyberSourceMergedSpec::ProcessingInformation2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processing_information2.rb

Overview

ProcessingInformation2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(authorization_options: SKIP, network: SKIP, additional_properties: nil) ⇒ ProcessingInformation2

Returns a new instance of ProcessingInformation2.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 41

def initialize(authorization_options: SKIP, network: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @authorization_options = authorization_options unless authorization_options == SKIP
  @network = network unless network == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#authorization_optionsAuthorizationOptions2

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 14

def authorization_options
  @authorization_options
end

#networkNetwork

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 18

def network
  @network
end

Class Method Details

.from_element(root) ⇒ Object



73
74
75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 73

def self.from_element(root)
  authorization_options = XmlUtilities.from_element(root,
                                                    'AuthorizationOptions2',
                                                    AuthorizationOptions2)
  network = XmlUtilities.from_element(root, 'Network', Network)

  new(authorization_options: authorization_options,
      network: network,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  authorization_options = AuthorizationOptions2.from_hash(hash['authorizationOptions']) if
    hash['authorizationOptions']
  network = Network.from_hash(hash['network']) if hash['network']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation2.new(authorization_options: authorization_options,
                             network: network,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['authorization_options'] = 'authorizationOptions'
  @_hash['network'] = 'network'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 29

def self.optionals
  %w[
    authorization_options
    network
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} authorization_options: #{@authorization_options.inspect}, network:"\
  " #{@network.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} authorization_options: #{@authorization_options}, network: #{@network},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/processing_information2.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'AuthorizationOptions2',
                                 authorization_options)
  XmlUtilities.add_as_subelement(doc, root, 'Network', network)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end