Class: CyberSourceMergedSpec::ProcessingInformation56

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processing_information56.rb

Overview

Decides whether to call Payer Authentication or Watchlist Screening service along with DM or not.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation56

Returns a new instance of ProcessingInformation56.



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 39

def initialize(action_list: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @action_list = action_list unless action_list == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#action_listArray[String]

  • Use CONSUMER_AUTHENTICATION to use Payer Authentication along with Decision Manager. For any other value, only Decision Manager will run.
  • Use WATCHLIST_SCREENING when you want to call Watchlist Screening service.

Returns:

  • (Array[String])


18
19
20
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 18

def action_list
  @action_list
end

Class Method Details

.from_element(root) ⇒ Object



66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 66

def self.from_element(root)
  action_list = XmlUtilities.from_element_to_array(root, 'actionList',
                                                   String)

  new(action_list: action_list,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  action_list = hash.key?('actionList') ? hash['actionList'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation56.new(action_list: action_list,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['action_list'] = 'actionList'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 28

def self.optionals
  %w[
    action_list
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



74
75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/processing_information56.rb', line 74

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'actionList', action_list)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end