Class: CyberSourceMergedSpec::ProcessingInformation60

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processing_information60.rb

Overview

ProcessingInformation60 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(action_list: SKIP, additional_properties: nil) ⇒ ProcessingInformation60

Returns a new instance of ProcessingInformation60.



40
41
42
43
44
45
46
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 40

def initialize(action_list: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @action_list = action_list unless action_list == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#action_listArray[String]

Follow-on action to apply to the case after the decision is successfully applied. Possible values are one of the following:

  • CAPTURE
  • REVERSE If decision is ACCEPT, then CAPTURE can be used in actionList. If decision is REJECT, then REVERSE can be used.

Returns:

  • (Array[String])


19
20
21
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 19

def action_list
  @action_list
end

Class Method Details

.from_element(root) ⇒ Object



67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 67

def self.from_element(root)
  action_list = XmlUtilities.from_element_to_array(root, 'actionList',
                                                   String)

  new(action_list: action_list,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  action_list = hash.key?('actionList') ? hash['actionList'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation60.new(action_list: action_list,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['action_list'] = 'actionList'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 29

def self.optionals
  %w[
    action_list
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} action_list: #{@action_list}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/processing_information60.rb', line 75

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'actionList', action_list)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end