Class: CyberSourceMergedSpec::ProcessingInformation68
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ProcessingInformation68
- Defined in:
- lib/cyber_source_merged_spec/models/processing_information68.rb
Overview
ProcessingInformation68 Model.
Instance Attribute Summary collapse
-
#bin_source ⇒ String
Bin Source File Identifier.
-
#payout_options ⇒ PayoutOptions
Payout fields request parameters.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bin_source: SKIP, payout_options: SKIP, additional_properties: nil) ⇒ ProcessingInformation68
constructor
A new instance of ProcessingInformation68.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bin_source: SKIP, payout_options: SKIP, additional_properties: nil) ⇒ ProcessingInformation68
Returns a new instance of ProcessingInformation68.
44 45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 44 def initialize(bin_source: SKIP, payout_options: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @bin_source = bin_source unless bin_source == SKIP @payout_options = unless == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bin_source ⇒ String
Bin Source File Identifier. Possible values:
- itmx
- rupay
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 17 def bin_source @bin_source end |
#payout_options ⇒ PayoutOptions
Payout fields request parameters
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 21 def @payout_options end |
Class Method Details
.from_element(root) ⇒ Object
75 76 77 78 79 80 81 82 83 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 75 def self.from_element(root) bin_source = XmlUtilities.from_element(root, 'binSource', String) = XmlUtilities.from_element(root, 'PayoutOptions', PayoutOptions) new(bin_source: bin_source, payout_options: , additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. bin_source = hash.key?('binSource') ? hash['binSource'] : SKIP = PayoutOptions.from_hash(hash['payoutOptions']) if hash['payoutOptions'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation68.new(bin_source: bin_source, payout_options: , additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['bin_source'] = 'binSource' @_hash['payout_options'] = 'payoutOptions' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 32 def self.optionals %w[ bin_source payout_options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} bin_source: #{@bin_source.inspect}, payout_options:"\ " #{@payout_options.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} bin_source: #{@bin_source}, payout_options: #{@payout_options},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
85 86 87 88 89 90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/processing_information68.rb', line 85 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'binSource', bin_source) XmlUtilities.add_as_subelement(doc, root, 'PayoutOptions', ) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |