Class: CyberSourceMergedSpec::ProcessingInformation7
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ProcessingInformation7
- Defined in:
- lib/cyber_source_merged_spec/models/processing_information7.rb
Overview
ProcessingInformation7 Model.
Instance Attribute Summary collapse
-
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the payment to invoke bundled services along with payment status.
-
#industry_data_type ⇒ String
Indicates that the transaction includes industry-specific data.
-
#link_id ⇒ String
Value that links the current authorization request to the original authorization request or previous declined Merchant Initiated Debt Recovery Transactions .
-
#merchant_verification_value ⇒ String
The override value of the Merchant Verification Value (MVV) received by various card brands.
-
#payment_solution ⇒ String
Type of digital payment solution for the transaction.
-
#payment_type ⇒ String
Identifier for the payment type.
-
#purchase_level ⇒ String
Set this field to 3 to indicate that the request includes Level III data.
-
#reconciliation_id ⇒ String
Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request.
-
#recurring_options ⇒ RecurringOptions1
Set this field to 3 to indicate that the request includes Level III data.
-
#refund_options ⇒ RefundOptions
Identifier for the payment type.
-
#report_group ⇒ String
Attribute that lets you define custom grouping for your processor reports.
-
#transaction_type_indicator ⇒ String
This field is used identify the type of payment transaction taking place.
-
#visa_checkout_id ⇒ String
Identifier for the Visa Checkout order.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(action_list: SKIP, payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, purchase_level: SKIP, recurring_options: SKIP, industry_data_type: SKIP, payment_type: SKIP, refund_options: SKIP, transaction_type_indicator: SKIP, merchant_verification_value: SKIP, additional_properties: nil) ⇒ ProcessingInformation7
constructor
A new instance of ProcessingInformation7.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(action_list: SKIP, payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, purchase_level: SKIP, recurring_options: SKIP, industry_data_type: SKIP, payment_type: SKIP, refund_options: SKIP, transaction_type_indicator: SKIP, merchant_verification_value: SKIP, additional_properties: nil) ⇒ ProcessingInformation7
Returns a new instance of ProcessingInformation7.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 208 def initialize(action_list: SKIP, payment_solution: SKIP, reconciliation_id: SKIP, link_id: SKIP, report_group: SKIP, visa_checkout_id: SKIP, purchase_level: SKIP, recurring_options: SKIP, industry_data_type: SKIP, payment_type: SKIP, refund_options: SKIP, transaction_type_indicator: SKIP, merchant_verification_value: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @action_list = action_list unless action_list == SKIP @payment_solution = payment_solution unless payment_solution == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @link_id = link_id unless link_id == SKIP @report_group = report_group unless report_group == SKIP @visa_checkout_id = visa_checkout_id unless visa_checkout_id == SKIP @purchase_level = purchase_level unless purchase_level == SKIP @recurring_options = unless == SKIP @industry_data_type = industry_data_type unless industry_data_type == SKIP @payment_type = payment_type unless payment_type == SKIP @refund_options = unless == SKIP unless transaction_type_indicator == SKIP @transaction_type_indicator = transaction_type_indicator end unless merchant_verification_value == SKIP @merchant_verification_value = merchant_verification_value end @additional_properties = additional_properties end |
Instance Attribute Details
#action_list ⇒ Array[String]
Array of actions (one or more) to be included in the payment to invoke bundled services along with payment status. Possible values are one or more of follows:
AP_REFUND: Use this when Alternative Payment Refund service is requested.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 18 def action_list @action_list end |
#industry_data_type ⇒ String
Indicates that the transaction includes industry-specific data. Possible Values:
airlinerestaurantlodgingauto_rentaltransithealthcare_medicalhealthcare_transittransit
Card Present, Airlines and Auto Rental
You must set this field to airline in order for airline data to be sent
to the processor. For example, if this
field is not set to airline or is not included in the request, no
airline data is sent to the processor.
You must set this field to restaurant in order for restaurant data to be
sent to the processor. When this field
is not set to restaurant or is not included in the request, no
restaurant data is sent to the processor.
You must set this field to auto_rental in order for auto rental data to
be sent to the processor. For example, if this
field is not set to auto_rental or is not included in the request, no
auto rental data is sent to the processor.
Restaurant data is supported only on CyberSource through VisaNet.
110 111 112 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 110 def industry_data_type @industry_data_type end |
#link_id ⇒ String
Value that links the current authorization request to the original authorization request or previous declined Merchant Initiated Debt Recovery Transactions . Set this value to the ID that was returned in the reply message from the original authorization request or previous declined Merchant Initiated Debt Recovery Transactions. This value is used for:
- Partial authorizations
- Split shipments
- Merchant Initiated Debt Recovery Transactions for Visa Platform Connect and China Union Pay merchants
64 65 66 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 64 def link_id @link_id end |
#merchant_verification_value ⇒ String
The override value of the Merchant Verification Value (MVV) received by
various card brands. MVV refers to the value assigned by the card
brand/network to identify participation in select merchant programs.
Sample value for Visa: 101010
163 164 165 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 163 def merchant_verification_value @merchant_verification_value end |
#payment_solution ⇒ String
Type of digital payment solution for the transaction. Possible Values:
visacheckout: Visa Checkout. This value is required for Visa Checkout transactions. For details, seepayment_solutionfield description in [Visa Checkout Using the REST API.](https://developer.cybersource.com/content/dam/docs/cybs/en-us/apifie lds/reference/all/rest/api-fields.pdf)001: Apple Pay.004: Cybersource In-App Solution.005: Masterpass. This value is required for Masterpass transactions on OmniPay Direct.006: Android Pay.007: Chase Pay.008: Samsung Pay.012: Google Pay.013: Cybersource P2PE Decryption014: Mastercard credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.015: Visa credential on file (COF) payment network token. Returned in authorizations that use a payment network token associated with a TMS token.027: Click to Pay.
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 43 def payment_solution @payment_solution end |
#payment_type ⇒ String
Identifier for the payment type
114 115 116 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 114 def payment_type @payment_type end |
#purchase_level ⇒ String
Set this field to 3 to indicate that the request includes Level III data.
79 80 81 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 79 def purchase_level @purchase_level end |
#reconciliation_id ⇒ String
Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request.
- For Payouts: max length for FDCCompass is String (22).
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 50 def reconciliation_id @reconciliation_id end |
#recurring_options ⇒ RecurringOptions1
Set this field to 3 to indicate that the request includes Level III data.
83 84 85 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 83 def @recurring_options end |
#refund_options ⇒ RefundOptions
Identifier for the payment type
118 119 120 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 118 def @refund_options end |
#report_group ⇒ String
Attribute that lets you define custom grouping for your processor reports. This field is supported only for Worldpay VAP.
69 70 71 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 69 def report_group @report_group end |
#transaction_type_indicator ⇒ String
This field is used identify the type of payment transaction taking place. This field is applicable for MasterCard transactions only. Possible values:
- 201- Mastercard Rebate
- 202- rePower Load Value
- 203- Gaming Re-pay
- 204- General Person-to-Person
- 205- General Transfer to Own Account
- 206- Agent Cash Out
- 207- Payment of Own Credit Card Bill
- 208- Business Disbursement
- 209- Government/Non-Profit Disbursement
- 210- Rapid Merchant Settlement
- 211- Cash in at ATM (Usage limited to specific countries)
- 212- Cash in at Point of Sale (Usage limited to specific countries)
- 213- General Business to Business Transfer
- 214- Mastercard Merchant Presented QR
- 215- Mastercard Merchant Presented QR Refund Payment
- 216- Utility Payments (for Brazil domestic use only)
- 217- Government Services (for Brazil domestic use only)
- 218- Mobile phone top-ups (for Brazil domestic use only)
- 219- Coupon booklet payments (for Brazil domestic use only)
- 220- General Person-to-Person Transfer
- 221- Person-to-Person Transfer to Card Account
- 222- General Transfer to Own Account
- 223- Agent Cash Out
- 224- Payment of Own Credit Card Bill
- 225- Business Disbursement
- 226- Transfer to Own Staged Digital Wallet Account
- 227- Transfer to Own Debit or Prepaid Account
- 228- General Business-to-Business Transfer
- 229- Installment-based repayment
- 230- Mastercard ATM Cash Pick-Up Transaction
- 231- Cryptocurrency
- 232- High-risk Securities
156 157 158 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 156 def transaction_type_indicator @transaction_type_indicator end |
#visa_checkout_id ⇒ String
Identifier for the Visa Checkout order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout callID field.
75 76 77 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 75 def visa_checkout_id @visa_checkout_id end |
Class Method Details
.from_element(root) ⇒ Object
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 291 def self.from_element(root) action_list = XmlUtilities.from_element_to_array(root, 'actionList', String) payment_solution = XmlUtilities.from_element(root, 'paymentSolution', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) link_id = XmlUtilities.from_element(root, 'linkId', String) report_group = XmlUtilities.from_element(root, 'reportGroup', String) visa_checkout_id = XmlUtilities.from_element(root, 'visaCheckoutId', String) purchase_level = XmlUtilities.from_element(root, 'purchaseLevel', String) = XmlUtilities.from_element(root, 'RecurringOptions1', RecurringOptions1) industry_data_type = XmlUtilities.from_element(root, 'industryDataType', String) payment_type = XmlUtilities.from_element(root, 'paymentType', String) = XmlUtilities.from_element(root, 'RefundOptions', RefundOptions) transaction_type_indicator = XmlUtilities.from_element( root, 'transactionTypeIndicator', String ) merchant_verification_value = XmlUtilities.from_element( root, 'merchantVerificationValue', String ) new(action_list: action_list, payment_solution: payment_solution, reconciliation_id: reconciliation_id, link_id: link_id, report_group: report_group, visa_checkout_id: visa_checkout_id, purchase_level: purchase_level, recurring_options: , industry_data_type: industry_data_type, payment_type: payment_type, refund_options: , transaction_type_indicator: transaction_type_indicator, merchant_verification_value: merchant_verification_value, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 242 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. action_list = hash.key?('actionList') ? hash['actionList'] : SKIP payment_solution = hash.key?('paymentSolution') ? hash['paymentSolution'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP link_id = hash.key?('linkId') ? hash['linkId'] : SKIP report_group = hash.key?('reportGroup') ? hash['reportGroup'] : SKIP visa_checkout_id = hash.key?('visaCheckoutId') ? hash['visaCheckoutId'] : SKIP purchase_level = hash.key?('purchaseLevel') ? hash['purchaseLevel'] : SKIP = RecurringOptions1.from_hash(hash['recurringOptions']) if hash['recurringOptions'] industry_data_type = hash.key?('industryDataType') ? hash['industryDataType'] : SKIP payment_type = hash.key?('paymentType') ? hash['paymentType'] : SKIP = RefundOptions.from_hash(hash['refundOptions']) if hash['refundOptions'] transaction_type_indicator = hash.key?('transactionTypeIndicator') ? hash['transactionTypeIndicator'] : SKIP merchant_verification_value = hash.key?('merchantVerificationValue') ? hash['merchantVerificationValue'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessingInformation7.new(action_list: action_list, payment_solution: payment_solution, reconciliation_id: reconciliation_id, link_id: link_id, report_group: report_group, visa_checkout_id: visa_checkout_id, purchase_level: purchase_level, recurring_options: , industry_data_type: industry_data_type, payment_type: payment_type, refund_options: , transaction_type_indicator: transaction_type_indicator, merchant_verification_value: merchant_verification_value, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 166 def self.names @_hash = {} if @_hash.nil? @_hash['action_list'] = 'actionList' @_hash['payment_solution'] = 'paymentSolution' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['link_id'] = 'linkId' @_hash['report_group'] = 'reportGroup' @_hash['visa_checkout_id'] = 'visaCheckoutId' @_hash['purchase_level'] = 'purchaseLevel' @_hash['recurring_options'] = 'recurringOptions' @_hash['industry_data_type'] = 'industryDataType' @_hash['payment_type'] = 'paymentType' @_hash['refund_options'] = 'refundOptions' @_hash['transaction_type_indicator'] = 'transactionTypeIndicator' @_hash['merchant_verification_value'] = 'merchantVerificationValue' @_hash end |
.nullables ⇒ Object
An array for nullable fields
204 205 206 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 204 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 185 def self.optionals %w[ action_list payment_solution reconciliation_id link_id report_group visa_checkout_id purchase_level recurring_options industry_data_type payment_type refund_options transaction_type_indicator merchant_verification_value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 376 def inspect class_name = self.class.name.split('::').last "<#{class_name} action_list: #{@action_list.inspect}, payment_solution:"\ " #{@payment_solution.inspect}, reconciliation_id: #{@reconciliation_id.inspect}, link_id:"\ " #{@link_id.inspect}, report_group: #{@report_group.inspect}, visa_checkout_id:"\ " #{@visa_checkout_id.inspect}, purchase_level: #{@purchase_level.inspect},"\ " recurring_options: #{@recurring_options.inspect}, industry_data_type:"\ " #{@industry_data_type.inspect}, payment_type: #{@payment_type.inspect}, refund_options:"\ " #{@refund_options.inspect}, transaction_type_indicator:"\ " #{@transaction_type_indicator.inspect}, merchant_verification_value:"\ " #{@merchant_verification_value.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 363 def to_s class_name = self.class.name.split('::').last "<#{class_name} action_list: #{@action_list}, payment_solution: #{@payment_solution},"\ " reconciliation_id: #{@reconciliation_id}, link_id: #{@link_id}, report_group:"\ " #{@report_group}, visa_checkout_id: #{@visa_checkout_id}, purchase_level:"\ " #{@purchase_level}, recurring_options: #{@recurring_options}, industry_data_type:"\ " #{@industry_data_type}, payment_type: #{@payment_type}, refund_options:"\ " #{@refund_options}, transaction_type_indicator: #{@transaction_type_indicator},"\ " merchant_verification_value: #{@merchant_verification_value}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/cyber_source_merged_spec/models/processing_information7.rb', line 333 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_array_as_subelement(doc, root, 'actionList', action_list) XmlUtilities.add_as_subelement(doc, root, 'paymentSolution', payment_solution) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'linkId', link_id) XmlUtilities.add_as_subelement(doc, root, 'reportGroup', report_group) XmlUtilities.add_as_subelement(doc, root, 'visaCheckoutId', visa_checkout_id) XmlUtilities.add_as_subelement(doc, root, 'purchaseLevel', purchase_level) XmlUtilities.add_as_subelement(doc, root, 'RecurringOptions1', ) XmlUtilities.add_as_subelement(doc, root, 'industryDataType', industry_data_type) XmlUtilities.add_as_subelement(doc, root, 'paymentType', payment_type) XmlUtilities.add_as_subelement(doc, root, 'RefundOptions', ) XmlUtilities.add_as_subelement(doc, root, 'transactionTypeIndicator', transaction_type_indicator) XmlUtilities.add_as_subelement(doc, root, 'merchantVerificationValue', merchant_verification_value) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |