Class: CyberSourceMergedSpec::ProcessingInformation72

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processing_information72.rb

Overview

Contains processing information, such as collection details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(request_phone: false, request_shipping: false, additional_properties: nil) ⇒ ProcessingInformation72

Returns a new instance of ProcessingInformation72.



41
42
43
44
45
46
47
48
49
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 41

def initialize(request_phone: false, request_shipping: false,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @request_phone = request_phone unless request_phone == SKIP
  @request_shipping = request_shipping unless request_shipping == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#request_phoneTrueClass | FalseClass

Collect the payers phone number during the payment.

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 14

def request_phone
  @request_phone
end

#request_shippingTrueClass | FalseClass

Collect the payers shipping address during the payment.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 18

def request_shipping
  @request_shipping
end

Class Method Details

.from_element(root) ⇒ Object



72
73
74
75
76
77
78
79
80
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 72

def self.from_element(root)
  request_phone = XmlUtilities.from_element(root, 'requestPhone', TrueClass)
  request_shipping = XmlUtilities.from_element(root, 'requestShipping',
                                               TrueClass)

  new(request_phone: request_phone,
      request_shipping: request_shipping,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  request_phone = hash['requestPhone'] ||= false
  request_shipping = hash['requestShipping'] ||= false

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessingInformation72.new(request_phone: request_phone,
                              request_shipping: request_shipping,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['request_phone'] = 'requestPhone'
  @_hash['request_shipping'] = 'requestShipping'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 29

def self.optionals
  %w[
    request_phone
    request_shipping
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} request_phone: #{@request_phone.inspect}, request_shipping:"\
  " #{@request_shipping.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} request_phone: #{@request_phone}, request_shipping: #{@request_shipping},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



82
83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/processing_information72.rb', line 82

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'requestPhone', request_phone)
  XmlUtilities.add_as_subelement(doc, root, 'requestShipping',
                                 request_shipping)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end