Class: CyberSourceMergedSpec::ProcessorInformation2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processor_information2.rb

Overview

ProcessorInformation2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(approval_code: SKIP, transaction_id: SKIP, network_transaction_id: SKIP, response_code: SKIP, system_trace_audit_number: SKIP, response_details: SKIP, merchant_advice: SKIP, merchant_risk_prediction: SKIP, seller_protection: SKIP, network: SKIP, additional_properties: nil) ⇒ ProcessorInformation2

Returns a new instance of ProcessorInformation2.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 183

def initialize(approval_code: SKIP, transaction_id: SKIP,
               network_transaction_id: SKIP, response_code: SKIP,
               system_trace_audit_number: SKIP, response_details: SKIP,
               merchant_advice: SKIP, merchant_risk_prediction: SKIP,
               seller_protection: SKIP, network: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @approval_code = approval_code unless approval_code == SKIP
  @transaction_id = transaction_id unless transaction_id == SKIP
  @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP
  @response_code = response_code unless response_code == SKIP
  unless system_trace_audit_number == SKIP
    @system_trace_audit_number =
      system_trace_audit_number
  end
  @response_details = response_details unless response_details == SKIP
  @merchant_advice = merchant_advice unless merchant_advice == SKIP
  @merchant_risk_prediction = merchant_risk_prediction unless merchant_risk_prediction == SKIP
  @seller_protection = seller_protection unless seller_protection == SKIP
  @network = network unless network == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#approval_codeString

Authorization code. Returned only when the processor returns this value. The length of this value depends on your processor. Returned by authorization service.

PIN debit

Authorization code that is returned by the processor. Returned by PIN debit credit.

Elavon Encrypted Account Number Program

The returned value is OFFLINE.

TSYS Acquiring Solutions

The returned value for a successful zero amount authorization is 000000.

Returns:

  • (String)


23
24
25
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 23

def approval_code
  @approval_code
end

#merchant_adviceMerchantAdvice

This field might contain information about a decline.

Returns:



120
121
122
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 120

def merchant_advice
  @merchant_advice
end

#merchant_risk_predictionString

Mastercard is introducing the Merchant Risk Predict Service in the middle East/Africa Region. A newly launched service comprised of seven independent artificial intelligence (AI)-powered scores intended to augment existing merchant risk management practices.

Returns:

  • (String)


128
129
130
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 128

def merchant_risk_prediction
  @merchant_risk_prediction
end

#networkNetwork

Mastercard is introducing the Merchant Risk Predict Service in the middle East/Africa Region. A newly launched service comprised of seven independent artificial intelligence (AI)-powered scores intended to augment existing merchant risk management practices.

Returns:



144
145
146
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 144

def network
  @network
end

#network_transaction_idString

Same value as processorInformation.transactionId

Returns:

  • (String)


67
68
69
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 67

def network_transaction_id
  @network_transaction_id
end

#response_codeString

For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.

PIN debit

Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.

AIBMS

If this value is 08, you can accept the transaction if the customer provides you with identification.

Atos

This value is the response code sent from Atos and it might also include the response code from the bank. Format: aa,bb with the two values separated by a comma and where:

  • aa is the two-digit error message from Atos.
  • bb is the optional two-digit error message from the bank.

Comercio Latino

This value is the status code and the error or response code received from the processor separated by a colon. Format: [status code]:E[error code] or [status code]:R[response code] Example 2:R06

JCN Gateway

Processor-defined detail error code. The associated response category code is in the processorInformation.responseCategoryCode field. String (3)

paypalgateway

Processor generated ID for the itemized detail.

Returns:

  • (String)


100
101
102
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 100

def response_code
  @response_code
end

#response_detailsString

This field might contain information about a decline.

Returns:

  • (String)


116
117
118
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 116

def response_details
  @response_details
end

#seller_protectionProcessorInformationSellerProtection

Mastercard is introducing the Merchant Risk Predict Service in the middle East/Africa Region. A newly launched service comprised of seven independent artificial intelligence (AI)-powered scores intended to augment existing merchant risk management practices.



136
137
138
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 136

def seller_protection
  @seller_protection
end

#system_trace_audit_numberString

This field is returned only for American Express Direct and CyberSource through VisaNet. Returned by authorization and incremental authorization services.

American Express Direct

System trace audit number (STAN). This value identifies the transaction and is useful when investigating a chargeback dispute.

CyberSource through VisaNet

System trace number that must be printed on the customer’s receipt.

Returns:

  • (String)


112
113
114
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 112

def system_trace_audit_number
  @system_trace_audit_number
end

#transaction_idString

Network transaction identifier (TID). You can use this value to identify a specific transaction when you are discussing the transaction with your processor. Not all processors provide this value. Returned by the authorization service.

PIN debit

Transaction identifier generated by the processor. Returned by PIN debit credit.

GPX

Processor transaction ID.

Cielo

For Cielo, this value is the non-sequential unit (NSU) and is supported for all transactions. The value is generated by Cielo or the issuing bank.

Comercio Latino

For Comercio Latino, this value is the proof of sale or non-sequential unit (NSU) number generated by the acquirers Cielo and Rede, or the issuing bank.

CyberSource through VisaNet and GPN

For details about this value for CyberSource through VisaNet and GPN, see "processorInformation.networkTransactionId" in [REST API Fields](https://developer.cybersource.com/content/dam/docs/cybs/en-us/apif ields/reference/all/rest/api-fields.pdf)

Moneris

This value identifies the transaction on a host system. It contains the following information:

  • Terminal used to process the transaction
  • Shift during which the transaction took place
  • Batch number
  • Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
  • Terminal ID = 66012345
  • Shift number = 001
  • Batch number = 069
  • Transaction number = 003

Returns:

  • (String)


63
64
65
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 63

def transaction_id
  @transaction_id
end

Class Method Details

.from_element(root) ⇒ Object



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 251

def self.from_element(root)
  approval_code = XmlUtilities.from_element(root, 'approvalCode', String)
  transaction_id = XmlUtilities.from_element(root, 'transactionId', String)
  network_transaction_id = XmlUtilities.from_element(root,
                                                     'networkTransactionId',
                                                     String)
  response_code = XmlUtilities.from_element(root, 'responseCode', String)
  system_trace_audit_number = XmlUtilities.from_element(
    root, 'systemTraceAuditNumber', String
  )
  response_details = XmlUtilities.from_element(root, 'responseDetails',
                                               String)
  merchant_advice = XmlUtilities.from_element(root, 'MerchantAdvice',
                                              MerchantAdvice)
  merchant_risk_prediction = XmlUtilities.from_element(
    root, 'merchantRiskPrediction', String
  )
  seller_protection = XmlUtilities.from_element(
    root, 'processorInformationSellerProtection',
    ProcessorInformationSellerProtection
  )
  network = XmlUtilities.from_element(root, 'Network', Network)

  new(approval_code: approval_code,
      transaction_id: transaction_id,
      network_transaction_id: network_transaction_id,
      response_code: response_code,
      system_trace_audit_number: system_trace_audit_number,
      response_details: response_details,
      merchant_advice: merchant_advice,
      merchant_risk_prediction: merchant_risk_prediction,
      seller_protection: seller_protection,
      network: network,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 209

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  approval_code = hash.key?('approvalCode') ? hash['approvalCode'] : SKIP
  transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP
  network_transaction_id =
    hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP
  response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP
  system_trace_audit_number =
    hash.key?('systemTraceAuditNumber') ? hash['systemTraceAuditNumber'] : SKIP
  response_details =
    hash.key?('responseDetails') ? hash['responseDetails'] : SKIP
  merchant_advice = MerchantAdvice.from_hash(hash['merchantAdvice']) if hash['merchantAdvice']
  merchant_risk_prediction =
    hash.key?('merchantRiskPrediction') ? hash['merchantRiskPrediction'] : SKIP
  if hash['sellerProtection']
    seller_protection = ProcessorInformationSellerProtection.from_hash(hash['sellerProtection'])
  end
  network = Network.from_hash(hash['network']) if hash['network']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorInformation2.new(approval_code: approval_code,
                            transaction_id: transaction_id,
                            network_transaction_id: network_transaction_id,
                            response_code: response_code,
                            system_trace_audit_number: system_trace_audit_number,
                            response_details: response_details,
                            merchant_advice: merchant_advice,
                            merchant_risk_prediction: merchant_risk_prediction,
                            seller_protection: seller_protection,
                            network: network,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 147

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['approval_code'] = 'approvalCode'
  @_hash['transaction_id'] = 'transactionId'
  @_hash['network_transaction_id'] = 'networkTransactionId'
  @_hash['response_code'] = 'responseCode'
  @_hash['system_trace_audit_number'] = 'systemTraceAuditNumber'
  @_hash['response_details'] = 'responseDetails'
  @_hash['merchant_advice'] = 'merchantAdvice'
  @_hash['merchant_risk_prediction'] = 'merchantRiskPrediction'
  @_hash['seller_protection'] = 'sellerProtection'
  @_hash['network'] = 'network'
  @_hash
end

.nullablesObject

An array for nullable fields



179
180
181
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 179

def self.nullables
  []
end

.optionalsObject

An array for optional fields



163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 163

def self.optionals
  %w[
    approval_code
    transaction_id
    network_transaction_id
    response_code
    system_trace_audit_number
    response_details
    merchant_advice
    merchant_risk_prediction
    seller_protection
    network
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



325
326
327
328
329
330
331
332
333
334
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 325

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} approval_code: #{@approval_code.inspect}, transaction_id:"\
  " #{@transaction_id.inspect}, network_transaction_id: #{@network_transaction_id.inspect},"\
  " response_code: #{@response_code.inspect}, system_trace_audit_number:"\
  " #{@system_trace_audit_number.inspect}, response_details: #{@response_details.inspect},"\
  " merchant_advice: #{@merchant_advice.inspect}, merchant_risk_prediction:"\
  " #{@merchant_risk_prediction.inspect}, seller_protection: #{@seller_protection.inspect},"\
  " network: #{@network.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



314
315
316
317
318
319
320
321
322
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 314

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} approval_code: #{@approval_code}, transaction_id: #{@transaction_id},"\
  " network_transaction_id: #{@network_transaction_id}, response_code: #{@response_code},"\
  " system_trace_audit_number: #{@system_trace_audit_number}, response_details:"\
  " #{@response_details}, merchant_advice: #{@merchant_advice}, merchant_risk_prediction:"\
  " #{@merchant_risk_prediction}, seller_protection: #{@seller_protection}, network:"\
  " #{@network}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/cyber_source_merged_spec/models/processor_information2.rb', line 287

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'approvalCode', approval_code)
  XmlUtilities.add_as_subelement(doc, root, 'transactionId', transaction_id)
  XmlUtilities.add_as_subelement(doc, root, 'networkTransactionId',
                                 network_transaction_id)
  XmlUtilities.add_as_subelement(doc, root, 'responseCode', response_code)
  XmlUtilities.add_as_subelement(doc, root, 'systemTraceAuditNumber',
                                 system_trace_audit_number)
  XmlUtilities.add_as_subelement(doc, root, 'responseDetails',
                                 response_details)
  XmlUtilities.add_as_subelement(doc, root, 'MerchantAdvice',
                                 merchant_advice)
  XmlUtilities.add_as_subelement(doc, root, 'merchantRiskPrediction',
                                 merchant_risk_prediction)
  XmlUtilities.add_as_subelement(doc, root,
                                 'processorInformationSellerProtection',
                                 seller_protection)
  XmlUtilities.add_as_subelement(doc, root, 'Network', network)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end