Class: CyberSourceMergedSpec::ProcessorInformation3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processor_information3.rb

Overview

ProcessorInformation3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(pre_approval_token: SKIP, network: SKIP, additional_properties: nil) ⇒ ProcessorInformation3

Returns a new instance of ProcessorInformation3.



43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 43

def initialize(pre_approval_token: SKIP, network: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @pre_approval_token = pre_approval_token unless pre_approval_token == SKIP
  @network = network unless network == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#networkNetwork

This is a token generated by PSP, which is received in response to the Sessions service. This token should be sent in the following transactions.

Returns:



20
21
22
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 20

def network
  @network
end

#pre_approval_tokenString

This is a token generated by PSP, which is received in response to the Sessions service. This token should be sent in the following transactions.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 15

def pre_approval_token
  @pre_approval_token
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 75

def self.from_element(root)
  pre_approval_token = XmlUtilities.from_element(root, 'preApprovalToken',
                                                 String)
  network = XmlUtilities.from_element(root, 'Network', Network)

  new(pre_approval_token: pre_approval_token,
      network: network,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  pre_approval_token =
    hash.key?('preApprovalToken') ? hash['preApprovalToken'] : SKIP
  network = Network.from_hash(hash['network']) if hash['network']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorInformation3.new(pre_approval_token: pre_approval_token,
                            network: network,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['pre_approval_token'] = 'preApprovalToken'
  @_hash['network'] = 'network'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 31

def self.optionals
  %w[
    pre_approval_token
    network
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} pre_approval_token: #{@pre_approval_token.inspect}, network:"\
  " #{@network.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} pre_approval_token: #{@pre_approval_token}, network: #{@network},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/processor_information3.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'preApprovalToken',
                                 pre_approval_token)
  XmlUtilities.add_as_subelement(doc, root, 'Network', network)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end