Class: CyberSourceMergedSpec::ProcessorInformation33
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ProcessorInformation33
- Defined in:
- lib/cyber_source_merged_spec/models/processor_information33.rb
Overview
ProcessorInformation33 Model.
Instance Attribute Summary collapse
-
#system_trace_audit_number ⇒ String
This field is returned by authorization and incremental authorization services.
-
#transaction_id ⇒ String
Network transaction identifier (TID).
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(system_trace_audit_number: SKIP, transaction_id: SKIP, additional_properties: nil) ⇒ ProcessorInformation33
constructor
A new instance of ProcessorInformation33.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(system_trace_audit_number: SKIP, transaction_id: SKIP, additional_properties: nil) ⇒ ProcessorInformation33
Returns a new instance of ProcessorInformation33.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 45 def initialize(system_trace_audit_number: SKIP, transaction_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless system_trace_audit_number == SKIP @system_trace_audit_number = system_trace_audit_number end @transaction_id = transaction_id unless transaction_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#system_trace_audit_number ⇒ String
This field is returned by authorization and incremental authorization services. System trace number that must be printed on the customer’s receipt.
16 17 18 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 16 def system_trace_audit_number @system_trace_audit_number end |
#transaction_id ⇒ String
Network transaction identifier (TID). This value can be used to identify a specific transaction when you are discussing the transaction with your processor.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 22 def transaction_id @transaction_id end |
Class Method Details
.from_element(root) ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 80 def self.from_element(root) system_trace_audit_number = XmlUtilities.from_element( root, 'systemTraceAuditNumber', String ) transaction_id = XmlUtilities.from_element(root, 'transactionId', String) new(system_trace_audit_number: system_trace_audit_number, transaction_id: transaction_id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. system_trace_audit_number = hash.key?('systemTraceAuditNumber') ? hash['systemTraceAuditNumber'] : SKIP transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorInformation33.new(system_trace_audit_number: system_trace_audit_number, transaction_id: transaction_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['system_trace_audit_number'] = 'systemTraceAuditNumber' @_hash['transaction_id'] = 'transactionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 33 def self.optionals %w[ system_trace_audit_number transaction_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} system_trace_audit_number: #{@system_trace_audit_number.inspect},"\ " transaction_id: #{@transaction_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 104 def to_s class_name = self.class.name.split('::').last "<#{class_name} system_trace_audit_number: #{@system_trace_audit_number}, transaction_id:"\ " #{@transaction_id}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/processor_information33.rb', line 91 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'systemTraceAuditNumber', system_trace_audit_number) XmlUtilities.add_as_subelement(doc, root, 'transactionId', transaction_id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |