Class: CyberSourceMergedSpec::ProcessorInformation8

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/processor_information8.rb

Overview

ProcessorInformation8 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transaction_id: SKIP, network_transaction_id: SKIP, response_details: SKIP, response_code: SKIP, provider_response: SKIP, update_time_utc: SKIP, network: SKIP, additional_properties: nil) ⇒ ProcessorInformation8

Returns a new instance of ProcessorInformation8.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 139

def initialize(transaction_id: SKIP, network_transaction_id: SKIP,
               response_details: SKIP, response_code: SKIP,
               provider_response: SKIP, update_time_utc: SKIP,
               network: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @transaction_id = transaction_id unless transaction_id == SKIP
  @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP
  @response_details = response_details unless response_details == SKIP
  @response_code = response_code unless response_code == SKIP
  @provider_response = provider_response unless provider_response == SKIP
  @update_time_utc = update_time_utc unless update_time_utc == SKIP
  @network = network unless network == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#networkNetwork

The date and time when the transaction was last updated, in Internet date and time format.

Returns:



106
107
108
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 106

def network
  @network
end

#network_transaction_idString

Same value as processorInformation.transactionId

Returns:

  • (String)


54
55
56
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 54

def network_transaction_id
  @network_transaction_id
end

#provider_responseString

Processor response to the API request.

Returns:

  • (String)


96
97
98
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 96

def provider_response
  @provider_response
end

#response_codeString

For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.

PIN debit

Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.

AIBMS

If this value is 08, you can accept the transaction if the customer provides you with identification.

Atos

This value is the response code sent from Atos and it might also include the response code from the bank. Format: aa,bb with the two values separated by a comma and where:

  • aa is the two-digit error message from Atos.
  • bb is the optional two-digit error message from the bank.

Comercio Latino

This value is the status code and the error or response code received from the processor separated by a colon. Format: [status code]:E[error code] or [status code]:R[response code] Example 2:R06

JCN Gateway

Processor-defined detail error code. The associated response category code is in the processorInformation.responseCategoryCode field. String (3)

paypalgateway

Processor generated ID for the itemized detail.

Returns:

  • (String)


92
93
94
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 92

def response_code
  @response_code
end

#response_detailsString

The processor code that describes why the transaction state is pending or reversed.

Returns:

  • (String)


59
60
61
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 59

def response_details
  @response_details
end

#transaction_idString

Network transaction identifier (TID). You can use this value to identify a specific transaction when you are discussing the transaction with your processor. Not all processors provide this value. Returned by the authorization service.

PIN debit

Transaction identifier generated by the processor. Returned by PIN debit credit.

GPX

Processor transaction ID.

Cielo

For Cielo, this value is the non-sequential unit (NSU) and is supported for all transactions. The value is generated by Cielo or the issuing bank.

Comercio Latino

For Comercio Latino, this value is the proof of sale or non-sequential unit (NSU) number generated by the acquirers Cielo and Rede, or the issuing bank.

CyberSource through VisaNet and GPN

For details about this value for CyberSource through VisaNet and GPN, see "processorInformation.networkTransactionId" in [REST API Fields](https://developer.cybersource.com/content/dam/docs/cybs/en-us/apif ields/reference/all/rest/api-fields.pdf)

Moneris

This value identifies the transaction on a host system. It contains the following information:

  • Terminal used to process the transaction
  • Shift during which the transaction took place
  • Batch number
  • Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
  • Terminal ID = 66012345
  • Shift number = 001
  • Batch number = 069
  • Transaction number = 003

Returns:

  • (String)


50
51
52
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 50

def transaction_id
  @transaction_id
end

#update_time_utcString

The date and time when the transaction was last updated, in Internet date and time format.

Returns:

  • (String)


101
102
103
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 101

def update_time_utc
  @update_time_utc
end

Class Method Details

.from_element(root) ⇒ Object



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 191

def self.from_element(root)
  transaction_id = XmlUtilities.from_element(root, 'transactionId', String)
  network_transaction_id = XmlUtilities.from_element(root,
                                                     'networkTransactionId',
                                                     String)
  response_details = XmlUtilities.from_element(root, 'responseDetails',
                                               String)
  response_code = XmlUtilities.from_element(root, 'responseCode', String)
  provider_response = XmlUtilities.from_element(root, 'providerResponse',
                                                String)
  update_time_utc = XmlUtilities.from_element(root, 'updateTimeUtc', String)
  network = XmlUtilities.from_element(root, 'Network', Network)

  new(transaction_id: transaction_id,
      network_transaction_id: network_transaction_id,
      response_details: response_details,
      response_code: response_code,
      provider_response: provider_response,
      update_time_utc: update_time_utc,
      network: network,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 157

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP
  network_transaction_id =
    hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP
  response_details =
    hash.key?('responseDetails') ? hash['responseDetails'] : SKIP
  response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP
  provider_response =
    hash.key?('providerResponse') ? hash['providerResponse'] : SKIP
  update_time_utc =
    hash.key?('updateTimeUtc') ? hash['updateTimeUtc'] : SKIP
  network = Network.from_hash(hash['network']) if hash['network']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProcessorInformation8.new(transaction_id: transaction_id,
                            network_transaction_id: network_transaction_id,
                            response_details: response_details,
                            response_code: response_code,
                            provider_response: provider_response,
                            update_time_utc: update_time_utc,
                            network: network,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



109
110
111
112
113
114
115
116
117
118
119
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 109

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transaction_id'] = 'transactionId'
  @_hash['network_transaction_id'] = 'networkTransactionId'
  @_hash['response_details'] = 'responseDetails'
  @_hash['response_code'] = 'responseCode'
  @_hash['provider_response'] = 'providerResponse'
  @_hash['update_time_utc'] = 'updateTimeUtc'
  @_hash['network'] = 'network'
  @_hash
end

.nullablesObject

An array for nullable fields



135
136
137
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 135

def self.nullables
  []
end

.optionalsObject

An array for optional fields



122
123
124
125
126
127
128
129
130
131
132
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 122

def self.optionals
  %w[
    transaction_id
    network_transaction_id
    response_details
    response_code
    provider_response
    update_time_utc
    network
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



245
246
247
248
249
250
251
252
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 245

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_id: #{@transaction_id.inspect}, network_transaction_id:"\
  " #{@network_transaction_id.inspect}, response_details: #{@response_details.inspect},"\
  " response_code: #{@response_code.inspect}, provider_response:"\
  " #{@provider_response.inspect}, update_time_utc: #{@update_time_utc.inspect}, network:"\
  " #{@network.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



235
236
237
238
239
240
241
242
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 235

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_id: #{@transaction_id}, network_transaction_id:"\
  " #{@network_transaction_id}, response_details: #{@response_details}, response_code:"\
  " #{@response_code}, provider_response: #{@provider_response}, update_time_utc:"\
  " #{@update_time_utc}, network: #{@network}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/cyber_source_merged_spec/models/processor_information8.rb', line 214

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'transactionId', transaction_id)
  XmlUtilities.add_as_subelement(doc, root, 'networkTransactionId',
                                 network_transaction_id)
  XmlUtilities.add_as_subelement(doc, root, 'responseDetails',
                                 response_details)
  XmlUtilities.add_as_subelement(doc, root, 'responseCode', response_code)
  XmlUtilities.add_as_subelement(doc, root, 'providerResponse',
                                 provider_response)
  XmlUtilities.add_as_subelement(doc, root, 'updateTimeUtc',
                                 update_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'Network', network)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end