Class: CyberSourceMergedSpec::PtsV2CreateOrderPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2CreateOrderPost201Response
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb
Overview
PtsV2CreateOrderPost201Response Model.
Instance Attribute Summary collapse
-
#buyer_information ⇒ BuyerInformation11
Reference number for the transaction.
-
#client_reference_information ⇒ ClientReferenceInformation3
Reference number for the transaction.
-
#payment_information ⇒ PaymentInformation21
Reference number for the transaction.
-
#processor_information ⇒ ProcessorInformation27
Reference number for the transaction.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
-
#update_time_utc ⇒ String
The date and time when the request was last updated.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(submit_time_utc: SKIP, update_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, buyer_information: SKIP, additional_properties: nil) ⇒ PtsV2CreateOrderPost201Response
constructor
A new instance of PtsV2CreateOrderPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(submit_time_utc: SKIP, update_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, buyer_information: SKIP, additional_properties: nil) ⇒ PtsV2CreateOrderPost201Response
Returns a new instance of PtsV2CreateOrderPost201Response.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 110 def initialize(submit_time_utc: SKIP, update_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, buyer_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @update_time_utc = update_time_utc unless update_time_utc == SKIP @status = status unless status == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @processor_information = processor_information unless processor_information == SKIP @payment_information = payment_information unless payment_information == SKIP @buyer_information = buyer_information unless buyer_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#buyer_information ⇒ BuyerInformation11
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
75 76 77 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 75 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation3
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
51 52 53 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 51 def client_reference_information @client_reference_information end |
#payment_information ⇒ PaymentInformation21
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
67 68 69 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 67 def payment_information @payment_information end |
#processor_information ⇒ ProcessorInformation27
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
59 60 61 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 59 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 43 def reconciliation_id @reconciliation_id end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- CREATED
- SAVED
- APPROVED
- VOIDED
- COMPLETED
- PAYER_ACTION_REQUIRED
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 35 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 18 def submit_time_utc @submit_time_utc end |
#update_time_utc ⇒ String
The date and time when the request was last updated.
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 24 def update_time_utc @update_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 172 def self.from_element(root) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) update_time_utc = XmlUtilities.from_element(root, 'updateTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation3', ClientReferenceInformation3 ) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation27', ProcessorInformation27 ) payment_information = XmlUtilities.from_element(root, 'PaymentInformation21', PaymentInformation21) buyer_information = XmlUtilities.from_element(root, 'BuyerInformation11', BuyerInformation11) new(submit_time_utc: submit_time_utc, update_time_utc: update_time_utc, status: status, reconciliation_id: reconciliation_id, client_reference_information: client_reference_information, processor_information: processor_information, payment_information: payment_information, buyer_information: buyer_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 132 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP update_time_utc = hash.key?('updateTimeUtc') ? hash['updateTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end processor_information = ProcessorInformation27.from_hash(hash['processorInformation']) if hash['processorInformation'] payment_information = PaymentInformation21.from_hash(hash['paymentInformation']) if hash['paymentInformation'] buyer_information = BuyerInformation11.from_hash(hash['buyerInformation']) if hash['buyerInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2CreateOrderPost201Response.new(submit_time_utc: submit_time_utc, update_time_utc: update_time_utc, status: status, reconciliation_id: reconciliation_id, client_reference_information: client_reference_information, processor_information: processor_information, payment_information: payment_information, buyer_information: buyer_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 78 def self.names @_hash = {} if @_hash.nil? @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['update_time_utc'] = 'updateTimeUtc' @_hash['status'] = 'status' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['processor_information'] = 'processorInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['buyer_information'] = 'buyerInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
106 107 108 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 106 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 92 def self.optionals %w[ submit_time_utc update_time_utc status reconciliation_id client_reference_information processor_information payment_information buyer_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 238 def inspect class_name = self.class.name.split('::').last "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, update_time_utc:"\ " #{@update_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\ " #{@reconciliation_id.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, processor_information:"\ " #{@processor_information.inspect}, payment_information: #{@payment_information.inspect},"\ " buyer_information: #{@buyer_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
227 228 229 230 231 232 233 234 235 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 227 def to_s class_name = self.class.name.split('::').last "<#{class_name} submit_time_utc: #{@submit_time_utc}, update_time_utc: #{@update_time_utc},"\ " status: #{@status}, reconciliation_id: #{@reconciliation_id},"\ " client_reference_information: #{@client_reference_information}, processor_information:"\ " #{@processor_information}, payment_information: #{@payment_information},"\ " buyer_information: #{@buyer_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_create_order_post201_response.rb', line 202 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'updateTimeUtc', update_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation3', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation27', processor_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation21', payment_information) XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation11', buyer_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |