Class: CyberSourceMergedSpec::PtsV2CreditsPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb

Overview

PtsV2CreditsPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, credit_amount_details: SKIP, processing_information: SKIP, processor_information: SKIP, payment_information: SKIP, order_information: SKIP, merchant_information: SKIP, clearing_information: SKIP, point_of_sale_information: SKIP, token_information: SKIP, payment_account_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ PtsV2CreditsPost201Response

Returns a new instance of PtsV2CreditsPost201Response.



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 197

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP,
               reconciliation_id: SKIP, client_reference_information: SKIP,
               credit_amount_details: SKIP, processing_information: SKIP,
               processor_information: SKIP, payment_information: SKIP,
               order_information: SKIP, merchant_information: SKIP,
               clearing_information: SKIP, point_of_sale_information: SKIP,
               token_information: SKIP, payment_account_information: SKIP,
               error_information: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @credit_amount_details = credit_amount_details unless credit_amount_details == SKIP
  @processing_information = processing_information unless processing_information == SKIP
  @processor_information = processor_information unless processor_information == SKIP
  @payment_information = payment_information unless payment_information == SKIP
  @order_information = order_information unless order_information == SKIP
  @merchant_information = merchant_information unless merchant_information == SKIP
  @clearing_information = clearing_information unless clearing_information == SKIP
  unless point_of_sale_information == SKIP
    @point_of_sale_information =
      point_of_sale_information
  end
  @token_information = token_information unless token_information == SKIP
  unless  == SKIP
    @payment_account_information =
      
  end
  @error_information = error_information unless error_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#clearing_informationClearingInformation

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



112
113
114
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 112

def clearing_information
  @clearing_information
end

#client_reference_informationClientReferenceInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



56
57
58
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 56

def client_reference_information
  @client_reference_information
end

#credit_amount_detailsCreditAmountDetails

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



64
65
66
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 64

def credit_amount_details
  @credit_amount_details
end

#error_informationErrorInformation2

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



144
145
146
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 144

def error_information
  @error_information
end

#idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 14

def links
  @links
end

#merchant_informationMerchantInformation7

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



104
105
106
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 104

def merchant_information
  @merchant_information
end

#order_informationOrderInformation9

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



96
97
98
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 96

def order_information
  @order_information
end

#payment_account_informationPaymentAccountInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



136
137
138
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 136

def 
  @payment_account_information
end

#payment_informationPaymentInformation8

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



88
89
90
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 88

def payment_information
  @payment_information
end

#point_of_sale_informationPointOfSaleInformation7

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



120
121
122
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 120

def point_of_sale_information
  @point_of_sale_information
end

#processing_informationProcessingInformation12

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



72
73
74
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 72

def processing_information
  @processing_information
end

#processor_informationProcessorInformation10

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



80
81
82
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 80

def processor_information
  @processor_information
end

#reconciliation_idString

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:

  • (String)


48
49
50
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 48

def reconciliation_id
  @reconciliation_id
end

#statusString

The status of the submitted transaction. Possible values:

  • PENDING
  • AUTHORIZED
  • DECLINED
  • INVALID_REQUEST
  • COMPLETED (as in the case of PIN Debit Full Financial Credit)

Returns:

  • (String)


40
41
42
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 40

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

#token_informationTokenInformation3

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



128
129
130
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 128

def token_information
  @token_information
end

Class Method Details

.from_element(root) ⇒ Object



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 305

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links5', Links5)
  id = XmlUtilities.from_element(root, 'id', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  status = XmlUtilities.from_element(root, 'status', String)
  reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId',
                                                String)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation1',
    ClientReferenceInformation1
  )
  credit_amount_details = XmlUtilities.from_element(root,
                                                    'CreditAmountDetails',
                                                    CreditAmountDetails)
  processing_information = XmlUtilities.from_element(
    root, 'ProcessingInformation12', ProcessingInformation12
  )
  processor_information = XmlUtilities.from_element(
    root, 'ProcessorInformation10', ProcessorInformation10
  )
  payment_information = XmlUtilities.from_element(root,
                                                  'PaymentInformation8',
                                                  PaymentInformation8)
  order_information = XmlUtilities.from_element(root, 'OrderInformation9',
                                                OrderInformation9)
  merchant_information = XmlUtilities.from_element(root,
                                                   'MerchantInformation7',
                                                   MerchantInformation7)
  clearing_information = XmlUtilities.from_element(root,
                                                   'ClearingInformation',
                                                   ClearingInformation)
  point_of_sale_information = XmlUtilities.from_element(
    root, 'PointOfSaleInformation7', PointOfSaleInformation7
  )
  token_information = XmlUtilities.from_element(root, 'TokenInformation3',
                                                TokenInformation3)
   = XmlUtilities.from_element(
    root, 'PaymentAccountInformation1',
    PaymentAccountInformation1
  )
  error_information = XmlUtilities.from_element(root, 'ErrorInformation2',
                                                ErrorInformation2)

  new(links: links,
      id: id,
      submit_time_utc: submit_time_utc,
      status: status,
      reconciliation_id: reconciliation_id,
      client_reference_information: client_reference_information,
      credit_amount_details: credit_amount_details,
      processing_information: processing_information,
      processor_information: processor_information,
      payment_information: payment_information,
      order_information: order_information,
      merchant_information: merchant_information,
      clearing_information: clearing_information,
      point_of_sale_information: point_of_sale_information,
      token_information: token_information,
      payment_account_information: ,
      error_information: error_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 238

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links5.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation1.from_hash(hash['clientReferenceInformation'])
  end
  credit_amount_details = CreditAmountDetails.from_hash(hash['creditAmountDetails']) if
    hash['creditAmountDetails']
  processing_information = ProcessingInformation12.from_hash(hash['processingInformation']) if
    hash['processingInformation']
  processor_information = ProcessorInformation10.from_hash(hash['processorInformation']) if
    hash['processorInformation']
  payment_information = PaymentInformation8.from_hash(hash['paymentInformation']) if
    hash['paymentInformation']
  order_information = OrderInformation9.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  merchant_information = MerchantInformation7.from_hash(hash['merchantInformation']) if
    hash['merchantInformation']
  clearing_information = ClearingInformation.from_hash(hash['clearingInformation']) if
    hash['clearingInformation']
  if hash['pointOfSaleInformation']
    point_of_sale_information = PointOfSaleInformation7.from_hash(hash['pointOfSaleInformation'])
  end
  token_information = TokenInformation3.from_hash(hash['tokenInformation']) if
    hash['tokenInformation']
  if hash['paymentAccountInformation']
     = PaymentAccountInformation1.from_hash(hash['paymentAccountInformation'])
  end
  error_information = ErrorInformation2.from_hash(hash['errorInformation']) if
    hash['errorInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PtsV2CreditsPost201Response.new(links: links,
                                  id: id,
                                  submit_time_utc: submit_time_utc,
                                  status: status,
                                  reconciliation_id: reconciliation_id,
                                  client_reference_information: client_reference_information,
                                  credit_amount_details: credit_amount_details,
                                  processing_information: processing_information,
                                  processor_information: processor_information,
                                  payment_information: payment_information,
                                  order_information: order_information,
                                  merchant_information: merchant_information,
                                  clearing_information: clearing_information,
                                  point_of_sale_information: point_of_sale_information,
                                  token_information: token_information,
                                  payment_account_information: ,
                                  error_information: error_information,
                                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 147

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['credit_amount_details'] = 'creditAmountDetails'
  @_hash['processing_information'] = 'processingInformation'
  @_hash['processor_information'] = 'processorInformation'
  @_hash['payment_information'] = 'paymentInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash['merchant_information'] = 'merchantInformation'
  @_hash['clearing_information'] = 'clearingInformation'
  @_hash['point_of_sale_information'] = 'pointOfSaleInformation'
  @_hash['token_information'] = 'tokenInformation'
  @_hash['payment_account_information'] = 'paymentAccountInformation'
  @_hash['error_information'] = 'errorInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



193
194
195
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 193

def self.nullables
  []
end

.optionalsObject

An array for optional fields



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 170

def self.optionals
  %w[
    links
    id
    submit_time_utc
    status
    reconciliation_id
    client_reference_information
    credit_amount_details
    processing_information
    processor_information
    payment_information
    order_information
    merchant_information
    clearing_information
    point_of_sale_information
    token_information
    payment_account_information
    error_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 424

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\
  " #{@reconciliation_id.inspect}, client_reference_information:"\
  " #{@client_reference_information.inspect}, credit_amount_details:"\
  " #{@credit_amount_details.inspect}, processing_information:"\
  " #{@processing_information.inspect}, processor_information:"\
  " #{@processor_information.inspect}, payment_information: #{@payment_information.inspect},"\
  " order_information: #{@order_information.inspect}, merchant_information:"\
  " #{@merchant_information.inspect}, clearing_information: #{@clearing_information.inspect},"\
  " point_of_sale_information: #{@point_of_sale_information.inspect}, token_information:"\
  " #{@token_information.inspect}, payment_account_information:"\
  " #{@payment_account_information.inspect}, error_information: #{@error_information.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 409

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\
  " #{@status}, reconciliation_id: #{@reconciliation_id}, client_reference_information:"\
  " #{@client_reference_information}, credit_amount_details: #{@credit_amount_details},"\
  " processing_information: #{@processing_information}, processor_information:"\
  " #{@processor_information}, payment_information: #{@payment_information},"\
  " order_information: #{@order_information}, merchant_information: #{@merchant_information},"\
  " clearing_information: #{@clearing_information}, point_of_sale_information:"\
  " #{@point_of_sale_information}, token_information: #{@token_information},"\
  " payment_account_information: #{@payment_account_information}, error_information:"\
  " #{@error_information}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/cyber_source_merged_spec/models/pts_v2_credits_post201_response.rb', line 368

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links5', links)
  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'reconciliationId',
                                 reconciliation_id)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation1',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'CreditAmountDetails',
                                 credit_amount_details)
  XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation12',
                                 processing_information)
  XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation10',
                                 processor_information)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation8',
                                 payment_information)
  XmlUtilities.add_as_subelement(doc, root, 'OrderInformation9',
                                 order_information)
  XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation7',
                                 merchant_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClearingInformation',
                                 clearing_information)
  XmlUtilities.add_as_subelement(doc, root, 'PointOfSaleInformation7',
                                 point_of_sale_information)
  XmlUtilities.add_as_subelement(doc, root, 'TokenInformation3',
                                 token_information)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentAccountInformation1',
                                 )
  XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation2',
                                 error_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end