Class: CyberSourceMergedSpec::PtsV2PaymentsPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb

Overview

PtsV2PaymentsPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, message: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, processing_information: SKIP, processor_information: SKIP, issuer_information: SKIP, payment_account_information: SKIP, payment_information: SKIP, payment_insights_information: SKIP, order_information: SKIP, point_of_sale_information: SKIP, installment_information: SKIP, token_information: SKIP, buyer_information: SKIP, risk_information: SKIP, consumer_authentication_information: SKIP, merchant_information: SKIP, clearing_information: SKIP, embedded_actions: SKIP, watchlist_screening_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response

Returns a new instance of PtsV2PaymentsPost201Response.



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 256

def initialize(links: SKIP, id: SKIP, message: SKIP, submit_time_utc: SKIP,
               status: SKIP, reconciliation_id: SKIP,
               error_information: SKIP, client_reference_information: SKIP,
               processing_information: SKIP, processor_information: SKIP,
               issuer_information: SKIP, payment_account_information: SKIP,
               payment_information: SKIP,
               payment_insights_information: SKIP, order_information: SKIP,
               point_of_sale_information: SKIP,
               installment_information: SKIP, token_information: SKIP,
               buyer_information: SKIP, risk_information: SKIP,
               consumer_authentication_information: SKIP,
               merchant_information: SKIP, clearing_information: SKIP,
               embedded_actions: SKIP,
               watchlist_screening_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @message = message unless message == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP
  @error_information = error_information unless error_information == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @processing_information = processing_information unless processing_information == SKIP
  @processor_information = processor_information unless processor_information == SKIP
  @issuer_information = issuer_information unless issuer_information == SKIP
  unless  == SKIP
    @payment_account_information =
      
  end
  @payment_information = payment_information unless payment_information == SKIP
  unless payment_insights_information == SKIP
    @payment_insights_information =
      payment_insights_information
  end
  @order_information = order_information unless order_information == SKIP
  unless point_of_sale_information == SKIP
    @point_of_sale_information =
      point_of_sale_information
  end
  @installment_information = installment_information unless installment_information == SKIP
  @token_information = token_information unless token_information == SKIP
  @buyer_information = buyer_information unless buyer_information == SKIP
  @risk_information = risk_information unless risk_information == SKIP
  unless consumer_authentication_information == SKIP
    @consumer_authentication_information =
      consumer_authentication_information
  end
  @merchant_information = merchant_information unless merchant_information == SKIP
  @clearing_information = clearing_information unless clearing_information == SKIP
  @embedded_actions = embedded_actions unless embedded_actions == SKIP
  unless watchlist_screening_information == SKIP
    @watchlist_screening_information =
      watchlist_screening_information
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#buyer_informationBuyerInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



159
160
161
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 159

def buyer_information
  @buyer_information
end

#clearing_informationClearingInformation

Contains the result of risk assessment.

Returns:



175
176
177
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 175

def clearing_information
  @clearing_information
end

#client_reference_informationClientReferenceInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



71
72
73
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 71

def client_reference_information
  @client_reference_information
end

#consumer_authentication_informationConsumerAuthenticationInformation1

Contains the result of risk assessment.



167
168
169
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 167

def consumer_authentication_information
  @consumer_authentication_information
end

#embedded_actionsEmbeddedActions

Contains embedded actions, that includes status and response for every actions in the list.

Returns:



180
181
182
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 180

def embedded_actions
  @embedded_actions
end

#error_informationErrorInformation

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



63
64
65
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 63

def error_information
  @error_information
end

#idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 22

def id
  @id
end

#installment_informationInstallmentInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



143
144
145
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 143

def installment_information
  @installment_information
end

#issuer_informationIssuerInformation2

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



95
96
97
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 95

def issuer_information
  @issuer_information
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 14

def links
  @links
end

#merchant_informationMerchantInformation1

Contains the result of risk assessment.



171
172
173
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 171

def merchant_information
  @merchant_information
end

#messageString

More information about the transaction response.

Returns:

  • (String)


26
27
28
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 26

def message
  @message
end

#order_informationOrderInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



127
128
129
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 127

def order_information
  @order_information
end

#payment_account_informationPaymentAccountInformation

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



103
104
105
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 103

def 
  @payment_account_information
end

#payment_informationPaymentInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



111
112
113
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 111

def payment_information
  @payment_information
end

#payment_insights_informationPaymentInsightsInformation

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



119
120
121
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 119

def payment_insights_information
  @payment_insights_information
end

#point_of_sale_informationPointOfSaleInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



135
136
137
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 135

def point_of_sale_information
  @point_of_sale_information
end

#processing_informationProcessingInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



79
80
81
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 79

def processing_information
  @processing_information
end

#processor_informationProcessorInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.



87
88
89
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 87

def processor_information
  @processor_information
end

#reconciliation_idString

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:

  • (String)


55
56
57
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 55

def reconciliation_id
  @reconciliation_id
end

#risk_informationRiskInformation1

Contains the result of risk assessment.

Returns:



163
164
165
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 163

def risk_information
  @risk_information
end

#statusString

The status of the submitted transaction. Possible values:

  • AUTHORIZED
  • PARTIAL_AUTHORIZED
  • AUTHORIZED_PENDING_REVIEW
  • AUTHORIZED_RISK_DECLINED
  • PENDING_AUTHENTICATION
  • PENDING_REVIEW
  • DECLINED
  • INVALID_REQUEST

Returns:

  • (String)


47
48
49
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 47

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


34
35
36
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 34

def submit_time_utc
  @submit_time_utc
end

#token_informationTokenInformation1

Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.

Returns:



151
152
153
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 151

def token_information
  @token_information
end

#watchlist_screening_informationWatchlistScreeningInformation1

Contains embedded actions, that includes status and response for every actions in the list.



185
186
187
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 185

def watchlist_screening_information
  @watchlist_screening_information
end

Class Method Details

.from_element(root) ⇒ Object



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 414

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links', Links)
  id = XmlUtilities.from_element(root, 'id', String)
  message = XmlUtilities.from_element(root, 'message', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  status = XmlUtilities.from_element(root, 'status', String)
  reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId',
                                                String)
  error_information = XmlUtilities.from_element(root, 'ErrorInformation',
                                                ErrorInformation)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation1',
    ClientReferenceInformation1
  )
  processing_information = XmlUtilities.from_element(
    root, 'ProcessingInformation1', ProcessingInformation1
  )
  processor_information = XmlUtilities.from_element(root,
                                                    'ProcessorInformation1',
                                                    ProcessorInformation1)
  issuer_information = XmlUtilities.from_element(root, 'IssuerInformation2',
                                                 IssuerInformation2)
   = XmlUtilities.from_element(
    root, 'PaymentAccountInformation', PaymentAccountInformation
  )
  payment_information = XmlUtilities.from_element(root,
                                                  'PaymentInformation1',
                                                  PaymentInformation1)
  payment_insights_information = XmlUtilities.from_element(
    root, 'PaymentInsightsInformation',
    PaymentInsightsInformation
  )
  order_information = XmlUtilities.from_element(root, 'OrderInformation1',
                                                OrderInformation1)
  point_of_sale_information = XmlUtilities.from_element(
    root, 'PointOfSaleInformation1', PointOfSaleInformation1
  )
  installment_information = XmlUtilities.from_element(
    root, 'InstallmentInformation1', InstallmentInformation1
  )
  token_information = XmlUtilities.from_element(root, 'TokenInformation1',
                                                TokenInformation1)
  buyer_information = XmlUtilities.from_element(root, 'BuyerInformation1',
                                                BuyerInformation1)
  risk_information = XmlUtilities.from_element(root, 'RiskInformation1',
                                               RiskInformation1)
  consumer_authentication_information = XmlUtilities.from_element(
    root, 'ConsumerAuthenticationInformation1',
    ConsumerAuthenticationInformation1
  )
  merchant_information = XmlUtilities.from_element(root,
                                                   'MerchantInformation1',
                                                   MerchantInformation1)
  clearing_information = XmlUtilities.from_element(root,
                                                   'ClearingInformation',
                                                   ClearingInformation)
  embedded_actions = XmlUtilities.from_element(root, 'EmbeddedActions',
                                               EmbeddedActions)
  watchlist_screening_information = XmlUtilities.from_element(
    root, 'WatchlistScreeningInformation1',
    WatchlistScreeningInformation1
  )

  new(links: links,
      id: id,
      message: message,
      submit_time_utc: submit_time_utc,
      status: status,
      reconciliation_id: reconciliation_id,
      error_information: error_information,
      client_reference_information: client_reference_information,
      processing_information: processing_information,
      processor_information: processor_information,
      issuer_information: issuer_information,
      payment_account_information: ,
      payment_information: payment_information,
      payment_insights_information: payment_insights_information,
      order_information: order_information,
      point_of_sale_information: point_of_sale_information,
      installment_information: installment_information,
      token_information: token_information,
      buyer_information: buyer_information,
      risk_information: risk_information,
      consumer_authentication_information: consumer_authentication_information,
      merchant_information: merchant_information,
      clearing_information: clearing_information,
      embedded_actions: embedded_actions,
      watchlist_screening_information: watchlist_screening_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 321

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  reconciliation_id =
    hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP
  error_information = ErrorInformation.from_hash(hash['errorInformation']) if
    hash['errorInformation']
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation1.from_hash(hash['clientReferenceInformation'])
  end
  processing_information = ProcessingInformation1.from_hash(hash['processingInformation']) if
    hash['processingInformation']
  processor_information = ProcessorInformation1.from_hash(hash['processorInformation']) if
    hash['processorInformation']
  issuer_information = IssuerInformation2.from_hash(hash['issuerInformation']) if
    hash['issuerInformation']
  if hash['paymentAccountInformation']
     = PaymentAccountInformation.from_hash(hash['paymentAccountInformation'])
  end
  payment_information = PaymentInformation1.from_hash(hash['paymentInformation']) if
    hash['paymentInformation']
  if hash['paymentInsightsInformation']
    payment_insights_information = PaymentInsightsInformation.from_hash(hash['paymentInsightsInformation'])
  end
  order_information = OrderInformation1.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  if hash['pointOfSaleInformation']
    point_of_sale_information = PointOfSaleInformation1.from_hash(hash['pointOfSaleInformation'])
  end
  installment_information = InstallmentInformation1.from_hash(hash['installmentInformation']) if
    hash['installmentInformation']
  token_information = TokenInformation1.from_hash(hash['tokenInformation']) if
    hash['tokenInformation']
  buyer_information = BuyerInformation1.from_hash(hash['buyerInformation']) if
    hash['buyerInformation']
  risk_information = RiskInformation1.from_hash(hash['riskInformation']) if
    hash['riskInformation']
  if hash['consumerAuthenticationInformation']
    consumer_authentication_information = ConsumerAuthenticationInformation1.from_hash(hash['consumerAuthenticationInformation'])
  end
  merchant_information = MerchantInformation1.from_hash(hash['merchantInformation']) if
    hash['merchantInformation']
  clearing_information = ClearingInformation.from_hash(hash['clearingInformation']) if
    hash['clearingInformation']
  embedded_actions = EmbeddedActions.from_hash(hash['embeddedActions']) if
    hash['embeddedActions']
  if hash['watchlistScreeningInformation']
    watchlist_screening_information = WatchlistScreeningInformation1.from_hash(hash['watchlistScreeningInformation'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PtsV2PaymentsPost201Response.new(links: links,
                                   id: id,
                                   message: message,
                                   submit_time_utc: submit_time_utc,
                                   status: status,
                                   reconciliation_id: reconciliation_id,
                                   error_information: error_information,
                                   client_reference_information: client_reference_information,
                                   processing_information: processing_information,
                                   processor_information: processor_information,
                                   issuer_information: issuer_information,
                                   payment_account_information: ,
                                   payment_information: payment_information,
                                   payment_insights_information: payment_insights_information,
                                   order_information: order_information,
                                   point_of_sale_information: point_of_sale_information,
                                   installment_information: installment_information,
                                   token_information: token_information,
                                   buyer_information: buyer_information,
                                   risk_information: risk_information,
                                   consumer_authentication_information: consumer_authentication_information,
                                   merchant_information: merchant_information,
                                   clearing_information: clearing_information,
                                   embedded_actions: embedded_actions,
                                   watchlist_screening_information: watchlist_screening_information,
                                   additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 188

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['message'] = 'message'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash['reconciliation_id'] = 'reconciliationId'
  @_hash['error_information'] = 'errorInformation'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['processing_information'] = 'processingInformation'
  @_hash['processor_information'] = 'processorInformation'
  @_hash['issuer_information'] = 'issuerInformation'
  @_hash['payment_account_information'] = 'paymentAccountInformation'
  @_hash['payment_information'] = 'paymentInformation'
  @_hash['payment_insights_information'] = 'paymentInsightsInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash['point_of_sale_information'] = 'pointOfSaleInformation'
  @_hash['installment_information'] = 'installmentInformation'
  @_hash['token_information'] = 'tokenInformation'
  @_hash['buyer_information'] = 'buyerInformation'
  @_hash['risk_information'] = 'riskInformation'
  @_hash['consumer_authentication_information'] =
    'consumerAuthenticationInformation'
  @_hash['merchant_information'] = 'merchantInformation'
  @_hash['clearing_information'] = 'clearingInformation'
  @_hash['embedded_actions'] = 'embeddedActions'
  @_hash['watchlist_screening_information'] =
    'watchlistScreeningInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



252
253
254
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 252

def self.nullables
  []
end

.optionalsObject

An array for optional fields



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 221

def self.optionals
  %w[
    links
    id
    message
    submit_time_utc
    status
    reconciliation_id
    error_information
    client_reference_information
    processing_information
    processor_information
    issuer_information
    payment_account_information
    payment_information
    payment_insights_information
    order_information
    point_of_sale_information
    installment_information
    token_information
    buyer_information
    risk_information
    consumer_authentication_information
    merchant_information
    clearing_information
    embedded_actions
    watchlist_screening_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 584

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, message: #{@message.inspect},"\
  " submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\
  " reconciliation_id: #{@reconciliation_id.inspect}, error_information:"\
  " #{@error_information.inspect}, client_reference_information:"\
  " #{@client_reference_information.inspect}, processing_information:"\
  " #{@processing_information.inspect}, processor_information:"\
  " #{@processor_information.inspect}, issuer_information: #{@issuer_information.inspect},"\
  " payment_account_information: #{@payment_account_information.inspect}, payment_information:"\
  " #{@payment_information.inspect}, payment_insights_information:"\
  " #{@payment_insights_information.inspect}, order_information:"\
  " #{@order_information.inspect}, point_of_sale_information:"\
  " #{@point_of_sale_information.inspect}, installment_information:"\
  " #{@installment_information.inspect}, token_information: #{@token_information.inspect},"\
  " buyer_information: #{@buyer_information.inspect}, risk_information:"\
  " #{@risk_information.inspect}, consumer_authentication_information:"\
  " #{@consumer_authentication_information.inspect}, merchant_information:"\
  " #{@merchant_information.inspect}, clearing_information: #{@clearing_information.inspect},"\
  " embedded_actions: #{@embedded_actions.inspect}, watchlist_screening_information:"\
  " #{@watchlist_screening_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 563

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, message: #{@message}, submit_time_utc:"\
  " #{@submit_time_utc}, status: #{@status}, reconciliation_id: #{@reconciliation_id},"\
  " error_information: #{@error_information}, client_reference_information:"\
  " #{@client_reference_information}, processing_information: #{@processing_information},"\
  " processor_information: #{@processor_information}, issuer_information:"\
  " #{@issuer_information}, payment_account_information: #{@payment_account_information},"\
  " payment_information: #{@payment_information}, payment_insights_information:"\
  " #{@payment_insights_information}, order_information: #{@order_information},"\
  " point_of_sale_information: #{@point_of_sale_information}, installment_information:"\
  " #{@installment_information}, token_information: #{@token_information}, buyer_information:"\
  " #{@buyer_information}, risk_information: #{@risk_information},"\
  " consumer_authentication_information: #{@consumer_authentication_information},"\
  " merchant_information: #{@merchant_information}, clearing_information:"\
  " #{@clearing_information}, embedded_actions: #{@embedded_actions},"\
  " watchlist_screening_information: #{@watchlist_screening_information},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response.rb', line 505

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links', links)
  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'reconciliationId',
                                 reconciliation_id)
  XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation',
                                 error_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation1',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation1',
                                 processing_information)
  XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation1',
                                 processor_information)
  XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation2',
                                 issuer_information)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentAccountInformation',
                                 )
  XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation1',
                                 payment_information)
  XmlUtilities.add_as_subelement(doc, root, 'PaymentInsightsInformation',
                                 payment_insights_information)
  XmlUtilities.add_as_subelement(doc, root, 'OrderInformation1',
                                 order_information)
  XmlUtilities.add_as_subelement(doc, root, 'PointOfSaleInformation1',
                                 point_of_sale_information)
  XmlUtilities.add_as_subelement(doc, root, 'InstallmentInformation1',
                                 installment_information)
  XmlUtilities.add_as_subelement(doc, root, 'TokenInformation1',
                                 token_information)
  XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation1',
                                 buyer_information)
  XmlUtilities.add_as_subelement(doc, root, 'RiskInformation1',
                                 risk_information)
  XmlUtilities.add_as_subelement(doc, root,
                                 'ConsumerAuthenticationInformation1',
                                 consumer_authentication_information)
  XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation1',
                                 merchant_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClearingInformation',
                                 clearing_information)
  XmlUtilities.add_as_subelement(doc, root, 'EmbeddedActions',
                                 embedded_actions)
  XmlUtilities.add_as_subelement(doc, root,
                                 'WatchlistScreeningInformation1',
                                 watchlist_screening_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end