Class: CyberSourceMergedSpec::PullFunds

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/pull_funds.rb

Overview

PullFunds Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(domestic_participant: SKIP, cross_border_participant: SKIP, additional_properties: nil) ⇒ PullFunds

Returns a new instance of PullFunds.



47
48
49
50
51
52
53
54
55
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 47

def initialize(domestic_participant: SKIP, cross_border_participant: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @domestic_participant = domestic_participant unless domestic_participant == SKIP
  @cross_border_participant = cross_border_participant unless cross_border_participant == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cross_border_participantString

This field indicates if cross-border AFTs (pull funds) are allowed. Possible values:

- `true`
- `false`

Returns:

  • (String)


24
25
26
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 24

def cross_border_participant
  @cross_border_participant
end

#domestic_participantString

This field indicates if domestic AFTs (pull funds) are allowed. Possible values:

- `true`
- `false`

Returns:

  • (String)


17
18
19
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 17

def domestic_participant
  @domestic_participant
end

Class Method Details

.from_element(root) ⇒ Object



80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 80

def self.from_element(root)
  domestic_participant = XmlUtilities.from_element(root,
                                                   'domesticParticipant',
                                                   String)
  cross_border_participant = XmlUtilities.from_element(
    root, 'crossBorderParticipant', String
  )

  new(domestic_participant: domestic_participant,
      cross_border_participant: cross_border_participant,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  domestic_participant =
    hash.key?('domesticParticipant') ? hash['domesticParticipant'] : SKIP
  cross_border_participant =
    hash.key?('crossBorderParticipant') ? hash['crossBorderParticipant'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PullFunds.new(domestic_participant: domestic_participant,
                cross_border_participant: cross_border_participant,
                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['domestic_participant'] = 'domesticParticipant'
  @_hash['cross_border_participant'] = 'crossBorderParticipant'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 35

def self.optionals
  %w[
    domestic_participant
    cross_border_participant
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} domestic_participant: #{@domestic_participant.inspect},"\
  " cross_border_participant: #{@cross_border_participant.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} domestic_participant: #{@domestic_participant}, cross_border_participant:"\
  " #{@cross_border_participant}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/pull_funds.rb', line 93

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'domesticParticipant',
                                 domestic_participant)
  XmlUtilities.add_as_subelement(doc, root, 'crossBorderParticipant',
                                 cross_border_participant)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end