Class: CyberSourceMergedSpec::PullFundsController

Inherits:
BaseController show all
Defined in:
lib/cyber_source_merged_spec/controllers/pull_funds_controller.rb

Overview

PullFundsController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from CyberSourceMergedSpec::BaseController

Instance Method Details

#create_pull_funds_refund(pull_funds_refund_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id) ⇒ ApiResponse

Refund an Account Funding Transaction (AFT). parameter: TODO: type description here Account Funding Transaction. here here here here description here description here

Parameters:

  • pull_funds_refund_request (PullFundsRefundRequest)

    Required

  • id (String)

    Required parameter: The transaction id of a previous

  • content_type (String)

    Required parameter: TODO: type description

  • x_requestid (String)

    Required parameter: TODO: type description

  • v_c_merchant_id (String)

    Required parameter: TODO: type description

  • v_c_permissions (String)

    Required parameter: TODO: type description

  • v_c_correlation_id (String)

    Required parameter: TODO: type

  • v_c_organization_id (String)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/cyber_source_merged_spec/controllers/pull_funds_controller.rb', line 157

def create_pull_funds_refund(pull_funds_refund_request,
                             id,
                             content_type,
                             x_requestid,
                             v_c_merchant_id,
                             v_c_permissions,
                             v_c_correlation_id,
                             v_c_organization_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/pts/v1/pull-funds-transfer/{id}/refund',
                                 Server::DEFAULT)
               .body_param(new_parameter(pull_funds_refund_request)
                            .is_required(true))
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter(content_type, key: 'Content-Type')
                              .is_required(true))
               .header_param(new_parameter(x_requestid, key: 'x-requestid')
                              .is_required(true))
               .header_param(new_parameter(v_c_merchant_id, key: 'v-c-merchant-id')
                              .is_required(true))
               .header_param(new_parameter(v_c_permissions, key: 'v-c-permissions')
                              .is_required(true))
               .header_param(new_parameter(v_c_correlation_id, key: 'v-c-correlation-id')
                              .is_required(true))
               .header_param(new_parameter(v_c_organization_id, key: 'v-c-organization-id')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(PullFundsRefund201Response.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Invalid request.',
                             PullFundsRefund400ResponseException)
                .local_error('401',
                             'Unauthorized.',
                             PullFundsRefund401ResponseException)
                .local_error('404',
                             'Not Found.',
                             PullFundsRefund404ResponseException)
                .local_error('502',
                             'Unexpected system error or system timeout.',
                             PullFundsRefund502ResponseException))
    .execute
end

#create_pull_funds_reversal(pull_funds_reversal_request, id, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id) ⇒ ApiResponse

Reverse an Account Funding Transaction (AFT). parameter: TODO: type description here Account Funding Transaction. here here here here description here description here

Parameters:

  • pull_funds_reversal_request (PullFundsReversalRequest)

    Required

  • id (String)

    Required parameter: The transaction id of a previous

  • content_type (String)

    Required parameter: TODO: type description

  • x_requestid (String)

    Required parameter: TODO: type description

  • v_c_merchant_id (String)

    Required parameter: TODO: type description

  • v_c_permissions (String)

    Required parameter: TODO: type description

  • v_c_correlation_id (String)

    Required parameter: TODO: type

  • v_c_organization_id (String)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/cyber_source_merged_spec/controllers/pull_funds_controller.rb', line 89

def create_pull_funds_reversal(pull_funds_reversal_request,
                               id,
                               content_type,
                               x_requestid,
                               v_c_merchant_id,
                               v_c_permissions,
                               v_c_correlation_id,
                               v_c_organization_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/pts/v1/pull-funds-transfer/{id}/reversal',
                                 Server::DEFAULT)
               .body_param(new_parameter(pull_funds_reversal_request)
                            .is_required(true))
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter(content_type, key: 'Content-Type')
                              .is_required(true))
               .header_param(new_parameter(x_requestid, key: 'x-requestid')
                              .is_required(true))
               .header_param(new_parameter(v_c_merchant_id, key: 'v-c-merchant-id')
                              .is_required(true))
               .header_param(new_parameter(v_c_permissions, key: 'v-c-permissions')
                              .is_required(true))
               .header_param(new_parameter(v_c_correlation_id, key: 'v-c-correlation-id')
                              .is_required(true))
               .header_param(new_parameter(v_c_organization_id, key: 'v-c-organization-id')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(PullFundsReversal201Response.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Invalid request.',
                             PullFundsReversal400ResponseException)
                .local_error('401',
                             'Unauthorized.',
                             PullFundsReversal401ResponseException)
                .local_error('404',
                             'Not Found.',
                             PullFundsReversal404ResponseException)
                .local_error('502',
                             'Unexpected system error or system timeout.',
                             PullFundsReversal502ResponseException))
    .execute
end

#create_pull_funds_transfer(pull_funds_request, content_type, x_requestid, v_c_merchant_id, v_c_permissions, v_c_correlation_id, v_c_organization_id) ⇒ ApiResponse

Receive funds using an Account Funding Transaction (AFT). type description here here here here here description here description here

Parameters:

  • pull_funds_request (PullFundsRequest)

    Required parameter: TODO:

  • content_type (String)

    Required parameter: TODO: type description

  • x_requestid (String)

    Required parameter: TODO: type description

  • v_c_merchant_id (String)

    Required parameter: TODO: type description

  • v_c_permissions (String)

    Required parameter: TODO: type description

  • v_c_correlation_id (String)

    Required parameter: TODO: type

  • v_c_organization_id (String)

    Required parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/controllers/pull_funds_controller.rb', line 25

def create_pull_funds_transfer(pull_funds_request,
                               content_type,
                               x_requestid,
                               v_c_merchant_id,
                               v_c_permissions,
                               v_c_correlation_id,
                               v_c_organization_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/pts/v1/pull-funds-transfer',
                                 Server::DEFAULT)
               .body_param(new_parameter(pull_funds_request)
                            .is_required(true))
               .header_param(new_parameter(content_type, key: 'Content-Type')
                              .is_required(true))
               .header_param(new_parameter(x_requestid, key: 'x-requestid')
                              .is_required(true))
               .header_param(new_parameter(v_c_merchant_id, key: 'v-c-merchant-id')
                              .is_required(true))
               .header_param(new_parameter(v_c_permissions, key: 'v-c-permissions')
                              .is_required(true))
               .header_param(new_parameter(v_c_correlation_id, key: 'v-c-correlation-id')
                              .is_required(true))
               .header_param(new_parameter(v_c_organization_id, key: 'v-c-organization-id')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(PullFunds201Response.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Invalid request.',
                             PullFunds400ResponseException)
                .local_error('401',
                             'Unauthorized.',
                             PullFunds401ResponseException)
                .local_error('404',
                             'Not Found.',
                             PullFunds404ResponseException)
                .local_error('502',
                             'Unexpected system error or system timeout.',
                             PullFunds502ResponseException))
    .execute
end