Class: CyberSourceMergedSpec::PullFundsRefundRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb

Overview

PullFundsRefundRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(order_information:, client_reference_information: SKIP, additional_properties: nil) ⇒ PullFundsRefundRequest

Returns a new instance of PullFundsRefundRequest.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 40

def initialize(order_information:, client_reference_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @order_information = order_information
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation64

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 14

def client_reference_information
  @client_reference_information
end

#order_informationOrderInformation47

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 18

def order_information
  @order_information
end

Class Method Details

.from_element(root) ⇒ Object



77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 77

def self.from_element(root)
  order_information = XmlUtilities.from_element(root, 'OrderInformation47',
                                                OrderInformation47)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation64',
    ClientReferenceInformation64
  )

  new(order_information: order_information,
      client_reference_information: client_reference_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  order_information = OrderInformation47.from_hash(hash['orderInformation']) if
    hash['orderInformation']
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation64.from_hash(hash['clientReferenceInformation'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PullFundsRefundRequest.new(order_information: order_information,
                             client_reference_information: client_reference_information,
                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['order_information'] = 'orderInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 29

def self.optionals
  %w[
    client_reference_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



112
113
114
115
116
117
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 112

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\
  " order_information: #{@order_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 104

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information},"\
  " order_information: #{@order_information}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/pull_funds_refund_request.rb', line 90

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'OrderInformation47',
                                 order_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation64',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end