Class: CyberSourceMergedSpec::PullFundsReversalRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb

Overview

PullFundsReversalRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reversal_information:, client_reference_information: SKIP, additional_properties: nil) ⇒ PullFundsReversalRequest

Returns a new instance of PullFundsReversalRequest.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 40

def initialize(reversal_information:, client_reference_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @reversal_information = reversal_information
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation64

TODO: Write general description for this method



14
15
16
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 14

def client_reference_information
  @client_reference_information
end

#reversal_informationReversalInformation2

TODO: Write general description for this method



18
19
20
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 18

def reversal_information
  @reversal_information
end

Class Method Details

.from_element(root) ⇒ Object



77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 77

def self.from_element(root)
  reversal_information = XmlUtilities.from_element(root,
                                                   'ReversalInformation2',
                                                   ReversalInformation2)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation64',
    ClientReferenceInformation64
  )

  new(reversal_information: reversal_information,
      client_reference_information: client_reference_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reversal_information = ReversalInformation2.from_hash(hash['reversalInformation']) if
    hash['reversalInformation']
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation64.from_hash(hash['clientReferenceInformation'])
  end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PullFundsReversalRequest.new(reversal_information: reversal_information,
                               client_reference_information: client_reference_information,
                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['reversal_information'] = 'reversalInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



36
37
38
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 36

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 29

def self.optionals
  %w[
    client_reference_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



113
114
115
116
117
118
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 113

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information.inspect},"\
  " reversal_information: #{@reversal_information.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



105
106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 105

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_reference_information: #{@client_reference_information},"\
  " reversal_information: #{@reversal_information}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/pull_funds_reversal_request.rb', line 91

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'ReversalInformation2',
                                 reversal_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation64',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end