Class: CyberSourceMergedSpec::RawDatum
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::RawDatum
- Defined in:
- lib/cyber_source_merged_spec/models/raw_datum.rb
Overview
RawDatum Model.
Instance Attribute Summary collapse
-
#data ⇒ String
Field that contains the device fingerprint data from the specified provider.
-
#provider ⇒ String
Possible values: - cardinal - inauth - threatmetrix.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(data: SKIP, provider: SKIP, additional_properties: nil) ⇒ RawDatum
constructor
A new instance of RawDatum.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(data: SKIP, provider: SKIP, additional_properties: nil) ⇒ RawDatum
Returns a new instance of RawDatum.
45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 45 def initialize(data: SKIP, provider: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @data = data unless data == SKIP @provider = provider unless provider == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ String
Field that contains the device fingerprint data from the specified provider. The value should be Base64 encoded.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 15 def data @data end |
#provider ⇒ String
Possible values:
- cardinal
- inauth
- threatmetrix
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 22 def provider @provider end |
Class Method Details
.from_element(root) ⇒ Object
75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 75 def self.from_element(root) data = XmlUtilities.from_element(root, 'data', String) provider = XmlUtilities.from_element(root, 'provider', String) new(data: data, provider: provider, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. data = hash.key?('data') ? hash['data'] : SKIP provider = hash.key?('provider') ? hash['provider'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RawDatum.new(data: data, provider: provider, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['data'] = 'data' @_hash['provider'] = 'provider' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 33 def self.optionals %w[ data provider ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} data: #{@data.inspect}, provider: #{@provider.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
96 97 98 99 100 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 96 def to_s class_name = self.class.name.split('::').last "<#{class_name} data: #{@data}, provider: #{@provider}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cyber_source_merged_spec/models/raw_datum.rb', line 84 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'data', data) XmlUtilities.add_as_subelement(doc, root, 'provider', provider) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |