Class: CyberSourceMergedSpec::ReactivationInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/reactivation_information.rb

Overview

ReactivationInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(missed_payments_count: SKIP, missed_payments_total_amount: SKIP, additional_properties: nil) ⇒ ReactivationInformation

Returns a new instance of ReactivationInformation.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 43

def initialize(missed_payments_count: SKIP,
               missed_payments_total_amount: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @missed_payments_count = missed_payments_count unless missed_payments_count == SKIP
  unless missed_payments_total_amount == SKIP
    @missed_payments_total_amount =
      missed_payments_total_amount
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#missed_payments_countString

Number of payments that should have occurred while the subscription was in a suspended status.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 15

def missed_payments_count
  @missed_payments_count
end

#missed_payments_total_amountString

Total amount that will be charged upon reactivation if processMissedPayments is set to true.

Returns:

  • (String)


20
21
22
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 20

def missed_payments_total_amount
  @missed_payments_total_amount
end

Class Method Details

.from_element(root) ⇒ Object



80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 80

def self.from_element(root)
  missed_payments_count = XmlUtilities.from_element(root,
                                                    'missedPaymentsCount',
                                                    String)
  missed_payments_total_amount = XmlUtilities.from_element(
    root, 'missedPaymentsTotalAmount', String
  )

  new(missed_payments_count: missed_payments_count,
      missed_payments_total_amount: missed_payments_total_amount,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  missed_payments_count =
    hash.key?('missedPaymentsCount') ? hash['missedPaymentsCount'] : SKIP
  missed_payments_total_amount =
    hash.key?('missedPaymentsTotalAmount') ? hash['missedPaymentsTotalAmount'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ReactivationInformation.new(missed_payments_count: missed_payments_count,
                              missed_payments_total_amount: missed_payments_total_amount,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['missed_payments_count'] = 'missedPaymentsCount'
  @_hash['missed_payments_total_amount'] = 'missedPaymentsTotalAmount'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 31

def self.optionals
  %w[
    missed_payments_count
    missed_payments_total_amount
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



115
116
117
118
119
120
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 115

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} missed_payments_count: #{@missed_payments_count.inspect},"\
  " missed_payments_total_amount: #{@missed_payments_total_amount.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



107
108
109
110
111
112
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 107

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} missed_payments_count: #{@missed_payments_count},"\
  " missed_payments_total_amount: #{@missed_payments_total_amount}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/reactivation_information.rb', line 93

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'missedPaymentsCount',
                                 missed_payments_count)
  XmlUtilities.add_as_subelement(doc, root, 'missedPaymentsTotalAmount',
                                 missed_payments_total_amount)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end