Class: CyberSourceMergedSpec::RecurringOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::RecurringOptions
- Defined in:
- lib/cyber_source_merged_spec/models/recurring_options.rb
Overview
RecurringOptions Model.
Instance Attribute Summary collapse
-
#first_recurring_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this transaction is the first in a series of recurring payments.
-
#loan_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this is a payment towards an existing contractual loan.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(loan_payment: false, first_recurring_payment: false, additional_properties: nil) ⇒ RecurringOptions
constructor
A new instance of RecurringOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(loan_payment: false, first_recurring_payment: false, additional_properties: nil) ⇒ RecurringOptions
Returns a new instance of RecurringOptions.
53 54 55 56 57 58 59 60 61 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 53 def initialize(loan_payment: false, first_recurring_payment: false, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @loan_payment = loan_payment unless loan_payment == SKIP @first_recurring_payment = first_recurring_payment unless first_recurring_payment == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#first_recurring_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this transaction is the first in a series of recurring payments. This field is supported only for Atos, FDC Nashville Global, and OmniPay Direct. Possible values:
trueIndicates this is the first payment in a series of recurring paymentsfalse(default) Indicates this is not the first payment in a series of recurring payments.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 30 def first_recurring_payment @first_recurring_payment end |
#loan_payment ⇒ TrueClass | FalseClass
Flag that indicates whether this is a payment towards an existing contractual loan. Possible values:
true: Loan paymentfalse: (default) Not a loan payment
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 18 def loan_payment @loan_payment end |
Class Method Details
.from_element(root) ⇒ Object
84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 84 def self.from_element(root) loan_payment = XmlUtilities.from_element(root, 'loanPayment', TrueClass) first_recurring_payment = XmlUtilities.from_element( root, 'firstRecurringPayment', TrueClass ) new(loan_payment: loan_payment, first_recurring_payment: first_recurring_payment, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 64 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. loan_payment = hash['loanPayment'] ||= false first_recurring_payment = hash['firstRecurringPayment'] ||= false # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RecurringOptions.new(loan_payment: loan_payment, first_recurring_payment: first_recurring_payment, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['loan_payment'] = 'loanPayment' @_hash['first_recurring_payment'] = 'firstRecurringPayment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 41 def self.optionals %w[ loan_payment first_recurring_payment ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} loan_payment: #{@loan_payment.inspect}, first_recurring_payment:"\ " #{@first_recurring_payment.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} loan_payment: #{@loan_payment}, first_recurring_payment:"\ " #{@first_recurring_payment}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/recurring_options.rb', line 95 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'loanPayment', loan_payment) XmlUtilities.add_as_subelement(doc, root, 'firstRecurringPayment', first_recurring_payment) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |