Class: CyberSourceMergedSpec::RecurringOptions4

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/recurring_options4.rb

Overview

RecurringOptions4 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_recurring_payment: SKIP, additional_properties: nil) ⇒ RecurringOptions4

Returns a new instance of RecurringOptions4.



39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 39

def initialize(first_recurring_payment: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_recurring_payment = first_recurring_payment unless first_recurring_payment == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#first_recurring_paymentTrueClass | FalseClass

Indicates the transaction that is the first of a series of recurring payments.

  • True = is first recurring payment
  • False = is not first recurring payment Conditional for MITCOF transactions

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 18

def first_recurring_payment
  @first_recurring_payment
end

Class Method Details

.from_element(root) ⇒ Object



67
68
69
70
71
72
73
74
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 67

def self.from_element(root)
  first_recurring_payment = XmlUtilities.from_element(
    root, 'firstRecurringPayment', TrueClass
  )

  new(first_recurring_payment: first_recurring_payment,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_recurring_payment =
    hash.key?('firstRecurringPayment') ? hash['firstRecurringPayment'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RecurringOptions4.new(first_recurring_payment: first_recurring_payment,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_recurring_payment'] = 'firstRecurringPayment'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 28

def self.optionals
  %w[
    first_recurring_payment
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_recurring_payment: #{@first_recurring_payment.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 88

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_recurring_payment: #{@first_recurring_payment},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



76
77
78
79
80
81
82
83
84
85
# File 'lib/cyber_source_merged_spec/models/recurring_options4.rb', line 76

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'firstRecurringPayment',
                                 first_recurring_payment)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end