Class: CyberSourceMergedSpec::RefundAmountDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/refund_amount_details.rb

Overview

RefundAmountDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(refund_amount: SKIP, credit_amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ RefundAmountDetails

Returns a new instance of RefundAmountDetails.



83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 83

def initialize(refund_amount: SKIP, credit_amount: SKIP, currency: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @refund_amount = refund_amount unless refund_amount == SKIP
  @credit_amount = credit_amount unless credit_amount == SKIP
  @currency = currency unless currency == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#credit_amountString

Amount that was credited to the cardholder’s account. Returned by PIN debit credit.

Returns:

  • (String)


19
20
21
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 19

def credit_amount
  @credit_amount
end

#currencyString

Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/cur rencies.pdf)

Used by

Authorization Required field. Authorization Reversal For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request.

PIN Debit

Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.

GPX

This field is optional for reversing an authorization or credit.

DCC for First Data

Your local currency.

Tax Calculation

Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.

Returns:

  • (String)


58
59
60
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 58

def currency
  @currency
end

#refund_amountString

Total amount of the refund.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 14

def refund_amount
  @refund_amount
end

Class Method Details

.from_element(root) ⇒ Object



117
118
119
120
121
122
123
124
125
126
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 117

def self.from_element(root)
  refund_amount = XmlUtilities.from_element(root, 'refundAmount', String)
  credit_amount = XmlUtilities.from_element(root, 'creditAmount', String)
  currency = XmlUtilities.from_element(root, 'currency', String)

  new(refund_amount: refund_amount,
      credit_amount: credit_amount,
      currency: currency,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 95

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  refund_amount = hash.key?('refundAmount') ? hash['refundAmount'] : SKIP
  credit_amount = hash.key?('creditAmount') ? hash['creditAmount'] : SKIP
  currency = hash.key?('currency') ? hash['currency'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RefundAmountDetails.new(refund_amount: refund_amount,
                          credit_amount: credit_amount,
                          currency: currency,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 61

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['refund_amount'] = 'refundAmount'
  @_hash['credit_amount'] = 'creditAmount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



79
80
81
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 79

def self.nullables
  []
end

.optionalsObject

An array for optional fields



70
71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 70

def self.optionals
  %w[
    refund_amount
    credit_amount
    currency
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



148
149
150
151
152
153
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 148

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} refund_amount: #{@refund_amount.inspect}, credit_amount:"\
  " #{@credit_amount.inspect}, currency: #{@currency.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



141
142
143
144
145
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 141

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} refund_amount: #{@refund_amount}, credit_amount: #{@credit_amount},"\
  " currency: #{@currency}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/cyber_source_merged_spec/models/refund_amount_details.rb', line 128

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'refundAmount', refund_amount)
  XmlUtilities.add_as_subelement(doc, root, 'creditAmount', credit_amount)
  XmlUtilities.add_as_subelement(doc, root, 'currency', currency)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end