Class: CyberSourceMergedSpec::ReportingV3NotificationofChangesGet200Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb

Overview

ReportingV3NotificationofChangesGet200Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(notification_of_changes: SKIP, additional_properties: nil) ⇒ ReportingV3NotificationofChangesGet200Response

Returns a new instance of ReportingV3NotificationofChangesGet200Response.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 35

def initialize(notification_of_changes: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @notification_of_changes = notification_of_changes unless notification_of_changes == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#notification_of_changesArray[NotificationOfChange]

List of Notification Of Change Info values

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 14

def notification_of_changes
  @notification_of_changes
end

Class Method Details

.from_element(root) ⇒ Object



71
72
73
74
75
76
77
78
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 71

def self.from_element(root)
  notification_of_changes = XmlUtilities.from_element_to_array(
    root, 'NotificationOfChange', NotificationOfChange
  )

  new(notification_of_changes: notification_of_changes,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  notification_of_changes = nil
  unless hash['notificationOfChanges'].nil?
    notification_of_changes = []
    hash['notificationOfChanges'].each do |structure|
      notification_of_changes << (NotificationOfChange.from_hash(structure) if structure)
    end
  end

  notification_of_changes = SKIP unless hash.key?('notificationOfChanges')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ReportingV3NotificationofChangesGet200Response.new(notification_of_changes: notification_of_changes,
                                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['notification_of_changes'] = 'notificationOfChanges'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 24

def self.optionals
  %w[
    notification_of_changes
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} notification_of_changes: #{@notification_of_changes.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} notification_of_changes: #{@notification_of_changes},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/reporting_v3_notificationof_changes_get200_response.rb', line 80

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'NotificationOfChange',
                                       notification_of_changes)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end