Class: CyberSourceMergedSpec::RetrievalSummary

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/retrieval_summary.rb

Overview

RetrievalSummary Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(count: SKIP, time: SKIP, account_id: SKIP, additional_properties: nil) ⇒ RetrievalSummary

Returns a new instance of RetrievalSummary.



48
49
50
51
52
53
54
55
56
57
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 48

def initialize(count: SKIP, time: SKIP, account_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @count = count unless count == SKIP
  @time = time unless time == SKIP
  @account_id =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#account_idString

Account Id

Returns:

  • (String)


23
24
25
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 23

def 
  @account_id
end

#countFloat

Chargeback summary list count

Returns:

  • (Float)


15
16
17
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 15

def count
  @count
end

#timeDateTime

Summary Date

Returns:

  • (DateTime)


19
20
21
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 19

def time
  @time
end

Class Method Details

.from_element(root) ⇒ Object



90
91
92
93
94
95
96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 90

def self.from_element(root)
  count = XmlUtilities.from_element(root, 'count', Float)
  time = XmlUtilities.from_element(root, 'time', String,
                                   datetime_format: 'rfc3339')
   = XmlUtilities.from_element(root, 'accountId', String)

  new(count: count,
      time: time,
      account_id: ,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  count = hash.key?('count') ? hash['count'] : SKIP
  time = if hash.key?('time')
           (DateTimeHelper.from_rfc3339(hash['time']) if hash['time'])
         else
           SKIP
         end
   = hash.key?('accountId') ? hash['accountId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RetrievalSummary.new(count: count,
                       time: time,
                       account_id: ,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['count'] = 'count'
  @_hash['time'] = 'time'
  @_hash['account_id'] = 'accountId'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 35

def self.optionals
  %w[
    count
    time
    account_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



123
124
125
126
127
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 123

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} count: #{@count.inspect}, time: #{@time.inspect}, account_id:"\
  " #{@account_id.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_timeObject



86
87
88
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 86

def to_custom_time
  DateTimeHelper.to_rfc3339(time)
end

#to_sObject

Provides a human-readable string representation of the object.



116
117
118
119
120
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 116

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} count: #{@count}, time: #{@time}, account_id: #{@account_id},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/cyber_source_merged_spec/models/retrieval_summary.rb', line 102

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'count', count)
  XmlUtilities.add_as_subelement(doc, root, 'time', time,
                                 datetime_format: 'rfc3339')
  XmlUtilities.add_as_subelement(doc, root, 'accountId', )
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end