Class: CyberSourceMergedSpec::ReversalAmountDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/reversal_amount_details.rb

Overview

ReversalAmountDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reversed_amount: SKIP, original_transaction_amount: SKIP, currency: SKIP, additional_properties: nil) ⇒ ReversalAmountDetails

Returns a new instance of ReversalAmountDetails.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 84

def initialize(reversed_amount: SKIP, original_transaction_amount: SKIP,
               currency: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reversed_amount = reversed_amount unless reversed_amount == SKIP
  unless original_transaction_amount == SKIP
    @original_transaction_amount =
      original_transaction_amount
  end
  @currency = currency unless currency == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyString

Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/cur rencies.pdf)

Used by

Authorization Required field. Authorization Reversal For an authorization reversal (reversalInformation) or a capture (processingOptions.capture is set to true), you must use the same currency that you used in your payment authorization request.

PIN Debit

Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.

GPX

This field is optional for reversing an authorization or credit.

DCC for First Data

Your local currency.

Tax Calculation

Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.

Returns:

  • (String)


59
60
61
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 59

def currency
  @currency
end

#original_transaction_amountString

Amount of the original transaction. Returned by authorization reversal and void.

Returns:

  • (String)


20
21
22
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 20

def original_transaction_amount
  @original_transaction_amount
end

#reversed_amountString

Total reversed amount. Returned by authorization reversal.

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 15

def reversed_amount
  @reversed_amount
end

Class Method Details

.from_element(root) ⇒ Object



123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 123

def self.from_element(root)
  reversed_amount = XmlUtilities.from_element(root, 'reversedAmount',
                                              String)
  original_transaction_amount = XmlUtilities.from_element(
    root, 'originalTransactionAmount', String
  )
  currency = XmlUtilities.from_element(root, 'currency', String)

  new(reversed_amount: reversed_amount,
      original_transaction_amount: original_transaction_amount,
      currency: currency,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 99

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reversed_amount =
    hash.key?('reversedAmount') ? hash['reversedAmount'] : SKIP
  original_transaction_amount =
    hash.key?('originalTransactionAmount') ? hash['originalTransactionAmount'] : SKIP
  currency = hash.key?('currency') ? hash['currency'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ReversalAmountDetails.new(reversed_amount: reversed_amount,
                            original_transaction_amount: original_transaction_amount,
                            currency: currency,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 62

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reversed_amount'] = 'reversedAmount'
  @_hash['original_transaction_amount'] = 'originalTransactionAmount'
  @_hash['currency'] = 'currency'
  @_hash
end

.nullablesObject

An array for nullable fields



80
81
82
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 80

def self.nullables
  []
end

.optionalsObject

An array for optional fields



71
72
73
74
75
76
77
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 71

def self.optionals
  %w[
    reversed_amount
    original_transaction_amount
    currency
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



160
161
162
163
164
165
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 160

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reversed_amount: #{@reversed_amount.inspect}, original_transaction_amount:"\
  " #{@original_transaction_amount.inspect}, currency: #{@currency.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



152
153
154
155
156
157
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 152

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reversed_amount: #{@reversed_amount}, original_transaction_amount:"\
  " #{@original_transaction_amount}, currency: #{@currency}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/cyber_source_merged_spec/models/reversal_amount_details.rb', line 137

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'reversedAmount',
                                 reversed_amount)
  XmlUtilities.add_as_subelement(doc, root, 'originalTransactionAmount',
                                 original_transaction_amount)
  XmlUtilities.add_as_subelement(doc, root, 'currency', currency)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end