Class: CyberSourceMergedSpec::ReversalInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/reversal_information.rb

Overview

ReversalInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount_details: SKIP, reason: SKIP, additional_properties: nil) ⇒ ReversalInformation

Returns a new instance of ReversalInformation.



44
45
46
47
48
49
50
51
52
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 44

def initialize(amount_details: SKIP, reason: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount_details = amount_details unless amount_details == SKIP
  @reason = reason unless reason == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#amount_detailsAmountDetails5

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 14

def amount_details
  @amount_details
end

#reasonString

Reason for the authorization reversal. Possible value:

  • 34: Suspected fraud This field is ignored for processors that do not support this value. Returned by authorization reversal.

Returns:

  • (String)


21
22
23
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 21

def reason
  @reason
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 75

def self.from_element(root)
  amount_details = XmlUtilities.from_element(root, 'AmountDetails5',
                                             AmountDetails5)
  reason = XmlUtilities.from_element(root, 'reason', String)

  new(amount_details: amount_details,
      reason: reason,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount_details = AmountDetails5.from_hash(hash['amountDetails']) if hash['amountDetails']
  reason = hash.key?('reason') ? hash['reason'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ReversalInformation.new(amount_details: amount_details,
                          reason: reason,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount_details'] = 'amountDetails'
  @_hash['reason'] = 'reason'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 32

def self.optionals
  %w[
    amount_details
    reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details.inspect}, reason: #{@reason.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount_details: #{@amount_details}, reason: #{@reason},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/reversal_information.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'AmountDetails5',
                                 amount_details)
  XmlUtilities.add_as_subelement(doc, root, 'reason', reason)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end