Class: CyberSourceMergedSpec::RiskV1AddressVerificationsPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb

Overview

RiskV1AddressVerificationsPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, submit_time_local: SKIP, status: SKIP, message: SKIP, client_reference_information: SKIP, address_verification_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ RiskV1AddressVerificationsPost201Response

Returns a new instance of RiskV1AddressVerificationsPost201Response.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 144

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP,
               submit_time_local: SKIP, status: SKIP, message: SKIP,
               client_reference_information: SKIP,
               address_verification_information: SKIP,
               error_information: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @submit_time_local = submit_time_local unless submit_time_local == SKIP
  @status = status unless status == SKIP
  @message = message unless message == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  unless address_verification_information == SKIP
    @address_verification_information =
      address_verification_information
  end
  @error_information = error_information unless error_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#address_verification_informationRiskAddressVerificationInformation

The message describing the reason of the status. Value can be

  • Apartment number missing or not found.
  • Insufficient address information.
  • House/Box number not found on street.
  • Multiple address matches were found.
  • P.O. Box identifier not found or out of range.
  • Route service identifier not found or out of range.
  • Street name not found in Postal code.
  • Postal code not found in database.
  • Unable to verify or correct address.
  • Multiple addres matches were found (international)
  • Address match not found (no reason given)
  • Unsupported character set


90
91
92
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 90

def address_verification_information
  @address_verification_information
end

#client_reference_informationClientReferenceInformation49

The message describing the reason of the status. Value can be

  • Apartment number missing or not found.
  • Insufficient address information.
  • House/Box number not found on street.
  • Multiple address matches were found.
  • P.O. Box identifier not found or out of range.
  • Route service identifier not found or out of range.
  • Street name not found in Postal code.
  • Postal code not found in database.
  • Unable to verify or correct address.
  • Multiple addres matches were found (international)
  • Address match not found (no reason given)
  • Unsupported character set


74
75
76
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 74

def client_reference_information
  @client_reference_information
end

#error_informationErrorInformation27

The message describing the reason of the status. Value can be

  • Apartment number missing or not found.
  • Insufficient address information.
  • House/Box number not found on street.
  • Multiple address matches were found.
  • P.O. Box identifier not found or out of range.
  • Route service identifier not found or out of range.
  • Street name not found in Postal code.
  • Postal code not found in database.
  • Unable to verify or correct address.
  • Multiple addres matches were found (international)
  • Address match not found (no reason given)
  • Unsupported character set

Returns:



106
107
108
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 106

def error_information
  @error_information
end

#idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 14

def links
  @links
end

#messageString

The message describing the reason of the status. Value can be

  • Apartment number missing or not found.
  • Insufficient address information.
  • House/Box number not found on street.
  • Multiple address matches were found.
  • P.O. Box identifier not found or out of range.
  • Route service identifier not found or out of range.
  • Street name not found in Postal code.
  • Postal code not found in database.
  • Unable to verify or correct address.
  • Multiple addres matches were found (international)
  • Address match not found (no reason given)
  • Unsupported character set

Returns:

  • (String)


58
59
60
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 58

def message
  @message
end

#statusString

The status for the call can be:

  • COMPLETED
  • INVALID_REQUEST
  • DECLINED

Returns:

  • (String)


42
43
44
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 42

def status
  @status
end

#submit_time_localString

Time that the transaction was submitted in local time. Generated by Cybersource.

Returns:

  • (String)


35
36
37
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 35

def submit_time_local
  @submit_time_local
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_element(root) ⇒ Object



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 212

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links1', Links1)
  id = XmlUtilities.from_element(root, 'id', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  submit_time_local = XmlUtilities.from_element(root, 'submitTimeLocal',
                                                String)
  status = XmlUtilities.from_element(root, 'status', String)
  message = XmlUtilities.from_element(root, 'message', String)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation49',
    ClientReferenceInformation49
  )
  address_verification_information = XmlUtilities.from_element(
    root, 'riskAddressVerificationInformation',
    RiskAddressVerificationInformation
  )
  error_information = XmlUtilities.from_element(root, 'ErrorInformation27',
                                                ErrorInformation27)

  new(links: links,
      id: id,
      submit_time_utc: submit_time_utc,
      submit_time_local: submit_time_local,
      status: status,
      message: message,
      client_reference_information: client_reference_information,
      address_verification_information: address_verification_information,
      error_information: error_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 171

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links1.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  submit_time_local =
    hash.key?('submitTimeLocal') ? hash['submitTimeLocal'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation49.from_hash(hash['clientReferenceInformation'])
  end
  if hash['addressVerificationInformation']
    address_verification_information = RiskAddressVerificationInformation.from_hash(hash['addressVerificationInformation'])
  end
  error_information = ErrorInformation27.from_hash(hash['errorInformation']) if
    hash['errorInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskV1AddressVerificationsPost201Response.new(links: links,
                                                id: id,
                                                submit_time_utc: submit_time_utc,
                                                submit_time_local: submit_time_local,
                                                status: status,
                                                message: message,
                                                client_reference_information: client_reference_information,
                                                address_verification_information: address_verification_information,
                                                error_information: error_information,
                                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 109

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['submit_time_local'] = 'submitTimeLocal'
  @_hash['status'] = 'status'
  @_hash['message'] = 'message'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['address_verification_information'] =
    'addressVerificationInformation'
  @_hash['error_information'] = 'errorInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



140
141
142
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 140

def self.nullables
  []
end

.optionalsObject

An array for optional fields



125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 125

def self.optionals
  %w[
    links
    id
    submit_time_utc
    submit_time_local
    status
    message
    client_reference_information
    address_verification_information
    error_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



278
279
280
281
282
283
284
285
286
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 278

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, submit_time_local: #{@submit_time_local.inspect}, status:"\
  " #{@status.inspect}, message: #{@message.inspect}, client_reference_information:"\
  " #{@client_reference_information.inspect}, address_verification_information:"\
  " #{@address_verification_information.inspect}, error_information:"\
  " #{@error_information.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



268
269
270
271
272
273
274
275
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 268

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc},"\
  " submit_time_local: #{@submit_time_local}, status: #{@status}, message: #{@message},"\
  " client_reference_information: #{@client_reference_information},"\
  " address_verification_information: #{@address_verification_information}, error_information:"\
  " #{@error_information}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/cyber_source_merged_spec/models/risk_v1_address_verifications_post201_response.rb', line 243

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links1', links)
  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeLocal',
                                 submit_time_local)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation49',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root,
                                 'riskAddressVerificationInformation',
                                 address_verification_information)
  XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation27',
                                 error_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end