Class: CyberSourceMergedSpec::RiskV1AuthenticationSetupsPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb

Overview

RiskV1AuthenticationSetupsPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, consumer_authentication_information: SKIP, client_reference_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ RiskV1AuthenticationSetupsPost201Response

Returns a new instance of RiskV1AuthenticationSetupsPost201Response.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 88

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP,
               consumer_authentication_information: SKIP,
               client_reference_information: SKIP, error_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @status = status unless status == SKIP
  unless consumer_authentication_information == SKIP
    @consumer_authentication_information =
      consumer_authentication_information
  end
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  @error_information = error_information unless error_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation49

The status for payerAuthentication 201 setup calls. Possible value is:

  • COMPLETED
  • FAILED


48
49
50
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 48

def client_reference_information
  @client_reference_information
end

#consumer_authentication_informationConsumerAuthenticationInformation6

The status for payerAuthentication 201 setup calls. Possible value is:

  • COMPLETED
  • FAILED


42
43
44
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 42

def consumer_authentication_information
  @consumer_authentication_information
end

#error_informationErrorInformation24

The status for payerAuthentication 201 setup calls. Possible value is:

  • COMPLETED
  • FAILED

Returns:



54
55
56
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 54

def error_information
  @error_information
end

#idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 14

def links
  @links
end

#statusString

The status for payerAuthentication 201 setup calls. Possible value is:

  • COMPLETED
  • FAILED

Returns:

  • (String)


36
37
38
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 36

def status
  @status
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_element(root) ⇒ Object



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 148

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links1', Links1)
  id = XmlUtilities.from_element(root, 'id', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  status = XmlUtilities.from_element(root, 'status', String)
  consumer_authentication_information = XmlUtilities.from_element(
    root, 'ConsumerAuthenticationInformation6',
    ConsumerAuthenticationInformation6
  )
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation49',
    ClientReferenceInformation49
  )
  error_information = XmlUtilities.from_element(root, 'ErrorInformation24',
                                                ErrorInformation24)

  new(links: links,
      id: id,
      submit_time_utc: submit_time_utc,
      status: status,
      consumer_authentication_information: consumer_authentication_information,
      client_reference_information: client_reference_information,
      error_information: error_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 112

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links1.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  if hash['consumerAuthenticationInformation']
    consumer_authentication_information = ConsumerAuthenticationInformation6.from_hash(hash['consumerAuthenticationInformation'])
  end
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation49.from_hash(hash['clientReferenceInformation'])
  end
  error_information = ErrorInformation24.from_hash(hash['errorInformation']) if
    hash['errorInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskV1AuthenticationSetupsPost201Response.new(links: links,
                                                id: id,
                                                submit_time_utc: submit_time_utc,
                                                status: status,
                                                consumer_authentication_information: consumer_authentication_information,
                                                client_reference_information: client_reference_information,
                                                error_information: error_information,
                                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 57

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['status'] = 'status'
  @_hash['consumer_authentication_information'] =
    'consumerAuthenticationInformation'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['error_information'] = 'errorInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



84
85
86
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 84

def self.nullables
  []
end

.optionalsObject

An array for optional fields



71
72
73
74
75
76
77
78
79
80
81
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 71

def self.optionals
  %w[
    links
    id
    submit_time_utc
    status
    consumer_authentication_information
    client_reference_information
    error_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



205
206
207
208
209
210
211
212
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 205

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, status: #{@status.inspect},"\
  " consumer_authentication_information: #{@consumer_authentication_information.inspect},"\
  " client_reference_information: #{@client_reference_information.inspect}, error_information:"\
  " #{@error_information.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



196
197
198
199
200
201
202
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 196

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\
  " #{@status}, consumer_authentication_information: #{@consumer_authentication_information},"\
  " client_reference_information: #{@client_reference_information}, error_information:"\
  " #{@error_information}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentication_setups_post201_response.rb', line 174

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links1', links)
  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root,
                                 'ConsumerAuthenticationInformation6',
                                 consumer_authentication_information)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation49',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation24',
                                 error_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end