Class: CyberSourceMergedSpec::RiskV1ExportComplianceInquiriesPost201Response

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb

Overview

RiskV1ExportComplianceInquiriesPost201Response Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, submit_time_local: SKIP, status: SKIP, message: SKIP, client_reference_information: SKIP, export_compliance_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ RiskV1ExportComplianceInquiriesPost201Response

Returns a new instance of RiskV1ExportComplianceInquiriesPost201Response.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 111

def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP,
               submit_time_local: SKIP, status: SKIP, message: SKIP,
               client_reference_information: SKIP,
               export_compliance_information: SKIP, error_information: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @links = links unless links == SKIP
  @id = id unless id == SKIP
  @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP
  @submit_time_local = submit_time_local unless submit_time_local == SKIP
  @status = status unless status == SKIP
  @message = message unless message == SKIP
  unless client_reference_information == SKIP
    @client_reference_information =
      client_reference_information
  end
  unless export_compliance_information == SKIP
    @export_compliance_information =
      export_compliance_information
  end
  @error_information = error_information unless error_information == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_reference_informationClientReferenceInformation49

The message describing the reason of the status. Value can be

  • The customer matched the Denied Parties List
  • The Export bill_country/ship_country match
  • Export email_country match
  • Export hostname_country/ip_country match


58
59
60
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 58

def client_reference_information
  @client_reference_information
end

#error_informationErrorInformation28

The message describing the reason of the status. Value can be

  • The customer matched the Denied Parties List
  • The Export bill_country/ship_country match
  • Export email_country match
  • Export hostname_country/ip_country match

Returns:



74
75
76
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 74

def error_information
  @error_information
end

#export_compliance_informationExportComplianceInformation1

The message describing the reason of the status. Value can be

  • The customer matched the Denied Parties List
  • The Export bill_country/ship_country match
  • Export email_country match
  • Export hostname_country/ip_country match


66
67
68
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 66

def export_compliance_information
  @export_compliance_information
end

#idString

An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.

Returns:

  • (String)


22
23
24
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 22

def id
  @id
end

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 14

def links
  @links
end

#messageString

The message describing the reason of the status. Value can be

  • The customer matched the Denied Parties List
  • The Export bill_country/ship_country match
  • Export email_country match
  • Export hostname_country/ip_country match

Returns:

  • (String)


50
51
52
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 50

def message
  @message
end

#statusString

The status for the call can be:

  • COMPLETED
  • INVALID_REQUEST
  • DECLINED

Returns:

  • (String)


42
43
44
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 42

def status
  @status
end

#submit_time_localString

Time that the transaction was submitted in local time. Generated by Cybersource.

Returns:

  • (String)


35
36
37
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 35

def submit_time_local
  @submit_time_local
end

#submit_time_utcString

Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. Returned by Cybersource for all services.

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 30

def submit_time_utc
  @submit_time_utc
end

Class Method Details

.from_element(root) ⇒ Object



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 179

def self.from_element(root)
  links = XmlUtilities.from_element(root, 'Links1', Links1)
  id = XmlUtilities.from_element(root, 'id', String)
  submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String)
  submit_time_local = XmlUtilities.from_element(root, 'submitTimeLocal',
                                                String)
  status = XmlUtilities.from_element(root, 'status', String)
  message = XmlUtilities.from_element(root, 'message', String)
  client_reference_information = XmlUtilities.from_element(
    root, 'ClientReferenceInformation49',
    ClientReferenceInformation49
  )
  export_compliance_information = XmlUtilities.from_element(
    root, 'ExportComplianceInformation1',
    ExportComplianceInformation1
  )
  error_information = XmlUtilities.from_element(root, 'ErrorInformation28',
                                                ErrorInformation28)

  new(links: links,
      id: id,
      submit_time_utc: submit_time_utc,
      submit_time_local: submit_time_local,
      status: status,
      message: message,
      client_reference_information: client_reference_information,
      export_compliance_information: export_compliance_information,
      error_information: error_information,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 138

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  links = Links1.from_hash(hash['_links']) if hash['_links']
  id = hash.key?('id') ? hash['id'] : SKIP
  submit_time_utc =
    hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP
  submit_time_local =
    hash.key?('submitTimeLocal') ? hash['submitTimeLocal'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP
  if hash['clientReferenceInformation']
    client_reference_information = ClientReferenceInformation49.from_hash(hash['clientReferenceInformation'])
  end
  if hash['exportComplianceInformation']
    export_compliance_information = ExportComplianceInformation1.from_hash(hash['exportComplianceInformation'])
  end
  error_information = ErrorInformation28.from_hash(hash['errorInformation']) if
    hash['errorInformation']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RiskV1ExportComplianceInquiriesPost201Response.new(links: links,
                                                     id: id,
                                                     submit_time_utc: submit_time_utc,
                                                     submit_time_local: submit_time_local,
                                                     status: status,
                                                     message: message,
                                                     client_reference_information: client_reference_information,
                                                     export_compliance_information: export_compliance_information,
                                                     error_information: error_information,
                                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 77

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['links'] = '_links'
  @_hash['id'] = 'id'
  @_hash['submit_time_utc'] = 'submitTimeUtc'
  @_hash['submit_time_local'] = 'submitTimeLocal'
  @_hash['status'] = 'status'
  @_hash['message'] = 'message'
  @_hash['client_reference_information'] = 'clientReferenceInformation'
  @_hash['export_compliance_information'] = 'exportComplianceInformation'
  @_hash['error_information'] = 'errorInformation'
  @_hash
end

.nullablesObject

An array for nullable fields



107
108
109
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 107

def self.nullables
  []
end

.optionalsObject

An array for optional fields



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 92

def self.optionals
  %w[
    links
    id
    submit_time_utc
    submit_time_local
    status
    message
    client_reference_information
    export_compliance_information
    error_information
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



244
245
246
247
248
249
250
251
252
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 244

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\
  " #{@submit_time_utc.inspect}, submit_time_local: #{@submit_time_local.inspect}, status:"\
  " #{@status.inspect}, message: #{@message.inspect}, client_reference_information:"\
  " #{@client_reference_information.inspect}, export_compliance_information:"\
  " #{@export_compliance_information.inspect}, error_information:"\
  " #{@error_information.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



234
235
236
237
238
239
240
241
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 234

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc},"\
  " submit_time_local: #{@submit_time_local}, status: #{@status}, message: #{@message},"\
  " client_reference_information: #{@client_reference_information},"\
  " export_compliance_information: #{@export_compliance_information}, error_information:"\
  " #{@error_information}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/cyber_source_merged_spec/models/risk_v1_export_compliance_inquiries_post201_response.rb', line 210

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'Links1', links)
  XmlUtilities.add_as_subelement(doc, root, 'id', id)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc',
                                 submit_time_utc)
  XmlUtilities.add_as_subelement(doc, root, 'submitTimeLocal',
                                 submit_time_local)
  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation49',
                                 client_reference_information)
  XmlUtilities.add_as_subelement(doc, root, 'ExportComplianceInformation1',
                                 export_compliance_information)
  XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation28',
                                 error_information)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end