Class: CyberSourceMergedSpec::Room

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/room.rb

Overview

Room Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(daily_rate: SKIP, number_of_nights: SKIP, additional_properties: nil) ⇒ Room

Returns a new instance of Room.



42
43
44
45
46
47
48
49
50
# File 'lib/cyber_source_merged_spec/models/room.rb', line 42

def initialize(daily_rate: SKIP, number_of_nights: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @daily_rate = daily_rate unless daily_rate == SKIP
  @number_of_nights = number_of_nights unless number_of_nights == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#daily_rateString

Daily cost of the room.

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/room.rb', line 14

def daily_rate
  @daily_rate
end

#number_of_nightsInteger

Number of nights billed at the rate specified by travelInformation.lodging.room[].dailyRate.

Returns:

  • (Integer)


19
20
21
# File 'lib/cyber_source_merged_spec/models/room.rb', line 19

def number_of_nights
  @number_of_nights
end

Class Method Details

.from_element(root) ⇒ Object



74
75
76
77
78
79
80
81
82
# File 'lib/cyber_source_merged_spec/models/room.rb', line 74

def self.from_element(root)
  daily_rate = XmlUtilities.from_element(root, 'dailyRate', String)
  number_of_nights = XmlUtilities.from_element(root, 'numberOfNights',
                                               Integer)

  new(daily_rate: daily_rate,
      number_of_nights: number_of_nights,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/room.rb', line 53

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  daily_rate = hash.key?('dailyRate') ? hash['dailyRate'] : SKIP
  number_of_nights =
    hash.key?('numberOfNights') ? hash['numberOfNights'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Room.new(daily_rate: daily_rate,
           number_of_nights: number_of_nights,
           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/cyber_source_merged_spec/models/room.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['daily_rate'] = 'dailyRate'
  @_hash['number_of_nights'] = 'numberOfNights'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/cyber_source_merged_spec/models/room.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/cyber_source_merged_spec/models/room.rb', line 30

def self.optionals
  %w[
    daily_rate
    number_of_nights
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
# File 'lib/cyber_source_merged_spec/models/room.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} daily_rate: #{@daily_rate.inspect}, number_of_nights:"\
  " #{@number_of_nights.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/room.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} daily_rate: #{@daily_rate}, number_of_nights: #{@number_of_nights},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/room.rb', line 84

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'dailyRate', daily_rate)
  XmlUtilities.add_as_subelement(doc, root, 'numberOfNights',
                                 number_of_nights)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end