Class: CyberSourceMergedSpec::Score2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/score2.rb

Overview

Score2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(factor_codes: SKIP, result: SKIP, additional_properties: nil) ⇒ Score2

Returns a new instance of Score2.



41
42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 41

def initialize(factor_codes: SKIP, result: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @factor_codes = factor_codes unless factor_codes == SKIP
  @result = result unless result == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#factor_codesArray[String]

Array of factor codes.

Returns:

  • (Array[String])


14
15
16
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 14

def factor_codes
  @factor_codes
end

#resultInteger

The description for this field is not available.

Returns:

  • (Integer)


18
19
20
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 18

def result
  @result
end

Class Method Details

.from_element(root) ⇒ Object



71
72
73
74
75
76
77
78
79
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 71

def self.from_element(root)
  factor_codes = XmlUtilities.from_element_to_array(root, 'factorCodes',
                                                    String)
  result = XmlUtilities.from_element(root, 'result', Integer)

  new(factor_codes: factor_codes,
      result: result,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  factor_codes = hash.key?('factorCodes') ? hash['factorCodes'] : SKIP
  result = hash.key?('result') ? hash['result'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Score2.new(factor_codes: factor_codes,
             result: result,
             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['factor_codes'] = 'factorCodes'
  @_hash['result'] = 'result'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 29

def self.optionals
  %w[
    factor_codes
    result
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} factor_codes: #{@factor_codes.inspect}, result: #{@result.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} factor_codes: #{@factor_codes}, result: #{@result}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cyber_source_merged_spec/models/score2.rb', line 81

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'factorCodes',
                                       factor_codes)
  XmlUtilities.add_as_subelement(doc, root, 'result', result)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end