Class: CyberSourceMergedSpec::StrongAuthentication2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/strong_authentication2.rb

Overview

StrongAuthentication2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(authentication_indicator: SKIP, additional_properties: nil) ⇒ StrongAuthentication2

Returns a new instance of StrongAuthentication2.



41
42
43
44
45
46
47
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 41

def initialize(authentication_indicator: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @authentication_indicator = authentication_indicator unless authentication_indicator == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#authentication_indicatorString

Indicates the type of Authentication request 01 - Payment transaction 02 - Recurring transaction 03 - Installment transaction 04 - Add card 05 - Maintain card 06 - Cardholder verification as part of EMV token ID and V

Returns:

  • (String)


20
21
22
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 20

def authentication_indicator
  @authentication_indicator
end

Class Method Details

.from_element(root) ⇒ Object



69
70
71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 69

def self.from_element(root)
  authentication_indicator = XmlUtilities.from_element(
    root, 'authenticationIndicator', String
  )

  new(authentication_indicator: authentication_indicator,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  authentication_indicator =
    hash.key?('authenticationIndicator') ? hash['authenticationIndicator'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  StrongAuthentication2.new(authentication_indicator: authentication_indicator,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['authentication_indicator'] = 'authenticationIndicator'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 30

def self.optionals
  %w[
    authentication_indicator
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} authentication_indicator: #{@authentication_indicator.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



90
91
92
93
94
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 90

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} authentication_indicator: #{@authentication_indicator},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



78
79
80
81
82
83
84
85
86
87
# File 'lib/cyber_source_merged_spec/models/strong_authentication2.rb', line 78

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'authenticationIndicator',
                                 authentication_indicator)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end