Class: CyberSourceMergedSpec::SubscriptionInformation1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::SubscriptionInformation1
- Defined in:
- lib/cyber_source_merged_spec/models/subscription_information1.rb
Overview
SubscriptionInformation1 Model.
Instance Attribute Summary collapse
-
#code ⇒ String
Subscription code.
-
#status ⇒ String
Subscription Status: -
PENDING-ACTIVE-FAILED.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, status: SKIP, additional_properties: nil) ⇒ SubscriptionInformation1
constructor
A new instance of SubscriptionInformation1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, status: SKIP, additional_properties: nil) ⇒ SubscriptionInformation1
Returns a new instance of SubscriptionInformation1.
44 45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 44 def initialize(code: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
Subscription code.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 14 def code @code end |
#status ⇒ String
Subscription Status:
PENDINGACTIVEFAILED
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 21 def status @status end |
Class Method Details
.from_element(root) ⇒ Object
74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 74 def self.from_element(root) code = XmlUtilities.from_element(root, 'code', String) status = XmlUtilities.from_element(root, 'status', String) new(code: code, status: status, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SubscriptionInformation1.new(code: code, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 32 def self.optionals %w[ code status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, status: #{@status.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, status: #{@status}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/subscription_information1.rb', line 83 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'code', code) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |