Class: CyberSourceMergedSpec::Tms400ResponseError
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Tms400ResponseError
- Defined in:
- lib/cyber_source_merged_spec/models/tms400_response_error.rb
Overview
Tms400ResponseError Model.
Instance Attribute Summary collapse
-
#details ⇒ Array[Detail43]
The detailed message related to the type.
-
#message ⇒ String
The detailed message related to the type.
-
#type ⇒ String
The type of error.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ Tms400ResponseError
constructor
A new instance of Tms400ResponseError.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, message: SKIP, details: SKIP, additional_properties: nil) ⇒ Tms400ResponseError
Returns a new instance of Tms400ResponseError.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 54 def initialize(type: SKIP, message: SKIP, details: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @message = unless == SKIP @details = details unless details == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#details ⇒ Array[Detail43]
The detailed message related to the type.
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 29 def details @details end |
#message ⇒ String
The detailed message related to the type.
25 26 27 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 25 def @message end |
#type ⇒ String
The type of error. Possible Values:
- invalidHeaders
- missingHeaders
- invalidFields
- missingFields
- unsupportedPaymentMethodModification
- invalidCombination
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 21 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 97 def self.from_element(root) type = XmlUtilities.from_element(root, 'type', String) = XmlUtilities.from_element(root, 'message', String) details = XmlUtilities.from_element_to_array(root, 'Detail43', Detail43) new(type: type, message: , details: details, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Parameter is an array, so we need to iterate through it details = nil unless hash['details'].nil? details = [] hash['details'].each do |structure| details << (Detail43.from_hash(structure) if structure) end end details = SKIP unless hash.key?('details') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Tms400ResponseError.new(type: type, message: , details: details, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['message'] = 'message' @_hash['details'] = 'details' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 47 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 41 def self.optionals %w[ type message details ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
128 129 130 131 132 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 128 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, message: #{@message.inspect}, details:"\ " #{@details.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
121 122 123 124 125 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 121 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, message: #{@message}, details: #{@details},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/cyber_source_merged_spec/models/tms400_response_error.rb', line 108 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'message', ) XmlUtilities.add_array_as_subelement(doc, root, 'Detail43', details) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |