Class: CyberSourceMergedSpec::Tms404ResponseError

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/tms404_response_error.rb

Overview

Tms404ResponseError Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, message: SKIP, additional_properties: nil) ⇒ Tms404ResponseError

Returns a new instance of Tms404ResponseError.



44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 44

def initialize(type: SKIP, message: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#messageString

The detailed message related to the type.

Returns:

  • (String)


21
22
23
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 21

def message
  @message
end

#typeString

The type of error. Possible Values:

- notFound
- subscriptionNotFound

Returns:

  • (String)


17
18
19
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 17

def type
  @type
end

Class Method Details

.from_element(root) ⇒ Object



74
75
76
77
78
79
80
81
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 74

def self.from_element(root)
  type = XmlUtilities.from_element(root, 'type', String)
  message = XmlUtilities.from_element(root, 'message', String)

  new(type: type,
      message: message,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Tms404ResponseError.new(type: type,
                          message: message,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 32

def self.optionals
  %w[
    type
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



102
103
104
105
106
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 102

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, message: #{@message.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



95
96
97
98
99
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 95

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, message: #{@message}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



83
84
85
86
87
88
89
90
91
92
# File 'lib/cyber_source_merged_spec/models/tms404_response_error.rb', line 83

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'type', type)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end