Class: CyberSourceMergedSpec::TmsPointOfSaleInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb

Overview

TmsPointOfSaleInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(emv_tags:, additional_properties: nil) ⇒ TmsPointOfSaleInformation

Returns a new instance of TmsPointOfSaleInformation.



33
34
35
36
37
38
39
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 33

def initialize(emv_tags:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @emv_tags = emv_tags
  @additional_properties = additional_properties
end

Instance Attribute Details

#emv_tagsArray[EmvTag]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 14

def emv_tags
  @emv_tags
end

Class Method Details

.from_element(root) ⇒ Object



69
70
71
72
73
74
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 69

def self.from_element(root)
  emv_tags = XmlUtilities.from_element_to_array(root, 'EmvTag', EmvTag)

  new(emv_tags: emv_tags,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 42

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  emv_tags = nil
  unless hash['emvTags'].nil?
    emv_tags = []
    hash['emvTags'].each do |structure|
      emv_tags << (EmvTag.from_hash(structure) if structure)
    end
  end

  emv_tags = nil unless hash.key?('emvTags')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TmsPointOfSaleInformation.new(emv_tags: emv_tags,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['emv_tags'] = 'emvTags'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



93
94
95
96
97
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 93

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} emv_tags: #{@emv_tags.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} emv_tags: #{@emv_tags}, additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



76
77
78
79
80
81
82
83
84
# File 'lib/cyber_source_merged_spec/models/tms_point_of_sale_information.rb', line 76

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'EmvTag', emv_tags)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end