Class: CyberSourceMergedSpec::TokenInformation10

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/token_information10.rb

Overview

TokenInformation10 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(jti: SKIP, transient_token_jwt: SKIP, additional_properties: nil) ⇒ TokenInformation10

Returns a new instance of TokenInformation10.



43
44
45
46
47
48
49
50
51
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 43

def initialize(jti: SKIP, transient_token_jwt: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @jti = jti unless jti == SKIP
  @transient_token_jwt = transient_token_jwt unless transient_token_jwt == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#jtiString

TMS Transient Token, 64 hexadecimal id value representing captured payment credentials (including Sensitive Authentication Data, e.g. CVV).

Returns:

  • (String)


15
16
17
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 15

def jti
  @jti
end

#transient_token_jwtString

Flex API Transient Token encoded as JWT (JSON Web Token), e.g. Flex microform or Unified Payment checkout result.

Returns:

  • (String)


20
21
22
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 20

def transient_token_jwt
  @transient_token_jwt
end

Class Method Details

.from_element(root) ⇒ Object



75
76
77
78
79
80
81
82
83
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 75

def self.from_element(root)
  jti = XmlUtilities.from_element(root, 'jti', String)
  transient_token_jwt = XmlUtilities.from_element(root, 'transientTokenJwt',
                                                  String)

  new(jti: jti,
      transient_token_jwt: transient_token_jwt,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  jti = hash.key?('jti') ? hash['jti'] : SKIP
  transient_token_jwt =
    hash.key?('transientTokenJwt') ? hash['transientTokenJwt'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenInformation10.new(jti: jti,
                         transient_token_jwt: transient_token_jwt,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['jti'] = 'jti'
  @_hash['transient_token_jwt'] = 'transientTokenJwt'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 31

def self.optionals
  %w[
    jti
    transient_token_jwt
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



105
106
107
108
109
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 105

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} jti: #{@jti.inspect}, transient_token_jwt: #{@transient_token_jwt.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



98
99
100
101
102
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 98

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} jti: #{@jti}, transient_token_jwt: #{@transient_token_jwt},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/cyber_source_merged_spec/models/token_information10.rb', line 85

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'jti', jti)
  XmlUtilities.add_as_subelement(doc, root, 'transientTokenJwt',
                                 transient_token_jwt)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end