Class: CyberSourceMergedSpec::TokenInformation3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::TokenInformation3
- Defined in:
- lib/cyber_source_merged_spec/models/token_information3.rb
Overview
TokenInformation3 Model.
Instance Attribute Summary collapse
-
#third_party_token ⇒ ThirdPartyToken1
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(third_party_token: SKIP, additional_properties: nil) ⇒ TokenInformation3
constructor
A new instance of TokenInformation3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(third_party_token: SKIP, additional_properties: nil) ⇒ TokenInformation3
Returns a new instance of TokenInformation3.
35 36 37 38 39 40 41 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 35 def initialize(third_party_token: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @third_party_token = third_party_token unless third_party_token == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#third_party_token ⇒ ThirdPartyToken1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 14 def third_party_token @third_party_token end |
Class Method Details
.from_element(root) ⇒ Object
63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 63 def self.from_element(root) third_party_token = XmlUtilities.from_element(root, 'ThirdPartyToken1', ThirdPartyToken1) new(third_party_token: third_party_token, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. third_party_token = ThirdPartyToken1.from_hash(hash['thirdPartyToken']) if hash['thirdPartyToken'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TokenInformation3.new(third_party_token: third_party_token, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['third_party_token'] = 'thirdPartyToken' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 24 def self.optionals %w[ third_party_token ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} third_party_token: #{@third_party_token.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} third_party_token: #{@third_party_token}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/token_information3.rb', line 71 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'ThirdPartyToken1', third_party_token) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |