Class: CyberSourceMergedSpec::Tokencreate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/tokencreate.rb

Overview

Tokencreate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(status: SKIP, reason: SKIP, message: SKIP, additional_properties: nil) ⇒ Tokencreate

Returns a new instance of Tokencreate.



55
56
57
58
59
60
61
62
63
64
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 55

def initialize(status: SKIP, reason: SKIP, message: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = status unless status == SKIP
  @reason = reason unless reason == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#messageString

The detail message related to the status and reason listed above.

Returns:

  • (String)


30
31
32
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 30

def message
  @message
end

#reasonString

The reason of the status. Possible values:

  • INVALID_DATA
  • SYSTEM_ERROR
  • MISSING_FIELD

Returns:

  • (String)


26
27
28
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 26

def reason
  @reason
end

#statusString

The status of the token create. Possible value is:

- SUCCESS
- SERVER_ERROR
- INVALID_REQUEST

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 18

def status
  @status
end

Class Method Details

.from_element(root) ⇒ Object



89
90
91
92
93
94
95
96
97
98
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 89

def self.from_element(root)
  status = XmlUtilities.from_element(root, 'status', String)
  reason = XmlUtilities.from_element(root, 'reason', String)
  message = XmlUtilities.from_element(root, 'message', String)

  new(status: status,
      reason: reason,
      message: message,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 67

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  status = hash.key?('status') ? hash['status'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  message = hash.key?('message') ? hash['message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Tokencreate.new(status: status,
                  reason: reason,
                  message: message,
                  additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash['reason'] = 'reason'
  @_hash['message'] = 'message'
  @_hash
end

.nullablesObject

An array for nullable fields



51
52
53
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 51

def self.nullables
  []
end

.optionalsObject

An array for optional fields



42
43
44
45
46
47
48
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 42

def self.optionals
  %w[
    status
    reason
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



120
121
122
123
124
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 120

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, reason: #{@reason.inspect}, message:"\
  " #{@message.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



113
114
115
116
117
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 113

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, reason: #{@reason}, message: #{@message},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



100
101
102
103
104
105
106
107
108
109
110
# File 'lib/cyber_source_merged_spec/models/tokencreate.rb', line 100

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'status', status)
  XmlUtilities.add_as_subelement(doc, root, 'reason', reason)
  XmlUtilities.add_as_subelement(doc, root, 'message', message)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end