Class: CyberSourceMergedSpec::TokenizeResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/tokenize_response.rb

Overview

TokenizeResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(responses: SKIP, additional_properties: nil) ⇒ TokenizeResponse

Returns a new instance of TokenizeResponse.



35
36
37
38
39
40
41
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 35

def initialize(responses: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @responses = responses unless responses == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#responsesArray[Response]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 14

def responses
  @responses
end

Class Method Details

.from_element(root) ⇒ Object



71
72
73
74
75
76
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 71

def self.from_element(root)
  responses = XmlUtilities.from_element_to_array(root, 'Response', Response)

  new(responses: responses,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  responses = nil
  unless hash['responses'].nil?
    responses = []
    hash['responses'].each do |structure|
      responses << (Response.from_hash(structure) if structure)
    end
  end

  responses = SKIP unless hash.key?('responses')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenizeResponse.new(responses: responses,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['responses'] = 'responses'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 24

def self.optionals
  %w[
    responses
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} responses: #{@responses.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} responses: #{@responses}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



78
79
80
81
82
83
84
85
86
# File 'lib/cyber_source_merged_spec/models/tokenize_response.rb', line 78

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_array_as_subelement(doc, root, 'Response', responses)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end