Class: CyberSourceMergedSpec::TokenizedCard17

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/tokenized_card17.rb

Overview

TokenizedCard17 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(transaction_type: SKIP, type: SKIP, expiration_month: SKIP, expiration_year: SKIP, number: SKIP, additional_properties: nil) ⇒ TokenizedCard17

Returns a new instance of TokenizedCard17.



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 259

def initialize(transaction_type: SKIP, type: SKIP, expiration_month: SKIP,
               expiration_year: SKIP, number: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @transaction_type = transaction_type unless transaction_type == SKIP
  @type = type unless type == SKIP
  @expiration_month = expiration_month unless expiration_month == SKIP
  @expiration_year = expiration_year unless expiration_year == SKIP
  @number = number unless number == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#expiration_monthString

One of two possible meanings:

  • The two-digit month in which a token expires.
  • The two-digit month in which a card expires. Format: MM Possible values: 01 through 12 NOTE The meaning of this field is dependent on the payment processor that is returning the value in an authorization reply. Please see the processor-specific details below.

Barclays and Streamline

For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (01 through 12) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause CyberSource to reject your request. However, an invalid expiration date might cause the issuer to reject your request.

Encoded Account Numbers

For encoded account numbers (card_type=039), if there is no expiration date on the card, use 12.
Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Samsung Pay and Apple Pay

Month in which the token expires. CyberSource includes this field in the reply message when it decrypts the payment blob for the tokenized transaction.

Returns:

  • (String)


193
194
195
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 193

def expiration_month
  @expiration_month
end

#expiration_yearString

One of two possible meanings:

  • The four-digit year in which a token expires.
  • The four-digit year in which a card expires. Format: YYYY Possible values: 1900 through 3000 Data type: Non-negative integer NOTE The meaning of this field is dependent on the payment processor that is returning the value in an authorization reply. Please see the processor-specific details below.

Barclays and Streamline

For Maestro (UK Domestic) and Maestro (International) cards on Barclays and Streamline, this must be a valid value (1900 through 3000) but is not required to be a valid expiration date. In other words, an expiration date that is in the past does not cause CyberSource to reject your request. However, an invalid expiration date might cause the issuer to reject your request.

Encoded Account Numbers

For encoded account numbers (card_ type=039), if there is no expiration date on the card, use 2021.

FDC Nashville Global and FDMS South

You can send in 2 digits or 4 digits. When you send in 2 digits, they must be the last 2 digits of the year.

Samsung Pay and Apple Pay

Year in which the token expires. CyberSource includes this field in the reply message when it decrypts the payment blob for the tokenized transaction. Important It is your responsibility to determine whether a field is required for the transaction you are requesting.

Returns:

  • (String)


226
227
228
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 226

def expiration_year
  @expiration_year
end

#numberString

Customer’s payment network token value.

Returns:

  • (String)


230
231
232
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 230

def number
  @number
end

#transaction_typeString

Type of transaction that provided the token data. This value does not specify the token service provider; it specifies the entity that provided you with information about the token. Possible value:

  • 2: Near-field communication (NFC) transaction. The customer’s mobile device provided the token data for a contactless EMV transaction. For recurring transactions, use this value if the original transaction was a contactless EMV transaction.

Visa Platform Connect

  • 1: For Rupay and In App tokenization. Example: InApp apple pay.
  • 3: Card/Credential On File Tokenization. NOTE No CyberSource through VisaNet acquirers support EMV at this time. Required field for PIN debit credit or PIN debit purchase transactions that use payment network tokens; otherwise, not used.

Rupay

  • 3: Card/Credential On File Tokenization.
  • 4: Tokenizined Transaction. Should be used for Guest Checkout transactions with token.

Returns:

  • (String)


33
34
35
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 33

def transaction_type
  @transaction_type
end

#typeString

Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:

  • 001: Visa. Use card type value 001 for Visa Electron.
  • 002: Mastercard, Eurocard, which is a European regional brand of Mastercard.
  • 003: American Express
  • 004: Discover
  • 005: Diners Club
  • 006: Carte Blanche
  • 007: JCB
  • 008: Optima
  • 009: GE Private Label
  • 010: Beneficial Private Label
  • 011: Twinpay Credit Card
  • 012: Twinpay Debit Card
  • 013: WalMart
  • 014: Enroute
  • 015: Lowe's Consumer
  • 016: Home Depot Consumer
  • 017: MBNA
  • 018: Dick's Sportswear
  • 019: Casual Corner
  • 020: Sears
  • 021: JAL
  • 023: Disney Card
  • 024: Maestro (UK Domestic)[^1]
  • 025: Sam's Club Consumer
  • 026: Sam's Club Business
  • 027: Nico's
  • 028: Paymentech Bill Me Later
  • 029: Bebe
  • 030: Restoration Hardware
  • 031: Delta Online
  • 032: Solo
  • 033: Visa Electron. Do not use this value. Use 001 for all Visa card types.
  • 034: Dankort
  • 035: Laser
  • 036: Cartes Bancaires
  • 037: Carta Si
  • 038: Pinless Debit
  • 039: Encoded account number
  • 040: UATP
  • 041: HOUSEHOLD
  • 042: Maestro (International)[^1]
  • 043: GE MONEY
  • 044: Korean Cards
  • 045: Style Cards
  • 046: JCrew
  • 047: Payeasecn eWallet
  • 048: Payeasecn Bank Transfer
  • 049: Meijer
  • 050: Hipercard
  • 051: Aura
  • 052: Redecard
  • 053: Orico card
  • 054: Elo
  • 055: Capitol One Private Label
  • 056: Carnet
  • 057: Costco Private Label
  • 058: Carnet
  • 059: ValueLink
  • 060: MADA
  • 061: RuPay
  • 062: China UnionPay
  • 063: Falabella Private Label
  • 064: Prompt Card
  • 065: Korean Domestic
  • 066: Banricompras
  • 067: MEEZA
  • 068: PayPak
  • 070: EFTPOS
  • 071: Codensa
  • 072: Olimpica
  • 073: Colsubsidio
  • 074: Tuya
  • 075: Sodexo
  • 076: Naranja
  • 077: Cabal
  • 078: DINELCO
  • 079: PANAL
  • 080: EPM
  • 081: Jaywan [^1]: For this card type, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include the paymentInformation.card.type or paymentInformation.tokenizedCard.type field in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include the paymentInformation.card.type in your request for any payer authentication services.

Used by

Authorization Required for Carte Blanche and JCB. Optional for all other card types.

Card Present reply

This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:

  • American Express Direct
  • Credit Mutuel-CIC
  • FDC Nashville Global
  • OmniPay Direct
  • SIX

Google Pay transactions

For PAN-based Google Pay transactions, this field is returned in the API response.

GPX

This field only supports transactions from the following card types:

  • Visa
  • Mastercard
  • AMEX
  • Discover
  • Diners
  • JCB
  • Union Pay International

Returns:

  • (String)


166
167
168
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 166

def type
  @type
end

Class Method Details

.from_element(root) ⇒ Object



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 303

def self.from_element(root)
  transaction_type = XmlUtilities.from_element(root, 'transactionType',
                                               String)
  type = XmlUtilities.from_element(root, 'type', String)
  expiration_month = XmlUtilities.from_element(root, 'expirationMonth',
                                               String)
  expiration_year = XmlUtilities.from_element(root, 'expirationYear',
                                              String)
  number = XmlUtilities.from_element(root, 'number', String)

  new(transaction_type: transaction_type,
      type: type,
      expiration_month: expiration_month,
      expiration_year: expiration_year,
      number: number,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 274

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  transaction_type =
    hash.key?('transactionType') ? hash['transactionType'] : SKIP
  type = hash.key?('type') ? hash['type'] : SKIP
  expiration_month =
    hash.key?('expirationMonth') ? hash['expirationMonth'] : SKIP
  expiration_year =
    hash.key?('expirationYear') ? hash['expirationYear'] : SKIP
  number = hash.key?('number') ? hash['number'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TokenizedCard17.new(transaction_type: transaction_type,
                      type: type,
                      expiration_month: expiration_month,
                      expiration_year: expiration_year,
                      number: number,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



233
234
235
236
237
238
239
240
241
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 233

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['transaction_type'] = 'transactionType'
  @_hash['type'] = 'type'
  @_hash['expiration_month'] = 'expirationMonth'
  @_hash['expiration_year'] = 'expirationYear'
  @_hash['number'] = 'number'
  @_hash
end

.nullablesObject

An array for nullable fields



255
256
257
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 255

def self.nullables
  []
end

.optionalsObject

An array for optional fields



244
245
246
247
248
249
250
251
252
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 244

def self.optionals
  %w[
    transaction_type
    type
    expiration_month
    expiration_year
    number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



347
348
349
350
351
352
353
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 347

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_type: #{@transaction_type.inspect}, type: #{@type.inspect},"\
  " expiration_month: #{@expiration_month.inspect}, expiration_year:"\
  " #{@expiration_year.inspect}, number: #{@number.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



339
340
341
342
343
344
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 339

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} transaction_type: #{@transaction_type}, type: #{@type}, expiration_month:"\
  " #{@expiration_month}, expiration_year: #{@expiration_year}, number: #{@number},"\
  " additional_properties: #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/cyber_source_merged_spec/models/tokenized_card17.rb', line 321

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'transactionType',
                                 transaction_type)
  XmlUtilities.add_as_subelement(doc, root, 'type', type)
  XmlUtilities.add_as_subelement(doc, root, 'expirationMonth',
                                 expiration_month)
  XmlUtilities.add_as_subelement(doc, root, 'expirationYear',
                                 expiration_year)
  XmlUtilities.add_as_subelement(doc, root, 'number', number)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end