Class: CyberSourceMergedSpec::TotalChargeback

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/cyber_source_merged_spec/models/total_chargeback.rb

Overview

TotalChargeback Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency:, value:, additional_properties: nil) ⇒ TotalChargeback

Returns a new instance of TotalChargeback.



38
39
40
41
42
43
44
45
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 38

def initialize(currency:, value:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @currency = currency
  @value = value
  @additional_properties = additional_properties
end

Instance Attribute Details

#currencyString

Valid ISO 4217 ALPHA-3 currency code

Returns:

  • (String)


14
15
16
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 14

def currency
  @currency
end

#valueString

Valid ISO 4217 ALPHA-3 currency code

Returns:

  • (String)


18
19
20
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 18

def value
  @value
end

Class Method Details

.from_element(root) ⇒ Object



68
69
70
71
72
73
74
75
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 68

def self.from_element(root)
  currency = XmlUtilities.from_element(root, 'currency', String)
  value = XmlUtilities.from_element(root, 'value', String)

  new(currency: currency,
      value: value,
      additional_properties: additional_properties)
end

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  value = hash.key?('value') ? hash['value'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TotalChargeback.new(currency: currency,
                      value: value,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



96
97
98
99
100
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 96

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, value: #{@value.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



89
90
91
92
93
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 89

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, value: #{@value}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_xml_element(doc, root_name) ⇒ Object



77
78
79
80
81
82
83
84
85
86
# File 'lib/cyber_source_merged_spec/models/total_chargeback.rb', line 77

def to_xml_element(doc, root_name)
  root = doc.create_element(root_name)

  XmlUtilities.add_as_subelement(doc, root, 'currency', currency)
  XmlUtilities.add_as_subelement(doc, root, 'value', value)
  XmlUtilities.add_as_subelement(doc, root, 'additional_properties',
                                 additional_properties)

  root
end