Class: CyberSourceMergedSpec::TssV2TransactionsGet200Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::TssV2TransactionsGet200Response
- Defined in:
- lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb
Overview
TssV2TransactionsGet200Response Model.
Instance Attribute Summary collapse
-
#application_information ⇒ ApplicationInformation
The status of the submitted transaction.
-
#bank_account_validation ⇒ BankAccountValidation
The status of the submitted transaction.
-
#buyer_information ⇒ BuyerInformation44
The status of the submitted transaction.
-
#client_reference_information ⇒ ClientReferenceInformation75
The status of the submitted transaction.
-
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation11
The status of the submitted transaction.
-
#device_information ⇒ DeviceInformation18
The status of the submitted transaction.
-
#error_information ⇒ ErrorInformation33
The status of the submitted transaction.
-
#fraud_marking_information ⇒ FraudMarkingInformation
The status of the submitted transaction.
-
#health_care_information ⇒ HealthCareInformation
The status of the submitted transaction.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#installment_information ⇒ InstallmentInformation10
The status of the submitted transaction.
-
#links ⇒ Links245
The object containing the custom data that the merchant defines.
-
#merchant_defined_information ⇒ Array[MerchantDefinedInformation]
The object containing the custom data that the merchant defines.
-
#merchant_id ⇒ String
Your CyberSource merchant ID.
-
#merchant_information ⇒ MerchantInformation24
The object containing the custom data that the merchant defines.
-
#order_information ⇒ OrderInformation57
The object containing the custom data that the merchant defines.
-
#payment_information ⇒ PaymentInformation43
The object containing the custom data that the merchant defines.
-
#payment_insights_information ⇒ PaymentInsightsInformation
The object containing the custom data that the merchant defines.
-
#payout_options ⇒ PayoutOptions1
The object containing the custom data that the merchant defines.
-
#point_of_sale_information ⇒ PointOfSaleInformation14
The object containing the custom data that the merchant defines.
-
#processing_information ⇒ ProcessingInformation69
The object containing the custom data that the merchant defines.
-
#processor_information ⇒ ProcessorInformation34
The object containing the custom data that the merchant defines.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#recurring_payment_information ⇒ RecurringPaymentInformation3
The object containing the custom data that the merchant defines.
-
#risk_information ⇒ RiskInformation10
The object containing the custom data that the merchant defines.
-
#root_id ⇒ String
Contains the transaction identifier for the first transaction in the series of transactions.
-
#sender_information ⇒ SenderInformation5
The object containing the custom data that the merchant defines.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
-
#token_information ⇒ TokenInformation11
The object containing the custom data that the merchant defines.
-
#unscheduled_payment_information ⇒ UnscheduledPaymentInformation
The object containing the custom data that the merchant defines.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, root_id: SKIP, reconciliation_id: SKIP, merchant_id: SKIP, submit_time_utc: SKIP, status: SKIP, application_information: SKIP, bank_account_validation: SKIP, buyer_information: SKIP, client_reference_information: SKIP, consumer_authentication_information: SKIP, device_information: SKIP, error_information: SKIP, installment_information: SKIP, fraud_marking_information: SKIP, health_care_information: SKIP, merchant_defined_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, payment_insights_information: SKIP, payout_options: SKIP, unscheduled_payment_information: SKIP, processing_information: SKIP, processor_information: SKIP, recurring_payment_information: SKIP, point_of_sale_information: SKIP, risk_information: SKIP, sender_information: SKIP, token_information: SKIP, links: SKIP, additional_properties: nil) ⇒ TssV2TransactionsGet200Response
constructor
A new instance of TssV2TransactionsGet200Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, root_id: SKIP, reconciliation_id: SKIP, merchant_id: SKIP, submit_time_utc: SKIP, status: SKIP, application_information: SKIP, bank_account_validation: SKIP, buyer_information: SKIP, client_reference_information: SKIP, consumer_authentication_information: SKIP, device_information: SKIP, error_information: SKIP, installment_information: SKIP, fraud_marking_information: SKIP, health_care_information: SKIP, merchant_defined_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, payment_insights_information: SKIP, payout_options: SKIP, unscheduled_payment_information: SKIP, processing_information: SKIP, processor_information: SKIP, recurring_payment_information: SKIP, point_of_sale_information: SKIP, risk_information: SKIP, sender_information: SKIP, token_information: SKIP, links: SKIP, additional_properties: nil) ⇒ TssV2TransactionsGet200Response
Returns a new instance of TssV2TransactionsGet200Response.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 235 def initialize(id: SKIP, root_id: SKIP, reconciliation_id: SKIP, merchant_id: SKIP, submit_time_utc: SKIP, status: SKIP, application_information: SKIP, bank_account_validation: SKIP, buyer_information: SKIP, client_reference_information: SKIP, consumer_authentication_information: SKIP, device_information: SKIP, error_information: SKIP, installment_information: SKIP, fraud_marking_information: SKIP, health_care_information: SKIP, merchant_defined_information: SKIP, merchant_information: SKIP, order_information: SKIP, payment_information: SKIP, payment_insights_information: SKIP, payout_options: SKIP, unscheduled_payment_information: SKIP, processing_information: SKIP, processor_information: SKIP, recurring_payment_information: SKIP, point_of_sale_information: SKIP, risk_information: SKIP, sender_information: SKIP, token_information: SKIP, links: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @root_id = root_id unless root_id == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @merchant_id = merchant_id unless merchant_id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @application_information = application_information unless application_information == SKIP @bank_account_validation = bank_account_validation unless bank_account_validation == SKIP @buyer_information = buyer_information unless buyer_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end unless consumer_authentication_information == SKIP @consumer_authentication_information = consumer_authentication_information end @device_information = device_information unless device_information == SKIP @error_information = error_information unless error_information == SKIP @installment_information = installment_information unless installment_information == SKIP unless fraud_marking_information == SKIP @fraud_marking_information = fraud_marking_information end @health_care_information = health_care_information unless health_care_information == SKIP unless merchant_defined_information == SKIP @merchant_defined_information = merchant_defined_information end @merchant_information = merchant_information unless merchant_information == SKIP @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP unless payment_insights_information == SKIP @payment_insights_information = payment_insights_information end @payout_options = unless == SKIP unless unscheduled_payment_information == SKIP @unscheduled_payment_information = unscheduled_payment_information end @processing_information = processing_information unless processing_information == SKIP @processor_information = processor_information unless processor_information == SKIP unless recurring_payment_information == SKIP @recurring_payment_information = recurring_payment_information end unless point_of_sale_information == SKIP @point_of_sale_information = point_of_sale_information end @risk_information = risk_information unless risk_information == SKIP @sender_information = sender_information unless sender_information == SKIP @token_information = token_information unless token_information == SKIP @links = links unless links == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#application_information ⇒ ApplicationInformation
The status of the submitted transaction.
56 57 58 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 56 def application_information @application_information end |
#bank_account_validation ⇒ BankAccountValidation
The status of the submitted transaction.
60 61 62 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 60 def bank_account_validation @bank_account_validation end |
#buyer_information ⇒ BuyerInformation44
The status of the submitted transaction.
64 65 66 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 64 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation75
The status of the submitted transaction.
68 69 70 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 68 def client_reference_information @client_reference_information end |
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation11
The status of the submitted transaction.
72 73 74 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 72 def consumer_authentication_information @consumer_authentication_information end |
#device_information ⇒ DeviceInformation18
The status of the submitted transaction.
76 77 78 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 76 def device_information @device_information end |
#error_information ⇒ ErrorInformation33
The status of the submitted transaction.
80 81 82 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 80 def error_information @error_information end |
#fraud_marking_information ⇒ FraudMarkingInformation
The status of the submitted transaction.
88 89 90 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 88 def fraud_marking_information @fraud_marking_information end |
#health_care_information ⇒ HealthCareInformation
The status of the submitted transaction.
92 93 94 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 92 def health_care_information @health_care_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 18 def id @id end |
#installment_information ⇒ InstallmentInformation10
The status of the submitted transaction.
84 85 86 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 84 def installment_information @installment_information end |
#links ⇒ Links245
The object containing the custom data that the merchant defines.
152 153 154 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 152 def links @links end |
#merchant_defined_information ⇒ Array[MerchantDefinedInformation]
The object containing the custom data that the merchant defines.
96 97 98 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 96 def merchant_defined_information @merchant_defined_information end |
#merchant_id ⇒ String
Your CyberSource merchant ID.
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 40 def merchant_id @merchant_id end |
#merchant_information ⇒ MerchantInformation24
The object containing the custom data that the merchant defines.
100 101 102 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 100 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation57
The object containing the custom data that the merchant defines.
104 105 106 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 104 def order_information @order_information end |
#payment_information ⇒ PaymentInformation43
The object containing the custom data that the merchant defines.
108 109 110 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 108 def payment_information @payment_information end |
#payment_insights_information ⇒ PaymentInsightsInformation
The object containing the custom data that the merchant defines.
112 113 114 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 112 def payment_insights_information @payment_insights_information end |
#payout_options ⇒ PayoutOptions1
The object containing the custom data that the merchant defines.
116 117 118 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 116 def @payout_options end |
#point_of_sale_information ⇒ PointOfSaleInformation14
The object containing the custom data that the merchant defines.
136 137 138 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 136 def point_of_sale_information @point_of_sale_information end |
#processing_information ⇒ ProcessingInformation69
The object containing the custom data that the merchant defines.
124 125 126 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 124 def processing_information @processing_information end |
#processor_information ⇒ ProcessorInformation34
The object containing the custom data that the merchant defines.
128 129 130 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 128 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
36 37 38 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 36 def reconciliation_id @reconciliation_id end |
#recurring_payment_information ⇒ RecurringPaymentInformation3
The object containing the custom data that the merchant defines.
132 133 134 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 132 def recurring_payment_information @recurring_payment_information end |
#risk_information ⇒ RiskInformation10
The object containing the custom data that the merchant defines.
140 141 142 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 140 def risk_information @risk_information end |
#root_id ⇒ String
Contains the transaction identifier for the first transaction in the series of transactions. For example, you might send an authorization request for a payment, followed by a capture request for that payment, and then a refund request for that captured payment. Each of those requests, if successful, creates a resource that is assigned an identifier, which is returned in the response. The rootId identifies the first ID in the series, which in this case would be the ID of the original authorization.
28 29 30 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 28 def root_id @root_id end |
#sender_information ⇒ SenderInformation5
The object containing the custom data that the merchant defines.
144 145 146 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 144 def sender_information @sender_information end |
#status ⇒ String
The status of the submitted transaction.
52 53 54 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 52 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
48 49 50 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 48 def submit_time_utc @submit_time_utc end |
#token_information ⇒ TokenInformation11
The object containing the custom data that the merchant defines.
148 149 150 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 148 def token_information @token_information end |
#unscheduled_payment_information ⇒ UnscheduledPaymentInformation
The object containing the custom data that the merchant defines.
120 121 122 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 120 def unscheduled_payment_information @unscheduled_payment_information end |
Class Method Details
.from_element(root) ⇒ Object
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 435 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) root_id = XmlUtilities.from_element(root, 'rootId', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) merchant_id = XmlUtilities.from_element(root, 'merchantId', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUTC', String) status = XmlUtilities.from_element(root, 'status', String) application_information = XmlUtilities.from_element( root, 'ApplicationInformation', ApplicationInformation ) bank_account_validation = XmlUtilities.from_element( root, 'BankAccountValidation', BankAccountValidation ) buyer_information = XmlUtilities.from_element(root, 'BuyerInformation44', BuyerInformation44) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation75', ClientReferenceInformation75 ) consumer_authentication_information = XmlUtilities.from_element( root, 'ConsumerAuthenticationInformation11', ConsumerAuthenticationInformation11 ) device_information = XmlUtilities.from_element(root, 'DeviceInformation18', DeviceInformation18) error_information = XmlUtilities.from_element(root, 'ErrorInformation33', ErrorInformation33) installment_information = XmlUtilities.from_element( root, 'InstallmentInformation10', InstallmentInformation10 ) fraud_marking_information = XmlUtilities.from_element( root, 'FraudMarkingInformation', FraudMarkingInformation ) health_care_information = XmlUtilities.from_element( root, 'HealthCareInformation', HealthCareInformation ) merchant_defined_information = XmlUtilities.from_element_to_array( root, 'MerchantDefinedInformation', MerchantDefinedInformation ) merchant_information = XmlUtilities.from_element(root, 'MerchantInformation24', MerchantInformation24) order_information = XmlUtilities.from_element(root, 'OrderInformation57', OrderInformation57) payment_information = XmlUtilities.from_element(root, 'PaymentInformation43', PaymentInformation43) payment_insights_information = XmlUtilities.from_element( root, 'PaymentInsightsInformation', PaymentInsightsInformation ) = XmlUtilities.from_element(root, 'PayoutOptions1', PayoutOptions1) unscheduled_payment_information = XmlUtilities.from_element( root, 'UnscheduledPaymentInformation', UnscheduledPaymentInformation ) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation69', ProcessingInformation69 ) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation34', ProcessorInformation34 ) recurring_payment_information = XmlUtilities.from_element( root, 'RecurringPaymentInformation3', RecurringPaymentInformation3 ) point_of_sale_information = XmlUtilities.from_element( root, 'PointOfSaleInformation14', PointOfSaleInformation14 ) risk_information = XmlUtilities.from_element(root, 'RiskInformation10', RiskInformation10) sender_information = XmlUtilities.from_element(root, 'SenderInformation5', SenderInformation5) token_information = XmlUtilities.from_element(root, 'TokenInformation11', TokenInformation11) links = XmlUtilities.from_element(root, 'Links245', Links245) new(id: id, root_id: root_id, reconciliation_id: reconciliation_id, merchant_id: merchant_id, submit_time_utc: submit_time_utc, status: status, application_information: application_information, bank_account_validation: bank_account_validation, buyer_information: buyer_information, client_reference_information: client_reference_information, consumer_authentication_information: consumer_authentication_information, device_information: device_information, error_information: error_information, installment_information: installment_information, fraud_marking_information: fraud_marking_information, health_care_information: health_care_information, merchant_defined_information: merchant_defined_information, merchant_information: merchant_information, order_information: order_information, payment_information: payment_information, payment_insights_information: payment_insights_information, payout_options: , unscheduled_payment_information: unscheduled_payment_information, processing_information: processing_information, processor_information: processor_information, recurring_payment_information: recurring_payment_information, point_of_sale_information: point_of_sale_information, risk_information: risk_information, sender_information: sender_information, token_information: token_information, links: links, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 316 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP root_id = hash.key?('rootId') ? hash['rootId'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP merchant_id = hash.key?('merchantId') ? hash['merchantId'] : SKIP submit_time_utc = hash.key?('submitTimeUTC') ? hash['submitTimeUTC'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP application_information = ApplicationInformation.from_hash(hash['applicationInformation']) if hash['applicationInformation'] bank_account_validation = BankAccountValidation.from_hash(hash['bankAccountValidation']) if hash['bankAccountValidation'] buyer_information = BuyerInformation44.from_hash(hash['buyerInformation']) if hash['buyerInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation75.from_hash(hash['clientReferenceInformation']) end if hash['consumerAuthenticationInformation'] consumer_authentication_information = ConsumerAuthenticationInformation11.from_hash(hash['consumerAuthenticationInformation']) end device_information = DeviceInformation18.from_hash(hash['deviceInformation']) if hash['deviceInformation'] error_information = ErrorInformation33.from_hash(hash['errorInformation']) if hash['errorInformation'] if hash['installmentInformation'] installment_information = InstallmentInformation10.from_hash(hash['installmentInformation']) end if hash['fraudMarkingInformation'] fraud_marking_information = FraudMarkingInformation.from_hash(hash['fraudMarkingInformation']) end health_care_information = HealthCareInformation.from_hash(hash['healthCareInformation']) if hash['healthCareInformation'] # Parameter is an array, so we need to iterate through it merchant_defined_information = nil unless hash['merchantDefinedInformation'].nil? merchant_defined_information = [] hash['merchantDefinedInformation'].each do |structure| merchant_defined_information << (MerchantDefinedInformation.from_hash(structure) if structure) end end merchant_defined_information = SKIP unless hash.key?('merchantDefinedInformation') merchant_information = MerchantInformation24.from_hash(hash['merchantInformation']) if hash['merchantInformation'] order_information = OrderInformation57.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation43.from_hash(hash['paymentInformation']) if hash['paymentInformation'] if hash['paymentInsightsInformation'] payment_insights_information = PaymentInsightsInformation.from_hash(hash['paymentInsightsInformation']) end = PayoutOptions1.from_hash(hash['payoutOptions']) if hash['payoutOptions'] if hash['unscheduledPaymentInformation'] unscheduled_payment_information = UnscheduledPaymentInformation.from_hash(hash['unscheduledPaymentInformation']) end processing_information = ProcessingInformation69.from_hash(hash['processingInformation']) if hash['processingInformation'] processor_information = ProcessorInformation34.from_hash(hash['processorInformation']) if hash['processorInformation'] if hash['recurringPaymentInformation'] recurring_payment_information = RecurringPaymentInformation3.from_hash(hash['recurringPaymentInformation']) end if hash['pointOfSaleInformation'] point_of_sale_information = PointOfSaleInformation14.from_hash(hash['pointOfSaleInformation']) end risk_information = RiskInformation10.from_hash(hash['riskInformation']) if hash['riskInformation'] sender_information = SenderInformation5.from_hash(hash['senderInformation']) if hash['senderInformation'] token_information = TokenInformation11.from_hash(hash['tokenInformation']) if hash['tokenInformation'] links = Links245.from_hash(hash['_links']) if hash['_links'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TssV2TransactionsGet200Response.new(id: id, root_id: root_id, reconciliation_id: reconciliation_id, merchant_id: merchant_id, submit_time_utc: submit_time_utc, status: status, application_information: application_information, bank_account_validation: bank_account_validation, buyer_information: buyer_information, client_reference_information: client_reference_information, consumer_authentication_information: consumer_authentication_information, device_information: device_information, error_information: error_information, installment_information: installment_information, fraud_marking_information: fraud_marking_information, health_care_information: health_care_information, merchant_defined_information: merchant_defined_information, merchant_information: merchant_information, order_information: order_information, payment_information: payment_information, payment_insights_information: payment_insights_information, payout_options: , unscheduled_payment_information: unscheduled_payment_information, processing_information: processing_information, processor_information: processor_information, recurring_payment_information: recurring_payment_information, point_of_sale_information: point_of_sale_information, risk_information: risk_information, sender_information: sender_information, token_information: token_information, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 155 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['root_id'] = 'rootId' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['merchant_id'] = 'merchantId' @_hash['submit_time_utc'] = 'submitTimeUTC' @_hash['status'] = 'status' @_hash['application_information'] = 'applicationInformation' @_hash['bank_account_validation'] = 'bankAccountValidation' @_hash['buyer_information'] = 'buyerInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['consumer_authentication_information'] = 'consumerAuthenticationInformation' @_hash['device_information'] = 'deviceInformation' @_hash['error_information'] = 'errorInformation' @_hash['installment_information'] = 'installmentInformation' @_hash['fraud_marking_information'] = 'fraudMarkingInformation' @_hash['health_care_information'] = 'healthCareInformation' @_hash['merchant_defined_information'] = 'merchantDefinedInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['payment_insights_information'] = 'paymentInsightsInformation' @_hash['payout_options'] = 'payoutOptions' @_hash['unscheduled_payment_information'] = 'unscheduledPaymentInformation' @_hash['processing_information'] = 'processingInformation' @_hash['processor_information'] = 'processorInformation' @_hash['recurring_payment_information'] = 'recurringPaymentInformation' @_hash['point_of_sale_information'] = 'pointOfSaleInformation' @_hash['risk_information'] = 'riskInformation' @_hash['sender_information'] = 'senderInformation' @_hash['token_information'] = 'tokenInformation' @_hash['links'] = '_links' @_hash end |
.nullables ⇒ Object
An array for nullable fields
231 232 233 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 231 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 194 def self.optionals %w[ id root_id reconciliation_id merchant_id submit_time_utc status application_information bank_account_validation buyer_information client_reference_information consumer_authentication_information device_information error_information installment_information fraud_marking_information health_care_information merchant_defined_information merchant_information order_information payment_information payment_insights_information payout_options unscheduled_payment_information processing_information processor_information recurring_payment_information point_of_sale_information risk_information sender_information token_information links ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 643 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, root_id: #{@root_id.inspect}, reconciliation_id:"\ " #{@reconciliation_id.inspect}, merchant_id: #{@merchant_id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, application_information:"\ " #{@application_information.inspect}, bank_account_validation:"\ " #{@bank_account_validation.inspect}, buyer_information: #{@buyer_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " consumer_authentication_information: #{@consumer_authentication_information.inspect},"\ " device_information: #{@device_information.inspect}, error_information:"\ " #{@error_information.inspect}, installment_information:"\ " #{@installment_information.inspect}, fraud_marking_information:"\ " #{@fraud_marking_information.inspect}, health_care_information:"\ " #{@health_care_information.inspect}, merchant_defined_information:"\ " #{@merchant_defined_information.inspect}, merchant_information:"\ " #{@merchant_information.inspect}, order_information: #{@order_information.inspect},"\ " payment_information: #{@payment_information.inspect}, payment_insights_information:"\ " #{@payment_insights_information.inspect}, payout_options: #{@payout_options.inspect},"\ " unscheduled_payment_information: #{@unscheduled_payment_information.inspect},"\ " processing_information: #{@processing_information.inspect}, processor_information:"\ " #{@processor_information.inspect}, recurring_payment_information:"\ " #{@recurring_payment_information.inspect}, point_of_sale_information:"\ " #{@point_of_sale_information.inspect}, risk_information: #{@risk_information.inspect},"\ " sender_information: #{@sender_information.inspect}, token_information:"\ " #{@token_information.inspect}, links: #{@links.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 619 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, root_id: #{@root_id}, reconciliation_id: #{@reconciliation_id},"\ " merchant_id: #{@merchant_id}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " application_information: #{@application_information}, bank_account_validation:"\ " #{@bank_account_validation}, buyer_information: #{@buyer_information},"\ " client_reference_information: #{@client_reference_information},"\ " consumer_authentication_information: #{@consumer_authentication_information},"\ " device_information: #{@device_information}, error_information: #{@error_information},"\ " installment_information: #{@installment_information}, fraud_marking_information:"\ " #{@fraud_marking_information}, health_care_information: #{@health_care_information},"\ " merchant_defined_information: #{@merchant_defined_information}, merchant_information:"\ " #{@merchant_information}, order_information: #{@order_information}, payment_information:"\ " #{@payment_information}, payment_insights_information: #{@payment_insights_information},"\ " payout_options: #{@payout_options}, unscheduled_payment_information:"\ " #{@unscheduled_payment_information}, processing_information: #{@processing_information},"\ " processor_information: #{@processor_information}, recurring_payment_information:"\ " #{@recurring_payment_information}, point_of_sale_information:"\ " #{@point_of_sale_information}, risk_information: #{@risk_information}, sender_information:"\ " #{@sender_information}, token_information: #{@token_information}, links: #{@links},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/cyber_source_merged_spec/models/tss_v2_transactions_get200_response.rb', line 550 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'rootId', root_id) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'merchantId', merchant_id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUTC', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'ApplicationInformation', application_information) XmlUtilities.add_as_subelement(doc, root, 'BankAccountValidation', bank_account_validation) XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation44', buyer_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation75', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'ConsumerAuthenticationInformation11', consumer_authentication_information) XmlUtilities.add_as_subelement(doc, root, 'DeviceInformation18', device_information) XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation33', error_information) XmlUtilities.add_as_subelement(doc, root, 'InstallmentInformation10', installment_information) XmlUtilities.add_as_subelement(doc, root, 'FraudMarkingInformation', fraud_marking_information) XmlUtilities.add_as_subelement(doc, root, 'HealthCareInformation', health_care_information) XmlUtilities.add_array_as_subelement(doc, root, 'MerchantDefinedInformation', merchant_defined_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation24', merchant_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation57', order_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation43', payment_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInsightsInformation', payment_insights_information) XmlUtilities.add_as_subelement(doc, root, 'PayoutOptions1', ) XmlUtilities.add_as_subelement(doc, root, 'UnscheduledPaymentInformation', unscheduled_payment_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation69', processing_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation34', processor_information) XmlUtilities.add_as_subelement(doc, root, 'RecurringPaymentInformation3', recurring_payment_information) XmlUtilities.add_as_subelement(doc, root, 'PointOfSaleInformation14', point_of_sale_information) XmlUtilities.add_as_subelement(doc, root, 'RiskInformation10', risk_information) XmlUtilities.add_as_subelement(doc, root, 'SenderInformation5', sender_information) XmlUtilities.add_as_subelement(doc, root, 'TokenInformation11', token_information) XmlUtilities.add_as_subelement(doc, root, 'Links245', links) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |