Class: CyberSourceMergedSpec::UpdatePayments
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::UpdatePayments
- Defined in:
- lib/cyber_source_merged_spec/models/update_payments.rb
Overview
UpdatePayments Model.
Instance Attribute Summary collapse
-
#billing_cycles_to_skip ⇒ Array[Integer]
A list of billing cycles that are marked to be skipped.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(billing_cycles_to_skip: SKIP, additional_properties: nil) ⇒ UpdatePayments
constructor
A new instance of UpdatePayments.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(billing_cycles_to_skip: SKIP, additional_properties: nil) ⇒ UpdatePayments
Returns a new instance of UpdatePayments.
38 39 40 41 42 43 44 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 38 def initialize(billing_cycles_to_skip: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @billing_cycles_to_skip = billing_cycles_to_skip unless billing_cycles_to_skip == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#billing_cycles_to_skip ⇒ Array[Integer]
A list of billing cycles that are marked to be skipped. The payment cannot be added to the list if it is a retry attempt. The payment cannot be added to or removed from the list if it is on the same day as its scheduled processing time.
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 17 def billing_cycles_to_skip @billing_cycles_to_skip end |
Class Method Details
.from_element(root) ⇒ Object
66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 66 def self.from_element(root) billing_cycles_to_skip = XmlUtilities.from_element_to_array( root, 'billingCyclesToSkip', Integer ) new(billing_cycles_to_skip: billing_cycles_to_skip, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. billing_cycles_to_skip = hash.key?('billingCyclesToSkip') ? hash['billingCyclesToSkip'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdatePayments.new(billing_cycles_to_skip: billing_cycles_to_skip, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['billing_cycles_to_skip'] = 'billingCyclesToSkip' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 27 def self.optionals %w[ billing_cycles_to_skip ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 94 def inspect class_name = self.class.name.split('::').last "<#{class_name} billing_cycles_to_skip: #{@billing_cycles_to_skip.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 87 def to_s class_name = self.class.name.split('::').last "<#{class_name} billing_cycles_to_skip: #{@billing_cycles_to_skip}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/update_payments.rb', line 75 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_array_as_subelement(doc, root, 'billingCyclesToSkip', billing_cycles_to_skip) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |