Class: CyberSourceMergedSpec::UpdatePlanResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::UpdatePlanResponse
- Defined in:
- lib/cyber_source_merged_spec/models/update_plan_response.rb
Overview
UpdatePlanResponse Model.
Instance Attribute Summary collapse
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#links ⇒ Links1
TODO: Write general description for this method.
-
#plan_information ⇒ PlanInformation5
The status of the submitted transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, plan_information: SKIP, additional_properties: nil) ⇒ UpdatePlanResponse
constructor
A new instance of UpdatePlanResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, plan_information: SKIP, additional_properties: nil) ⇒ UpdatePlanResponse
Returns a new instance of UpdatePlanResponse.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 71 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, plan_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @plan_information = plan_information unless plan_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 22 def id @id end |
#links ⇒ Links1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 14 def links @links end |
#plan_information ⇒ PlanInformation5
The status of the submitted transaction. Possible values:
- COMPLETED
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 42 def plan_information @plan_information end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- COMPLETED
36 37 38 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 36 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 113 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links1', Links1) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) plan_information = XmlUtilities.from_element(root, 'PlanInformation5', PlanInformation5) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, plan_information: plan_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 85 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links1.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP plan_information = PlanInformation5.from_hash(hash['planInformation']) if hash['planInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdatePlanResponse.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, plan_information: plan_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
45 46 47 48 49 50 51 52 53 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 45 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['plan_information'] = 'planInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
67 68 69 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 67 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
56 57 58 59 60 61 62 63 64 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 56 def self.optionals %w[ links id submit_time_utc status plan_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
154 155 156 157 158 159 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 154 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, plan_information:"\ " #{@plan_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
146 147 148 149 150 151 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 146 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, plan_information: #{@plan_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/cyber_source_merged_spec/models/update_plan_response.rb', line 129 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links1', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'PlanInformation5', plan_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |