Class: CyberSourceMergedSpec::UpdateSubscriptionResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::UpdateSubscriptionResponse
- Defined in:
- lib/cyber_source_merged_spec/models/update_subscription_response.rb
Overview
UpdateSubscriptionResponse Model.
Instance Attribute Summary collapse
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#links ⇒ Links235
TODO: Write general description for this method.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
-
#subscription_information ⇒ SubscriptionInformation1
The status of the submitted transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, subscription_information: SKIP, additional_properties: nil) ⇒ UpdateSubscriptionResponse
constructor
A new instance of UpdateSubscriptionResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, subscription_information: SKIP, additional_properties: nil) ⇒ UpdateSubscriptionResponse
Returns a new instance of UpdateSubscriptionResponse.
77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 77 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, subscription_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @subscription_information = subscription_information unless subscription_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 22 def id @id end |
#links ⇒ Links235
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 14 def links @links end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- COMPLETED
- PENDING_REVIEW
- DECLINED
- INVALID_REQUEST
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 39 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 30 def submit_time_utc @submit_time_utc end |
#subscription_information ⇒ SubscriptionInformation1
The status of the submitted transaction. Possible values:
- COMPLETED
- PENDING_REVIEW
- DECLINED
- INVALID_REQUEST
48 49 50 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 48 def subscription_information @subscription_information end |
Class Method Details
.from_element(root) ⇒ Object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 120 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links235', Links235) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) subscription_information = XmlUtilities.from_element( root, 'SubscriptionInformation1', SubscriptionInformation1 ) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, subscription_information: subscription_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 91 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links235.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP if hash['subscriptionInformation'] subscription_information = SubscriptionInformation1.from_hash(hash['subscriptionInformation']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdateSubscriptionResponse.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, subscription_information: subscription_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 57 58 59 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['subscription_information'] = 'subscriptionInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
73 74 75 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 73 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 62 def self.optionals %w[ links id submit_time_utc status subscription_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
162 163 164 165 166 167 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 162 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, subscription_information:"\ " #{@subscription_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
154 155 156 157 158 159 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 154 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, subscription_information: #{@subscription_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/cyber_source_merged_spec/models/update_subscription_response.rb', line 137 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links235', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'SubscriptionInformation1', subscription_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |