Class: CyberSourceMergedSpec::UserAgent
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::UserAgent
- Defined in:
- lib/cyber_source_merged_spec/models/user_agent.rb
Overview
The images to be used as background on Klarna’s payment page (the image best matching the resolution will be used). This is a pass-through field. Check Klarna’s documentation for more information about the correct format. This value can also be set in the merchant configuration.
Instance Attribute Summary collapse
-
#url ⇒ String
Url for the image.
-
#width ⇒ Integer
Width of the image.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(url: SKIP, width: SKIP, additional_properties: nil) ⇒ UserAgent
constructor
A new instance of UserAgent.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(url: SKIP, width: SKIP, additional_properties: nil) ⇒ UserAgent
Returns a new instance of UserAgent.
44 45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 44 def initialize(url: SKIP, width: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @url = url unless url == SKIP @width = width unless width == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#url ⇒ String
Url for the image
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 17 def url @url end |
#width ⇒ Integer
Width of the image
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 21 def width @width end |
Class Method Details
.from_element(root) ⇒ Object
74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 74 def self.from_element(root) url = XmlUtilities.from_element(root, 'url', String) width = XmlUtilities.from_element(root, 'width', Integer) new(url: url, width: width, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. url = hash.key?('url') ? hash['url'] : SKIP width = hash.key?('width') ? hash['width'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UserAgent.new(url: url, width: width, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['url'] = 'url' @_hash['width'] = 'width' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 32 def self.optionals %w[ url width ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} url: #{@url.inspect}, width: #{@width.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} url: #{@url}, width: #{@width}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/user_agent.rb', line 83 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'url', url) XmlUtilities.add_as_subelement(doc, root, 'width', width) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |