Class: CyberSourceMergedSpec::Account12
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Account12
- Defined in:
- lib/cyber_source_merged_spec/models/account12.rb
Overview
Account12 Model.
Instance Attribute Summary collapse
-
#iban ⇒ String
International Bank Account Number (IBAN) for the bank account.
-
#number ⇒ String
Account number.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(number: SKIP, iban: SKIP, additional_properties: nil) ⇒ Account12
constructor
A new instance of Account12.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(number: SKIP, iban: SKIP, additional_properties: nil) ⇒ Account12
Returns a new instance of Account12.
46 47 48 49 50 51 52 53 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 46 def initialize(number: SKIP, iban: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @number = number unless number == SKIP @iban = iban unless iban == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#iban ⇒ String
International Bank Account Number (IBAN) for the bank account. For some countries you can provide this number instead of the traditional bank account information. You can use this field only when scoring a direct debit transaction.
23 24 25 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 23 def iban @iban end |
#number ⇒ String
Account number. When processing encoded account numbers, use this field for the encoded account number.
16 17 18 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 16 def number @number end |
Class Method Details
.from_element(root) ⇒ Object
76 77 78 79 80 81 82 83 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 76 def self.from_element(root) number = XmlUtilities.from_element(root, 'number', String) iban = XmlUtilities.from_element(root, 'iban', String) new(number: number, iban: iban, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. number = hash.key?('number') ? hash['number'] : SKIP iban = hash.key?('iban') ? hash['iban'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Account12.new(number: number, iban: iban, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['number'] = 'number' @_hash['iban'] = 'iban' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 34 def self.optionals %w[ number iban ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 104 def inspect class_name = self.class.name.split('::').last "<#{class_name} number: #{@number.inspect}, iban: #{@iban.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 97 def to_s class_name = self.class.name.split('::').last "<#{class_name} number: #{@number}, iban: #{@iban}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
85 86 87 88 89 90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/account12.rb', line 85 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'number', number) XmlUtilities.add_as_subelement(doc, root, 'iban', iban) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |