Class: CyberSourceMergedSpec::AmountDetails37
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::AmountDetails37
- Defined in:
- lib/cyber_source_merged_spec/models/amount_details37.rb
Overview
AmountDetails37 Model.
Instance Attribute Summary collapse
-
#currency ⇒ String
Currency used for the order.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency: SKIP, additional_properties: nil) ⇒ AmountDetails37
constructor
A new instance of AmountDetails37.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency: SKIP, additional_properties: nil) ⇒ AmountDetails37
Returns a new instance of AmountDetails37.
70 71 72 73 74 75 76 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 70 def initialize(currency: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @currency = currency unless currency == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#currency ⇒ String
Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/cur rencies.pdf)
Used by
Authorization
Required field.
Authorization Reversal
For an authorization reversal (reversalInformation) or a capture
(processingOptions.capture is set to true), you must use the same
currency that you used in your payment authorization request.
PIN Debit
Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Returned by PIN debit purchase. For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickre f/currencies.pdf). Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.
GPX
This field is optional for reversing an authorization or credit.
DCC for First Data
Your local currency.
Tax Calculation
Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency.
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 49 def currency @currency end |
Class Method Details
.from_element(root) ⇒ Object
97 98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 97 def self.from_element(root) currency = XmlUtilities.from_element(root, 'currency', String) new(currency: currency, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 79 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency = hash.key?('currency') ? hash['currency'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AmountDetails37.new(currency: currency, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 52 def self.names @_hash = {} if @_hash.nil? @_hash['currency'] = 'currency' @_hash end |
.nullables ⇒ Object
An array for nullable fields
66 67 68 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 66 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 59 def self.optionals %w[ currency ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency: #{@currency}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
104 105 106 107 108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/amount_details37.rb', line 104 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'currency', currency) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |