Class: CyberSourceMergedSpec::AmountDetails54
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::AmountDetails54
- Defined in:
- lib/cyber_source_merged_spec/models/amount_details54.rb
Overview
AmountDetails54 Model.
Instance Attribute Summary collapse
-
#billing_amount ⇒ String
Billing amount for the billing period.
-
#setup_fee ⇒ String
Subscription setup fee.
-
#surcharge ⇒ Surcharge3
Subscription setup fee.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(billing_amount: SKIP, setup_fee: SKIP, surcharge: SKIP, additional_properties: nil) ⇒ AmountDetails54
constructor
A new instance of AmountDetails54.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(billing_amount: SKIP, setup_fee: SKIP, surcharge: SKIP, additional_properties: nil) ⇒ AmountDetails54
Returns a new instance of AmountDetails54.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 47 def initialize(billing_amount: SKIP, setup_fee: SKIP, surcharge: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @billing_amount = billing_amount unless billing_amount == SKIP @setup_fee = setup_fee unless setup_fee == SKIP @surcharge = surcharge unless surcharge == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#billing_amount ⇒ String
Billing amount for the billing period.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 14 def billing_amount @billing_amount end |
#setup_fee ⇒ String
Subscription setup fee
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 18 def setup_fee @setup_fee end |
#surcharge ⇒ Surcharge3
Subscription setup fee
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 22 def surcharge @surcharge end |
Class Method Details
.from_element(root) ⇒ Object
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 81 def self.from_element(root) billing_amount = XmlUtilities.from_element(root, 'billingAmount', String) setup_fee = XmlUtilities.from_element(root, 'setupFee', String) surcharge = XmlUtilities.from_element(root, 'Surcharge3', Surcharge3) new(billing_amount: billing_amount, setup_fee: setup_fee, surcharge: surcharge, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. billing_amount = hash.key?('billingAmount') ? hash['billingAmount'] : SKIP setup_fee = hash.key?('setupFee') ? hash['setupFee'] : SKIP surcharge = Surcharge3.from_hash(hash['surcharge']) if hash['surcharge'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AmountDetails54.new(billing_amount: billing_amount, setup_fee: setup_fee, surcharge: surcharge, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['billing_amount'] = 'billingAmount' @_hash['setup_fee'] = 'setupFee' @_hash['surcharge'] = 'surcharge' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 34 def self.optionals %w[ billing_amount setup_fee surcharge ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
112 113 114 115 116 117 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 112 def inspect class_name = self.class.name.split('::').last "<#{class_name} billing_amount: #{@billing_amount.inspect}, setup_fee:"\ " #{@setup_fee.inspect}, surcharge: #{@surcharge.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} billing_amount: #{@billing_amount}, setup_fee: #{@setup_fee}, surcharge:"\ " #{@surcharge}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/amount_details54.rb', line 92 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'billingAmount', billing_amount) XmlUtilities.add_as_subelement(doc, root, 'setupFee', setup_fee) XmlUtilities.add_as_subelement(doc, root, 'Surcharge3', surcharge) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |