Class: CyberSourceMergedSpec::AuthenticatedIdentity1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::AuthenticatedIdentity1
- Defined in:
- lib/cyber_source_merged_spec/models/authenticated_identity1.rb
Overview
AuthenticatedIdentity1 Model.
Instance Attribute Summary collapse
-
#data ⇒ String
The data from the authenticated identity.
-
#id ⇒ String
The id from the authenticated identity.
-
#provider ⇒ String
The provider of the authenticated identity.
-
#relying_party_id ⇒ String
The id of the Relying Party.
-
#user_authentication_method ⇒ String
The method used to authenticate the user.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, provider: SKIP, data: SKIP, relying_party_id: SKIP, user_authentication_method: SKIP, additional_properties: nil) ⇒ AuthenticatedIdentity1
constructor
A new instance of AuthenticatedIdentity1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, provider: SKIP, data: SKIP, relying_party_id: SKIP, user_authentication_method: SKIP, additional_properties: nil) ⇒ AuthenticatedIdentity1
Returns a new instance of AuthenticatedIdentity1.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 92 def initialize(id: SKIP, provider: SKIP, data: SKIP, relying_party_id: SKIP, user_authentication_method: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @provider = provider unless provider == SKIP @data = data unless data == SKIP @relying_party_id = unless == SKIP unless user_authentication_method == SKIP @user_authentication_method = user_authentication_method end @additional_properties = additional_properties end |
Instance Attribute Details
#data ⇒ String
The data from the authenticated identity. For Passkey this could be the FIDO Attestation. For Classic Cloud Token Framework (CTF) this could be a JWS containing device authentication information signed by a devices private key. Base64URL encoded string (RFC4648). The encoding is the same as Base64, but uses '-' characters instead of '+' and '_' characters instead of '/'.
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 34 def data @data end |
#id ⇒ String
The id from the authenticated identity. Base64URL encoded string (RFC4648). The encoding is the same as Base64, but uses '-' characters instead of '+' and '_' characters instead of '/'.
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 17 def id @id end |
#provider ⇒ String
The provider of the authenticated identity. Possible Values:
- VISA_PAYMENT_PASSKEY
- CLIENT_DEVICE_CERT_JWS
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 24 def provider @provider end |
#relying_party_id ⇒ String
The id of the Relying Party. Base64URL encoded string (RFC4648). The encoding is the same as Base64, but uses '-' characters instead of '+' and '_' characters instead of '/'.
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 41 def @relying_party_id end |
#user_authentication_method ⇒ String
The method used to authenticate the user. Possible Values:
- USERNAME_PASSWORD
- PASSCODE_PASSWORD
- PASSCODE
- PASSWORD
- PATTERN
- BIOMETRIC_FINGERPRINT
- BIOMETRIC_FACIAL
- BIOMETRIC_IRIS
- BIOMETRIC_VOICE
- BIOMETRIC_BEHAVIORAL
- DEVICE_UNLOCKED_METHOD_UNKNOWN
- OTP_SMS
- OTP_EMAIL
- OTP_SMS_KNOWLEDGE
- KNOWLEDGE_BASED_AUTHENTICATION
- USER_UNVERIFIED
- BIOMETRIC
63 64 65 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 63 def user_authentication_method @user_authentication_method end |
Class Method Details
.from_element(root) ⇒ Object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 137 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) provider = XmlUtilities.from_element(root, 'provider', String) data = XmlUtilities.from_element(root, 'data', String) = XmlUtilities.from_element(root, 'relyingPartyId', String) user_authentication_method = XmlUtilities.from_element( root, 'userAuthenticationMethod', String ) new(id: id, provider: provider, data: data, relying_party_id: , user_authentication_method: user_authentication_method, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 109 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP provider = hash.key?('provider') ? hash['provider'] : SKIP data = hash.key?('data') ? hash['data'] : SKIP = hash.key?('relyingPartyId') ? hash['relyingPartyId'] : SKIP user_authentication_method = hash.key?('userAuthenticationMethod') ? hash['userAuthenticationMethod'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AuthenticatedIdentity1.new(id: id, provider: provider, data: data, relying_party_id: , user_authentication_method: user_authentication_method, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
66 67 68 69 70 71 72 73 74 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 66 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['provider'] = 'provider' @_hash['data'] = 'data' @_hash['relying_party_id'] = 'relyingPartyId' @_hash['user_authentication_method'] = 'userAuthenticationMethod' @_hash end |
.nullables ⇒ Object
An array for nullable fields
88 89 90 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 88 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
77 78 79 80 81 82 83 84 85 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 77 def self.optionals %w[ id provider data relying_party_id user_authentication_method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
180 181 182 183 184 185 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 180 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, provider: #{@provider.inspect}, data: #{@data.inspect},"\ " relying_party_id: #{@relying_party_id.inspect}, user_authentication_method:"\ " #{@user_authentication_method.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
172 173 174 175 176 177 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 172 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, provider: #{@provider}, data: #{@data}, relying_party_id:"\ " #{@relying_party_id}, user_authentication_method: #{@user_authentication_method},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/cyber_source_merged_spec/models/authenticated_identity1.rb', line 155 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'provider', provider) XmlUtilities.add_as_subelement(doc, root, 'data', data) XmlUtilities.add_as_subelement(doc, root, 'relyingPartyId', ) XmlUtilities.add_as_subelement(doc, root, 'userAuthenticationMethod', user_authentication_method) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |