Class: CyberSourceMergedSpec::Avs1
- Defined in:
- lib/cyber_source_merged_spec/models/avs1.rb
Overview
Avs1 Model.
Instance Attribute Summary collapse
-
#code_raw ⇒ String
AVS result code sent directly from the processor.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code_raw: SKIP, additional_properties: nil) ⇒ Avs1
constructor
A new instance of Avs1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code_raw: SKIP, additional_properties: nil) ⇒ Avs1
Returns a new instance of Avs1.
39 40 41 42 43 44 45 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 39 def initialize(code_raw: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code_raw = code_raw unless code_raw == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code_raw ⇒ String
AVS result code sent directly from the processor. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of AVS. Use for debugging purposes only. Returned by authorization service.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 18 def code_raw @code_raw end |
Class Method Details
.from_element(root) ⇒ Object
66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 66 def self.from_element(root) code_raw = XmlUtilities.from_element(root, 'codeRaw', String) new(code_raw: code_raw, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code_raw = hash.key?('codeRaw') ? hash['codeRaw'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Avs1.new(code_raw: code_raw, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['code_raw'] = 'codeRaw' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 28 def self.optionals %w[ code_raw ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} code_raw: #{@code_raw.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} code_raw: #{@code_raw}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
73 74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/avs1.rb', line 73 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'codeRaw', code_raw) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |