Class: CyberSourceMergedSpec::BankAccount46
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::BankAccount46
- Defined in:
- lib/cyber_source_merged_spec/models/bank_account46.rb
Overview
BankAccount46 Model.
Instance Attribute Summary collapse
-
#number ⇒ String
Account number.
-
#routing_number ⇒ String
Bank routing number.
-
#type ⇒ String
Account type.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, number: SKIP, routing_number: SKIP, additional_properties: nil) ⇒ BankAccount46
constructor
A new instance of BankAccount46.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, number: SKIP, routing_number: SKIP, additional_properties: nil) ⇒ BankAccount46
Returns a new instance of BankAccount46.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 54 def initialize(type: SKIP, number: SKIP, routing_number: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @number = number unless number == SKIP @routing_number = routing_number unless routing_number == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#number ⇒ String
Account number. When processing encoded account numbers, use this field for the encoded account number.
25 26 27 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 25 def number @number end |
#routing_number ⇒ String
Bank routing number. This is also called the transit number
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 29 def routing_number @routing_number end |
#type ⇒ String
Account type. Possible Values:
- checking : C
- general ledger : G This value is supported only on Wells Fargo ACH
- savings : S (U.S. dollars only)
- corporate checking : X (U.S. dollars only)
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 19 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 88 def self.from_element(root) type = XmlUtilities.from_element(root, 'type', String) number = XmlUtilities.from_element(root, 'number', String) routing_number = XmlUtilities.from_element(root, 'routingNumber', String) new(type: type, number: number, routing_number: routing_number, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP number = hash.key?('number') ? hash['number'] : SKIP routing_number = hash.key?('routingNumber') ? hash['routingNumber'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BankAccount46.new(type: type, number: number, routing_number: routing_number, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['number'] = 'number' @_hash['routing_number'] = 'routingNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
41 42 43 44 45 46 47 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 41 def self.optionals %w[ type number routing_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, number: #{@number.inspect}, routing_number:"\ " #{@routing_number.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, number: #{@number}, routing_number: #{@routing_number},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/bank_account46.rb', line 99 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'number', number) XmlUtilities.add_as_subelement(doc, root, 'routingNumber', routing_number) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |