Class: CyberSourceMergedSpec::Brand
- Defined in:
- lib/cyber_source_merged_spec/models/brand.rb
Overview
Brand Model.
Instance Attribute Summary collapse
-
#brand_name ⇒ String
This field contains the card brand name.
-
#type ⇒ String
This field contains a 3-digit numeric value that indicates the card type within Cybersource eco-system.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, brand_name: SKIP, additional_properties: nil) ⇒ Brand
constructor
A new instance of Brand.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, brand_name: SKIP, additional_properties: nil) ⇒ Brand
Returns a new instance of Brand.
203 204 205 206 207 208 209 210 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 203 def initialize(type: SKIP, brand_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @brand_name = brand_name unless brand_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#brand_name ⇒ String
This field contains the card brand name. Some of the possible values (not an exhaustive list) are -
- VISA
- MASTERCARD
- AMERICAN EXPRESS
- DISCOVER
- DINERS CLUB
- CARTE BLANCHE
- JCB
- OPTIMA
- TWINPAY CREDIT CARD
- TWINPAY DEBIT CARD
- WALMART
- ENROUTE
- LOWES CONSUMER
- HOME DEPOT CONSUMER
- MBNA
- DICKS SPORTWEAR
- CASUAL CORNER
- SEARS
- JAL
- DISNEY CARD
- SWITCH/SOLO
- SAMS CLUB CONSUMER
- SAMS CLUB BUSINESS
- NICOS HOUSE CARD
- BEBE
- RESTORATION HARDWARE
- DELTA ONLINE
- SOLO
- VISA ELECTRON
- DANKORT
- LASER
- CARTE BANCAIRE
- CARTA SI
- ENCODED ACCOUNT
- UATP
- HOUSEHOLD
- MAESTRO
- GE CAPITAL
- KOREAN CARDS
- STYLE CARDS
- JCREW
- MEIJER
- HIPERCARD
- AURA
- REDECARD
- ORICO HOUSE CARD
- MADA
- ELO
- CAPITAL ONE PRIVATE LABEL
- CARNET
- RUPAY
- CHINA UNION PAY
- FALABELLA PRIVATE LABEL
- PROMPTCARD
- KOREAN DOMESTIC
- BANRICOMPRAS
- MEEZA
- PAYPAK
- JAYWAN
- TPN
180 181 182 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 180 def brand_name @brand_name end |
#type ⇒ String
This field contains a 3-digit numeric value that indicates the card type within Cybersource eco-system. Possible values from BIN Lookup Service (based on availability and enablement):
000: Unsupported Card Type001: Visa002: Mastercard003: American Express004: Discover005: Diners Club007: JCB036: Cartes Bancaire042: Maestro054: Elo058: Carnet060: MADA061: RuPay062: China UnionPay064: Prompt Card067: Meeza068: PayPak070: EFTPOS081: Jaywan082: TPN Glossary of possible values in the payments ecosystem:001: Visa002: Mastercard003: American Express004: Discover005: Diners Club006: Carte Blanche007: JCB008: Optima009: GE Private Label010: Beneficial Private Label011: Twinpay Credit Card012: Twinpay Debit Card013: Walmart014: EnRoute015: Lowe's Consumer016: Home Depot Consumer017: MBNA018: Dick's Sportwear019: Casual Corner020: Sears021: JAL023: Disney Card024: Switch/Solo025: Sam's Club Consumer026: Sam's Club Business027: Nico's028: Paymentech Bill Me Later029: Bebe030: Restoration Hardware031: Delta Online032: Solo033: Visa Electron034: Dankort035: Laser036: Cartes Bancaire037: Carta Si040: UATP041: HOUSEHOLD042: Maestro043: GE MONEY044: Korean Cards045: Style Cards046: J.Crew047: Payeasecn eWallet048: Payeasecn Bank Transfer049: Meijer050: Hipercard051: Aura052: Redecard053: Orico Card054: Elo055: Capital One Private Label057: Costco Private Label058: Carnet059: ValueLink060: MADA061: RuPay062: China UnionPay063: Falabella Private Label064: Prompt Card065: Korean Domestic066: Banricompras067: Meeza068: PayPak070: EFTPOS071: Codensa072: Olimpica073: Colsubsidio074: Tuya075: Sodexo076: Naranja077: Cabal078: DINELCO079: PANAL080: EPM081: Jaywan082: TPN
115 116 117 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 115 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
233 234 235 236 237 238 239 240 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 233 def self.from_element(root) type = XmlUtilities.from_element(root, 'type', String) brand_name = XmlUtilities.from_element(root, 'brandName', String) new(type: type, brand_name: brand_name, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 213 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP brand_name = hash.key?('brandName') ? hash['brandName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Brand.new(type: type, brand_name: brand_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
183 184 185 186 187 188 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 183 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['brand_name'] = 'brandName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
199 200 201 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 199 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
191 192 193 194 195 196 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 191 def self.optionals %w[ type brand_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
261 262 263 264 265 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 261 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, brand_name: #{@brand_name.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
254 255 256 257 258 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 254 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, brand_name: #{@brand_name}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/cyber_source_merged_spec/models/brand.rb', line 242 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'brandName', brand_name) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |