Class: CyberSourceMergedSpec::Brand28
- Defined in:
- lib/cyber_source_merged_spec/models/brand28.rb
Overview
Brand28 Model.
Instance Attribute Summary collapse
-
#brand_name ⇒ String
This field contains the card brand name.
-
#type ⇒ String
Three-digit value that indicates the card type.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, brand_name: SKIP, additional_properties: nil) ⇒ Brand28
constructor
A new instance of Brand28.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, brand_name: SKIP, additional_properties: nil) ⇒ Brand28
Returns a new instance of Brand28.
226 227 228 229 230 231 232 233 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 226 def initialize(type: SKIP, brand_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @brand_name = brand_name unless brand_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#brand_name ⇒ String
This field contains the card brand name. Some of the possible values (not an exhaustive list) are -
- VISA
- MASTERCARD
- AMERICAN EXPRESS
- DISCOVER
- DINERS CLUB
- CARTE BLANCHE
- JCB
- OPTIMA
- TWINPAY CREDIT CARD
- TWINPAY DEBIT CARD
- WALMART
- ENROUTE
- LOWES CONSUMER
- HOME DEPOT CONSUMER
- MBNA
- DICKS SPORTWEAR
- CASUAL CORNER
- SEARS
- JAL
- DISNEY CARD
- SWITCH/SOLO
- SAMS CLUB CONSUMER
- SAMS CLUB BUSINESS
- NICOS HOUSE CARD
- BEBE
- RESTORATION HARDWARE
- DELTA ONLINE
- SOLO
- VISA ELECTRON
- DANKORT
- LASER
- CARTE BANCAIRE
- CARTA SI
- ENCODED ACCOUNT
- UATP
- HOUSEHOLD
- MAESTRO
- GE CAPITAL
- KOREAN CARDS
- STYLE CARDS
- JCREW
- MEIJER
- HIPERCARD
- AURA
- REDECARD
- ORICO HOUSE CARD
- ELO
- CAPITAL ONE PRIVATE LABEL
- CARNET
- RUPAY
- CHINA UNION PAY
- FALABELLA PRIVATE LABEL
- PROMPTCARD
- KOREAN DOMESTIC
- BANRICOMPRAS
203 204 205 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 203 def brand_name @brand_name end |
#type ⇒ String
Three-digit value that indicates the card type. IMPORTANT It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type. Possible values:
001: Visa. Use card type value001for Visa Electron.002: Mastercard, Eurocard, which is a European regional brand of Mastercard.003: American Express004: Discover005: Diners Club006: Carte Blanche007: JCB008: Optima009: GE Private Label010: Beneficial Private Label011: Twinpay Credit Card012: Twinpay Debit Card013: WalMart014: Enroute015: Lowe's Consumer016: Home Depot Consumer017: MBNA018: Dick's Sportswear019: Casual Corner020: Sears021: JAL023: Disney Card024: Maestro (UK Domestic)[^1]025: Sam's Club Consumer026: Sam's Club Business027: Nico's028: Paymentech Bill Me Later029: Bebe030: Restoration Hardware031: Delta Online032: Solo033: Visa Electron. Do not use this value. Use001for all Visa card types.034: Dankort035: Laser036: Cartes Bancaires037: Carta Si038: Pinless Debit039: Encoded account number040: UATP041: HOUSEHOLD042: Maestro (International)[^1]043: GE MONEY044: Korean Cards045: Style Cards046: JCrew047: Payeasecn eWallet048: Payeasecn Bank Transfer049: Meijer050: Hipercard051: Aura052: Redecard053: Orico card054: Elo055: Capitol One Private Label056: Carnet057: Costco Private Label058: Carnet059: ValueLink060: MADA061: RuPay062: China UnionPay063: Falabella Private Label064: Prompt Card065: Korean Domestic066: Banricompras067: MEEZA068: PayPak070: EFTPOS071: Codensa072: Olimpica073: Colsubsidio074: Tuya075: Sodexo076: Naranja077: Cabal078: DINELCO079: PANAL080: EPM081: Jaywan [^1]: For this card type, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include thepaymentInformation.card.typeorpaymentInformation.tokenizedCard.typefield in a request for an authorization or a stand-alone credit. [^4]: For this card type, you must include thepaymentInformation.card.typein your request for any payer authentication services.
Used by
Authorization Required for Carte Blanche and JCB. Optional for all other card types.
Card Present reply
This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message. Returned by the Credit service. This reply field is only supported by the following processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX
Google Pay transactions
For PAN-based Google Pay transactions, this field is returned in the API response.
GPX
This field only supports transactions from the following card types:
- Visa
- Mastercard
- AMEX
- Discover
- Diners
- JCB
- Union Pay International
143 144 145 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 143 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
256 257 258 259 260 261 262 263 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 256 def self.from_element(root) type = XmlUtilities.from_element(root, 'type', String) brand_name = XmlUtilities.from_element(root, 'brandName', String) new(type: type, brand_name: brand_name, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 236 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP brand_name = hash.key?('brandName') ? hash['brandName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Brand28.new(type: type, brand_name: brand_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
206 207 208 209 210 211 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 206 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['brand_name'] = 'brandName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
222 223 224 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 222 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
214 215 216 217 218 219 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 214 def self.optionals %w[ type brand_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
284 285 286 287 288 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 284 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, brand_name: #{@brand_name.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
277 278 279 280 281 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 277 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, brand_name: #{@brand_name}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
265 266 267 268 269 270 271 272 273 274 |
# File 'lib/cyber_source_merged_spec/models/brand28.rb', line 265 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'brandName', brand_name) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |