Class: CyberSourceMergedSpec::CardArt
- Defined in:
- lib/cyber_source_merged_spec/models/card_art.rb
Overview
CardArt Model.
Instance Attribute Summary collapse
-
#combined_asset ⇒ CombinedAsset6
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(combined_asset: SKIP, additional_properties: nil) ⇒ CardArt
constructor
A new instance of CardArt.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(combined_asset: SKIP, additional_properties: nil) ⇒ CardArt
Returns a new instance of CardArt.
35 36 37 38 39 40 41 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 35 def initialize(combined_asset: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @combined_asset = combined_asset unless combined_asset == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#combined_asset ⇒ CombinedAsset6
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 14 def combined_asset @combined_asset end |
Class Method Details
.from_element(root) ⇒ Object
62 63 64 65 66 67 68 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 62 def self.from_element(root) combined_asset = XmlUtilities.from_element(root, 'CombinedAsset6', CombinedAsset6) new(combined_asset: combined_asset, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. combined_asset = CombinedAsset6.from_hash(hash['combinedAsset']) if hash['combinedAsset'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CardArt.new(combined_asset: combined_asset, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['combined_asset'] = 'combinedAsset' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 24 def self.optionals %w[ combined_asset ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} combined_asset: #{@combined_asset.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} combined_asset: #{@combined_asset}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/card_art.rb', line 70 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'CombinedAsset6', combined_asset) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |