Class: CyberSourceMergedSpec::ClientReferenceInformation76
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ClientReferenceInformation76
- Defined in:
- lib/cyber_source_merged_spec/models/client_reference_information76.rb
Overview
ClientReferenceInformation76 Model.
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the Connection Method client (such as Virtual Terminal or SOAP Toolkit API) that the merchant uses to send a transaction request to CyberSource.
-
#application_user ⇒ String
The entity that is responsible for running the transaction and submitting the processing request to CyberSource.
-
#code ⇒ String
Merchant-generated order reference or tracking number.
-
#partner ⇒ Partner34
The entity that is responsible for running the transaction and submitting the processing request to CyberSource.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, application_name: SKIP, application_user: SKIP, partner: SKIP, additional_properties: nil) ⇒ ClientReferenceInformation76
constructor
A new instance of ClientReferenceInformation76.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, application_name: SKIP, application_user: SKIP, partner: SKIP, additional_properties: nil) ⇒ ClientReferenceInformation76
Returns a new instance of ClientReferenceInformation76.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 76 def initialize(code: SKIP, application_name: SKIP, application_user: SKIP, partner: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @application_name = application_name unless application_name == SKIP @application_user = application_user unless application_user == SKIP @partner = partner unless partner == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#application_name ⇒ String
The name of the Connection Method client (such as Virtual Terminal or SOAP Toolkit API) that the merchant uses to send a transaction request to CyberSource.
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 37 def application_name @application_name end |
#application_user ⇒ String
The entity that is responsible for running the transaction and submitting the processing request to CyberSource. This could be a person, a system, or a connection method.
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 43 def application_user @application_user end |
#code ⇒ String
Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.
Used by
Authorization Required field.
PIN Debit
Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed. Required field for all PIN Debit requests (purchase, credit, and reversal).
FDC Nashville Global
Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports.
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 31 def code @code end |
#partner ⇒ Partner34
The entity that is responsible for running the transaction and submitting the processing request to CyberSource. This could be a person, a system, or a connection method.
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 49 def partner @partner end |
Class Method Details
.from_element(root) ⇒ Object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 115 def self.from_element(root) code = XmlUtilities.from_element(root, 'code', String) application_name = XmlUtilities.from_element(root, 'applicationName', String) application_user = XmlUtilities.from_element(root, 'applicationUser', String) partner = XmlUtilities.from_element(root, 'Partner34', Partner34) new(code: code, application_name: application_name, application_user: application_user, partner: partner, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP application_name = hash.key?('applicationName') ? hash['applicationName'] : SKIP application_user = hash.key?('applicationUser') ? hash['applicationUser'] : SKIP partner = Partner34.from_hash(hash['partner']) if hash['partner'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ClientReferenceInformation76.new(code: code, application_name: application_name, application_user: application_user, partner: partner, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
52 53 54 55 56 57 58 59 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 52 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['application_name'] = 'applicationName' @_hash['application_user'] = 'applicationUser' @_hash['partner'] = 'partner' @_hash end |
.nullables ⇒ Object
An array for nullable fields
72 73 74 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 72 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 62 def self.optionals %w[ code application_name application_user partner ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
154 155 156 157 158 159 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 154 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, application_name: #{@application_name.inspect},"\ " application_user: #{@application_user.inspect}, partner: #{@partner.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
146 147 148 149 150 151 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 146 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, application_name: #{@application_name}, application_user:"\ " #{@application_user}, partner: #{@partner}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/cyber_source_merged_spec/models/client_reference_information76.rb', line 130 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'code', code) XmlUtilities.add_as_subelement(doc, root, 'applicationName', application_name) XmlUtilities.add_as_subelement(doc, root, 'applicationUser', application_user) XmlUtilities.add_as_subelement(doc, root, 'Partner34', partner) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |