Class: CyberSourceMergedSpec::ConsumerAuthentication1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ConsumerAuthentication1
- Defined in:
- lib/cyber_source_merged_spec/models/consumer_authentication1.rb
Overview
ConsumerAuthentication1 Model.
Instance Attribute Summary collapse
-
#cavv ⇒ String
Cardholder authentication verification value (CAVV).
-
#strong_authentication ⇒ StrongAuthentication4
Cardholder authentication verification value (CAVV).
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cavv: SKIP, strong_authentication: SKIP, additional_properties: nil) ⇒ ConsumerAuthentication1
constructor
A new instance of ConsumerAuthentication1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cavv: SKIP, strong_authentication: SKIP, additional_properties: nil) ⇒ ConsumerAuthentication1
Returns a new instance of ConsumerAuthentication1.
49 50 51 52 53 54 55 56 57 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 49 def initialize(cavv: SKIP, strong_authentication: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @cavv = cavv unless cavv == SKIP @strong_authentication = strong_authentication unless strong_authentication == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#cavv ⇒ String
Cardholder authentication verification value (CAVV).
Conditional: this field is mandatory if the transaction is using either a
Visa or Visa Electron card, and if the commerce indicator is = VBV.
If in hexabinary format, length of field value must be =40.
If in base64 format, length of field must be =28.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 18 def cavv @cavv end |
#strong_authentication ⇒ StrongAuthentication4
Cardholder authentication verification value (CAVV).
Conditional: this field is mandatory if the transaction is using either a
Visa or Visa Electron card, and if the commerce indicator is = VBV.
If in hexabinary format, length of field value must be =40.
If in base64 format, length of field must be =28.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 26 def strong_authentication @strong_authentication end |
Class Method Details
.from_element(root) ⇒ Object
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 81 def self.from_element(root) cavv = XmlUtilities.from_element(root, 'cavv', String) strong_authentication = XmlUtilities.from_element(root, 'StrongAuthentication4', StrongAuthentication4) new(cavv: cavv, strong_authentication: strong_authentication, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cavv = hash.key?('cavv') ? hash['cavv'] : SKIP strong_authentication = StrongAuthentication4.from_hash(hash['strongAuthentication']) if hash['strongAuthentication'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConsumerAuthentication1.new(cavv: cavv, strong_authentication: strong_authentication, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['cavv'] = 'cavv' @_hash['strong_authentication'] = 'strongAuthentication' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 37 def self.optionals %w[ cavv strong_authentication ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 112 def inspect class_name = self.class.name.split('::').last "<#{class_name} cavv: #{@cavv.inspect}, strong_authentication:"\ " #{@strong_authentication.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 105 def to_s class_name = self.class.name.split('::').last "<#{class_name} cavv: #{@cavv}, strong_authentication: #{@strong_authentication},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication1.rb', line 92 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'cavv', cavv) XmlUtilities.add_as_subelement(doc, root, 'StrongAuthentication4', strong_authentication) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |