Class: CyberSourceMergedSpec::ConsumerAuthenticationInformation10
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ConsumerAuthenticationInformation10
- Defined in:
- lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb
Overview
ConsumerAuthenticationInformation10 Model.
Instance Attribute Summary collapse
-
#acs_operator_id ⇒ String
Directory Server assigned ACS identifier.
-
#acs_reference_number ⇒ String
Unique identifier assigned by the EMVCo Secretariat upon Testing and Approval.
-
#acs_rendering_type ⇒ String
Identifies the UI Type the ACS will use to complete the challenge.
-
#acs_transaction_id ⇒ String
Unique transaction identifier assigned by the ACS to identify a single transaction.
-
#authentication_result ⇒ String
Raw authentication data that comes from the cardissuing bank.
-
#authentication_status_msg ⇒ String
Message that explains the authenticationResult reply field.
-
#authentication_transaction_context_id ⇒ String
Payer authentication transaction identifier passed to link the validation and authorization calls.
-
#authentication_transaction_id ⇒ String
Payer authentication transaction identifier is used to link the check enrollment and validate authentication messages.
-
#authentication_type ⇒ String
Indicates the type of authentication that will be used to challenge the card holder.
-
#authorization_payload ⇒ String
The Base64 encoded JSON Payload of CB specific Authorization Values returned in the challenge Flow.
-
#cavv ⇒ String
Unique identifier generated by the card-issuing bank for Visa, American Express, JCB, Diners Club, and Discover transactions after the customer is authenticated.
-
#cavv_algorithm ⇒ String
Field that is returned only when the CAVV is generated, which occurs when paresStatus contains the values Y (successful authentication) or A (attempted authentication).
-
#challenge_cancel_code ⇒ String
An indicator as to why the transaction was canceled.
-
#directory_server_error_code ⇒ String
The directory server error code indicating a problem with this transaction.
-
#directory_server_error_description ⇒ String
Directory server text and additional detail about the error for this transaction.
-
#directory_server_transaction_id ⇒ String
The Directory Server Transaction ID is generated by the Mastercard Directory Server during the authentication transaction and passed back to the merchant with the authentication results.
-
#eci ⇒ String
Note This field applies only to non-U.S-issued cards.
-
#eci_raw ⇒ String
ECI value that can be returned for Visa, Mastercard, American Express, JCB, Diners Club, and Discover.
-
#effective_authentication_type ⇒ String
This field describes the type of 3DS transaction flow that took place.
-
#indicator ⇒ String
Indicator used to differentiate Internet transactions from other types.
-
#interaction_counter ⇒ String
Indicates the number of authentication cycles attempted by the cardholder and is tracked by the Issuing Banks ACS.Example: if customer gets the challenge window and enter in their one time password and hit submit then that interaction counter should just be 1.
-
#pares_status ⇒ String
Raw result of the authentication check.
-
#sdk_transaction_id ⇒ String
SDK unique transaction identifier that is generated on each new transaction.
-
#specification_version ⇒ String
This field contains the 3D Secure version that was used to process the transaction.
-
#three_ds_server_transaction_id ⇒ String
Unique transaction identifier assigned by the 3DS Server to identify a single transaction.
-
#transaction_token ⇒ String
Web based token used to authenticate consumer with Rupay authentication provider.
-
#ucaf_authentication_data ⇒ String
AAV is a unique identifier generated by the card-issuing bank for Mastercard Identity Check transactions after the customer is authenticated.
-
#ucaf_collection_indicator ⇒ String
For enroll, Returned only for Mastercard transactions.
-
#white_list_status ⇒ String
Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor.
-
#white_list_status_source ⇒ String
This data element will be populated by the system setting Whitelist Status.
-
#xid ⇒ String
Transaction identifier generated by CyberSource for successful enrollment or validation checks.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(acs_rendering_type: SKIP, acs_reference_number: SKIP, acs_transaction_id: SKIP, acs_operator_id: SKIP, authentication_result: SKIP, authentication_type: SKIP, authentication_status_msg: SKIP, authentication_transaction_id: SKIP, authentication_transaction_context_id: SKIP, transaction_token: SKIP, authorization_payload: SKIP, cavv: SKIP, cavv_algorithm: SKIP, challenge_cancel_code: SKIP, directory_server_error_code: SKIP, directory_server_error_description: SKIP, effective_authentication_type: SKIP, indicator: SKIP, interaction_counter: SKIP, eci: SKIP, eci_raw: SKIP, pares_status: SKIP, sdk_transaction_id: SKIP, specification_version: SKIP, three_ds_server_transaction_id: SKIP, ucaf_authentication_data: SKIP, ucaf_collection_indicator: SKIP, white_list_status: SKIP, white_list_status_source: SKIP, xid: SKIP, directory_server_transaction_id: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationInformation10
constructor
A new instance of ConsumerAuthenticationInformation10.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(acs_rendering_type: SKIP, acs_reference_number: SKIP, acs_transaction_id: SKIP, acs_operator_id: SKIP, authentication_result: SKIP, authentication_type: SKIP, authentication_status_msg: SKIP, authentication_transaction_id: SKIP, authentication_transaction_context_id: SKIP, transaction_token: SKIP, authorization_payload: SKIP, cavv: SKIP, cavv_algorithm: SKIP, challenge_cancel_code: SKIP, directory_server_error_code: SKIP, directory_server_error_description: SKIP, effective_authentication_type: SKIP, indicator: SKIP, interaction_counter: SKIP, eci: SKIP, eci_raw: SKIP, pares_status: SKIP, sdk_transaction_id: SKIP, specification_version: SKIP, three_ds_server_transaction_id: SKIP, ucaf_authentication_data: SKIP, ucaf_collection_indicator: SKIP, white_list_status: SKIP, white_list_status_source: SKIP, xid: SKIP, directory_server_transaction_id: SKIP, additional_properties: nil) ⇒ ConsumerAuthenticationInformation10
Returns a new instance of ConsumerAuthenticationInformation10.
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 397 def initialize(acs_rendering_type: SKIP, acs_reference_number: SKIP, acs_transaction_id: SKIP, acs_operator_id: SKIP, authentication_result: SKIP, authentication_type: SKIP, authentication_status_msg: SKIP, authentication_transaction_id: SKIP, authentication_transaction_context_id: SKIP, transaction_token: SKIP, authorization_payload: SKIP, cavv: SKIP, cavv_algorithm: SKIP, challenge_cancel_code: SKIP, directory_server_error_code: SKIP, directory_server_error_description: SKIP, effective_authentication_type: SKIP, indicator: SKIP, interaction_counter: SKIP, eci: SKIP, eci_raw: SKIP, pares_status: SKIP, sdk_transaction_id: SKIP, specification_version: SKIP, three_ds_server_transaction_id: SKIP, ucaf_authentication_data: SKIP, ucaf_collection_indicator: SKIP, white_list_status: SKIP, white_list_status_source: SKIP, xid: SKIP, directory_server_transaction_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @acs_rendering_type = acs_rendering_type unless acs_rendering_type == SKIP @acs_reference_number = acs_reference_number unless acs_reference_number == SKIP @acs_transaction_id = acs_transaction_id unless acs_transaction_id == SKIP @acs_operator_id = acs_operator_id unless acs_operator_id == SKIP @authentication_result = authentication_result unless authentication_result == SKIP @authentication_type = authentication_type unless authentication_type == SKIP unless authentication_status_msg == SKIP @authentication_status_msg = authentication_status_msg end unless authentication_transaction_id == SKIP @authentication_transaction_id = authentication_transaction_id end unless authentication_transaction_context_id == SKIP @authentication_transaction_context_id = authentication_transaction_context_id end @transaction_token = transaction_token unless transaction_token == SKIP @authorization_payload = unless == SKIP @cavv = cavv unless cavv == SKIP @cavv_algorithm = cavv_algorithm unless cavv_algorithm == SKIP @challenge_cancel_code = challenge_cancel_code unless challenge_cancel_code == SKIP unless directory_server_error_code == SKIP @directory_server_error_code = directory_server_error_code end unless directory_server_error_description == SKIP @directory_server_error_description = directory_server_error_description end unless effective_authentication_type == SKIP @effective_authentication_type = effective_authentication_type end @indicator = indicator unless indicator == SKIP @interaction_counter = interaction_counter unless interaction_counter == SKIP @eci = eci unless eci == SKIP @eci_raw = eci_raw unless eci_raw == SKIP @pares_status = pares_status unless pares_status == SKIP @sdk_transaction_id = sdk_transaction_id unless sdk_transaction_id == SKIP @specification_version = specification_version unless specification_version == SKIP unless three_ds_server_transaction_id == SKIP @three_ds_server_transaction_id = three_ds_server_transaction_id end @ucaf_authentication_data = ucaf_authentication_data unless ucaf_authentication_data == SKIP unless ucaf_collection_indicator == SKIP @ucaf_collection_indicator = ucaf_collection_indicator end @white_list_status = white_list_status unless white_list_status == SKIP @white_list_status_source = white_list_status_source unless white_list_status_source == SKIP @xid = xid unless xid == SKIP unless directory_server_transaction_id == SKIP @directory_server_transaction_id = directory_server_transaction_id end @additional_properties = additional_properties end |
Instance Attribute Details
#acs_operator_id ⇒ String
Directory Server assigned ACS identifier.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 30 def acs_operator_id @acs_operator_id end |
#acs_reference_number ⇒ String
Unique identifier assigned by the EMVCo Secretariat upon Testing and Approval.
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 21 def acs_reference_number @acs_reference_number end |
#acs_rendering_type ⇒ String
Identifies the UI Type the ACS will use to complete the challenge. NOTE: Only available for App transactions using the Cardinal Mobile SDK.
16 17 18 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 16 def acs_rendering_type @acs_rendering_type end |
#acs_transaction_id ⇒ String
Unique transaction identifier assigned by the ACS to identify a single transaction.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 26 def acs_transaction_id @acs_transaction_id end |
#authentication_result ⇒ String
Raw authentication data that comes from the cardissuing bank. Primary authentication field that indicates if authentication was successful and if liability shift occurred. You should examine first the result of this field. This field contains one of these values:
-1: Invalid PARes.0: Successful validation.1: Cardholder is not participating, but the attempt to authenticate was recorded.6: Issuer unable to perform authentication.9: Cardholder did not complete authentication.
44 45 46 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 44 def authentication_result @authentication_result end |
#authentication_status_msg ⇒ String
Message that explains the authenticationResult reply field.
62 63 64 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 62 def authentication_status_msg @authentication_status_msg end |
#authentication_transaction_context_id ⇒ String
Payer authentication transaction identifier passed to link the validation and authorization calls.
73 74 75 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 73 def authentication_transaction_context_id @authentication_transaction_context_id end |
#authentication_transaction_id ⇒ String
Payer authentication transaction identifier is used to link the check enrollment and validate authentication messages. For Rupay, this field should be passed as request only for Resend OTP use case.
68 69 70 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 68 def authentication_transaction_id @authentication_transaction_id end |
#authentication_type ⇒ String
Indicates the type of authentication that will be used to challenge the card holder. Possible Values: 01 - Static 02 - Dynamic 03 - OOB (Out of Band) 04 - Decoupled 20 - OTP hosted at merchant end. (Rupay S2S flow) NOTE: EMV 3-D Secure version 2.1.0 supports values 01-03. Version 2.2.0 supports values 01-04. Decoupled authentication is not supported at this time.
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 58 def authentication_type @authentication_type end |
#authorization_payload ⇒ String
The Base64 encoded JSON Payload of CB specific Authorization Values returned in the challenge Flow
83 84 85 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 83 def @authorization_payload end |
#cavv ⇒ String
Unique identifier generated by the card-issuing bank for Visa, American Express, JCB, Diners Club, and Discover transactions after the customer is authenticated. The value is in base64. When you request the card authorization service, CyberSource automatically converts the value, not the field name, to the format required by your payment processor.
93 94 95 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 93 def cavv @cavv end |
#cavv_algorithm ⇒ String
Field that is returned only when the CAVV is generated, which occurs when
paresStatus
contains the values Y (successful authentication) or A (attempted
authentication). If
you use the ATOS processor, send the value of this field in the
cavv_algorithm request field of the
authorization service. This field contains one of these values:
2: Visa, American Express, JCB, Diners Club, and Discover3: Mastercard
105 106 107 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 105 def cavv_algorithm @cavv_algorithm end |
#challenge_cancel_code ⇒ String
An indicator as to why the transaction was canceled. Possible Values:
01: Cardholder selected Cancel.02: Reserved for future EMVCo use (values invalid until defined by EMVCo).03: Transaction Timed Out—Decoupled Authentication04: Transaction timed out at ACS—other timeouts05: Transaction Timed out at ACS - First CReq not received by ACS06: Transaction Error07: Unknown08: Transaction Timed Out at SDK
119 120 121 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 119 def challenge_cancel_code @challenge_cancel_code end |
#directory_server_error_code ⇒ String
The directory server error code indicating a problem with this transaction. Note - Max Length of this field is typically 3 characters.
124 125 126 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 124 def directory_server_error_code @directory_server_error_code end |
#directory_server_error_description ⇒ String
Directory server text and additional detail about the error for this transaction.
129 130 131 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 129 def directory_server_error_description @directory_server_error_description end |
#directory_server_transaction_id ⇒ String
The Directory Server Transaction ID is generated by the Mastercard Directory Server during the authentication transaction and passed back to the merchant with the authentication results. For Cybersource Through Visanet Gateway: The value for this field corresponds to the following data in the TC 33 capture file3: Record: CP01 TCR7, Position: 114-149, Field: MC AVV Verification—Directory Server Transaction ID
313 314 315 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 313 def directory_server_transaction_id @directory_server_transaction_id end |
#eci ⇒ String
Note This field applies only to non-U.S-issued cards. For enroll, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions when the card is not enrolled. For more information, see "Interpreting the Reply," page 22. If you are not using the CyberSource payment services, you must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values:
06: The card can be enrolled. Liability shift.07: The card cannot be enrolled. No liability shift. For validate, Numeric electronic commerce indicator (ECI) returned only for Visa, American Express, JCB, Diners Club, and Discover transactions. The field is absent when authentication fails. You must send this value to your payment processor in the subsequent request for card authorization. This field contains one of these values:05: Successful authentication06: Authentication attempted07: Failed authentication (No response from the merchant because of a problem.)
209 210 211 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 209 def eci @eci end |
#eci_raw ⇒ String
ECI value that can be returned for Visa, Mastercard, American Express,
JCB, Diners Club, and Discover.
The field is absent when authentication fails. If your payment processor
is Streamline, you must pass the
value of this field instead of the value of eci or
ucafCollectionIndicator.
This field can contain one of these values:
01: Authentication attempted (Mastercard)02: Successful authentication (Mastercard)05: Successful authentication (Visa, American Express, JCB, Diners Club, and Discover)06: Authentication attempted (Visa, American Express, JCB, Diners Club, and Discover)
225 226 227 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 225 def eci_raw @eci_raw end |
#effective_authentication_type ⇒ String
This field describes the type of 3DS transaction flow that took place. It can be one of three possible flows; CH - Challenge FR - Frictionless FD - Frictionless with delegation, (challenge not generated by the issuer but by the scheme on behalf of the issuer).
138 139 140 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 138 def effective_authentication_type @effective_authentication_type end |
#indicator ⇒ String
Indicator used to differentiate Internet transactions from other types. The authentication failed if this field is not returned. For Visa, if your payment processor is Streamline, Barclays, AIBMS, or FDC Germany, you receive the value vbv_failure instead of internet when eci is 07. The value of this field is passed automatically to the authorization service if you request the services together. This field contains one of these values:
aesk: American Express SafeKey authentication verified successfully.aesk_attempted: Card not enrolled in American Express SafeKey, but the attempt to authenticate was recorded.dipb: Discover ProtectBuy authentication verified successfully.dipb_attempted: Card not enrolled in Discover ProtectBuy, but the attempt to authenticate was recorded.internet: Authentication was not verified successfully.js: J/Secure authentication verified successfully.js_attempted: Card not enrolled in J/Secure, but the attempt to authenticate was recorded.moto: Mail or telephone order.pb_attempted: Card not enrolled in Diners Club ProtectBuy, but the attempt to authenticate was recorded.recurring: Recurring transaction.spa: Mastercard Identity Check authentication verified successfully.spa_failure: Mastercard Identity Check failed authentication.vbv: Visa Secure authentication verified successfully.vbv_attempted: Card not enrolled in Visa Secure, but the attempt to authenticate was recorded.vbv_failure: Visa Secure authentication unavailable.
169 170 171 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 169 def indicator @indicator end |
#interaction_counter ⇒ String
Indicates the number of authentication cycles attempted by the cardholder and is tracked by the Issuing Banks ACS.Example: if customer gets the challenge window and enter in their one time password and hit submit then that interaction counter should just be 1. When customer gets the challenge window and the bank asks if they want to have the one time password sent to their phone or their email and they have to choose before going to the next screen to enter in their one time password then this interaction count would be 2. One for the selection of how they want the one time password delivered and another with them actually entering in the one time password and hitting the submit button.
183 184 185 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 183 def interaction_counter @interaction_counter end |
#pares_status ⇒ String
Raw result of the authentication check. If you are configured for Asia, Middle East, and Africa Gateway Processing, you need to send the value of this field in your authorization request. This field can contain one of these values:
A: Proof of authentication attempt was generated.N: Customer failed or canceled authentication. Transaction denied.U: Authentication not completed regardless of the reason.Y: Customer was successfully authenticated.
237 238 239 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 237 def pares_status @pares_status end |
#sdk_transaction_id ⇒ String
SDK unique transaction identifier that is generated on each new transaction.
242 243 244 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 242 def sdk_transaction_id @sdk_transaction_id end |
#specification_version ⇒ String
This field contains the 3D Secure version that was used to process the transaction. For example: 2.2.0
247 248 249 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 247 def specification_version @specification_version end |
#three_ds_server_transaction_id ⇒ String
Unique transaction identifier assigned by the 3DS Server to identify a single transaction.
252 253 254 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 252 def three_ds_server_transaction_id @three_ds_server_transaction_id end |
#transaction_token ⇒ String
Web based token used to authenticate consumer with Rupay authentication provider.
78 79 80 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 78 def transaction_token @transaction_token end |
#ucaf_authentication_data ⇒ String
AAV is a unique identifier generated by the card-issuing bank for Mastercard Identity Check transactions after the customer is authenticated. The value is in base64. Include the data in the card authorization request.
259 260 261 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 259 def ucaf_authentication_data @ucaf_authentication_data end |
#ucaf_collection_indicator ⇒ String
For enroll, Returned only for Mastercard transactions. Indicates that authentication is not required because the customer is not enrolled. Add the value of this field to the authorization field ucaf_collection_indicator. This field can contain these values: 0, 1. For validate, Numeric electronic commerce indicator (ECI) returned only for Mastercard Identity Check transactions. The field is absent when authentication fails. You must send this value to your payment processor in the request for card authorization. This field contain one of these values:
0: Authentication data not collected, and customer authentication was not completed.1: Authentication data not collected because customer authentication was not completed.2: Authentication data collected because customer completed authentication.
279 280 281 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 279 def ucaf_collection_indicator @ucaf_collection_indicator end |
#white_list_status ⇒ String
Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor. Possible Values: Y - 3DS Requestor is whitelisted by cardholder N - 3DS Requestor is not whitelisted by cardholder
287 288 289 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 287 def white_list_status @white_list_status end |
#white_list_status_source ⇒ String
This data element will be populated by the system setting Whitelist Status. Possible Values: 01 - 3DS/ Server/ 02 – DS/03 - ACS
292 293 294 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 292 def white_list_status_source @white_list_status_source end |
#xid ⇒ String
Transaction identifier generated by CyberSource for successful enrollment or validation checks. Use this value, which is in base64, to match an outgoing PAReq with an incoming PARes. CyberSource forwards the XID with the card authorization service to these payment processors in these cases:
- Barclays
- Streamline (when the ecommerceIndicator
=spa)
303 304 305 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 303 def xid @xid end |
Class Method Details
.from_element(root) ⇒ Object
585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 585 def self.from_element(root) acs_rendering_type = XmlUtilities.from_element(root, 'acsRenderingType', String) acs_reference_number = XmlUtilities.from_element(root, 'acsReferenceNumber', String) acs_transaction_id = XmlUtilities.from_element(root, 'acsTransactionId', String) acs_operator_id = XmlUtilities.from_element(root, 'acsOperatorID', String) authentication_result = XmlUtilities.from_element(root, 'authenticationResult', String) authentication_type = XmlUtilities.from_element(root, 'authenticationType', String) authentication_status_msg = XmlUtilities.from_element( root, 'authenticationStatusMsg', String ) authentication_transaction_id = XmlUtilities.from_element( root, 'authenticationTransactionId', String ) authentication_transaction_context_id = XmlUtilities.from_element( root, 'authenticationTransactionContextId', String ) transaction_token = XmlUtilities.from_element(root, 'transactionToken', String) = XmlUtilities.from_element(root, 'authorizationPayload', String) cavv = XmlUtilities.from_element(root, 'cavv', String) cavv_algorithm = XmlUtilities.from_element(root, 'cavvAlgorithm', String) challenge_cancel_code = XmlUtilities.from_element(root, 'challengeCancelCode', String) directory_server_error_code = XmlUtilities.from_element( root, 'directoryServerErrorCode', String ) directory_server_error_description = XmlUtilities.from_element( root, 'directoryServerErrorDescription', String ) effective_authentication_type = XmlUtilities.from_element( root, 'effectiveAuthenticationType', String ) indicator = XmlUtilities.from_element(root, 'indicator', String) interaction_counter = XmlUtilities.from_element(root, 'interactionCounter', String) eci = XmlUtilities.from_element(root, 'eci', String) eci_raw = XmlUtilities.from_element(root, 'eciRaw', String) pares_status = XmlUtilities.from_element(root, 'paresStatus', String) sdk_transaction_id = XmlUtilities.from_element(root, 'sdkTransactionId', String) specification_version = XmlUtilities.from_element(root, 'specificationVersion', String) three_ds_server_transaction_id = XmlUtilities.from_element( root, 'threeDSServerTransactionId', String ) ucaf_authentication_data = XmlUtilities.from_element( root, 'ucafAuthenticationData', String ) ucaf_collection_indicator = XmlUtilities.from_element( root, 'ucafCollectionIndicator', String ) white_list_status = XmlUtilities.from_element(root, 'whiteListStatus', String) white_list_status_source = XmlUtilities.from_element( root, 'whiteListStatusSource', String ) xid = XmlUtilities.from_element(root, 'xid', String) directory_server_transaction_id = XmlUtilities.from_element( root, 'directoryServerTransactionId', String ) new(acs_rendering_type: acs_rendering_type, acs_reference_number: acs_reference_number, acs_transaction_id: acs_transaction_id, acs_operator_id: acs_operator_id, authentication_result: authentication_result, authentication_type: authentication_type, authentication_status_msg: authentication_status_msg, authentication_transaction_id: authentication_transaction_id, authentication_transaction_context_id: authentication_transaction_context_id, transaction_token: transaction_token, authorization_payload: , cavv: cavv, cavv_algorithm: cavv_algorithm, challenge_cancel_code: challenge_cancel_code, directory_server_error_code: directory_server_error_code, directory_server_error_description: directory_server_error_description, effective_authentication_type: effective_authentication_type, indicator: indicator, interaction_counter: interaction_counter, eci: eci, eci_raw: eci_raw, pares_status: pares_status, sdk_transaction_id: sdk_transaction_id, specification_version: specification_version, three_ds_server_transaction_id: three_ds_server_transaction_id, ucaf_authentication_data: ucaf_authentication_data, ucaf_collection_indicator: ucaf_collection_indicator, white_list_status: white_list_status, white_list_status_source: white_list_status_source, xid: xid, directory_server_transaction_id: directory_server_transaction_id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 483 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. acs_rendering_type = hash.key?('acsRenderingType') ? hash['acsRenderingType'] : SKIP acs_reference_number = hash.key?('acsReferenceNumber') ? hash['acsReferenceNumber'] : SKIP acs_transaction_id = hash.key?('acsTransactionId') ? hash['acsTransactionId'] : SKIP acs_operator_id = hash.key?('acsOperatorID') ? hash['acsOperatorID'] : SKIP authentication_result = hash.key?('authenticationResult') ? hash['authenticationResult'] : SKIP authentication_type = hash.key?('authenticationType') ? hash['authenticationType'] : SKIP authentication_status_msg = hash.key?('authenticationStatusMsg') ? hash['authenticationStatusMsg'] : SKIP authentication_transaction_id = hash.key?('authenticationTransactionId') ? hash['authenticationTransactionId'] : SKIP authentication_transaction_context_id = hash.key?('authenticationTransactionContextId') ? hash['authenticationTransactionContextId'] : SKIP transaction_token = hash.key?('transactionToken') ? hash['transactionToken'] : SKIP = hash.key?('authorizationPayload') ? hash['authorizationPayload'] : SKIP cavv = hash.key?('cavv') ? hash['cavv'] : SKIP cavv_algorithm = hash.key?('cavvAlgorithm') ? hash['cavvAlgorithm'] : SKIP challenge_cancel_code = hash.key?('challengeCancelCode') ? hash['challengeCancelCode'] : SKIP directory_server_error_code = hash.key?('directoryServerErrorCode') ? hash['directoryServerErrorCode'] : SKIP directory_server_error_description = hash.key?('directoryServerErrorDescription') ? hash['directoryServerErrorDescription'] : SKIP effective_authentication_type = hash.key?('effectiveAuthenticationType') ? hash['effectiveAuthenticationType'] : SKIP indicator = hash.key?('indicator') ? hash['indicator'] : SKIP interaction_counter = hash.key?('interactionCounter') ? hash['interactionCounter'] : SKIP eci = hash.key?('eci') ? hash['eci'] : SKIP eci_raw = hash.key?('eciRaw') ? hash['eciRaw'] : SKIP pares_status = hash.key?('paresStatus') ? hash['paresStatus'] : SKIP sdk_transaction_id = hash.key?('sdkTransactionId') ? hash['sdkTransactionId'] : SKIP specification_version = hash.key?('specificationVersion') ? hash['specificationVersion'] : SKIP three_ds_server_transaction_id = hash.key?('threeDSServerTransactionId') ? hash['threeDSServerTransactionId'] : SKIP ucaf_authentication_data = hash.key?('ucafAuthenticationData') ? hash['ucafAuthenticationData'] : SKIP ucaf_collection_indicator = hash.key?('ucafCollectionIndicator') ? hash['ucafCollectionIndicator'] : SKIP white_list_status = hash.key?('whiteListStatus') ? hash['whiteListStatus'] : SKIP white_list_status_source = hash.key?('whiteListStatusSource') ? hash['whiteListStatusSource'] : SKIP xid = hash.key?('xid') ? hash['xid'] : SKIP directory_server_transaction_id = hash.key?('directoryServerTransactionId') ? hash['directoryServerTransactionId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ConsumerAuthenticationInformation10.new(acs_rendering_type: acs_rendering_type, acs_reference_number: acs_reference_number, acs_transaction_id: acs_transaction_id, acs_operator_id: acs_operator_id, authentication_result: authentication_result, authentication_type: authentication_type, authentication_status_msg: authentication_status_msg, authentication_transaction_id: authentication_transaction_id, authentication_transaction_context_id: authentication_transaction_context_id, transaction_token: transaction_token, authorization_payload: , cavv: cavv, cavv_algorithm: cavv_algorithm, challenge_cancel_code: challenge_cancel_code, directory_server_error_code: directory_server_error_code, directory_server_error_description: directory_server_error_description, effective_authentication_type: effective_authentication_type, indicator: indicator, interaction_counter: interaction_counter, eci: eci, eci_raw: eci_raw, pares_status: pares_status, sdk_transaction_id: sdk_transaction_id, specification_version: specification_version, three_ds_server_transaction_id: three_ds_server_transaction_id, ucaf_authentication_data: ucaf_authentication_data, ucaf_collection_indicator: ucaf_collection_indicator, white_list_status: white_list_status, white_list_status_source: white_list_status_source, xid: xid, directory_server_transaction_id: directory_server_transaction_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 316 def self.names @_hash = {} if @_hash.nil? @_hash['acs_rendering_type'] = 'acsRenderingType' @_hash['acs_reference_number'] = 'acsReferenceNumber' @_hash['acs_transaction_id'] = 'acsTransactionId' @_hash['acs_operator_id'] = 'acsOperatorID' @_hash['authentication_result'] = 'authenticationResult' @_hash['authentication_type'] = 'authenticationType' @_hash['authentication_status_msg'] = 'authenticationStatusMsg' @_hash['authentication_transaction_id'] = 'authenticationTransactionId' @_hash['authentication_transaction_context_id'] = 'authenticationTransactionContextId' @_hash['transaction_token'] = 'transactionToken' @_hash['authorization_payload'] = 'authorizationPayload' @_hash['cavv'] = 'cavv' @_hash['cavv_algorithm'] = 'cavvAlgorithm' @_hash['challenge_cancel_code'] = 'challengeCancelCode' @_hash['directory_server_error_code'] = 'directoryServerErrorCode' @_hash['directory_server_error_description'] = 'directoryServerErrorDescription' @_hash['effective_authentication_type'] = 'effectiveAuthenticationType' @_hash['indicator'] = 'indicator' @_hash['interaction_counter'] = 'interactionCounter' @_hash['eci'] = 'eci' @_hash['eci_raw'] = 'eciRaw' @_hash['pares_status'] = 'paresStatus' @_hash['sdk_transaction_id'] = 'sdkTransactionId' @_hash['specification_version'] = 'specificationVersion' @_hash['three_ds_server_transaction_id'] = 'threeDSServerTransactionId' @_hash['ucaf_authentication_data'] = 'ucafAuthenticationData' @_hash['ucaf_collection_indicator'] = 'ucafCollectionIndicator' @_hash['white_list_status'] = 'whiteListStatus' @_hash['white_list_status_source'] = 'whiteListStatusSource' @_hash['xid'] = 'xid' @_hash['directory_server_transaction_id'] = 'directoryServerTransactionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
393 394 395 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 393 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 356 def self.optionals %w[ acs_rendering_type acs_reference_number acs_transaction_id acs_operator_id authentication_result authentication_type authentication_status_msg authentication_transaction_id authentication_transaction_context_id transaction_token authorization_payload cavv cavv_algorithm challenge_cancel_code directory_server_error_code directory_server_error_description effective_authentication_type indicator interaction_counter eci eci_raw pares_status sdk_transaction_id specification_version three_ds_server_transaction_id ucaf_authentication_data ucaf_collection_indicator white_list_status white_list_status_source xid directory_server_transaction_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 785 def inspect class_name = self.class.name.split('::').last "<#{class_name} acs_rendering_type: #{@acs_rendering_type.inspect}, acs_reference_number:"\ " #{@acs_reference_number.inspect}, acs_transaction_id: #{@acs_transaction_id.inspect},"\ " acs_operator_id: #{@acs_operator_id.inspect}, authentication_result:"\ " #{@authentication_result.inspect}, authentication_type: #{@authentication_type.inspect},"\ " authentication_status_msg: #{@authentication_status_msg.inspect},"\ " authentication_transaction_id: #{@authentication_transaction_id.inspect},"\ " authentication_transaction_context_id: #{@authentication_transaction_context_id.inspect},"\ " transaction_token: #{@transaction_token.inspect}, authorization_payload:"\ " #{@authorization_payload.inspect}, cavv: #{@cavv.inspect}, cavv_algorithm:"\ " #{@cavv_algorithm.inspect}, challenge_cancel_code: #{@challenge_cancel_code.inspect},"\ " directory_server_error_code: #{@directory_server_error_code.inspect},"\ " directory_server_error_description: #{@directory_server_error_description.inspect},"\ " effective_authentication_type: #{@effective_authentication_type.inspect}, indicator:"\ " #{@indicator.inspect}, interaction_counter: #{@interaction_counter.inspect}, eci:"\ " #{@eci.inspect}, eci_raw: #{@eci_raw.inspect}, pares_status: #{@pares_status.inspect},"\ " sdk_transaction_id: #{@sdk_transaction_id.inspect}, specification_version:"\ " #{@specification_version.inspect}, three_ds_server_transaction_id:"\ " #{@three_ds_server_transaction_id.inspect}, ucaf_authentication_data:"\ " #{@ucaf_authentication_data.inspect}, ucaf_collection_indicator:"\ " #{@ucaf_collection_indicator.inspect}, white_list_status: #{@white_list_status.inspect},"\ " white_list_status_source: #{@white_list_status_source.inspect}, xid: #{@xid.inspect},"\ " directory_server_transaction_id: #{@directory_server_transaction_id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 760 def to_s class_name = self.class.name.split('::').last "<#{class_name} acs_rendering_type: #{@acs_rendering_type}, acs_reference_number:"\ " #{@acs_reference_number}, acs_transaction_id: #{@acs_transaction_id}, acs_operator_id:"\ " #{@acs_operator_id}, authentication_result: #{@authentication_result},"\ " authentication_type: #{@authentication_type}, authentication_status_msg:"\ " #{@authentication_status_msg}, authentication_transaction_id:"\ " #{@authentication_transaction_id}, authentication_transaction_context_id:"\ " #{@authentication_transaction_context_id}, transaction_token: #{@transaction_token},"\ " authorization_payload: #{@authorization_payload}, cavv: #{@cavv}, cavv_algorithm:"\ " #{@cavv_algorithm}, challenge_cancel_code: #{@challenge_cancel_code},"\ " directory_server_error_code: #{@directory_server_error_code},"\ " directory_server_error_description: #{@directory_server_error_description},"\ " effective_authentication_type: #{@effective_authentication_type}, indicator:"\ " #{@indicator}, interaction_counter: #{@interaction_counter}, eci: #{@eci}, eci_raw:"\ " #{@eci_raw}, pares_status: #{@pares_status}, sdk_transaction_id: #{@sdk_transaction_id},"\ " specification_version: #{@specification_version}, three_ds_server_transaction_id:"\ " #{@three_ds_server_transaction_id}, ucaf_authentication_data:"\ " #{@ucaf_authentication_data}, ucaf_collection_indicator: #{@ucaf_collection_indicator},"\ " white_list_status: #{@white_list_status}, white_list_status_source:"\ " #{@white_list_status_source}, xid: #{@xid}, directory_server_transaction_id:"\ " #{@directory_server_transaction_id}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'lib/cyber_source_merged_spec/models/consumer_authentication_information10.rb', line 693 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'acsRenderingType', acs_rendering_type) XmlUtilities.add_as_subelement(doc, root, 'acsReferenceNumber', acs_reference_number) XmlUtilities.add_as_subelement(doc, root, 'acsTransactionId', acs_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'acsOperatorID', acs_operator_id) XmlUtilities.add_as_subelement(doc, root, 'authenticationResult', authentication_result) XmlUtilities.add_as_subelement(doc, root, 'authenticationType', authentication_type) XmlUtilities.add_as_subelement(doc, root, 'authenticationStatusMsg', authentication_status_msg) XmlUtilities.add_as_subelement(doc, root, 'authenticationTransactionId', authentication_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'authenticationTransactionContextId', authentication_transaction_context_id) XmlUtilities.add_as_subelement(doc, root, 'transactionToken', transaction_token) XmlUtilities.add_as_subelement(doc, root, 'authorizationPayload', ) XmlUtilities.add_as_subelement(doc, root, 'cavv', cavv) XmlUtilities.add_as_subelement(doc, root, 'cavvAlgorithm', cavv_algorithm) XmlUtilities.add_as_subelement(doc, root, 'challengeCancelCode', challenge_cancel_code) XmlUtilities.add_as_subelement(doc, root, 'directoryServerErrorCode', directory_server_error_code) XmlUtilities.add_as_subelement(doc, root, 'directoryServerErrorDescription', directory_server_error_description) XmlUtilities.add_as_subelement(doc, root, 'effectiveAuthenticationType', effective_authentication_type) XmlUtilities.add_as_subelement(doc, root, 'indicator', indicator) XmlUtilities.add_as_subelement(doc, root, 'interactionCounter', interaction_counter) XmlUtilities.add_as_subelement(doc, root, 'eci', eci) XmlUtilities.add_as_subelement(doc, root, 'eciRaw', eci_raw) XmlUtilities.add_as_subelement(doc, root, 'paresStatus', pares_status) XmlUtilities.add_as_subelement(doc, root, 'sdkTransactionId', sdk_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'specificationVersion', specification_version) XmlUtilities.add_as_subelement(doc, root, 'threeDSServerTransactionId', three_ds_server_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'ucafAuthenticationData', ucaf_authentication_data) XmlUtilities.add_as_subelement(doc, root, 'ucafCollectionIndicator', ucaf_collection_indicator) XmlUtilities.add_as_subelement(doc, root, 'whiteListStatus', white_list_status) XmlUtilities.add_as_subelement(doc, root, 'whiteListStatusSource', white_list_status_source) XmlUtilities.add_as_subelement(doc, root, 'xid', xid) XmlUtilities.add_as_subelement(doc, root, 'directoryServerTransactionId', directory_server_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |