Class: CyberSourceMergedSpec::Customer51
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Customer51
- Defined in:
- lib/cyber_source_merged_spec/models/customer51.rb
Overview
Customer51 Model.
Instance Attribute Summary collapse
-
#customer_id ⇒ String
Unique identifier for the legacy Secure Storage token used in the transaction.
-
#id ⇒ String
Unique identifier for the Customer token used in the transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(customer_id:, id: SKIP, additional_properties: nil) ⇒ Customer51
constructor
A new instance of Customer51.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(customer_id:, id: SKIP, additional_properties: nil) ⇒ Customer51
Returns a new instance of Customer51.
47 48 49 50 51 52 53 54 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 47 def initialize(customer_id:, id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @customer_id = customer_id @id = id unless id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#customer_id ⇒ String
Unique identifier for the legacy Secure Storage token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 18 def customer_id @customer_id end |
#id ⇒ String
Unique identifier for the Customer token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional.
25 26 27 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 25 def id @id end |
Class Method Details
.from_element(root) ⇒ Object
77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 77 def self.from_element(root) customer_id = XmlUtilities.from_element(root, 'customerId', String) id = XmlUtilities.from_element(root, 'id', String) new(customer_id: customer_id, id: id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. customer_id = hash.key?('customerId') ? hash['customerId'] : nil id = hash.key?('id') ? hash['id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Customer51.new(customer_id: customer_id, id: id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
28 29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 28 def self.names @_hash = {} if @_hash.nil? @_hash['customer_id'] = 'customerId' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 36 def self.optionals %w[ id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 105 def inspect class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id.inspect}, id: #{@id.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} customer_id: #{@customer_id}, id: #{@id}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/customer51.rb', line 86 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'customerId', customer_id) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |