Class: CyberSourceMergedSpec::Customer59
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Customer59
- Defined in:
- lib/cyber_source_merged_spec/models/customer59.rb
Overview
Customer59 Model.
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the Customer token used in the transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, additional_properties: nil) ⇒ Customer59
constructor
A new instance of Customer59.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, additional_properties: nil) ⇒ Customer59
Returns a new instance of Customer59.
36 37 38 39 40 41 42 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 36 def initialize(id:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the Customer token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional.
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 17 def id @id end |
Class Method Details
.from_element(root) ⇒ Object
63 64 65 66 67 68 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 63 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) new(id: id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Customer59.new(id: id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 27 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
70 71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/customer59.rb', line 70 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |