Class: CyberSourceMergedSpec::Customer60
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Customer60
- Defined in:
- lib/cyber_source_merged_spec/models/customer60.rb
Overview
Customer60 Model.
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the Customer token used in the transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, additional_properties: nil) ⇒ Customer60
constructor
A new instance of Customer60.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, additional_properties: nil) ⇒ Customer60
Returns a new instance of Customer60.
38 39 40 41 42 43 44 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 38 def initialize(id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the Customer token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional.
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 17 def id @id end |
Class Method Details
.from_element(root) ⇒ Object
65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 65 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) new(id: id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Customer60.new(id: id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 27 def self.optionals %w[ id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/customer60.rb', line 72 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |