Class: CyberSourceMergedSpec::DeletePlanResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::DeletePlanResponse
- Defined in:
- lib/cyber_source_merged_spec/models/delete_plan_response.rb
Overview
DeletePlanResponse Model.
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(submit_time_utc: SKIP, status: SKIP, additional_properties: nil) ⇒ DeletePlanResponse
constructor
A new instance of DeletePlanResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(submit_time_utc: SKIP, status: SKIP, additional_properties: nil) ⇒ DeletePlanResponse
Returns a new instance of DeletePlanResponse.
47 48 49 50 51 52 53 54 55 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 47 def initialize(submit_time_utc: SKIP, status: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#status ⇒ String
The status of the submitted transaction. Possible values:
- COMPLETED
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 24 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 18 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
79 80 81 82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 79 def self.from_element(root) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) new(submit_time_utc: submit_time_utc, status: status, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. DeletePlanResponse.new(submit_time_utc: submit_time_utc, status: status, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 35 def self.optionals %w[ submit_time_utc status ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/delete_plan_response.rb', line 88 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |