Class: CyberSourceMergedSpec::Features
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Features
- Defined in:
- lib/cyber_source_merged_spec/models/features.rb
Overview
Features Model.
Instance Attribute Summary collapse
-
#acceptance_level ⇒ String
This field contains the acceptance level of the PAN.
-
#account_funding_source ⇒ String
This field contains the account funding source.
-
#account_funding_source_sub_type ⇒ String
This field contains the type of prepaid card.
-
#account_level_management ⇒ TrueClass | FalseClass
This field indicates if the BIN participates in Account Level Management (ALM).
-
#atm_enabled ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is enabled for ATM usage.
-
#auto_substantiation ⇒ TrueClass | FalseClass
This field indicates if auto-substantiation is enabled on the BIN.
-
#card_platform ⇒ String
This field contains the type of card platform.
-
#card_product ⇒ String
This field contains the type of issuer product.
-
#combo_card ⇒ String
This field indicates the type of combo card.
-
#commercial_card_level2 ⇒ TrueClass | FalseClass
This field indicates if a transaction on the instrument qualifies for level 2 interchange rates.
-
#commercial_card_level3 ⇒ TrueClass | FalseClass
This field indicates if a transaction on the instrument qualifies for level 3 interchange rates.
-
#corporate_purchase ⇒ TrueClass | FalseClass
This field indicates if the instrument can be used for corporate purchasing.
-
#ecom_enabled ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is enabled for ECOM usage.
-
#emi_eligible ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is eligible for Equated Monthly Installments (EMI).
-
#exempt_bin ⇒ TrueClass | FalseClass
This field indicates if a transaction on the instrument qualifies for government exempt interchange fee.
-
#fleet_card ⇒ TrueClass | FalseClass
This field indicates if the BIN is designated for fuel/fleet usage.
-
#flex_credential ⇒ TrueClass | FalseClass
This field indicates if the instrument is a flex credential.
-
#gambling_allowed ⇒ TrueClass | FalseClass
This field indicates if gambling transactions are allowed on the BIN.
-
#health_card ⇒ TrueClass | FalseClass
This field indicates if the BIN is for healthcare (HSA/FSA).
-
#message_type ⇒ String
This field contains the type of BIN based authentication.
-
#online_gambling_block ⇒ TrueClass | FalseClass
This field indicates if online gambling is blocked on the BIN.
-
#pos_domestic_only ⇒ TrueClass | FalseClass
This field indicates if the BIN is valid only for POS domestic usage.
-
#pos_enabled ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is enabled for POS usage.
-
#product_id ⇒ String
This field contains the Visa-assigned product identifier associated with the BIN.
-
#product_id_subtype ⇒ String
This field contains the Visa-assigned product subtype identifier associated with the BIN.
-
#shared_bin ⇒ TrueClass | FalseClass
This field indicates if the BIN is shared by multiple issuers Possible values: -
true-false. -
#si_eligible ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is eligible for Standing Instructions (recurring payments).
-
#three_ds_support ⇒ TrueClass | FalseClass
This field indicates if the payment instrument supports 3D Secure authentication.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_funding_source: SKIP, account_funding_source_sub_type: SKIP, card_product: SKIP, message_type: SKIP, acceptance_level: SKIP, card_platform: SKIP, combo_card: SKIP, corporate_purchase: SKIP, health_card: SKIP, shared_bin: SKIP, pos_domestic_only: SKIP, gambling_allowed: SKIP, commercial_card_level2: SKIP, commercial_card_level3: SKIP, exempt_bin: SKIP, account_level_management: SKIP, online_gambling_block: SKIP, auto_substantiation: SKIP, flex_credential: SKIP, product_id: SKIP, product_id_subtype: SKIP, three_ds_support: SKIP, si_eligible: SKIP, emi_eligible: SKIP, fleet_card: SKIP, atm_enabled: SKIP, pos_enabled: SKIP, ecom_enabled: SKIP, additional_properties: nil) ⇒ Features
constructor
A new instance of Features.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_funding_source: SKIP, account_funding_source_sub_type: SKIP, card_product: SKIP, message_type: SKIP, acceptance_level: SKIP, card_platform: SKIP, combo_card: SKIP, corporate_purchase: SKIP, health_card: SKIP, shared_bin: SKIP, pos_domestic_only: SKIP, gambling_allowed: SKIP, commercial_card_level2: SKIP, commercial_card_level3: SKIP, exempt_bin: SKIP, account_level_management: SKIP, online_gambling_block: SKIP, auto_substantiation: SKIP, flex_credential: SKIP, product_id: SKIP, product_id_subtype: SKIP, three_ds_support: SKIP, si_eligible: SKIP, emi_eligible: SKIP, fleet_card: SKIP, atm_enabled: SKIP, pos_enabled: SKIP, ecom_enabled: SKIP, additional_properties: nil) ⇒ Features
Returns a new instance of Features.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 310 def initialize(account_funding_source: SKIP, account_funding_source_sub_type: SKIP, card_product: SKIP, message_type: SKIP, acceptance_level: SKIP, card_platform: SKIP, combo_card: SKIP, corporate_purchase: SKIP, health_card: SKIP, shared_bin: SKIP, pos_domestic_only: SKIP, gambling_allowed: SKIP, commercial_card_level2: SKIP, commercial_card_level3: SKIP, exempt_bin: SKIP, account_level_management: SKIP, online_gambling_block: SKIP, auto_substantiation: SKIP, flex_credential: SKIP, product_id: SKIP, product_id_subtype: SKIP, three_ds_support: SKIP, si_eligible: SKIP, emi_eligible: SKIP, fleet_card: SKIP, atm_enabled: SKIP, pos_enabled: SKIP, ecom_enabled: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_funding_source = account_funding_source unless account_funding_source == SKIP unless account_funding_source_sub_type == SKIP @account_funding_source_sub_type = account_funding_source_sub_type end @card_product = card_product unless card_product == SKIP @message_type = unless == SKIP @acceptance_level = acceptance_level unless acceptance_level == SKIP @card_platform = card_platform unless card_platform == SKIP @combo_card = combo_card unless combo_card == SKIP @corporate_purchase = corporate_purchase unless corporate_purchase == SKIP @health_card = health_card unless health_card == SKIP @shared_bin = shared_bin unless shared_bin == SKIP @pos_domestic_only = pos_domestic_only unless pos_domestic_only == SKIP @gambling_allowed = gambling_allowed unless gambling_allowed == SKIP @commercial_card_level2 = commercial_card_level2 unless commercial_card_level2 == SKIP @commercial_card_level3 = commercial_card_level3 unless commercial_card_level3 == SKIP @exempt_bin = exempt_bin unless exempt_bin == SKIP @account_level_management = account_level_management unless account_level_management == SKIP @online_gambling_block = online_gambling_block unless online_gambling_block == SKIP @auto_substantiation = auto_substantiation unless auto_substantiation == SKIP @flex_credential = flex_credential unless flex_credential == SKIP @product_id = product_id unless product_id == SKIP @product_id_subtype = product_id_subtype unless product_id_subtype == SKIP @three_ds_support = three_ds_support unless three_ds_support == SKIP @si_eligible = si_eligible unless si_eligible == SKIP @emi_eligible = emi_eligible unless emi_eligible == SKIP @fleet_card = fleet_card unless fleet_card == SKIP @atm_enabled = atm_enabled unless atm_enabled == SKIP @pos_enabled = pos_enabled unless pos_enabled == SKIP @ecom_enabled = ecom_enabled unless ecom_enabled == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#acceptance_level ⇒ String
This field contains the acceptance level of the PAN. Possible values:
- `0` : Normal
- `1` : Monitor
- `2` : Refuse
- `3` : Not Allowed
- `4` : Private
- `5` : Test
53 54 55 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 53 def acceptance_level @acceptance_level end |
#account_funding_source ⇒ String
This field contains the account funding source. Possible values:
- `CREDIT`
- `DEBIT`
- `PREPAID`
- `DEFERRED DEBIT`
- `CHARGE`
20 21 22 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 20 def account_funding_source @account_funding_source end |
#account_funding_source_sub_type ⇒ String
This field contains the type of prepaid card. Possible values:
- `Reloadable`
- `Non-reloadable`
27 28 29 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 27 def account_funding_source_sub_type @account_funding_source_sub_type end |
#account_level_management ⇒ TrueClass | FalseClass
This field indicates if the BIN participates in Account Level Management
(ALM).
Possible values:
- true
- false
141 142 143 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 141 def account_level_management @account_level_management end |
#atm_enabled ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is enabled for ATM usage.
Possible values:
- true
- false
220 221 222 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 220 def atm_enabled @atm_enabled end |
#auto_substantiation ⇒ TrueClass | FalseClass
This field indicates if auto-substantiation is enabled on the BIN.
Possible values:
- true
- false
155 156 157 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 155 def auto_substantiation @auto_substantiation end |
#card_platform ⇒ String
This field contains the type of card platform. Possible values:
- `BUSINESS`
- `CONSUMER`
- `CORPORATE`
- `COMMERCIAL`
- `GOVERNMENT`
63 64 65 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 63 def card_platform @card_platform end |
#card_product ⇒ String
This field contains the type of issuer product. Example values:
- Visa Classic
- Visa Signature
- Visa Infinite
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 35 def card_product @card_product end |
#combo_card ⇒ String
This field indicates the type of combo card. Possible values:
- 0 (Not a combo card)
- 1 (Credit and Prepaid Combo card)
- 2 (Credit and Debit Combo card)
- 3 (Prepaid Credit and Prepaid Debit combo card)
72 73 74 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 72 def combo_card @combo_card end |
#commercial_card_level2 ⇒ TrueClass | FalseClass
This field indicates if a transaction on the instrument qualifies for
level 2 interchange rates.
Possible values:
- true
- false
117 118 119 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 117 def commercial_card_level2 @commercial_card_level2 end |
#commercial_card_level3 ⇒ TrueClass | FalseClass
This field indicates if a transaction on the instrument qualifies for
level 3 interchange rates.
Possible values:
- true
- false
125 126 127 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 125 def commercial_card_level3 @commercial_card_level3 end |
#corporate_purchase ⇒ TrueClass | FalseClass
This field indicates if the instrument can be used for corporate purchasing. This field is only applicable for American Express cards. Possible values:
- `true`
- `false`
80 81 82 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 80 def corporate_purchase @corporate_purchase end |
#ecom_enabled ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is enabled for ECOM usage.
Possible values:
- true
- false
234 235 236 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 234 def ecom_enabled @ecom_enabled end |
#emi_eligible ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is eligible for Equated
Monthly Installments (EMI).
Possible values:
- true
- false
205 206 207 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 205 def emi_eligible @emi_eligible end |
#exempt_bin ⇒ TrueClass | FalseClass
This field indicates if a transaction on the instrument qualifies for
government exempt interchange fee.
Possible values:
- true
- false
133 134 135 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 133 def exempt_bin @exempt_bin end |
#fleet_card ⇒ TrueClass | FalseClass
This field indicates if the BIN is designated for fuel/fleet usage. These
specialized BINs support additional Level2/Level 3 transaction data.
Possible values:
- true
- false
213 214 215 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 213 def fleet_card @fleet_card end |
#flex_credential ⇒ TrueClass | FalseClass
This field indicates if the instrument is a flex credential.
Possible values:
- true
- false
162 163 164 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 162 def flex_credential @flex_credential end |
#gambling_allowed ⇒ TrueClass | FalseClass
This field indicates if gambling transactions are allowed on the BIN.
Possible values:
- true
- false
109 110 111 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 109 def gambling_allowed @gambling_allowed end |
#health_card ⇒ TrueClass | FalseClass
This field indicates if the BIN is for healthcare (HSA/FSA). Currently,
this field is only supported for Visa BINs.
Possible values:
- true
- false
88 89 90 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 88 def health_card @health_card end |
#message_type ⇒ String
This field contains the type of BIN based authentication. Possible values:
- `S`: Single Message
- `D`: Dual Message
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 42 def @message_type end |
#online_gambling_block ⇒ TrueClass | FalseClass
This field indicates if online gambling is blocked on the BIN.
Possible values:
- true
- false
148 149 150 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 148 def online_gambling_block @online_gambling_block end |
#pos_domestic_only ⇒ TrueClass | FalseClass
This field indicates if the BIN is valid only for POS domestic usage.
Possible values:
- true
- false
102 103 104 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 102 def pos_domestic_only @pos_domestic_only end |
#pos_enabled ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is enabled for POS usage.
Possible values:
- true
- false
227 228 229 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 227 def pos_enabled @pos_enabled end |
#product_id ⇒ String
This field contains the Visa-assigned product identifier associated with the BIN. This field is only supported for Visa BINs. Example values:
- Q4
- P
- AX
171 172 173 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 171 def product_id @product_id end |
#product_id_subtype ⇒ String
This field contains the Visa-assigned product subtype identifier associated with the BIN. This field is only supported for Visa BINs. Example values:
- BB
- EX
- L2
- C2
181 182 183 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 181 def product_id_subtype @product_id_subtype end |
#shared_bin ⇒ TrueClass | FalseClass
This field indicates if the BIN is shared by multiple issuers
Possible values:
- true
- false
95 96 97 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 95 def shared_bin @shared_bin end |
#si_eligible ⇒ TrueClass | FalseClass
This field indicates if the payment instrument is eligible for Standing
Instructions (recurring payments).
Possible values:
- true
- false
197 198 199 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 197 def si_eligible @si_eligible end |
#three_ds_support ⇒ TrueClass | FalseClass
This field indicates if the payment instrument supports 3D Secure
authentication.
Possible values:
- true
- false
189 190 191 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 189 def three_ds_support @three_ds_support end |
Class Method Details
.from_element(root) ⇒ Object
449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 449 def self.from_element(root) account_funding_source = XmlUtilities.from_element(root, 'accountFundingSource', String) account_funding_source_sub_type = XmlUtilities.from_element( root, 'accountFundingSourceSubType', String ) card_product = XmlUtilities.from_element(root, 'cardProduct', String) = XmlUtilities.from_element(root, 'messageType', String) acceptance_level = XmlUtilities.from_element(root, 'acceptanceLevel', String) card_platform = XmlUtilities.from_element(root, 'cardPlatform', String) combo_card = XmlUtilities.from_element(root, 'comboCard', String) corporate_purchase = XmlUtilities.from_element(root, 'corporatePurchase', TrueClass) health_card = XmlUtilities.from_element(root, 'healthCard', TrueClass) shared_bin = XmlUtilities.from_element(root, 'sharedBIN', TrueClass) pos_domestic_only = XmlUtilities.from_element(root, 'posDomesticOnly', TrueClass) gambling_allowed = XmlUtilities.from_element(root, 'gamblingAllowed', TrueClass) commercial_card_level2 = XmlUtilities.from_element(root, 'commercialCardLevel2', TrueClass) commercial_card_level3 = XmlUtilities.from_element(root, 'commercialCardLevel3', TrueClass) exempt_bin = XmlUtilities.from_element(root, 'exemptBIN', TrueClass) account_level_management = XmlUtilities.from_element( root, 'accountLevelManagement', TrueClass ) online_gambling_block = XmlUtilities.from_element(root, 'onlineGamblingBlock', TrueClass) auto_substantiation = XmlUtilities.from_element(root, 'autoSubstantiation', TrueClass) flex_credential = XmlUtilities.from_element(root, 'flexCredential', TrueClass) product_id = XmlUtilities.from_element(root, 'productId', String) product_id_subtype = XmlUtilities.from_element(root, 'productIdSubtype', String) three_ds_support = XmlUtilities.from_element(root, 'threeDSSupport', TrueClass) si_eligible = XmlUtilities.from_element(root, 'siEligible', TrueClass) emi_eligible = XmlUtilities.from_element(root, 'emiEligible', TrueClass) fleet_card = XmlUtilities.from_element(root, 'fleetCard', TrueClass) atm_enabled = XmlUtilities.from_element(root, 'atmEnabled', TrueClass) pos_enabled = XmlUtilities.from_element(root, 'posEnabled', TrueClass) ecom_enabled = XmlUtilities.from_element(root, 'ecomEnabled', TrueClass) new(account_funding_source: account_funding_source, account_funding_source_sub_type: account_funding_source_sub_type, card_product: card_product, message_type: , acceptance_level: acceptance_level, card_platform: card_platform, combo_card: combo_card, corporate_purchase: corporate_purchase, health_card: health_card, shared_bin: shared_bin, pos_domestic_only: pos_domestic_only, gambling_allowed: gambling_allowed, commercial_card_level2: commercial_card_level2, commercial_card_level3: commercial_card_level3, exempt_bin: exempt_bin, account_level_management: account_level_management, online_gambling_block: online_gambling_block, auto_substantiation: auto_substantiation, flex_credential: flex_credential, product_id: product_id, product_id_subtype: product_id_subtype, three_ds_support: three_ds_support, si_eligible: si_eligible, emi_eligible: emi_eligible, fleet_card: fleet_card, atm_enabled: atm_enabled, pos_enabled: pos_enabled, ecom_enabled: ecom_enabled, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 363 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_funding_source = hash.key?('accountFundingSource') ? hash['accountFundingSource'] : SKIP account_funding_source_sub_type = hash.key?('accountFundingSourceSubType') ? hash['accountFundingSourceSubType'] : SKIP card_product = hash.key?('cardProduct') ? hash['cardProduct'] : SKIP = hash.key?('messageType') ? hash['messageType'] : SKIP acceptance_level = hash.key?('acceptanceLevel') ? hash['acceptanceLevel'] : SKIP card_platform = hash.key?('cardPlatform') ? hash['cardPlatform'] : SKIP combo_card = hash.key?('comboCard') ? hash['comboCard'] : SKIP corporate_purchase = hash.key?('corporatePurchase') ? hash['corporatePurchase'] : SKIP health_card = hash.key?('healthCard') ? hash['healthCard'] : SKIP shared_bin = hash.key?('sharedBIN') ? hash['sharedBIN'] : SKIP pos_domestic_only = hash.key?('posDomesticOnly') ? hash['posDomesticOnly'] : SKIP gambling_allowed = hash.key?('gamblingAllowed') ? hash['gamblingAllowed'] : SKIP commercial_card_level2 = hash.key?('commercialCardLevel2') ? hash['commercialCardLevel2'] : SKIP commercial_card_level3 = hash.key?('commercialCardLevel3') ? hash['commercialCardLevel3'] : SKIP exempt_bin = hash.key?('exemptBIN') ? hash['exemptBIN'] : SKIP account_level_management = hash.key?('accountLevelManagement') ? hash['accountLevelManagement'] : SKIP online_gambling_block = hash.key?('onlineGamblingBlock') ? hash['onlineGamblingBlock'] : SKIP auto_substantiation = hash.key?('autoSubstantiation') ? hash['autoSubstantiation'] : SKIP flex_credential = hash.key?('flexCredential') ? hash['flexCredential'] : SKIP product_id = hash.key?('productId') ? hash['productId'] : SKIP product_id_subtype = hash.key?('productIdSubtype') ? hash['productIdSubtype'] : SKIP three_ds_support = hash.key?('threeDSSupport') ? hash['threeDSSupport'] : SKIP si_eligible = hash.key?('siEligible') ? hash['siEligible'] : SKIP emi_eligible = hash.key?('emiEligible') ? hash['emiEligible'] : SKIP fleet_card = hash.key?('fleetCard') ? hash['fleetCard'] : SKIP atm_enabled = hash.key?('atmEnabled') ? hash['atmEnabled'] : SKIP pos_enabled = hash.key?('posEnabled') ? hash['posEnabled'] : SKIP ecom_enabled = hash.key?('ecomEnabled') ? hash['ecomEnabled'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Features.new(account_funding_source: account_funding_source, account_funding_source_sub_type: account_funding_source_sub_type, card_product: card_product, message_type: , acceptance_level: acceptance_level, card_platform: card_platform, combo_card: combo_card, corporate_purchase: corporate_purchase, health_card: health_card, shared_bin: shared_bin, pos_domestic_only: pos_domestic_only, gambling_allowed: gambling_allowed, commercial_card_level2: commercial_card_level2, commercial_card_level3: commercial_card_level3, exempt_bin: exempt_bin, account_level_management: account_level_management, online_gambling_block: online_gambling_block, auto_substantiation: auto_substantiation, flex_credential: flex_credential, product_id: product_id, product_id_subtype: product_id_subtype, three_ds_support: three_ds_support, si_eligible: si_eligible, emi_eligible: emi_eligible, fleet_card: fleet_card, atm_enabled: atm_enabled, pos_enabled: pos_enabled, ecom_enabled: ecom_enabled, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 237 def self.names @_hash = {} if @_hash.nil? @_hash['account_funding_source'] = 'accountFundingSource' @_hash['account_funding_source_sub_type'] = 'accountFundingSourceSubType' @_hash['card_product'] = 'cardProduct' @_hash['message_type'] = 'messageType' @_hash['acceptance_level'] = 'acceptanceLevel' @_hash['card_platform'] = 'cardPlatform' @_hash['combo_card'] = 'comboCard' @_hash['corporate_purchase'] = 'corporatePurchase' @_hash['health_card'] = 'healthCard' @_hash['shared_bin'] = 'sharedBIN' @_hash['pos_domestic_only'] = 'posDomesticOnly' @_hash['gambling_allowed'] = 'gamblingAllowed' @_hash['commercial_card_level2'] = 'commercialCardLevel2' @_hash['commercial_card_level3'] = 'commercialCardLevel3' @_hash['exempt_bin'] = 'exemptBIN' @_hash['account_level_management'] = 'accountLevelManagement' @_hash['online_gambling_block'] = 'onlineGamblingBlock' @_hash['auto_substantiation'] = 'autoSubstantiation' @_hash['flex_credential'] = 'flexCredential' @_hash['product_id'] = 'productId' @_hash['product_id_subtype'] = 'productIdSubtype' @_hash['three_ds_support'] = 'threeDSSupport' @_hash['si_eligible'] = 'siEligible' @_hash['emi_eligible'] = 'emiEligible' @_hash['fleet_card'] = 'fleetCard' @_hash['atm_enabled'] = 'atmEnabled' @_hash['pos_enabled'] = 'posEnabled' @_hash['ecom_enabled'] = 'ecomEnabled' @_hash end |
.nullables ⇒ Object
An array for nullable fields
306 307 308 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 306 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 272 def self.optionals %w[ account_funding_source account_funding_source_sub_type card_product message_type acceptance_level card_platform combo_card corporate_purchase health_card shared_bin pos_domestic_only gambling_allowed commercial_card_level2 commercial_card_level3 exempt_bin account_level_management online_gambling_block auto_substantiation flex_credential product_id product_id_subtype three_ds_support si_eligible emi_eligible fleet_card atm_enabled pos_enabled ecom_enabled ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 602 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_funding_source: #{@account_funding_source.inspect},"\ " account_funding_source_sub_type: #{@account_funding_source_sub_type.inspect},"\ " card_product: #{@card_product.inspect}, message_type: #{@message_type.inspect},"\ " acceptance_level: #{@acceptance_level.inspect}, card_platform: #{@card_platform.inspect},"\ " combo_card: #{@combo_card.inspect}, corporate_purchase: #{@corporate_purchase.inspect},"\ " health_card: #{@health_card.inspect}, shared_bin: #{@shared_bin.inspect},"\ " pos_domestic_only: #{@pos_domestic_only.inspect}, gambling_allowed:"\ " #{@gambling_allowed.inspect}, commercial_card_level2: #{@commercial_card_level2.inspect},"\ " commercial_card_level3: #{@commercial_card_level3.inspect}, exempt_bin:"\ " #{@exempt_bin.inspect}, account_level_management: #{@account_level_management.inspect},"\ " online_gambling_block: #{@online_gambling_block.inspect}, auto_substantiation:"\ " #{@auto_substantiation.inspect}, flex_credential: #{@flex_credential.inspect}, product_id:"\ " #{@product_id.inspect}, product_id_subtype: #{@product_id_subtype.inspect},"\ " three_ds_support: #{@three_ds_support.inspect}, si_eligible: #{@si_eligible.inspect},"\ " emi_eligible: #{@emi_eligible.inspect}, fleet_card: #{@fleet_card.inspect}, atm_enabled:"\ " #{@atm_enabled.inspect}, pos_enabled: #{@pos_enabled.inspect}, ecom_enabled:"\ " #{@ecom_enabled.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 583 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_funding_source: #{@account_funding_source},"\ " account_funding_source_sub_type: #{@account_funding_source_sub_type}, card_product:"\ " #{@card_product}, message_type: #{@message_type}, acceptance_level: #{@acceptance_level},"\ " card_platform: #{@card_platform}, combo_card: #{@combo_card}, corporate_purchase:"\ " #{@corporate_purchase}, health_card: #{@health_card}, shared_bin: #{@shared_bin},"\ " pos_domestic_only: #{@pos_domestic_only}, gambling_allowed: #{@gambling_allowed},"\ " commercial_card_level2: #{@commercial_card_level2}, commercial_card_level3:"\ " #{@commercial_card_level3}, exempt_bin: #{@exempt_bin}, account_level_management:"\ " #{@account_level_management}, online_gambling_block: #{@online_gambling_block},"\ " auto_substantiation: #{@auto_substantiation}, flex_credential: #{@flex_credential},"\ " product_id: #{@product_id}, product_id_subtype: #{@product_id_subtype}, three_ds_support:"\ " #{@three_ds_support}, si_eligible: #{@si_eligible}, emi_eligible: #{@emi_eligible},"\ " fleet_card: #{@fleet_card}, atm_enabled: #{@atm_enabled}, pos_enabled: #{@pos_enabled},"\ " ecom_enabled: #{@ecom_enabled}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/cyber_source_merged_spec/models/features.rb', line 531 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'accountFundingSource', account_funding_source) XmlUtilities.add_as_subelement(doc, root, 'accountFundingSourceSubType', account_funding_source_sub_type) XmlUtilities.add_as_subelement(doc, root, 'cardProduct', card_product) XmlUtilities.add_as_subelement(doc, root, 'messageType', ) XmlUtilities.add_as_subelement(doc, root, 'acceptanceLevel', acceptance_level) XmlUtilities.add_as_subelement(doc, root, 'cardPlatform', card_platform) XmlUtilities.add_as_subelement(doc, root, 'comboCard', combo_card) XmlUtilities.add_as_subelement(doc, root, 'corporatePurchase', corporate_purchase) XmlUtilities.add_as_subelement(doc, root, 'healthCard', health_card) XmlUtilities.add_as_subelement(doc, root, 'sharedBIN', shared_bin) XmlUtilities.add_as_subelement(doc, root, 'posDomesticOnly', pos_domestic_only) XmlUtilities.add_as_subelement(doc, root, 'gamblingAllowed', gambling_allowed) XmlUtilities.add_as_subelement(doc, root, 'commercialCardLevel2', commercial_card_level2) XmlUtilities.add_as_subelement(doc, root, 'commercialCardLevel3', commercial_card_level3) XmlUtilities.add_as_subelement(doc, root, 'exemptBIN', exempt_bin) XmlUtilities.add_as_subelement(doc, root, 'accountLevelManagement', account_level_management) XmlUtilities.add_as_subelement(doc, root, 'onlineGamblingBlock', online_gambling_block) XmlUtilities.add_as_subelement(doc, root, 'autoSubstantiation', auto_substantiation) XmlUtilities.add_as_subelement(doc, root, 'flexCredential', flex_credential) XmlUtilities.add_as_subelement(doc, root, 'productId', product_id) XmlUtilities.add_as_subelement(doc, root, 'productIdSubtype', product_id_subtype) XmlUtilities.add_as_subelement(doc, root, 'threeDSSupport', three_ds_support) XmlUtilities.add_as_subelement(doc, root, 'siEligible', si_eligible) XmlUtilities.add_as_subelement(doc, root, 'emiEligible', emi_eligible) XmlUtilities.add_as_subelement(doc, root, 'fleetCard', fleet_card) XmlUtilities.add_as_subelement(doc, root, 'atmEnabled', atm_enabled) XmlUtilities.add_as_subelement(doc, root, 'posEnabled', pos_enabled) XmlUtilities.add_as_subelement(doc, root, 'ecomEnabled', ecom_enabled) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |