Class: CyberSourceMergedSpec::Field
- Defined in:
- lib/cyber_source_merged_spec/models/field.rb
Overview
Provide validation failed input field details
Instance Attribute Summary collapse
-
#localization_key ⇒ String
Localized Key Name.
-
#message ⇒ String
Error description about validation failed field.
-
#path ⇒ String
Path of the failed property.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(path: SKIP, message: SKIP, localization_key: SKIP, additional_properties: nil) ⇒ Field
constructor
A new instance of Field.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(path: SKIP, message: SKIP, localization_key: SKIP, additional_properties: nil) ⇒ Field
Returns a new instance of Field.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 47 def initialize(path: SKIP, message: SKIP, localization_key: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @path = path unless path == SKIP @message = unless == SKIP @localization_key = localization_key unless localization_key == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#localization_key ⇒ String
Localized Key Name
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 22 def localization_key @localization_key end |
#message ⇒ String
Error description about validation failed field
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 18 def @message end |
#path ⇒ String
Path of the failed property
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 14 def path @path end |
Class Method Details
.from_element(root) ⇒ Object
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 82 def self.from_element(root) path = XmlUtilities.from_element(root, 'path', String) = XmlUtilities.from_element(root, 'message', String) localization_key = XmlUtilities.from_element(root, 'localizationKey', String) new(path: path, message: , localization_key: localization_key, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. path = hash.key?('path') ? hash['path'] : SKIP = hash.key?('message') ? hash['message'] : SKIP localization_key = hash.key?('localizationKey') ? hash['localizationKey'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Field.new(path: path, message: , localization_key: localization_key, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['path'] = 'path' @_hash['message'] = 'message' @_hash['localization_key'] = 'localizationKey' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 34 def self.optionals %w[ path message localization_key ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
115 116 117 118 119 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 115 def inspect class_name = self.class.name.split('::').last "<#{class_name} path: #{@path.inspect}, message: #{@message.inspect}, localization_key:"\ " #{@localization_key.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 108 def to_s class_name = self.class.name.split('::').last "<#{class_name} path: #{@path}, message: #{@message}, localization_key:"\ " #{@localization_key}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/field.rb', line 94 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'path', path) XmlUtilities.add_as_subelement(doc, root, 'message', ) XmlUtilities.add_as_subelement(doc, root, 'localizationKey', localization_key) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |