Class: CyberSourceMergedSpec::FraudMarkingInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::FraudMarkingInformation
- Defined in:
- lib/cyber_source_merged_spec/models/fraud_marking_information.rb
Overview
FraudMarkingInformation Model.
Instance Attribute Summary collapse
-
#reason ⇒ String
Reason for adding the transaction to the negative list.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reason: SKIP, additional_properties: nil) ⇒ FraudMarkingInformation
constructor
A new instance of FraudMarkingInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reason: SKIP, additional_properties: nil) ⇒ FraudMarkingInformation
Returns a new instance of FraudMarkingInformation.
44 45 46 47 48 49 50 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 44 def initialize(reason: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reason = reason unless reason == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#reason ⇒ String
Reason for adding the transaction to the negative list. This field can contain one of the following values:
- fraud_chargeback: You have received a fraudrelated chargeback for the transaction.
- non_fraud_chargeback: You have received a non-fraudulent chargeback for the transaction.
- suspected: You believe that you will probably receive a chargeback for the transaction.
- creditback: You issued a refund to the customer to avoid a chargeback for the transaction.
23 24 25 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 23 def reason @reason end |
Class Method Details
.from_element(root) ⇒ Object
71 72 73 74 75 76 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 71 def self.from_element(root) reason = XmlUtilities.from_element(root, 'reason', String) new(reason: reason, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reason = hash.key?('reason') ? hash['reason'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. FraudMarkingInformation.new(reason: reason, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 33 def self.optionals %w[ reason ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
78 79 80 81 82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/fraud_marking_information.rb', line 78 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'reason', reason) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |