Class: CyberSourceMergedSpec::GenerateCaptureContextException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- CyberSourceMergedSpec::GenerateCaptureContextException
- Defined in:
- lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb
Overview
generateCaptureContextException class.
Instance Attribute Summary collapse
-
#links ⇒ Links211
TODO: Write general description for this method.
-
#response_status ⇒ ResponseStatus
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ GenerateCaptureContextException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ GenerateCaptureContextException
The constructor.
23 24 25 26 27 |
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#links ⇒ Links211
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 18 def links @links end |
#response_status ⇒ ResponseStatus
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 14 def response_status @response_status end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
47 48 49 50 |
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 47 def inspect class_name = self.class.name.split('::').last "<#{class_name} response_status: #{@response_status.inspect}, links: #{@links.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
41 42 43 44 |
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 41 def to_s class_name = self.class.name.split('::').last "<#{class_name} response_status: #{@response_status}, links: #{@links}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/exceptions/generate_capture_context_exception.rb', line 32 def unbox(hash) return nil unless hash @response_status = ResponseStatus.from_hash(hash['responseStatus']) if hash['responseStatus'] @links = Links211.from_hash(hash['_links']) if hash['_links'] end |