Class: CyberSourceMergedSpec::GetAccountInfoResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::GetAccountInfoResponse
- Defined in:
- lib/cyber_source_merged_spec/models/get_account_info_response.rb
Overview
GetAccountInfoResponse Model.
Instance Attribute Summary collapse
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#issuer_information ⇒ IssuerInformation6
The status of the submitted transaction.
-
#payment_account_information ⇒ PaymentAccountInformation2
The status of the submitted transaction.
-
#payout_information ⇒ PayoutInformation
The status of the submitted transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, payment_account_information: SKIP, issuer_information: SKIP, payout_information: SKIP, additional_properties: nil) ⇒ GetAccountInfoResponse
constructor
A new instance of GetAccountInfoResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, payment_account_information: SKIP, issuer_information: SKIP, payout_information: SKIP, additional_properties: nil) ⇒ GetAccountInfoResponse
Returns a new instance of GetAccountInfoResponse.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 89 def initialize(id: SKIP, submit_time_utc: SKIP, status: SKIP, payment_account_information: SKIP, issuer_information: SKIP, payout_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP unless payment_account_information == SKIP @payment_account_information = payment_account_information end @issuer_information = issuer_information unless issuer_information == SKIP @payout_information = payout_information unless payout_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 18 def id @id end |
#issuer_information ⇒ IssuerInformation6
The status of the submitted transaction. Possible values:
- COMPLETED
- MULTIPLE
- NO MATCH
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 50 def issuer_information @issuer_information end |
#payment_account_information ⇒ PaymentAccountInformation2
The status of the submitted transaction. Possible values:
- COMPLETED
- MULTIPLE
- NO MATCH
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 42 def payment_account_information @payment_account_information end |
#payout_information ⇒ PayoutInformation
The status of the submitted transaction. Possible values:
- COMPLETED
- MULTIPLE
- NO MATCH
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 58 def payout_information @payout_information end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- COMPLETED
- MULTIPLE
- NO MATCH
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 34 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 26 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 141 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) payment_account_information = XmlUtilities.from_element( root, 'PaymentAccountInformation2', PaymentAccountInformation2 ) issuer_information = XmlUtilities.from_element(root, 'IssuerInformation6', IssuerInformation6) payout_information = XmlUtilities.from_element(root, 'PayoutInformation', PayoutInformation) new(id: id, submit_time_utc: submit_time_utc, status: status, payment_account_information: payment_account_information, issuer_information: issuer_information, payout_information: payout_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 108 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP if hash['paymentAccountInformation'] payment_account_information = PaymentAccountInformation2.from_hash(hash['paymentAccountInformation']) end issuer_information = IssuerInformation6.from_hash(hash['issuerInformation']) if hash['issuerInformation'] payout_information = PayoutInformation.from_hash(hash['payoutInformation']) if hash['payoutInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetAccountInfoResponse.new(id: id, submit_time_utc: submit_time_utc, status: status, payment_account_information: payment_account_information, issuer_information: issuer_information, payout_information: payout_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['payment_account_information'] = 'paymentAccountInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash['payout_information'] = 'payoutInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
85 86 87 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 85 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 73 def self.optionals %w[ id submit_time_utc status payment_account_information issuer_information payout_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
192 193 194 195 196 197 198 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 192 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, submit_time_utc: #{@submit_time_utc.inspect}, status:"\ " #{@status.inspect}, payment_account_information: #{@payment_account_information.inspect},"\ " issuer_information: #{@issuer_information.inspect}, payout_information:"\ " #{@payout_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
183 184 185 186 187 188 189 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 183 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " payment_account_information: #{@payment_account_information}, issuer_information:"\ " #{@issuer_information}, payout_information: #{@payout_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/cyber_source_merged_spec/models/get_account_info_response.rb', line 163 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'PaymentAccountInformation2', payment_account_information) XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation6', issuer_information) XmlUtilities.add_as_subelement(doc, root, 'PayoutInformation', payout_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |