Class: CyberSourceMergedSpec::GetCardArtAssetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::GetCardArtAssetResponse
- Defined in:
- lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb
Overview
Represents the Card Art Asset associated to the Network Token.
Instance Attribute Summary collapse
-
#content ⇒ Array[Content]
Array of content objects representing the Card Art Asset.
-
#id ⇒ String
Unique identifier for the Card Art Asset.
-
#provider ⇒ String
The provider of the Card Art Asset.
-
#type ⇒ String
The type of Card Art Asset.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, type: SKIP, provider: SKIP, content: SKIP, additional_properties: nil) ⇒ GetCardArtAssetResponse
constructor
A new instance of GetCardArtAssetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, type: SKIP, provider: SKIP, content: SKIP, additional_properties: nil) ⇒ GetCardArtAssetResponse
Returns a new instance of GetCardArtAssetResponse.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 53 def initialize(id: SKIP, type: SKIP, provider: SKIP, content: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @type = type unless type == SKIP @provider = provider unless provider == SKIP @content = content unless content == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#content ⇒ Array[Content]
Array of content objects representing the Card Art Asset.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 26 def content @content end |
#id ⇒ String
Unique identifier for the Card Art Asset.
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 14 def id @id end |
#provider ⇒ String
The provider of the Card Art Asset.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 22 def provider @provider end |
#type ⇒ String
The type of Card Art Asset.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 18 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 99 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) type = XmlUtilities.from_element(root, 'type', String) provider = XmlUtilities.from_element(root, 'provider', String) content = XmlUtilities.from_element_to_array(root, 'Content', Content) new(id: id, type: type, provider: provider, content: content, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP provider = hash.key?('provider') ? hash['provider'] : SKIP # Parameter is an array, so we need to iterate through it content = nil unless hash['content'].nil? content = [] hash['content'].each do |structure| content << (Content.from_hash(structure) if structure) end end content = SKIP unless hash.key?('content') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetCardArtAssetResponse.new(id: id, type: type, provider: provider, content: content, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['type'] = 'type' @_hash['provider'] = 'provider' @_hash['content'] = 'content' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 39 def self.optionals %w[ id type provider content ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
133 134 135 136 137 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 133 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, type: #{@type.inspect}, provider: #{@provider.inspect},"\ " content: #{@content.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
126 127 128 129 130 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 126 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, type: #{@type}, provider: #{@provider}, content: #{@content},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/cyber_source_merged_spec/models/get_card_art_asset_response.rb', line 112 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'provider', provider) XmlUtilities.add_array_as_subelement(doc, root, 'Content', content) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |