Class: CyberSourceMergedSpec::GetSubscriptionsPaymentsResponse1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::GetSubscriptionsPaymentsResponse1
- Defined in:
- lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb
Overview
GetSubscriptionsPaymentsResponse1 Model.
Instance Attribute Summary collapse
-
#billing_cycles_to_skip ⇒ Array[Integer]
A list of billing cycles that are marked to be skipped.
-
#links ⇒ Links244
TODO: Write general description for this method.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, submit_time_utc: SKIP, status: SKIP, billing_cycles_to_skip: SKIP, additional_properties: nil) ⇒ GetSubscriptionsPaymentsResponse1
constructor
A new instance of GetSubscriptionsPaymentsResponse1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, submit_time_utc: SKIP, status: SKIP, billing_cycles_to_skip: SKIP, additional_properties: nil) ⇒ GetSubscriptionsPaymentsResponse1
Returns a new instance of GetSubscriptionsPaymentsResponse1.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 62 def initialize(links: SKIP, submit_time_utc: SKIP, status: SKIP, billing_cycles_to_skip: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @billing_cycles_to_skip = billing_cycles_to_skip unless billing_cycles_to_skip == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#billing_cycles_to_skip ⇒ Array[Integer]
A list of billing cycles that are marked to be skipped.
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 35 def billing_cycles_to_skip @billing_cycles_to_skip end |
#links ⇒ Links244
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 14 def links @links end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- COMPLETED
- PENDING_REVIEW
- DECLINED
- INVALID_REQUEST
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 31 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 22 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 101 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links244', Links244) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) billing_cycles_to_skip = XmlUtilities.from_element_to_array( root, 'billingCyclesToSkip', Integer ) new(links: links, submit_time_utc: submit_time_utc, status: status, billing_cycles_to_skip: billing_cycles_to_skip, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 75 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links244.from_hash(hash['_links']) if hash['_links'] submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP billing_cycles_to_skip = hash.key?('billingCyclesToSkip') ? hash['billingCyclesToSkip'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. GetSubscriptionsPaymentsResponse1.new(links: links, submit_time_utc: submit_time_utc, status: status, billing_cycles_to_skip: billing_cycles_to_skip, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['billing_cycles_to_skip'] = 'billingCyclesToSkip' @_hash end |
.nullables ⇒ Object
An array for nullable fields
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 58 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
48 49 50 51 52 53 54 55 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 48 def self.optionals %w[ links submit_time_utc status billing_cycles_to_skip ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
140 141 142 143 144 145 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 140 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, submit_time_utc: #{@submit_time_utc.inspect},"\ " status: #{@status.inspect}, billing_cycles_to_skip: #{@billing_cycles_to_skip.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
132 133 134 135 136 137 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 132 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " billing_cycles_to_skip: #{@billing_cycles_to_skip}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/cyber_source_merged_spec/models/get_subscriptions_payments_response1.rb', line 116 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links244', links) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_array_as_subelement(doc, root, 'billingCyclesToSkip', billing_cycles_to_skip) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |