Class: CyberSourceMergedSpec::InterchangeClearingLevelDetail
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::InterchangeClearingLevelDetail
- Defined in:
- lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb
Overview
InterchangeClearingLevelDetail Model.
Instance Attribute Summary collapse
-
#account_id ⇒ String
TODO: Write general description for this method.
-
#account_suffix ⇒ String
TODO: Write general description for this method.
-
#amount ⇒ String
TODO: Write general description for this method.
-
#application_name ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#auth_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#batch_time ⇒ DateTime
Valid ISO 4217 ALPHA-3 currency code.
-
#billback_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#billback_reason_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#billback_reason_description ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#card_indicator ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#cleared_level ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#clearing_rate_amount_one ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#clearing_rate_amount_three ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#clearing_rate_amount_two ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#clearing_rate_currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#conversion_rate ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#credit_delta_indicator ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#delta_cost ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#discount_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#discount_rate ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#downgrade_reason_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#fee_category ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#interchange_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#merchant_batch_number ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#merchant_priced_level ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#merchant_reference_number ⇒ String
TODO: Write general description for this method.
-
#minimum_unit ⇒ Integer
Valid ISO 4217 ALPHA-3 currency code.
-
#minimum_unit_currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#organization_id ⇒ String
TODO: Write general description for this method.
-
#payment_sub_type ⇒ String
TODO: Write general description for this method.
-
#payment_sub_type_description ⇒ String
TODO: Write general description for this method.
-
#per_transaction_charged ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#percent_rate_charged ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#price_amount_one ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#price_amount_two ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#price_type ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#process_time ⇒ DateTime
Valid ISO 4217 ALPHA-3 currency code.
-
#processed_time ⇒ DateTime
TODO: Write general description for this method.
-
#processor_batch_number ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#processor_merchant_id ⇒ String
TODO: Write general description for this method.
-
#re_class ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#request_id ⇒ String
TODO: Write general description for this method.
-
#settlement_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#settlement_currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#settlement_processor ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#settlement_time ⇒ DateTime
Valid ISO 4217 ALPHA-3 currency code.
-
#surcharge_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code.
-
#transaction_reference_number ⇒ String
TODO: Write general description for this method.
-
#transaction_time ⇒ DateTime
TODO: Write general description for this method.
-
#transaction_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id: SKIP, organization_id: SKIP, account_id: SKIP, processor_merchant_id: SKIP, transaction_reference_number: SKIP, merchant_reference_number: SKIP, account_suffix: SKIP, payment_sub_type: SKIP, payment_sub_type_description: SKIP, transaction_time: SKIP, processed_time: SKIP, transaction_type: SKIP, amount: SKIP, currency_code: SKIP, price_type: SKIP, price_amount_one: SKIP, price_amount_two: SKIP, re_class: SKIP, settlement_time: SKIP, settlement_processor: SKIP, merchant_batch_number: SKIP, cleared_level: SKIP, billback_reason_code: SKIP, billback_reason_description: SKIP, merchant_priced_level: SKIP, discount_rate: SKIP, discount_amount: SKIP, clearing_rate_amount_one: SKIP, clearing_rate_amount_two: SKIP, clearing_rate_amount_three: SKIP, clearing_rate_currency_code: SKIP, interchange_amount: SKIP, billback_amount: SKIP, settlement_amount: SKIP, settlement_currency_code: SKIP, conversion_rate: SKIP, delta_cost: SKIP, surcharge_amount: SKIP, percent_rate_charged: SKIP, per_transaction_charged: SKIP, downgrade_reason_code: SKIP, process_time: SKIP, auth_code: SKIP, batch_time: SKIP, processor_batch_number: SKIP, card_indicator: SKIP, minimum_unit: SKIP, minimum_unit_currency_code: SKIP, credit_delta_indicator: SKIP, fee_category: SKIP, application_name: SKIP, additional_properties: nil) ⇒ InterchangeClearingLevelDetail
constructor
A new instance of InterchangeClearingLevelDetail.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_batch_time ⇒ Object
- #to_custom_process_time ⇒ Object
- #to_custom_processed_time ⇒ Object
- #to_custom_settlement_time ⇒ Object
- #to_custom_transaction_time ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id: SKIP, organization_id: SKIP, account_id: SKIP, processor_merchant_id: SKIP, transaction_reference_number: SKIP, merchant_reference_number: SKIP, account_suffix: SKIP, payment_sub_type: SKIP, payment_sub_type_description: SKIP, transaction_time: SKIP, processed_time: SKIP, transaction_type: SKIP, amount: SKIP, currency_code: SKIP, price_type: SKIP, price_amount_one: SKIP, price_amount_two: SKIP, re_class: SKIP, settlement_time: SKIP, settlement_processor: SKIP, merchant_batch_number: SKIP, cleared_level: SKIP, billback_reason_code: SKIP, billback_reason_description: SKIP, merchant_priced_level: SKIP, discount_rate: SKIP, discount_amount: SKIP, clearing_rate_amount_one: SKIP, clearing_rate_amount_two: SKIP, clearing_rate_amount_three: SKIP, clearing_rate_currency_code: SKIP, interchange_amount: SKIP, billback_amount: SKIP, settlement_amount: SKIP, settlement_currency_code: SKIP, conversion_rate: SKIP, delta_cost: SKIP, surcharge_amount: SKIP, percent_rate_charged: SKIP, per_transaction_charged: SKIP, downgrade_reason_code: SKIP, process_time: SKIP, auth_code: SKIP, batch_time: SKIP, processor_batch_number: SKIP, card_indicator: SKIP, minimum_unit: SKIP, minimum_unit_currency_code: SKIP, credit_delta_indicator: SKIP, fee_category: SKIP, application_name: SKIP, additional_properties: nil) ⇒ InterchangeClearingLevelDetail
Returns a new instance of InterchangeClearingLevelDetail.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 336 def initialize(request_id: SKIP, organization_id: SKIP, account_id: SKIP, processor_merchant_id: SKIP, transaction_reference_number: SKIP, merchant_reference_number: SKIP, account_suffix: SKIP, payment_sub_type: SKIP, payment_sub_type_description: SKIP, transaction_time: SKIP, processed_time: SKIP, transaction_type: SKIP, amount: SKIP, currency_code: SKIP, price_type: SKIP, price_amount_one: SKIP, price_amount_two: SKIP, re_class: SKIP, settlement_time: SKIP, settlement_processor: SKIP, merchant_batch_number: SKIP, cleared_level: SKIP, billback_reason_code: SKIP, billback_reason_description: SKIP, merchant_priced_level: SKIP, discount_rate: SKIP, discount_amount: SKIP, clearing_rate_amount_one: SKIP, clearing_rate_amount_two: SKIP, clearing_rate_amount_three: SKIP, clearing_rate_currency_code: SKIP, interchange_amount: SKIP, billback_amount: SKIP, settlement_amount: SKIP, settlement_currency_code: SKIP, conversion_rate: SKIP, delta_cost: SKIP, surcharge_amount: SKIP, percent_rate_charged: SKIP, per_transaction_charged: SKIP, downgrade_reason_code: SKIP, process_time: SKIP, auth_code: SKIP, batch_time: SKIP, processor_batch_number: SKIP, card_indicator: SKIP, minimum_unit: SKIP, minimum_unit_currency_code: SKIP, credit_delta_indicator: SKIP, fee_category: SKIP, application_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @request_id = request_id unless request_id == SKIP @organization_id = organization_id unless organization_id == SKIP @account_id = account_id unless account_id == SKIP @processor_merchant_id = processor_merchant_id unless processor_merchant_id == SKIP unless transaction_reference_number == SKIP @transaction_reference_number = transaction_reference_number end unless merchant_reference_number == SKIP @merchant_reference_number = merchant_reference_number end @account_suffix = account_suffix unless account_suffix == SKIP @payment_sub_type = payment_sub_type unless payment_sub_type == SKIP unless payment_sub_type_description == SKIP @payment_sub_type_description = payment_sub_type_description end @transaction_time = transaction_time unless transaction_time == SKIP @processed_time = processed_time unless processed_time == SKIP @transaction_type = transaction_type unless transaction_type == SKIP @amount = amount unless amount == SKIP @currency_code = currency_code unless currency_code == SKIP @price_type = price_type unless price_type == SKIP @price_amount_one = price_amount_one unless price_amount_one == SKIP @price_amount_two = price_amount_two unless price_amount_two == SKIP @re_class = re_class unless re_class == SKIP @settlement_time = settlement_time unless settlement_time == SKIP @settlement_processor = settlement_processor unless settlement_processor == SKIP @merchant_batch_number = merchant_batch_number unless merchant_batch_number == SKIP @cleared_level = cleared_level unless cleared_level == SKIP @billback_reason_code = billback_reason_code unless billback_reason_code == SKIP unless billback_reason_description == SKIP @billback_reason_description = billback_reason_description end @merchant_priced_level = merchant_priced_level unless merchant_priced_level == SKIP @discount_rate = discount_rate unless discount_rate == SKIP @discount_amount = discount_amount unless discount_amount == SKIP @clearing_rate_amount_one = clearing_rate_amount_one unless clearing_rate_amount_one == SKIP @clearing_rate_amount_two = clearing_rate_amount_two unless clearing_rate_amount_two == SKIP unless clearing_rate_amount_three == SKIP @clearing_rate_amount_three = clearing_rate_amount_three end unless clearing_rate_currency_code == SKIP @clearing_rate_currency_code = clearing_rate_currency_code end @interchange_amount = interchange_amount unless interchange_amount == SKIP @billback_amount = billback_amount unless billback_amount == SKIP @settlement_amount = settlement_amount unless settlement_amount == SKIP @settlement_currency_code = settlement_currency_code unless settlement_currency_code == SKIP @conversion_rate = conversion_rate unless conversion_rate == SKIP @delta_cost = delta_cost unless delta_cost == SKIP @surcharge_amount = surcharge_amount unless surcharge_amount == SKIP @percent_rate_charged = percent_rate_charged unless percent_rate_charged == SKIP @per_transaction_charged = per_transaction_charged unless per_transaction_charged == SKIP @downgrade_reason_code = downgrade_reason_code unless downgrade_reason_code == SKIP @process_time = process_time unless process_time == SKIP @auth_code = auth_code unless auth_code == SKIP @batch_time = batch_time unless batch_time == SKIP @processor_batch_number = processor_batch_number unless processor_batch_number == SKIP @card_indicator = card_indicator unless card_indicator == SKIP @minimum_unit = minimum_unit unless minimum_unit == SKIP unless minimum_unit_currency_code == SKIP @minimum_unit_currency_code = minimum_unit_currency_code end @credit_delta_indicator = credit_delta_indicator unless credit_delta_indicator == SKIP @fee_category = fee_category unless fee_category == SKIP @application_name = application_name unless application_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_id ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 23 def account_id @account_id end |
#account_suffix ⇒ String
TODO: Write general description for this method
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 39 def account_suffix @account_suffix end |
#amount ⇒ String
TODO: Write general description for this method
63 64 65 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 63 def amount @amount end |
#application_name ⇒ String
Valid ISO 4217 ALPHA-3 currency code
215 216 217 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 215 def application_name @application_name end |
#auth_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
183 184 185 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 183 def auth_code @auth_code end |
#batch_time ⇒ DateTime
Valid ISO 4217 ALPHA-3 currency code
187 188 189 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 187 def batch_time @batch_time end |
#billback_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code
143 144 145 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 143 def billback_amount @billback_amount end |
#billback_reason_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
103 104 105 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 103 def billback_reason_code @billback_reason_code end |
#billback_reason_description ⇒ String
Valid ISO 4217 ALPHA-3 currency code
107 108 109 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 107 def billback_reason_description @billback_reason_description end |
#card_indicator ⇒ String
Valid ISO 4217 ALPHA-3 currency code
195 196 197 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 195 def card_indicator @card_indicator end |
#cleared_level ⇒ String
Valid ISO 4217 ALPHA-3 currency code
99 100 101 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 99 def cleared_level @cleared_level end |
#clearing_rate_amount_one ⇒ String
Valid ISO 4217 ALPHA-3 currency code
123 124 125 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 123 def clearing_rate_amount_one @clearing_rate_amount_one end |
#clearing_rate_amount_three ⇒ String
Valid ISO 4217 ALPHA-3 currency code
131 132 133 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 131 def clearing_rate_amount_three @clearing_rate_amount_three end |
#clearing_rate_amount_two ⇒ String
Valid ISO 4217 ALPHA-3 currency code
127 128 129 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 127 def clearing_rate_amount_two @clearing_rate_amount_two end |
#clearing_rate_currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
135 136 137 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 135 def clearing_rate_currency_code @clearing_rate_currency_code end |
#conversion_rate ⇒ String
Valid ISO 4217 ALPHA-3 currency code
155 156 157 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 155 def conversion_rate @conversion_rate end |
#credit_delta_indicator ⇒ String
Valid ISO 4217 ALPHA-3 currency code
207 208 209 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 207 def credit_delta_indicator @credit_delta_indicator end |
#currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
67 68 69 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 67 def currency_code @currency_code end |
#delta_cost ⇒ String
Valid ISO 4217 ALPHA-3 currency code
159 160 161 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 159 def delta_cost @delta_cost end |
#discount_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code
119 120 121 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 119 def discount_amount @discount_amount end |
#discount_rate ⇒ String
Valid ISO 4217 ALPHA-3 currency code
115 116 117 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 115 def discount_rate @discount_rate end |
#downgrade_reason_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
175 176 177 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 175 def downgrade_reason_code @downgrade_reason_code end |
#fee_category ⇒ String
Valid ISO 4217 ALPHA-3 currency code
211 212 213 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 211 def fee_category @fee_category end |
#interchange_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code
139 140 141 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 139 def interchange_amount @interchange_amount end |
#merchant_batch_number ⇒ String
Valid ISO 4217 ALPHA-3 currency code
95 96 97 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 95 def merchant_batch_number @merchant_batch_number end |
#merchant_priced_level ⇒ String
Valid ISO 4217 ALPHA-3 currency code
111 112 113 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 111 def merchant_priced_level @merchant_priced_level end |
#merchant_reference_number ⇒ String
TODO: Write general description for this method
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 35 def merchant_reference_number @merchant_reference_number end |
#minimum_unit ⇒ Integer
Valid ISO 4217 ALPHA-3 currency code
199 200 201 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 199 def minimum_unit @minimum_unit end |
#minimum_unit_currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
203 204 205 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 203 def minimum_unit_currency_code @minimum_unit_currency_code end |
#organization_id ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 19 def organization_id @organization_id end |
#payment_sub_type ⇒ String
TODO: Write general description for this method
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 43 def payment_sub_type @payment_sub_type end |
#payment_sub_type_description ⇒ String
TODO: Write general description for this method
47 48 49 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 47 def payment_sub_type_description @payment_sub_type_description end |
#per_transaction_charged ⇒ String
Valid ISO 4217 ALPHA-3 currency code
171 172 173 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 171 def per_transaction_charged @per_transaction_charged end |
#percent_rate_charged ⇒ String
Valid ISO 4217 ALPHA-3 currency code
167 168 169 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 167 def percent_rate_charged @percent_rate_charged end |
#price_amount_one ⇒ String
Valid ISO 4217 ALPHA-3 currency code
75 76 77 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 75 def price_amount_one @price_amount_one end |
#price_amount_two ⇒ String
Valid ISO 4217 ALPHA-3 currency code
79 80 81 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 79 def price_amount_two @price_amount_two end |
#price_type ⇒ String
Valid ISO 4217 ALPHA-3 currency code
71 72 73 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 71 def price_type @price_type end |
#process_time ⇒ DateTime
Valid ISO 4217 ALPHA-3 currency code
179 180 181 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 179 def process_time @process_time end |
#processed_time ⇒ DateTime
TODO: Write general description for this method
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 55 def processed_time @processed_time end |
#processor_batch_number ⇒ String
Valid ISO 4217 ALPHA-3 currency code
191 192 193 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 191 def processor_batch_number @processor_batch_number end |
#processor_merchant_id ⇒ String
TODO: Write general description for this method
27 28 29 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 27 def processor_merchant_id @processor_merchant_id end |
#re_class ⇒ String
Valid ISO 4217 ALPHA-3 currency code
83 84 85 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 83 def re_class @re_class end |
#request_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 15 def request_id @request_id end |
#settlement_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code
147 148 149 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 147 def settlement_amount @settlement_amount end |
#settlement_currency_code ⇒ String
Valid ISO 4217 ALPHA-3 currency code
151 152 153 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 151 def settlement_currency_code @settlement_currency_code end |
#settlement_processor ⇒ String
Valid ISO 4217 ALPHA-3 currency code
91 92 93 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 91 def settlement_processor @settlement_processor end |
#settlement_time ⇒ DateTime
Valid ISO 4217 ALPHA-3 currency code
87 88 89 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 87 def settlement_time @settlement_time end |
#surcharge_amount ⇒ String
Valid ISO 4217 ALPHA-3 currency code
163 164 165 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 163 def surcharge_amount @surcharge_amount end |
#transaction_reference_number ⇒ String
TODO: Write general description for this method
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 31 def transaction_reference_number @transaction_reference_number end |
#transaction_time ⇒ DateTime
TODO: Write general description for this method
51 52 53 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 51 def transaction_time @transaction_time end |
#transaction_type ⇒ String
TODO: Write general description for this method
59 60 61 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 59 def transaction_type @transaction_type end |
Class Method Details
.from_element(root) ⇒ Object
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 633 def self.from_element(root) request_id = XmlUtilities.from_element(root, 'requestId', String) organization_id = XmlUtilities.from_element(root, 'organizationId', String) account_id = XmlUtilities.from_element(root, 'accountId', String) processor_merchant_id = XmlUtilities.from_element(root, 'processorMerchantId', String) transaction_reference_number = XmlUtilities.from_element( root, 'transactionReferenceNumber', String ) merchant_reference_number = XmlUtilities.from_element( root, 'merchantReferenceNumber', String ) account_suffix = XmlUtilities.from_element(root, 'accountSuffix', String) payment_sub_type = XmlUtilities.from_element(root, 'paymentSubType', String) payment_sub_type_description = XmlUtilities.from_element( root, 'paymentSubTypeDescription', String ) transaction_time = XmlUtilities.from_element(root, 'transactionTime', String, datetime_format: 'rfc3339') processed_time = XmlUtilities.from_element(root, 'processedTime', String, datetime_format: 'rfc3339') transaction_type = XmlUtilities.from_element(root, 'transactionType', String) amount = XmlUtilities.from_element(root, 'amount', String) currency_code = XmlUtilities.from_element(root, 'currencyCode', String) price_type = XmlUtilities.from_element(root, 'priceType', String) price_amount_one = XmlUtilities.from_element(root, 'priceAmountOne', String) price_amount_two = XmlUtilities.from_element(root, 'priceAmountTwo', String) re_class = XmlUtilities.from_element(root, 'reClass', String) settlement_time = XmlUtilities.from_element(root, 'settlementTime', String, datetime_format: 'rfc3339') settlement_processor = XmlUtilities.from_element(root, 'settlementProcessor', String) merchant_batch_number = XmlUtilities.from_element(root, 'merchantBatchNumber', String) cleared_level = XmlUtilities.from_element(root, 'clearedLevel', String) billback_reason_code = XmlUtilities.from_element(root, 'billbackReasonCode', String) billback_reason_description = XmlUtilities.from_element( root, 'billbackReasonDescription', String ) merchant_priced_level = XmlUtilities.from_element(root, 'merchantPricedLevel', String) discount_rate = XmlUtilities.from_element(root, 'discountRate', String) discount_amount = XmlUtilities.from_element(root, 'discountAmount', String) clearing_rate_amount_one = XmlUtilities.from_element( root, 'clearingRateAmountOne', String ) clearing_rate_amount_two = XmlUtilities.from_element( root, 'clearingRateAmountTwo', String ) clearing_rate_amount_three = XmlUtilities.from_element( root, 'clearingRateAmountThree', String ) clearing_rate_currency_code = XmlUtilities.from_element( root, 'clearingRateCurrencyCode', String ) interchange_amount = XmlUtilities.from_element(root, 'interchangeAmount', String) billback_amount = XmlUtilities.from_element(root, 'billbackAmount', String) settlement_amount = XmlUtilities.from_element(root, 'settlementAmount', String) settlement_currency_code = XmlUtilities.from_element( root, 'settlementCurrencyCode', String ) conversion_rate = XmlUtilities.from_element(root, 'conversionRate', String) delta_cost = XmlUtilities.from_element(root, 'deltaCost', String) surcharge_amount = XmlUtilities.from_element(root, 'surchargeAmount', String) percent_rate_charged = XmlUtilities.from_element(root, 'percentRateCharged', String) per_transaction_charged = XmlUtilities.from_element( root, 'perTransactionCharged', String ) downgrade_reason_code = XmlUtilities.from_element(root, 'downgradeReasonCode', String) process_time = XmlUtilities.from_element(root, 'processTime', String, datetime_format: 'rfc3339') auth_code = XmlUtilities.from_element(root, 'authCode', String) batch_time = XmlUtilities.from_element(root, 'batchTime', String, datetime_format: 'rfc3339') processor_batch_number = XmlUtilities.from_element(root, 'processorBatchNumber', String) card_indicator = XmlUtilities.from_element(root, 'cardIndicator', String) minimum_unit = XmlUtilities.from_element(root, 'minimumUnit', Integer) minimum_unit_currency_code = XmlUtilities.from_element( root, 'minimumUnitCurrencyCode', String ) credit_delta_indicator = XmlUtilities.from_element(root, 'creditDeltaIndicator', String) fee_category = XmlUtilities.from_element(root, 'feeCategory', String) application_name = XmlUtilities.from_element(root, 'applicationName', String) new(request_id: request_id, organization_id: organization_id, account_id: account_id, processor_merchant_id: processor_merchant_id, transaction_reference_number: transaction_reference_number, merchant_reference_number: merchant_reference_number, account_suffix: account_suffix, payment_sub_type: payment_sub_type, payment_sub_type_description: payment_sub_type_description, transaction_time: transaction_time, processed_time: processed_time, transaction_type: transaction_type, amount: amount, currency_code: currency_code, price_type: price_type, price_amount_one: price_amount_one, price_amount_two: price_amount_two, re_class: re_class, settlement_time: settlement_time, settlement_processor: settlement_processor, merchant_batch_number: merchant_batch_number, cleared_level: cleared_level, billback_reason_code: billback_reason_code, billback_reason_description: billback_reason_description, merchant_priced_level: merchant_priced_level, discount_rate: discount_rate, discount_amount: discount_amount, clearing_rate_amount_one: clearing_rate_amount_one, clearing_rate_amount_two: clearing_rate_amount_two, clearing_rate_amount_three: clearing_rate_amount_three, clearing_rate_currency_code: clearing_rate_currency_code, interchange_amount: interchange_amount, billback_amount: billback_amount, settlement_amount: settlement_amount, settlement_currency_code: settlement_currency_code, conversion_rate: conversion_rate, delta_cost: delta_cost, surcharge_amount: surcharge_amount, percent_rate_charged: percent_rate_charged, per_transaction_charged: per_transaction_charged, downgrade_reason_code: downgrade_reason_code, process_time: process_time, auth_code: auth_code, batch_time: batch_time, processor_batch_number: processor_batch_number, card_indicator: card_indicator, minimum_unit: minimum_unit, minimum_unit_currency_code: minimum_unit_currency_code, credit_delta_indicator: credit_delta_indicator, fee_category: fee_category, application_name: application_name, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 443 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('requestId') ? hash['requestId'] : SKIP organization_id = hash.key?('organizationId') ? hash['organizationId'] : SKIP account_id = hash.key?('accountId') ? hash['accountId'] : SKIP processor_merchant_id = hash.key?('processorMerchantId') ? hash['processorMerchantId'] : SKIP transaction_reference_number = hash.key?('transactionReferenceNumber') ? hash['transactionReferenceNumber'] : SKIP merchant_reference_number = hash.key?('merchantReferenceNumber') ? hash['merchantReferenceNumber'] : SKIP account_suffix = hash.key?('accountSuffix') ? hash['accountSuffix'] : SKIP payment_sub_type = hash.key?('paymentSubType') ? hash['paymentSubType'] : SKIP payment_sub_type_description = hash.key?('paymentSubTypeDescription') ? hash['paymentSubTypeDescription'] : SKIP transaction_time = if hash.key?('transactionTime') (DateTimeHelper.from_rfc3339(hash['transactionTime']) if hash['transactionTime']) else SKIP end processed_time = if hash.key?('processedTime') (DateTimeHelper.from_rfc3339(hash['processedTime']) if hash['processedTime']) else SKIP end transaction_type = hash.key?('transactionType') ? hash['transactionType'] : SKIP amount = hash.key?('amount') ? hash['amount'] : SKIP currency_code = hash.key?('currencyCode') ? hash['currencyCode'] : SKIP price_type = hash.key?('priceType') ? hash['priceType'] : SKIP price_amount_one = hash.key?('priceAmountOne') ? hash['priceAmountOne'] : SKIP price_amount_two = hash.key?('priceAmountTwo') ? hash['priceAmountTwo'] : SKIP re_class = hash.key?('reClass') ? hash['reClass'] : SKIP settlement_time = if hash.key?('settlementTime') (DateTimeHelper.from_rfc3339(hash['settlementTime']) if hash['settlementTime']) else SKIP end settlement_processor = hash.key?('settlementProcessor') ? hash['settlementProcessor'] : SKIP merchant_batch_number = hash.key?('merchantBatchNumber') ? hash['merchantBatchNumber'] : SKIP cleared_level = hash.key?('clearedLevel') ? hash['clearedLevel'] : SKIP billback_reason_code = hash.key?('billbackReasonCode') ? hash['billbackReasonCode'] : SKIP billback_reason_description = hash.key?('billbackReasonDescription') ? hash['billbackReasonDescription'] : SKIP merchant_priced_level = hash.key?('merchantPricedLevel') ? hash['merchantPricedLevel'] : SKIP discount_rate = hash.key?('discountRate') ? hash['discountRate'] : SKIP discount_amount = hash.key?('discountAmount') ? hash['discountAmount'] : SKIP clearing_rate_amount_one = hash.key?('clearingRateAmountOne') ? hash['clearingRateAmountOne'] : SKIP clearing_rate_amount_two = hash.key?('clearingRateAmountTwo') ? hash['clearingRateAmountTwo'] : SKIP clearing_rate_amount_three = hash.key?('clearingRateAmountThree') ? hash['clearingRateAmountThree'] : SKIP clearing_rate_currency_code = hash.key?('clearingRateCurrencyCode') ? hash['clearingRateCurrencyCode'] : SKIP interchange_amount = hash.key?('interchangeAmount') ? hash['interchangeAmount'] : SKIP billback_amount = hash.key?('billbackAmount') ? hash['billbackAmount'] : SKIP settlement_amount = hash.key?('settlementAmount') ? hash['settlementAmount'] : SKIP settlement_currency_code = hash.key?('settlementCurrencyCode') ? hash['settlementCurrencyCode'] : SKIP conversion_rate = hash.key?('conversionRate') ? hash['conversionRate'] : SKIP delta_cost = hash.key?('deltaCost') ? hash['deltaCost'] : SKIP surcharge_amount = hash.key?('surchargeAmount') ? hash['surchargeAmount'] : SKIP percent_rate_charged = hash.key?('percentRateCharged') ? hash['percentRateCharged'] : SKIP per_transaction_charged = hash.key?('perTransactionCharged') ? hash['perTransactionCharged'] : SKIP downgrade_reason_code = hash.key?('downgradeReasonCode') ? hash['downgradeReasonCode'] : SKIP process_time = if hash.key?('processTime') (DateTimeHelper.from_rfc3339(hash['processTime']) if hash['processTime']) else SKIP end auth_code = hash.key?('authCode') ? hash['authCode'] : SKIP batch_time = if hash.key?('batchTime') (DateTimeHelper.from_rfc3339(hash['batchTime']) if hash['batchTime']) else SKIP end processor_batch_number = hash.key?('processorBatchNumber') ? hash['processorBatchNumber'] : SKIP card_indicator = hash.key?('cardIndicator') ? hash['cardIndicator'] : SKIP minimum_unit = hash.key?('minimumUnit') ? hash['minimumUnit'] : SKIP minimum_unit_currency_code = hash.key?('minimumUnitCurrencyCode') ? hash['minimumUnitCurrencyCode'] : SKIP credit_delta_indicator = hash.key?('creditDeltaIndicator') ? hash['creditDeltaIndicator'] : SKIP fee_category = hash.key?('feeCategory') ? hash['feeCategory'] : SKIP application_name = hash.key?('applicationName') ? hash['applicationName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InterchangeClearingLevelDetail.new(request_id: request_id, organization_id: organization_id, account_id: account_id, processor_merchant_id: processor_merchant_id, transaction_reference_number: transaction_reference_number, merchant_reference_number: merchant_reference_number, account_suffix: account_suffix, payment_sub_type: payment_sub_type, payment_sub_type_description: payment_sub_type_description, transaction_time: transaction_time, processed_time: processed_time, transaction_type: transaction_type, amount: amount, currency_code: currency_code, price_type: price_type, price_amount_one: price_amount_one, price_amount_two: price_amount_two, re_class: re_class, settlement_time: settlement_time, settlement_processor: settlement_processor, merchant_batch_number: merchant_batch_number, cleared_level: cleared_level, billback_reason_code: billback_reason_code, billback_reason_description: billback_reason_description, merchant_priced_level: merchant_priced_level, discount_rate: discount_rate, discount_amount: discount_amount, clearing_rate_amount_one: clearing_rate_amount_one, clearing_rate_amount_two: clearing_rate_amount_two, clearing_rate_amount_three: clearing_rate_amount_three, clearing_rate_currency_code: clearing_rate_currency_code, interchange_amount: interchange_amount, billback_amount: billback_amount, settlement_amount: settlement_amount, settlement_currency_code: settlement_currency_code, conversion_rate: conversion_rate, delta_cost: delta_cost, surcharge_amount: surcharge_amount, percent_rate_charged: percent_rate_charged, per_transaction_charged: per_transaction_charged, downgrade_reason_code: downgrade_reason_code, process_time: process_time, auth_code: auth_code, batch_time: batch_time, processor_batch_number: processor_batch_number, card_indicator: card_indicator, minimum_unit: minimum_unit, minimum_unit_currency_code: minimum_unit_currency_code, credit_delta_indicator: credit_delta_indicator, fee_category: fee_category, application_name: application_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 218 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'requestId' @_hash['organization_id'] = 'organizationId' @_hash['account_id'] = 'accountId' @_hash['processor_merchant_id'] = 'processorMerchantId' @_hash['transaction_reference_number'] = 'transactionReferenceNumber' @_hash['merchant_reference_number'] = 'merchantReferenceNumber' @_hash['account_suffix'] = 'accountSuffix' @_hash['payment_sub_type'] = 'paymentSubType' @_hash['payment_sub_type_description'] = 'paymentSubTypeDescription' @_hash['transaction_time'] = 'transactionTime' @_hash['processed_time'] = 'processedTime' @_hash['transaction_type'] = 'transactionType' @_hash['amount'] = 'amount' @_hash['currency_code'] = 'currencyCode' @_hash['price_type'] = 'priceType' @_hash['price_amount_one'] = 'priceAmountOne' @_hash['price_amount_two'] = 'priceAmountTwo' @_hash['re_class'] = 'reClass' @_hash['settlement_time'] = 'settlementTime' @_hash['settlement_processor'] = 'settlementProcessor' @_hash['merchant_batch_number'] = 'merchantBatchNumber' @_hash['cleared_level'] = 'clearedLevel' @_hash['billback_reason_code'] = 'billbackReasonCode' @_hash['billback_reason_description'] = 'billbackReasonDescription' @_hash['merchant_priced_level'] = 'merchantPricedLevel' @_hash['discount_rate'] = 'discountRate' @_hash['discount_amount'] = 'discountAmount' @_hash['clearing_rate_amount_one'] = 'clearingRateAmountOne' @_hash['clearing_rate_amount_two'] = 'clearingRateAmountTwo' @_hash['clearing_rate_amount_three'] = 'clearingRateAmountThree' @_hash['clearing_rate_currency_code'] = 'clearingRateCurrencyCode' @_hash['interchange_amount'] = 'interchangeAmount' @_hash['billback_amount'] = 'billbackAmount' @_hash['settlement_amount'] = 'settlementAmount' @_hash['settlement_currency_code'] = 'settlementCurrencyCode' @_hash['conversion_rate'] = 'conversionRate' @_hash['delta_cost'] = 'deltaCost' @_hash['surcharge_amount'] = 'surchargeAmount' @_hash['percent_rate_charged'] = 'percentRateCharged' @_hash['per_transaction_charged'] = 'perTransactionCharged' @_hash['downgrade_reason_code'] = 'downgradeReasonCode' @_hash['process_time'] = 'processTime' @_hash['auth_code'] = 'authCode' @_hash['batch_time'] = 'batchTime' @_hash['processor_batch_number'] = 'processorBatchNumber' @_hash['card_indicator'] = 'cardIndicator' @_hash['minimum_unit'] = 'minimumUnit' @_hash['minimum_unit_currency_code'] = 'minimumUnitCurrencyCode' @_hash['credit_delta_indicator'] = 'creditDeltaIndicator' @_hash['fee_category'] = 'feeCategory' @_hash['application_name'] = 'applicationName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
332 333 334 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 332 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 275 def self.optionals %w[ request_id organization_id account_id processor_merchant_id transaction_reference_number merchant_reference_number account_suffix payment_sub_type payment_sub_type_description transaction_time processed_time transaction_type amount currency_code price_type price_amount_one price_amount_two re_class settlement_time settlement_processor merchant_batch_number cleared_level billback_reason_code billback_reason_description merchant_priced_level discount_rate discount_amount clearing_rate_amount_one clearing_rate_amount_two clearing_rate_amount_three clearing_rate_currency_code interchange_amount billback_amount settlement_amount settlement_currency_code conversion_rate delta_cost surcharge_amount percent_rate_charged per_transaction_charged downgrade_reason_code process_time auth_code batch_time processor_batch_number card_indicator minimum_unit minimum_unit_currency_code credit_delta_indicator fee_category application_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 932 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, organization_id:"\ " #{@organization_id.inspect}, account_id: #{@account_id.inspect}, processor_merchant_id:"\ " #{@processor_merchant_id.inspect}, transaction_reference_number:"\ " #{@transaction_reference_number.inspect}, merchant_reference_number:"\ " #{@merchant_reference_number.inspect}, account_suffix: #{@account_suffix.inspect},"\ " payment_sub_type: #{@payment_sub_type.inspect}, payment_sub_type_description:"\ " #{@payment_sub_type_description.inspect}, transaction_time: #{@transaction_time.inspect},"\ " processed_time: #{@processed_time.inspect}, transaction_type:"\ " #{@transaction_type.inspect}, amount: #{@amount.inspect}, currency_code:"\ " #{@currency_code.inspect}, price_type: #{@price_type.inspect}, price_amount_one:"\ " #{@price_amount_one.inspect}, price_amount_two: #{@price_amount_two.inspect}, re_class:"\ " #{@re_class.inspect}, settlement_time: #{@settlement_time.inspect}, settlement_processor:"\ " #{@settlement_processor.inspect}, merchant_batch_number:"\ " #{@merchant_batch_number.inspect}, cleared_level: #{@cleared_level.inspect},"\ " billback_reason_code: #{@billback_reason_code.inspect}, billback_reason_description:"\ " #{@billback_reason_description.inspect}, merchant_priced_level:"\ " #{@merchant_priced_level.inspect}, discount_rate: #{@discount_rate.inspect},"\ " discount_amount: #{@discount_amount.inspect}, clearing_rate_amount_one:"\ " #{@clearing_rate_amount_one.inspect}, clearing_rate_amount_two:"\ " #{@clearing_rate_amount_two.inspect}, clearing_rate_amount_three:"\ " #{@clearing_rate_amount_three.inspect}, clearing_rate_currency_code:"\ " #{@clearing_rate_currency_code.inspect}, interchange_amount:"\ " #{@interchange_amount.inspect}, billback_amount: #{@billback_amount.inspect},"\ " settlement_amount: #{@settlement_amount.inspect}, settlement_currency_code:"\ " #{@settlement_currency_code.inspect}, conversion_rate: #{@conversion_rate.inspect},"\ " delta_cost: #{@delta_cost.inspect}, surcharge_amount: #{@surcharge_amount.inspect},"\ " percent_rate_charged: #{@percent_rate_charged.inspect}, per_transaction_charged:"\ " #{@per_transaction_charged.inspect}, downgrade_reason_code:"\ " #{@downgrade_reason_code.inspect}, process_time: #{@process_time.inspect}, auth_code:"\ " #{@auth_code.inspect}, batch_time: #{@batch_time.inspect}, processor_batch_number:"\ " #{@processor_batch_number.inspect}, card_indicator: #{@card_indicator.inspect},"\ " minimum_unit: #{@minimum_unit.inspect}, minimum_unit_currency_code:"\ " #{@minimum_unit_currency_code.inspect}, credit_delta_indicator:"\ " #{@credit_delta_indicator.inspect}, fee_category: #{@fee_category.inspect},"\ " application_name: #{@application_name.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_custom_batch_time ⇒ Object
629 630 631 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 629 def to_custom_batch_time DateTimeHelper.to_rfc3339(batch_time) end |
#to_custom_process_time ⇒ Object
625 626 627 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 625 def to_custom_process_time DateTimeHelper.to_rfc3339(process_time) end |
#to_custom_processed_time ⇒ Object
617 618 619 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 617 def to_custom_processed_time DateTimeHelper.to_rfc3339(processed_time) end |
#to_custom_settlement_time ⇒ Object
621 622 623 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 621 def to_custom_settlement_time DateTimeHelper.to_rfc3339(settlement_time) end |
#to_custom_transaction_time ⇒ Object
613 614 615 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 613 def to_custom_transaction_time DateTimeHelper.to_rfc3339(transaction_time) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 899 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, organization_id: #{@organization_id},"\ " account_id: #{@account_id}, processor_merchant_id: #{@processor_merchant_id},"\ " transaction_reference_number: #{@transaction_reference_number}, merchant_reference_number:"\ " #{@merchant_reference_number}, account_suffix: #{@account_suffix}, payment_sub_type:"\ " #{@payment_sub_type}, payment_sub_type_description: #{@payment_sub_type_description},"\ " transaction_time: #{@transaction_time}, processed_time: #{@processed_time},"\ " transaction_type: #{@transaction_type}, amount: #{@amount}, currency_code:"\ " #{@currency_code}, price_type: #{@price_type}, price_amount_one: #{@price_amount_one},"\ " price_amount_two: #{@price_amount_two}, re_class: #{@re_class}, settlement_time:"\ " #{@settlement_time}, settlement_processor: #{@settlement_processor},"\ " merchant_batch_number: #{@merchant_batch_number}, cleared_level: #{@cleared_level},"\ " billback_reason_code: #{@billback_reason_code}, billback_reason_description:"\ " #{@billback_reason_description}, merchant_priced_level: #{@merchant_priced_level},"\ " discount_rate: #{@discount_rate}, discount_amount: #{@discount_amount},"\ " clearing_rate_amount_one: #{@clearing_rate_amount_one}, clearing_rate_amount_two:"\ " #{@clearing_rate_amount_two}, clearing_rate_amount_three: #{@clearing_rate_amount_three},"\ " clearing_rate_currency_code: #{@clearing_rate_currency_code}, interchange_amount:"\ " #{@interchange_amount}, billback_amount: #{@billback_amount}, settlement_amount:"\ " #{@settlement_amount}, settlement_currency_code: #{@settlement_currency_code},"\ " conversion_rate: #{@conversion_rate}, delta_cost: #{@delta_cost}, surcharge_amount:"\ " #{@surcharge_amount}, percent_rate_charged: #{@percent_rate_charged},"\ " per_transaction_charged: #{@per_transaction_charged}, downgrade_reason_code:"\ " #{@downgrade_reason_code}, process_time: #{@process_time}, auth_code: #{@auth_code},"\ " batch_time: #{@batch_time}, processor_batch_number: #{@processor_batch_number},"\ " card_indicator: #{@card_indicator}, minimum_unit: #{@minimum_unit},"\ " minimum_unit_currency_code: #{@minimum_unit_currency_code}, credit_delta_indicator:"\ " #{@credit_delta_indicator}, fee_category: #{@fee_category}, application_name:"\ " #{@application_name}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 |
# File 'lib/cyber_source_merged_spec/models/interchange_clearing_level_detail.rb', line 799 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'requestId', request_id) XmlUtilities.add_as_subelement(doc, root, 'organizationId', organization_id) XmlUtilities.add_as_subelement(doc, root, 'accountId', account_id) XmlUtilities.add_as_subelement(doc, root, 'processorMerchantId', processor_merchant_id) XmlUtilities.add_as_subelement(doc, root, 'transactionReferenceNumber', transaction_reference_number) XmlUtilities.add_as_subelement(doc, root, 'merchantReferenceNumber', merchant_reference_number) XmlUtilities.add_as_subelement(doc, root, 'accountSuffix', account_suffix) XmlUtilities.add_as_subelement(doc, root, 'paymentSubType', payment_sub_type) XmlUtilities.add_as_subelement(doc, root, 'paymentSubTypeDescription', payment_sub_type_description) XmlUtilities.add_as_subelement(doc, root, 'transactionTime', transaction_time, datetime_format: 'rfc3339') XmlUtilities.add_as_subelement(doc, root, 'processedTime', processed_time, datetime_format: 'rfc3339') XmlUtilities.add_as_subelement(doc, root, 'transactionType', transaction_type) XmlUtilities.add_as_subelement(doc, root, 'amount', amount) XmlUtilities.add_as_subelement(doc, root, 'currencyCode', currency_code) XmlUtilities.add_as_subelement(doc, root, 'priceType', price_type) XmlUtilities.add_as_subelement(doc, root, 'priceAmountOne', price_amount_one) XmlUtilities.add_as_subelement(doc, root, 'priceAmountTwo', price_amount_two) XmlUtilities.add_as_subelement(doc, root, 'reClass', re_class) XmlUtilities.add_as_subelement(doc, root, 'settlementTime', settlement_time, datetime_format: 'rfc3339') XmlUtilities.add_as_subelement(doc, root, 'settlementProcessor', settlement_processor) XmlUtilities.add_as_subelement(doc, root, 'merchantBatchNumber', merchant_batch_number) XmlUtilities.add_as_subelement(doc, root, 'clearedLevel', cleared_level) XmlUtilities.add_as_subelement(doc, root, 'billbackReasonCode', billback_reason_code) XmlUtilities.add_as_subelement(doc, root, 'billbackReasonDescription', billback_reason_description) XmlUtilities.add_as_subelement(doc, root, 'merchantPricedLevel', merchant_priced_level) XmlUtilities.add_as_subelement(doc, root, 'discountRate', discount_rate) XmlUtilities.add_as_subelement(doc, root, 'discountAmount', discount_amount) XmlUtilities.add_as_subelement(doc, root, 'clearingRateAmountOne', clearing_rate_amount_one) XmlUtilities.add_as_subelement(doc, root, 'clearingRateAmountTwo', clearing_rate_amount_two) XmlUtilities.add_as_subelement(doc, root, 'clearingRateAmountThree', clearing_rate_amount_three) XmlUtilities.add_as_subelement(doc, root, 'clearingRateCurrencyCode', clearing_rate_currency_code) XmlUtilities.add_as_subelement(doc, root, 'interchangeAmount', interchange_amount) XmlUtilities.add_as_subelement(doc, root, 'billbackAmount', billback_amount) XmlUtilities.add_as_subelement(doc, root, 'settlementAmount', settlement_amount) XmlUtilities.add_as_subelement(doc, root, 'settlementCurrencyCode', settlement_currency_code) XmlUtilities.add_as_subelement(doc, root, 'conversionRate', conversion_rate) XmlUtilities.add_as_subelement(doc, root, 'deltaCost', delta_cost) XmlUtilities.add_as_subelement(doc, root, 'surchargeAmount', surcharge_amount) XmlUtilities.add_as_subelement(doc, root, 'percentRateCharged', percent_rate_charged) XmlUtilities.add_as_subelement(doc, root, 'perTransactionCharged', per_transaction_charged) XmlUtilities.add_as_subelement(doc, root, 'downgradeReasonCode', downgrade_reason_code) XmlUtilities.add_as_subelement(doc, root, 'processTime', process_time, datetime_format: 'rfc3339') XmlUtilities.add_as_subelement(doc, root, 'authCode', auth_code) XmlUtilities.add_as_subelement(doc, root, 'batchTime', batch_time, datetime_format: 'rfc3339') XmlUtilities.add_as_subelement(doc, root, 'processorBatchNumber', processor_batch_number) XmlUtilities.add_as_subelement(doc, root, 'cardIndicator', card_indicator) XmlUtilities.add_as_subelement(doc, root, 'minimumUnit', minimum_unit) XmlUtilities.add_as_subelement(doc, root, 'minimumUnitCurrencyCode', minimum_unit_currency_code) XmlUtilities.add_as_subelement(doc, root, 'creditDeltaIndicator', credit_delta_indicator) XmlUtilities.add_as_subelement(doc, root, 'feeCategory', fee_category) XmlUtilities.add_as_subelement(doc, root, 'applicationName', application_name) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |