Class: CyberSourceMergedSpec::Invoice1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Invoice1
- Defined in:
- lib/cyber_source_merged_spec/models/invoice1.rb
Overview
A list of invoices.
Instance Attribute Summary collapse
-
#created_date ⇒ String
Date and time (UTC) the invoice was created.
-
#customer_information ⇒ CustomerInformation2
Date and time (UTC) the invoice was created.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#invoice_information ⇒ InvoiceInformation2
Date and time (UTC) the invoice was created.
-
#links ⇒ Links251
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation62
Contains all of the order-related fields, such as the amount and line item details.
-
#status ⇒ String
The status of the invoice.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, status: SKIP, created_date: SKIP, customer_information: SKIP, invoice_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ Invoice1
constructor
A new instance of Invoice1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, status: SKIP, created_date: SKIP, customer_information: SKIP, invoice_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ Invoice1
Returns a new instance of Invoice1.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 93 def initialize(links: SKIP, id: SKIP, status: SKIP, created_date: SKIP, customer_information: SKIP, invoice_information: SKIP, order_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @status = status unless status == SKIP @created_date = created_date unless created_date == SKIP @customer_information = customer_information unless customer_information == SKIP @invoice_information = invoice_information unless invoice_information == SKIP @order_information = order_information unless order_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#created_date ⇒ String
Date and time (UTC) the invoice was created. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC.
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 41 def created_date @created_date end |
#customer_information ⇒ CustomerInformation2
Date and time (UTC) the invoice was created. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC.
48 49 50 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 48 def customer_information @customer_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 22 def id @id end |
#invoice_information ⇒ InvoiceInformation2
Date and time (UTC) the invoice was created. Format: YYYY-MM-DDThh:mm:ssZ Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC.
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 55 def invoice_information @invoice_information end |
#links ⇒ Links251
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 14 def links @links end |
#order_information ⇒ OrderInformation62
Contains all of the order-related fields, such as the amount and line item details.
60 61 62 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 60 def order_information @order_information end |
#status ⇒ String
The status of the invoice. Possible values:
- DRAFT
- CREATED
- SENT
- PARTIAL
- PAID
- CANCELED
- PENDING
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 34 def status @status end |
Class Method Details
.from_element(root) ⇒ Object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 143 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links251', Links251) id = XmlUtilities.from_element(root, 'id', String) status = XmlUtilities.from_element(root, 'status', String) created_date = XmlUtilities.from_element(root, 'createdDate', String) customer_information = XmlUtilities.from_element(root, 'CustomerInformation2', CustomerInformation2) invoice_information = XmlUtilities.from_element(root, 'InvoiceInformation2', InvoiceInformation2) order_information = XmlUtilities.from_element(root, 'OrderInformation62', OrderInformation62) new(links: links, id: id, status: status, created_date: created_date, customer_information: customer_information, invoice_information: invoice_information, order_information: order_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 110 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links251.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP created_date = hash.key?('createdDate') ? hash['createdDate'] : SKIP customer_information = CustomerInformation2.from_hash(hash['customerInformation']) if hash['customerInformation'] invoice_information = InvoiceInformation2.from_hash(hash['invoiceInformation']) if hash['invoiceInformation'] order_information = OrderInformation62.from_hash(hash['orderInformation']) if hash['orderInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Invoice1.new(links: links, id: id, status: status, created_date: created_date, customer_information: customer_information, invoice_information: invoice_information, order_information: order_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 63 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['status'] = 'status' @_hash['created_date'] = 'createdDate' @_hash['customer_information'] = 'customerInformation' @_hash['invoice_information'] = 'invoiceInformation' @_hash['order_information'] = 'orderInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
89 90 91 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 89 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 76 def self.optionals %w[ links id status created_date customer_information invoice_information order_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
196 197 198 199 200 201 202 203 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 196 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, status: #{@status.inspect},"\ " created_date: #{@created_date.inspect}, customer_information:"\ " #{@customer_information.inspect}, invoice_information: #{@invoice_information.inspect},"\ " order_information: #{@order_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
187 188 189 190 191 192 193 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 187 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, status: #{@status}, created_date:"\ " #{@created_date}, customer_information: #{@customer_information}, invoice_information:"\ " #{@invoice_information}, order_information: #{@order_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/cyber_source_merged_spec/models/invoice1.rb', line 167 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links251', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'createdDate', created_date) XmlUtilities.add_as_subelement(doc, root, 'CustomerInformation2', customer_information) XmlUtilities.add_as_subelement(doc, root, 'InvoiceInformation2', invoice_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation62', order_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |