Class: CyberSourceMergedSpec::IssuerInformation33
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::IssuerInformation33
- Defined in:
- lib/cyber_source_merged_spec/models/issuer_information33.rb
Overview
IssuerInformation33 Model.
Instance Attribute Summary collapse
-
#oct_cross_border_participant_indicator ⇒ TrueClass | FalseClass
Cross-border indicator for push funds (OCT).
-
#oct_domestic_participant_indicator ⇒ TrueClass | FalseClass
Domestic indicator for Push funds (OCT).
-
#oct_money_transfer_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border money transfer OCTs (push funds) are allowed.
-
#oct_money_transfer_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic money transfer OCTs (push funds) are allowed.
-
#oct_money_transfer_fast_funds_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border money transfer OCTs (fast push funds) are allowed.
-
#oct_money_transfer_fast_funds_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic money transfer OCTs (fast push funds) are allowed.
-
#oct_money_transfer_merchant_country_restricted ⇒ TrueClass | FalseClass
This field indicates if the recipient issuer can accept push funds (OCT) transactions from the merchant country.
-
#oct_non_money_transfer_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border non-money transfer OCTs (push funds) are allowed.
-
#oct_non_money_transfer_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic non-money transfer OCTs (push funds) are allowed.
-
#oct_non_money_transfer_fast_funds_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border non-money transfer OCTs (fast push funds) are allowed.
-
#oct_non_money_transfer_fast_funds_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic non-money transfer OCTs (fast push funds) are allowed.
-
#oct_online_gambling_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border gambling OCTs (push funds) are allowed.
-
#oct_online_gambling_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic gambling OCTs (push funds) are allowed.
-
#oct_online_gambling_fast_funds_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border gambling OCTs (fast push funds) are allowed.
-
#oct_online_gambling_fast_funds_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic gambling OCTs (fast push funds) are allowed.
-
#service_processing_type ⇒ String
This field contains values that identify the service type under which the transaction should be processed.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(oct_domestic_participant_indicator: SKIP, oct_cross_border_participant_indicator: SKIP, oct_money_transfer_domestic_indicator: SKIP, oct_money_transfer_cross_border_indicator: SKIP, oct_money_transfer_fast_funds_domestic_indicator: SKIP, oct_money_transfer_fast_funds_cross_border_indicator: SKIP, oct_money_transfer_merchant_country_restricted: SKIP, oct_non_money_transfer_domestic_indicator: SKIP, oct_non_money_transfer_cross_border_indicator: SKIP, oct_non_money_transfer_fast_funds_domestic_indicator: SKIP, oct_non_money_transfer_fast_funds_cross_border_indicator: SKIP, oct_online_gambling_domestic_indicator: SKIP, oct_online_gambling_cross_border_indicator: SKIP, oct_online_gambling_fast_funds_domestic_indicator: SKIP, oct_online_gambling_fast_funds_cross_border_indicator: SKIP, service_processing_type: SKIP, additional_properties: nil) ⇒ IssuerInformation33
constructor
A new instance of IssuerInformation33.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(oct_domestic_participant_indicator: SKIP, oct_cross_border_participant_indicator: SKIP, oct_money_transfer_domestic_indicator: SKIP, oct_money_transfer_cross_border_indicator: SKIP, oct_money_transfer_fast_funds_domestic_indicator: SKIP, oct_money_transfer_fast_funds_cross_border_indicator: SKIP, oct_money_transfer_merchant_country_restricted: SKIP, oct_non_money_transfer_domestic_indicator: SKIP, oct_non_money_transfer_cross_border_indicator: SKIP, oct_non_money_transfer_fast_funds_domestic_indicator: SKIP, oct_non_money_transfer_fast_funds_cross_border_indicator: SKIP, oct_online_gambling_domestic_indicator: SKIP, oct_online_gambling_cross_border_indicator: SKIP, oct_online_gambling_fast_funds_domestic_indicator: SKIP, oct_online_gambling_fast_funds_cross_border_indicator: SKIP, service_processing_type: SKIP, additional_properties: nil) ⇒ IssuerInformation33
Returns a new instance of IssuerInformation33.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 191 def initialize( oct_domestic_participant_indicator: SKIP, oct_cross_border_participant_indicator: SKIP, oct_money_transfer_domestic_indicator: SKIP, oct_money_transfer_cross_border_indicator: SKIP, oct_money_transfer_fast_funds_domestic_indicator: SKIP, oct_money_transfer_fast_funds_cross_border_indicator: SKIP, oct_money_transfer_merchant_country_restricted: SKIP, oct_non_money_transfer_domestic_indicator: SKIP, oct_non_money_transfer_cross_border_indicator: SKIP, oct_non_money_transfer_fast_funds_domestic_indicator: SKIP, oct_non_money_transfer_fast_funds_cross_border_indicator: SKIP, oct_online_gambling_domestic_indicator: SKIP, oct_online_gambling_cross_border_indicator: SKIP, oct_online_gambling_fast_funds_domestic_indicator: SKIP, oct_online_gambling_fast_funds_cross_border_indicator: SKIP, service_processing_type: SKIP, additional_properties: nil ) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless oct_domestic_participant_indicator == SKIP @oct_domestic_participant_indicator = oct_domestic_participant_indicator end unless oct_cross_border_participant_indicator == SKIP @oct_cross_border_participant_indicator = oct_cross_border_participant_indicator end unless oct_money_transfer_domestic_indicator == SKIP @oct_money_transfer_domestic_indicator = oct_money_transfer_domestic_indicator end unless oct_money_transfer_cross_border_indicator == SKIP @oct_money_transfer_cross_border_indicator = oct_money_transfer_cross_border_indicator end unless oct_money_transfer_fast_funds_domestic_indicator == SKIP @oct_money_transfer_fast_funds_domestic_indicator = oct_money_transfer_fast_funds_domestic_indicator end unless oct_money_transfer_fast_funds_cross_border_indicator == SKIP @oct_money_transfer_fast_funds_cross_border_indicator = oct_money_transfer_fast_funds_cross_border_indicator end unless oct_money_transfer_merchant_country_restricted == SKIP @oct_money_transfer_merchant_country_restricted = oct_money_transfer_merchant_country_restricted end unless oct_non_money_transfer_domestic_indicator == SKIP @oct_non_money_transfer_domestic_indicator = oct_non_money_transfer_domestic_indicator end unless oct_non_money_transfer_cross_border_indicator == SKIP @oct_non_money_transfer_cross_border_indicator = oct_non_money_transfer_cross_border_indicator end unless oct_non_money_transfer_fast_funds_domestic_indicator == SKIP @oct_non_money_transfer_fast_funds_domestic_indicator = oct_non_money_transfer_fast_funds_domestic_indicator end unless oct_non_money_transfer_fast_funds_cross_border_indicator == SKIP @oct_non_money_transfer_fast_funds_cross_border_indicator = oct_non_money_transfer_fast_funds_cross_border_indicator end unless oct_online_gambling_domestic_indicator == SKIP @oct_online_gambling_domestic_indicator = oct_online_gambling_domestic_indicator end unless oct_online_gambling_cross_border_indicator == SKIP @oct_online_gambling_cross_border_indicator = oct_online_gambling_cross_border_indicator end unless oct_online_gambling_fast_funds_domestic_indicator == SKIP @oct_online_gambling_fast_funds_domestic_indicator = oct_online_gambling_fast_funds_domestic_indicator end unless oct_online_gambling_fast_funds_cross_border_indicator == SKIP @oct_online_gambling_fast_funds_cross_border_indicator = oct_online_gambling_fast_funds_cross_border_indicator end @service_processing_type = service_processing_type unless service_processing_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#oct_cross_border_participant_indicator ⇒ TrueClass | FalseClass
Cross-border indicator for push funds (OCT). If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 24 def oct_cross_border_participant_indicator @oct_cross_border_participant_indicator end |
#oct_domestic_participant_indicator ⇒ TrueClass | FalseClass
Domestic indicator for Push funds (OCT). If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
17 18 19 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 17 def oct_domestic_participant_indicator @oct_domestic_participant_indicator end |
#oct_money_transfer_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 39 def oct_money_transfer_cross_border_indicator @oct_money_transfer_cross_border_indicator end |
#oct_money_transfer_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted.
Supported for Visa Direct.
32 33 34 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 32 def oct_money_transfer_domestic_indicator @oct_money_transfer_domestic_indicator end |
#oct_money_transfer_fast_funds_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
53 54 55 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 53 def oct_money_transfer_fast_funds_cross_border_indicator @oct_money_transfer_fast_funds_cross_border_indicator end |
#oct_money_transfer_fast_funds_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
46 47 48 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 46 def oct_money_transfer_fast_funds_domestic_indicator @oct_money_transfer_fast_funds_domestic_indicator end |
#oct_money_transfer_merchant_country_restricted ⇒ TrueClass | FalseClass
This field indicates if the recipient issuer can accept push funds (OCT) transactions from the merchant country. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
61 62 63 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 61 def oct_money_transfer_merchant_country_restricted @oct_money_transfer_merchant_country_restricted end |
#oct_non_money_transfer_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border non-money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
75 76 77 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 75 def oct_non_money_transfer_cross_border_indicator @oct_non_money_transfer_cross_border_indicator end |
#oct_non_money_transfer_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic non-money transfer OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
68 69 70 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 68 def oct_non_money_transfer_domestic_indicator @oct_non_money_transfer_domestic_indicator end |
#oct_non_money_transfer_fast_funds_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border non-money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
90 91 92 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 90 def oct_non_money_transfer_fast_funds_cross_border_indicator @oct_non_money_transfer_fast_funds_cross_border_indicator end |
#oct_non_money_transfer_fast_funds_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic non-money transfer OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
82 83 84 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 82 def oct_non_money_transfer_fast_funds_domestic_indicator @oct_non_money_transfer_fast_funds_domestic_indicator end |
#oct_online_gambling_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border gambling OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
104 105 106 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 104 def oct_online_gambling_cross_border_indicator @oct_online_gambling_cross_border_indicator end |
#oct_online_gambling_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic gambling OCTs (push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
97 98 99 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 97 def oct_online_gambling_domestic_indicator @oct_online_gambling_domestic_indicator end |
#oct_online_gambling_fast_funds_cross_border_indicator ⇒ TrueClass | FalseClass
Indicates whether cross-border gambling OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
118 119 120 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 118 def oct_online_gambling_fast_funds_cross_border_indicator @oct_online_gambling_fast_funds_cross_border_indicator end |
#oct_online_gambling_fast_funds_domestic_indicator ⇒ TrueClass | FalseClass
Indicates whether domestic gambling OCTs (fast push funds) are allowed. If no Funds Transfer Attributes Inquiry data is available for this card account, the field is omitted. Supported for Visa Direct.
111 112 113 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 111 def oct_online_gambling_fast_funds_domestic_indicator @oct_online_gambling_fast_funds_domestic_indicator end |
#service_processing_type ⇒ String
This field contains values that identify the service type under which the transaction should be processed. The valid value for the Visa Alias Directory Service is A0 (Alias) and 00 (normal transaction).
125 126 127 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 125 def service_processing_type @service_processing_type end |
Class Method Details
.from_element(root) ⇒ Object
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 341 def self.from_element(root) oct_domestic_participant_indicator = XmlUtilities.from_element( root, 'octDomesticParticipantIndicator', TrueClass ) oct_cross_border_participant_indicator = XmlUtilities.from_element( root, 'octCrossBorderParticipantIndicator', TrueClass ) oct_money_transfer_domestic_indicator = XmlUtilities.from_element( root, 'octMoneyTransferDomesticIndicator', TrueClass ) oct_money_transfer_cross_border_indicator = XmlUtilities.from_element( root, 'octMoneyTransferCrossBorderIndicator', TrueClass ) oct_money_transfer_fast_funds_domestic_indicator = XmlUtilities.from_element( root, 'octMoneyTransferFastFundsDomesticIndicator', TrueClass ) oct_money_transfer_fast_funds_cross_border_indicator = XmlUtilities.from_element( root, 'octMoneyTransferFastFundsCrossBorderIndicator', TrueClass ) oct_money_transfer_merchant_country_restricted = XmlUtilities.from_element( root, 'octMoneyTransferMerchantCountryRestricted', TrueClass ) oct_non_money_transfer_domestic_indicator = XmlUtilities.from_element( root, 'octNonMoneyTransferDomesticIndicator', TrueClass ) oct_non_money_transfer_cross_border_indicator = XmlUtilities.from_element( root, 'octNonMoneyTransferCrossBorderIndicator', TrueClass ) oct_non_money_transfer_fast_funds_domestic_indicator = XmlUtilities.from_element( root, 'octNonMoneyTransferFastFundsDomesticIndicator', TrueClass ) oct_non_money_transfer_fast_funds_cross_border_indicator = XmlUtilities.from_element( root, 'octNonMoneyTransferFastFundsCrossBorderIndicator', TrueClass ) oct_online_gambling_domestic_indicator = XmlUtilities.from_element( root, 'octOnlineGamblingDomesticIndicator', TrueClass ) oct_online_gambling_cross_border_indicator = XmlUtilities.from_element( root, 'octOnlineGamblingCrossBorderIndicator', TrueClass ) oct_online_gambling_fast_funds_domestic_indicator = XmlUtilities.from_element( root, 'octOnlineGamblingFastFundsDomesticIndicator', TrueClass ) oct_online_gambling_fast_funds_cross_border_indicator = XmlUtilities.from_element( root, 'octOnlineGamblingFastFundsCrossBorderIndicator', TrueClass ) service_processing_type = XmlUtilities.from_element( root, 'serviceProcessingType', String ) new(oct_domestic_participant_indicator: oct_domestic_participant_indicator, oct_cross_border_participant_indicator: oct_cross_border_participant_indicator, oct_money_transfer_domestic_indicator: oct_money_transfer_domestic_indicator, oct_money_transfer_cross_border_indicator: oct_money_transfer_cross_border_indicator, oct_money_transfer_fast_funds_domestic_indicator: oct_money_transfer_fast_funds_domestic_indicator, oct_money_transfer_fast_funds_cross_border_indicator: oct_money_transfer_fast_funds_cross_border_indicator, oct_money_transfer_merchant_country_restricted: oct_money_transfer_merchant_country_restricted, oct_non_money_transfer_domestic_indicator: oct_non_money_transfer_domestic_indicator, oct_non_money_transfer_cross_border_indicator: oct_non_money_transfer_cross_border_indicator, oct_non_money_transfer_fast_funds_domestic_indicator: oct_non_money_transfer_fast_funds_domestic_indicator, oct_non_money_transfer_fast_funds_cross_border_indicator: oct_non_money_transfer_fast_funds_cross_border_indicator, oct_online_gambling_domestic_indicator: oct_online_gambling_domestic_indicator, oct_online_gambling_cross_border_indicator: oct_online_gambling_cross_border_indicator, oct_online_gambling_fast_funds_domestic_indicator: oct_online_gambling_fast_funds_domestic_indicator, oct_online_gambling_fast_funds_cross_border_indicator: oct_online_gambling_fast_funds_cross_border_indicator, service_processing_type: service_processing_type, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 277 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. oct_domestic_participant_indicator = hash.key?('octDomesticParticipantIndicator') ? hash['octDomesticParticipantIndicator'] : SKIP oct_cross_border_participant_indicator = hash.key?('octCrossBorderParticipantIndicator') ? hash['octCrossBorderParticipantIndicator'] : SKIP oct_money_transfer_domestic_indicator = hash.key?('octMoneyTransferDomesticIndicator') ? hash['octMoneyTransferDomesticIndicator'] : SKIP oct_money_transfer_cross_border_indicator = hash.key?('octMoneyTransferCrossBorderIndicator') ? hash['octMoneyTransferCrossBorderIndicator'] : SKIP oct_money_transfer_fast_funds_domestic_indicator = hash.key?('octMoneyTransferFastFundsDomesticIndicator') ? hash['octMoneyTransferFastFundsDomesticIndicator'] : SKIP oct_money_transfer_fast_funds_cross_border_indicator = hash.key?('octMoneyTransferFastFundsCrossBorderIndicator') ? hash['octMoneyTransferFastFundsCrossBorderIndicator'] : SKIP oct_money_transfer_merchant_country_restricted = hash.key?('octMoneyTransferMerchantCountryRestricted') ? hash['octMoneyTransferMerchantCountryRestricted'] : SKIP oct_non_money_transfer_domestic_indicator = hash.key?('octNonMoneyTransferDomesticIndicator') ? hash['octNonMoneyTransferDomesticIndicator'] : SKIP oct_non_money_transfer_cross_border_indicator = hash.key?('octNonMoneyTransferCrossBorderIndicator') ? hash['octNonMoneyTransferCrossBorderIndicator'] : SKIP oct_non_money_transfer_fast_funds_domestic_indicator = hash.key?('octNonMoneyTransferFastFundsDomesticIndicator') ? hash['octNonMoneyTransferFastFundsDomesticIndicator'] : SKIP oct_non_money_transfer_fast_funds_cross_border_indicator = hash.key?('octNonMoneyTransferFastFundsCrossBorderIndicator') ? hash['octNonMoneyTransferFastFundsCrossBorderIndicator'] : SKIP oct_online_gambling_domestic_indicator = hash.key?('octOnlineGamblingDomesticIndicator') ? hash['octOnlineGamblingDomesticIndicator'] : SKIP oct_online_gambling_cross_border_indicator = hash.key?('octOnlineGamblingCrossBorderIndicator') ? hash['octOnlineGamblingCrossBorderIndicator'] : SKIP oct_online_gambling_fast_funds_domestic_indicator = hash.key?('octOnlineGamblingFastFundsDomesticIndicator') ? hash['octOnlineGamblingFastFundsDomesticIndicator'] : SKIP oct_online_gambling_fast_funds_cross_border_indicator = hash.key?('octOnlineGamblingFastFundsCrossBorderIndicator') ? hash['octOnlineGamblingFastFundsCrossBorderIndicator'] : SKIP service_processing_type = hash.key?('serviceProcessingType') ? hash['serviceProcessingType'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. IssuerInformation33.new(oct_domestic_participant_indicator: oct_domestic_participant_indicator, oct_cross_border_participant_indicator: oct_cross_border_participant_indicator, oct_money_transfer_domestic_indicator: oct_money_transfer_domestic_indicator, oct_money_transfer_cross_border_indicator: oct_money_transfer_cross_border_indicator, oct_money_transfer_fast_funds_domestic_indicator: oct_money_transfer_fast_funds_domestic_indicator, oct_money_transfer_fast_funds_cross_border_indicator: oct_money_transfer_fast_funds_cross_border_indicator, oct_money_transfer_merchant_country_restricted: oct_money_transfer_merchant_country_restricted, oct_non_money_transfer_domestic_indicator: oct_non_money_transfer_domestic_indicator, oct_non_money_transfer_cross_border_indicator: oct_non_money_transfer_cross_border_indicator, oct_non_money_transfer_fast_funds_domestic_indicator: oct_non_money_transfer_fast_funds_domestic_indicator, oct_non_money_transfer_fast_funds_cross_border_indicator: oct_non_money_transfer_fast_funds_cross_border_indicator, oct_online_gambling_domestic_indicator: oct_online_gambling_domestic_indicator, oct_online_gambling_cross_border_indicator: oct_online_gambling_cross_border_indicator, oct_online_gambling_fast_funds_domestic_indicator: oct_online_gambling_fast_funds_domestic_indicator, oct_online_gambling_fast_funds_cross_border_indicator: oct_online_gambling_fast_funds_cross_border_indicator, service_processing_type: service_processing_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 128 def self.names @_hash = {} if @_hash.nil? @_hash['oct_domestic_participant_indicator'] = 'octDomesticParticipantIndicator' @_hash['oct_cross_border_participant_indicator'] = 'octCrossBorderParticipantIndicator' @_hash['oct_money_transfer_domestic_indicator'] = 'octMoneyTransferDomesticIndicator' @_hash['oct_money_transfer_cross_border_indicator'] = 'octMoneyTransferCrossBorderIndicator' @_hash['oct_money_transfer_fast_funds_domestic_indicator'] = 'octMoneyTransferFastFundsDomesticIndicator' @_hash['oct_money_transfer_fast_funds_cross_border_indicator'] = 'octMoneyTransferFastFundsCrossBorderIndicator' @_hash['oct_money_transfer_merchant_country_restricted'] = 'octMoneyTransferMerchantCountryRestricted' @_hash['oct_non_money_transfer_domestic_indicator'] = 'octNonMoneyTransferDomesticIndicator' @_hash['oct_non_money_transfer_cross_border_indicator'] = 'octNonMoneyTransferCrossBorderIndicator' @_hash['oct_non_money_transfer_fast_funds_domestic_indicator'] = 'octNonMoneyTransferFastFundsDomesticIndicator' @_hash['oct_non_money_transfer_fast_funds_cross_border_indicator'] = 'octNonMoneyTransferFastFundsCrossBorderIndicator' @_hash['oct_online_gambling_domestic_indicator'] = 'octOnlineGamblingDomesticIndicator' @_hash['oct_online_gambling_cross_border_indicator'] = 'octOnlineGamblingCrossBorderIndicator' @_hash['oct_online_gambling_fast_funds_domestic_indicator'] = 'octOnlineGamblingFastFundsDomesticIndicator' @_hash['oct_online_gambling_fast_funds_cross_border_indicator'] = 'octOnlineGamblingFastFundsCrossBorderIndicator' @_hash['service_processing_type'] = 'serviceProcessingType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
187 188 189 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 187 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 165 def self.optionals %w[ oct_domestic_participant_indicator oct_cross_border_participant_indicator oct_money_transfer_domestic_indicator oct_money_transfer_cross_border_indicator oct_money_transfer_fast_funds_domestic_indicator oct_money_transfer_fast_funds_cross_border_indicator oct_money_transfer_merchant_country_restricted oct_non_money_transfer_domestic_indicator oct_non_money_transfer_cross_border_indicator oct_non_money_transfer_fast_funds_domestic_indicator oct_non_money_transfer_fast_funds_cross_border_indicator oct_online_gambling_domestic_indicator oct_online_gambling_cross_border_indicator oct_online_gambling_fast_funds_domestic_indicator oct_online_gambling_fast_funds_cross_border_indicator service_processing_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 510 def inspect class_name = self.class.name.split('::').last "<#{class_name} oct_domestic_participant_indicator:"\ " #{@oct_domestic_participant_indicator.inspect}, oct_cross_border_participant_indicator:"\ " #{@oct_cross_border_participant_indicator.inspect}, oct_money_transfer_domestic_indicator:"\ " #{@oct_money_transfer_domestic_indicator.inspect},"\ ' oct_money_transfer_cross_border_indicator:'\ " #{@oct_money_transfer_cross_border_indicator.inspect},"\ ' oct_money_transfer_fast_funds_domestic_indicator:'\ " #{@oct_money_transfer_fast_funds_domestic_indicator.inspect},"\ ' oct_money_transfer_fast_funds_cross_border_indicator:'\ " #{@oct_money_transfer_fast_funds_cross_border_indicator.inspect},"\ ' oct_money_transfer_merchant_country_restricted:'\ " #{@oct_money_transfer_merchant_country_restricted.inspect},"\ ' oct_non_money_transfer_domestic_indicator:'\ " #{@oct_non_money_transfer_domestic_indicator.inspect},"\ ' oct_non_money_transfer_cross_border_indicator:'\ " #{@oct_non_money_transfer_cross_border_indicator.inspect},"\ ' oct_non_money_transfer_fast_funds_domestic_indicator:'\ " #{@oct_non_money_transfer_fast_funds_domestic_indicator.inspect},"\ ' oct_non_money_transfer_fast_funds_cross_border_indicator:'\ " #{@oct_non_money_transfer_fast_funds_cross_border_indicator.inspect},"\ ' oct_online_gambling_domestic_indicator:'\ " #{@oct_online_gambling_domestic_indicator.inspect},"\ ' oct_online_gambling_cross_border_indicator:'\ " #{@oct_online_gambling_cross_border_indicator.inspect},"\ ' oct_online_gambling_fast_funds_domestic_indicator:'\ " #{@oct_online_gambling_fast_funds_domestic_indicator.inspect},"\ ' oct_online_gambling_fast_funds_cross_border_indicator:'\ " #{@oct_online_gambling_fast_funds_cross_border_indicator.inspect},"\ " service_processing_type: #{@service_processing_type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 480 def to_s class_name = self.class.name.split('::').last "<#{class_name} oct_domestic_participant_indicator: #{@oct_domestic_participant_indicator},"\ " oct_cross_border_participant_indicator: #{@oct_cross_border_participant_indicator},"\ " oct_money_transfer_domestic_indicator: #{@oct_money_transfer_domestic_indicator},"\ " oct_money_transfer_cross_border_indicator: #{@oct_money_transfer_cross_border_indicator},"\ ' oct_money_transfer_fast_funds_domestic_indicator:'\ " #{@oct_money_transfer_fast_funds_domestic_indicator},"\ ' oct_money_transfer_fast_funds_cross_border_indicator:'\ " #{@oct_money_transfer_fast_funds_cross_border_indicator},"\ ' oct_money_transfer_merchant_country_restricted:'\ " #{@oct_money_transfer_merchant_country_restricted},"\ " oct_non_money_transfer_domestic_indicator: #{@oct_non_money_transfer_domestic_indicator},"\ ' oct_non_money_transfer_cross_border_indicator:'\ " #{@oct_non_money_transfer_cross_border_indicator},"\ ' oct_non_money_transfer_fast_funds_domestic_indicator:'\ " #{@oct_non_money_transfer_fast_funds_domestic_indicator},"\ ' oct_non_money_transfer_fast_funds_cross_border_indicator:'\ " #{@oct_non_money_transfer_fast_funds_cross_border_indicator},"\ " oct_online_gambling_domestic_indicator: #{@oct_online_gambling_domestic_indicator},"\ ' oct_online_gambling_cross_border_indicator:'\ " #{@oct_online_gambling_cross_border_indicator},"\ ' oct_online_gambling_fast_funds_domestic_indicator:'\ " #{@oct_online_gambling_fast_funds_domestic_indicator},"\ ' oct_online_gambling_fast_funds_cross_border_indicator:'\ " #{@oct_online_gambling_fast_funds_cross_border_indicator}, service_processing_type:"\ " #{@service_processing_type}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/cyber_source_merged_spec/models/issuer_information33.rb', line 415 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'octDomesticParticipantIndicator', oct_domestic_participant_indicator) XmlUtilities.add_as_subelement(doc, root, 'octCrossBorderParticipantIndicator', oct_cross_border_participant_indicator) XmlUtilities.add_as_subelement(doc, root, 'octMoneyTransferDomesticIndicator', oct_money_transfer_domestic_indicator) XmlUtilities.add_as_subelement(doc, root, 'octMoneyTransferCrossBorderIndicator', oct_money_transfer_cross_border_indicator) XmlUtilities.add_as_subelement( doc, root, 'octMoneyTransferFastFundsDomesticIndicator', oct_money_transfer_fast_funds_domestic_indicator ) XmlUtilities.add_as_subelement( doc, root, 'octMoneyTransferFastFundsCrossBorderIndicator', oct_money_transfer_fast_funds_cross_border_indicator ) XmlUtilities.add_as_subelement( doc, root, 'octMoneyTransferMerchantCountryRestricted', oct_money_transfer_merchant_country_restricted ) XmlUtilities.add_as_subelement(doc, root, 'octNonMoneyTransferDomesticIndicator', oct_non_money_transfer_domestic_indicator) XmlUtilities.add_as_subelement( doc, root, 'octNonMoneyTransferCrossBorderIndicator', oct_non_money_transfer_cross_border_indicator ) XmlUtilities.add_as_subelement( doc, root, 'octNonMoneyTransferFastFundsDomesticIndicator', oct_non_money_transfer_fast_funds_domestic_indicator ) XmlUtilities.add_as_subelement( doc, root, 'octNonMoneyTransferFastFundsCrossBorderIndicator', oct_non_money_transfer_fast_funds_cross_border_indicator ) XmlUtilities.add_as_subelement(doc, root, 'octOnlineGamblingDomesticIndicator', oct_online_gambling_domestic_indicator) XmlUtilities.add_as_subelement(doc, root, 'octOnlineGamblingCrossBorderIndicator', oct_online_gambling_cross_border_indicator) XmlUtilities.add_as_subelement( doc, root, 'octOnlineGamblingFastFundsDomesticIndicator', oct_online_gambling_fast_funds_domestic_indicator ) XmlUtilities.add_as_subelement( doc, root, 'octOnlineGamblingFastFundsCrossBorderIndicator', oct_online_gambling_fast_funds_cross_border_indicator ) XmlUtilities.add_as_subelement(doc, root, 'serviceProcessingType', service_processing_type) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |