Class: CyberSourceMergedSpec::Links21
- Defined in:
- lib/cyber_source_merged_spec/models/links21.rb
Overview
Links21 Model.
Instance Attribute Summary collapse
-
#mself ⇒ Self20
TODO: Write general description for this method.
-
#payment_instruments ⇒ PaymentInstruments1
TODO: Write general description for this method.
-
#tokenized_cards ⇒ TokenizedCards
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, payment_instruments: SKIP, tokenized_cards: SKIP, additional_properties: nil) ⇒ Links21
constructor
A new instance of Links21.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, payment_instruments: SKIP, tokenized_cards: SKIP, additional_properties: nil) ⇒ Links21
Returns a new instance of Links21.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 47 def initialize(mself: SKIP, payment_instruments: SKIP, tokenized_cards: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @payment_instruments = payment_instruments unless payment_instruments == SKIP @tokenized_cards = tokenized_cards unless tokenized_cards == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#mself ⇒ Self20
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 14 def mself @mself end |
#payment_instruments ⇒ PaymentInstruments1
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 18 def payment_instruments @payment_instruments end |
#tokenized_cards ⇒ TokenizedCards
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 22 def tokenized_cards @tokenized_cards end |
Class Method Details
.from_element(root) ⇒ Object
83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 83 def self.from_element(root) mself = XmlUtilities.from_element(root, 'Self20', Self20) payment_instruments = XmlUtilities.from_element(root, 'PaymentInstruments1', PaymentInstruments1) tokenized_cards = XmlUtilities.from_element(root, 'TokenizedCards', TokenizedCards) new(mself: mself, payment_instruments: payment_instruments, tokenized_cards: tokenized_cards, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self20.from_hash(hash['self']) if hash['self'] payment_instruments = PaymentInstruments1.from_hash(hash['paymentInstruments']) if hash['paymentInstruments'] tokenized_cards = TokenizedCards.from_hash(hash['tokenized-cards']) if hash['tokenized-cards'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links21.new(mself: mself, payment_instruments: payment_instruments, tokenized_cards: tokenized_cards, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['payment_instruments'] = 'paymentInstruments' @_hash['tokenized_cards'] = 'tokenized-cards' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 34 def self.optionals %w[ mself payment_instruments tokenized_cards ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 124 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, payment_instruments:"\ " #{@payment_instruments.inspect}, tokenized_cards: #{@tokenized_cards.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, payment_instruments: #{@payment_instruments},"\ " tokenized_cards: #{@tokenized_cards}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/links21.rb', line 97 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Self20', mself) XmlUtilities.add_as_subelement(doc, root, 'PaymentInstruments1', payment_instruments) XmlUtilities.add_as_subelement(doc, root, 'TokenizedCards', tokenized_cards) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |