Class: CyberSourceMergedSpec::Links211
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Links211
- Defined in:
- lib/cyber_source_merged_spec/models/links211.rb
Overview
Links211 Model.
Instance Attribute Summary collapse
-
#documentation ⇒ Array[Documentation]
TODO: Write general description for this method.
-
#mnext ⇒ Array[Next3]
TODO: Write general description for this method.
-
#mself ⇒ Self209
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mnext: SKIP, documentation: SKIP, mself: SKIP, additional_properties: nil) ⇒ Links211
constructor
A new instance of Links211.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mnext: SKIP, documentation: SKIP, mself: SKIP, additional_properties: nil) ⇒ Links211
Returns a new instance of Links211.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 47 def initialize(mnext: SKIP, documentation: SKIP, mself: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mnext = mnext unless mnext == SKIP @documentation = documentation unless documentation == SKIP @mself = mself unless mself == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#documentation ⇒ Array[Documentation]
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 18 def documentation @documentation end |
#mnext ⇒ Array[Next3]
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 14 def mnext @mnext end |
#mself ⇒ Self209
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 22 def mself @mself end |
Class Method Details
.from_element(root) ⇒ Object
99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 99 def self.from_element(root) mnext = XmlUtilities.from_element_to_array(root, 'Next3', Next3) documentation = XmlUtilities.from_element_to_array(root, 'Documentation', Documentation) mself = XmlUtilities.from_element(root, 'Self209', Self209) new(mnext: mnext, documentation: documentation, mself: mself, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it mnext = nil unless hash['next'].nil? mnext = [] hash['next'].each do |structure| mnext << (Next3.from_hash(structure) if structure) end end mnext = SKIP unless hash.key?('next') # Parameter is an array, so we need to iterate through it documentation = nil unless hash['documentation'].nil? documentation = [] hash['documentation'].each do |structure| documentation << (Documentation.from_hash(structure) if structure) end end documentation = SKIP unless hash.key?('documentation') mself = Self209.from_hash(hash['self']) if hash['self'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links211.new(mnext: mnext, documentation: documentation, mself: mself, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['mnext'] = 'next' @_hash['documentation'] = 'documentation' @_hash['mself'] = 'self' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 34 def self.optionals %w[ mnext documentation mself ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
132 133 134 135 136 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 132 def inspect class_name = self.class.name.split('::').last "<#{class_name} mnext: #{@mnext.inspect}, documentation: #{@documentation.inspect}, mself:"\ " #{@mself.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
125 126 127 128 129 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 125 def to_s class_name = self.class.name.split('::').last "<#{class_name} mnext: #{@mnext}, documentation: #{@documentation}, mself: #{@mself},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/cyber_source_merged_spec/models/links211.rb', line 111 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_array_as_subelement(doc, root, 'Next3', mnext) XmlUtilities.add_array_as_subelement(doc, root, 'Documentation', documentation) XmlUtilities.add_as_subelement(doc, root, 'Self209', mself) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |