Class: CyberSourceMergedSpec::Links233
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Links233
- Defined in:
- lib/cyber_source_merged_spec/models/links233.rb
Overview
Links233 Model.
Instance Attribute Summary collapse
-
#activate ⇒ Activate
TODO: Write general description for this method.
-
#cancel ⇒ Cancel
TODO: Write general description for this method.
-
#mself ⇒ Self
TODO: Write general description for this method.
-
#suspend ⇒ Suspend
TODO: Write general description for this method.
-
#update ⇒ Update
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mself: SKIP, update: SKIP, cancel: SKIP, suspend: SKIP, activate: SKIP, additional_properties: nil) ⇒ Links233
constructor
A new instance of Links233.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mself: SKIP, update: SKIP, cancel: SKIP, suspend: SKIP, activate: SKIP, additional_properties: nil) ⇒ Links233
Returns a new instance of Links233.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 59 def initialize(mself: SKIP, update: SKIP, cancel: SKIP, suspend: SKIP, activate: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @mself = mself unless mself == SKIP @update = update unless update == SKIP @cancel = cancel unless cancel == SKIP @suspend = suspend unless suspend == SKIP @activate = activate unless activate == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#activate ⇒ Activate
TODO: Write general description for this method
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 30 def activate @activate end |
#cancel ⇒ Cancel
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 22 def cancel @cancel end |
#mself ⇒ Self
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 14 def mself @mself end |
#suspend ⇒ Suspend
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 26 def suspend @suspend end |
#update ⇒ Update
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 18 def update @update end |
Class Method Details
.from_element(root) ⇒ Object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 99 def self.from_element(root) mself = XmlUtilities.from_element(root, 'Self', Self) update = XmlUtilities.from_element(root, 'Update', Update) cancel = XmlUtilities.from_element(root, 'Cancel', Cancel) suspend = XmlUtilities.from_element(root, 'Suspend', Suspend) activate = XmlUtilities.from_element(root, 'Activate', Activate) new(mself: mself, update: update, cancel: cancel, suspend: suspend, activate: activate, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 73 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mself = Self.from_hash(hash['self']) if hash['self'] update = Update.from_hash(hash['update']) if hash['update'] cancel = Cancel.from_hash(hash['cancel']) if hash['cancel'] suspend = Suspend.from_hash(hash['suspend']) if hash['suspend'] activate = Activate.from_hash(hash['activate']) if hash['activate'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Links233.new(mself: mself, update: update, cancel: cancel, suspend: suspend, activate: activate, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['mself'] = 'self' @_hash['update'] = 'update' @_hash['cancel'] = 'cancel' @_hash['suspend'] = 'suspend' @_hash['activate'] = 'activate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 47 48 49 50 51 52 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 44 def self.optionals %w[ mself update cancel suspend activate ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
136 137 138 139 140 141 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 136 def inspect class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself.inspect}, update: #{@update.inspect}, cancel:"\ " #{@cancel.inspect}, suspend: #{@suspend.inspect}, activate: #{@activate.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
129 130 131 132 133 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 129 def to_s class_name = self.class.name.split('::').last "<#{class_name} mself: #{@mself}, update: #{@update}, cancel: #{@cancel}, suspend:"\ " #{@suspend}, activate: #{@activate}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/cyber_source_merged_spec/models/links233.rb', line 114 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Self', mself) XmlUtilities.add_as_subelement(doc, root, 'Update', update) XmlUtilities.add_as_subelement(doc, root, 'Cancel', cancel) XmlUtilities.add_as_subelement(doc, root, 'Suspend', suspend) XmlUtilities.add_as_subelement(doc, root, 'Activate', activate) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |