Class: CyberSourceMergedSpec::LoanOptions
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::LoanOptions
- Defined in:
- lib/cyber_source_merged_spec/models/loan_options.rb
Overview
LoanOptions Model.
Instance Attribute Summary collapse
-
#asset_type ⇒ String
Indicates whether a loan is for a recoverable item or a non-recoverable item.
-
#type ⇒ String
Type of loan based on an agreement between you and the issuer.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, asset_type: SKIP, additional_properties: nil) ⇒ LoanOptions
constructor
A new instance of LoanOptions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, asset_type: SKIP, additional_properties: nil) ⇒ LoanOptions
Returns a new instance of LoanOptions.
61 62 63 64 65 66 67 68 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 61 def initialize(type: SKIP, asset_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @asset_type = asset_type unless asset_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#asset_type ⇒ String
Indicates whether a loan is for a recoverable item or a non-recoverable item. Possible values:
N: non-recoverable itemR: recoverable item This field is supported only for BNDES transactions on CyberSource through VisaNet. The value for this field corresponds to the following data in the TC 33 capture file5: Record: CP07 TCR2, Position: 26, Field: Asset Indicator
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 38 def asset_type @asset_type end |
#type ⇒ String
Type of loan based on an agreement between you and the issuer. Examples: AGROCUSTEIO, AGRO-INVEST, BNDES-Type1, CBN, FINAME. This field is supported only for these kinds of payments:
- BNDES transactions on CyberSource through VisaNet.
- Installment payments with Mastercard on CyberSource through VisaNet in Brazil. For BNDES transactions, the value for this field corresponds to the following data in the TC 33 capture file:
- Record: CP07 TCR2, Position: 27-46, Field: Loan Type For installment payments with Mastercard in Brazil, the value for this field corresponds to the following data in the TC 33 capture file:
- Record: CP07 TCR4, Position: 5-24,Field: Financing Type
25 26 27 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 25 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
91 92 93 94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 91 def self.from_element(root) type = XmlUtilities.from_element(root, 'type', String) asset_type = XmlUtilities.from_element(root, 'assetType', String) new(type: type, asset_type: asset_type, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP asset_type = hash.key?('assetType') ? hash['assetType'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. LoanOptions.new(type: type, asset_type: asset_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['asset_type'] = 'assetType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
57 58 59 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 57 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 49 def self.optionals %w[ type asset_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
119 120 121 122 123 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 119 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, asset_type: #{@asset_type.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 112 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, asset_type: #{@asset_type}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
100 101 102 103 104 105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/loan_options.rb', line 100 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'assetType', asset_type) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |