Class: CyberSourceMergedSpec::MerchantInformation17
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::MerchantInformation17
- Defined in:
- lib/cyber_source_merged_spec/models/merchant_information17.rb
Overview
MerchantInformation17 Model.
Instance Attribute Summary collapse
-
#cancel_url ⇒ String
customer would be redirected to this url based on the decision of the transaction.
-
#merchant_descriptor ⇒ MerchantDescriptor11
TODO: Write general description for this method.
-
#success_url ⇒ String
customer would be redirected to this url based on the decision of the transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(merchant_descriptor: SKIP, cancel_url: SKIP, success_url: SKIP, additional_properties: nil) ⇒ MerchantInformation17
constructor
A new instance of MerchantInformation17.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(merchant_descriptor: SKIP, cancel_url: SKIP, success_url: SKIP, additional_properties: nil) ⇒ MerchantInformation17
Returns a new instance of MerchantInformation17.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 49 def initialize(merchant_descriptor: SKIP, cancel_url: SKIP, success_url: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @merchant_descriptor = merchant_descriptor unless merchant_descriptor == SKIP @cancel_url = cancel_url unless cancel_url == SKIP @success_url = success_url unless success_url == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#cancel_url ⇒ String
customer would be redirected to this url based on the decision of the transaction
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 19 def cancel_url @cancel_url end |
#merchant_descriptor ⇒ MerchantDescriptor11
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 14 def merchant_descriptor @merchant_descriptor end |
#success_url ⇒ String
customer would be redirected to this url based on the decision of the transaction
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 24 def success_url @success_url end |
Class Method Details
.from_element(root) ⇒ Object
84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 84 def self.from_element(root) merchant_descriptor = XmlUtilities.from_element(root, 'MerchantDescriptor11', MerchantDescriptor11) cancel_url = XmlUtilities.from_element(root, 'cancelUrl', String) success_url = XmlUtilities.from_element(root, 'successUrl', String) new(merchant_descriptor: merchant_descriptor, cancel_url: cancel_url, success_url: success_url, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 61 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. merchant_descriptor = MerchantDescriptor11.from_hash(hash['merchantDescriptor']) if hash['merchantDescriptor'] cancel_url = hash.key?('cancelUrl') ? hash['cancelUrl'] : SKIP success_url = hash.key?('successUrl') ? hash['successUrl'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantInformation17.new(merchant_descriptor: merchant_descriptor, cancel_url: cancel_url, success_url: success_url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['merchant_descriptor'] = 'merchantDescriptor' @_hash['cancel_url'] = 'cancelUrl' @_hash['success_url'] = 'successUrl' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 42 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 36 def self.optionals %w[ merchant_descriptor cancel_url success_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
118 119 120 121 122 123 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 118 def inspect class_name = self.class.name.split('::').last "<#{class_name} merchant_descriptor: #{@merchant_descriptor.inspect}, cancel_url:"\ " #{@cancel_url.inspect}, success_url: #{@success_url.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
111 112 113 114 115 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 111 def to_s class_name = self.class.name.split('::').last "<#{class_name} merchant_descriptor: #{@merchant_descriptor}, cancel_url: #{@cancel_url},"\ " success_url: #{@success_url}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/merchant_information17.rb', line 97 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'MerchantDescriptor11', merchant_descriptor) XmlUtilities.add_as_subelement(doc, root, 'cancelUrl', cancel_url) XmlUtilities.add_as_subelement(doc, root, 'successUrl', success_url) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |