Class: CyberSourceMergedSpec::MerchantInformation19
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::MerchantInformation19
- Defined in:
- lib/cyber_source_merged_spec/models/merchant_information19.rb
Overview
MerchantInformation19 Model.
Instance Attribute Summary collapse
-
#merchant_descriptor ⇒ MerchantDescriptor34
TODO: Write general description for this method.
-
#merchant_name ⇒ String
Your company’s name as you want it to appear to the customer in the issuing bank’s authentication form.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(merchant_descriptor: SKIP, merchant_name: SKIP, additional_properties: nil) ⇒ MerchantInformation19
constructor
A new instance of MerchantInformation19.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(merchant_descriptor: SKIP, merchant_name: SKIP, additional_properties: nil) ⇒ MerchantInformation19
Returns a new instance of MerchantInformation19.
43 44 45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 43 def initialize(merchant_descriptor: SKIP, merchant_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @merchant_descriptor = merchant_descriptor unless merchant_descriptor == SKIP @merchant_name = merchant_name unless merchant_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#merchant_descriptor ⇒ MerchantDescriptor34
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 14 def merchant_descriptor @merchant_descriptor end |
#merchant_name ⇒ String
Your company’s name as you want it to appear to the customer in the issuing bank’s authentication form. This value overrides the value specified by your merchant bank.
20 21 22 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 20 def merchant_name @merchant_name end |
Class Method Details
.from_element(root) ⇒ Object
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 75 def self.from_element(root) merchant_descriptor = XmlUtilities.from_element(root, 'MerchantDescriptor34', MerchantDescriptor34) merchant_name = XmlUtilities.from_element(root, 'merchantName', String) new(merchant_descriptor: merchant_descriptor, merchant_name: merchant_name, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. merchant_descriptor = MerchantDescriptor34.from_hash(hash['merchantDescriptor']) if hash['merchantDescriptor'] merchant_name = hash.key?('merchantName') ? hash['merchantName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. MerchantInformation19.new(merchant_descriptor: merchant_descriptor, merchant_name: merchant_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['merchant_descriptor'] = 'merchantDescriptor' @_hash['merchant_name'] = 'merchantName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 31 def self.optionals %w[ merchant_descriptor merchant_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
106 107 108 109 110 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 106 def inspect class_name = self.class.name.split('::').last "<#{class_name} merchant_descriptor: #{@merchant_descriptor.inspect}, merchant_name:"\ " #{@merchant_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 99 def to_s class_name = self.class.name.split('::').last "<#{class_name} merchant_descriptor: #{@merchant_descriptor}, merchant_name:"\ " #{@merchant_name}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/cyber_source_merged_spec/models/merchant_information19.rb', line 86 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'MerchantDescriptor34', merchant_descriptor) XmlUtilities.add_as_subelement(doc, root, 'merchantName', merchant_name) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |