Class: CyberSourceMergedSpec::OrderInformation43
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::OrderInformation43
- Defined in:
- lib/cyber_source_merged_spec/models/order_information43.rb
Overview
OrderInformation43 Model.
Instance Attribute Summary collapse
-
#amount_details ⇒ AmountDetails41
TODO: Write general description for this method.
-
#bill_to ⇒ BillTo69
TODO: Write general description for this method.
-
#is_cryptocurrency_purchase ⇒ String
Visa Platform Connect : This API will contain the Flag that specifies whether the payment is for the purchase of cryptocurrency.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount_details: SKIP, bill_to: SKIP, is_cryptocurrency_purchase: SKIP, additional_properties: nil) ⇒ OrderInformation43
constructor
A new instance of OrderInformation43.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount_details: SKIP, bill_to: SKIP, is_cryptocurrency_purchase: SKIP, additional_properties: nil) ⇒ OrderInformation43
Returns a new instance of OrderInformation43.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 55 def initialize(amount_details: SKIP, bill_to: SKIP, is_cryptocurrency_purchase: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @amount_details = amount_details unless amount_details == SKIP @bill_to = bill_to unless bill_to == SKIP unless is_cryptocurrency_purchase == SKIP @is_cryptocurrency_purchase = is_cryptocurrency_purchase end @additional_properties = additional_properties end |
Instance Attribute Details
#amount_details ⇒ AmountDetails41
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 14 def amount_details @amount_details end |
#bill_to ⇒ BillTo69
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 18 def bill_to @bill_to end |
#is_cryptocurrency_purchase ⇒ String
Visa Platform Connect :
This API will contain the Flag that specifies whether the payment is for the purchase of cryptocurrency. Additional values to add : This API will contain the Flag that specifies whether the payment is for the purchase of cryptocurrency. valid values are
- Y/y, true
- N/n, false
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 30 def is_cryptocurrency_purchase @is_cryptocurrency_purchase end |
Class Method Details
.from_element(root) ⇒ Object
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 93 def self.from_element(root) amount_details = XmlUtilities.from_element(root, 'AmountDetails41', AmountDetails41) bill_to = XmlUtilities.from_element(root, 'BillTo69', BillTo69) is_cryptocurrency_purchase = XmlUtilities.from_element( root, 'isCryptocurrencyPurchase', String ) new(amount_details: amount_details, bill_to: bill_to, is_cryptocurrency_purchase: is_cryptocurrency_purchase, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount_details = AmountDetails41.from_hash(hash['amountDetails']) if hash['amountDetails'] bill_to = BillTo69.from_hash(hash['billTo']) if hash['billTo'] is_cryptocurrency_purchase = hash.key?('isCryptocurrencyPurchase') ? hash['isCryptocurrencyPurchase'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OrderInformation43.new(amount_details: amount_details, bill_to: bill_to, is_cryptocurrency_purchase: is_cryptocurrency_purchase, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['amount_details'] = 'amountDetails' @_hash['bill_to'] = 'billTo' @_hash['is_cryptocurrency_purchase'] = 'isCryptocurrencyPurchase' @_hash end |
.nullables ⇒ Object
An array for nullable fields
51 52 53 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 51 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 42 def self.optionals %w[ amount_details bill_to is_cryptocurrency_purchase ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
130 131 132 133 134 135 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 130 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details.inspect}, bill_to: #{@bill_to.inspect},"\ " is_cryptocurrency_purchase: #{@is_cryptocurrency_purchase.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
122 123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 122 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount_details: #{@amount_details}, bill_to: #{@bill_to},"\ " is_cryptocurrency_purchase: #{@is_cryptocurrency_purchase}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/cyber_source_merged_spec/models/order_information43.rb', line 107 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'AmountDetails41', amount_details) XmlUtilities.add_as_subelement(doc, root, 'BillTo69', bill_to) XmlUtilities.add_as_subelement(doc, root, 'isCryptocurrencyPurchase', is_cryptocurrency_purchase) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |