Class: CyberSourceMergedSpec::Partner1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Partner1
- Defined in:
- lib/cyber_source_merged_spec/models/partner1.rb
Overview
Partner1 Model.
Instance Attribute Summary collapse
-
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to CyberSource.
-
#original_transaction_id ⇒ String
Value that links the previous transaction to the current follow-on request.
-
#solution_id ⇒ String
Identifier for the partner that is integrated to CyberSource.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner1
constructor
A new instance of Partner1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner1
Returns a new instance of Partner1.
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 73 def initialize(original_transaction_id: SKIP, developer_id: SKIP, solution_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @original_transaction_id = original_transaction_id unless original_transaction_id == SKIP @developer_id = developer_id unless developer_id == SKIP @solution_id = solution_id unless solution_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to CyberSource. Send this value in all requests that are sent through the partner solutions built by that developer. CyberSource assigns the ID to the developer. Note When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect.
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 40 def developer_id @developer_id end |
#original_transaction_id ⇒ String
Value that links the previous transaction to the current follow-on request. This value is assigned by the client software that is installed on the POS terminal, which makes it available to the terminal’s software and to CyberSource. Therefore, you can use this value to reconcile transactions between CyberSource and the terminal’s software. CyberSource does not forward this value to the processor. Instead, the value is forwarded to the CyberSource reporting functionality. This field is supported only on these processors:
- American Express Direct
- Credit Mutuel-CIC
- FDC Nashville Global
- OmniPay Direct
- SIX Optional field.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 30 def original_transaction_id @original_transaction_id end |
#solution_id ⇒ String
Identifier for the partner that is integrated to CyberSource. Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.
48 49 50 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 48 def solution_id @solution_id end |
Class Method Details
.from_element(root) ⇒ Object
108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 108 def self.from_element(root) original_transaction_id = XmlUtilities.from_element( root, 'originalTransactionId', String ) developer_id = XmlUtilities.from_element(root, 'developerId', String) solution_id = XmlUtilities.from_element(root, 'solutionId', String) new(original_transaction_id: original_transaction_id, developer_id: developer_id, solution_id: solution_id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 85 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. original_transaction_id = hash.key?('originalTransactionId') ? hash['originalTransactionId'] : SKIP developer_id = hash.key?('developerId') ? hash['developerId'] : SKIP solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Partner1.new(original_transaction_id: original_transaction_id, developer_id: developer_id, solution_id: solution_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
51 52 53 54 55 56 57 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 51 def self.names @_hash = {} if @_hash.nil? @_hash['original_transaction_id'] = 'originalTransactionId' @_hash['developer_id'] = 'developerId' @_hash['solution_id'] = 'solutionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
69 70 71 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 69 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
60 61 62 63 64 65 66 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 60 def self.optionals %w[ original_transaction_id developer_id solution_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
143 144 145 146 147 148 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 143 def inspect class_name = self.class.name.split('::').last "<#{class_name} original_transaction_id: #{@original_transaction_id.inspect}, developer_id:"\ " #{@developer_id.inspect}, solution_id: #{@solution_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
135 136 137 138 139 140 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 135 def to_s class_name = self.class.name.split('::').last "<#{class_name} original_transaction_id: #{@original_transaction_id}, developer_id:"\ " #{@developer_id}, solution_id: #{@solution_id}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/cyber_source_merged_spec/models/partner1.rb', line 121 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'originalTransactionId', original_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'developerId', developer_id) XmlUtilities.add_as_subelement(doc, root, 'solutionId', solution_id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |