Class: CyberSourceMergedSpec::Partner16
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Partner16
- Defined in:
- lib/cyber_source_merged_spec/models/partner16.rb
Overview
Partner16 Model.
Instance Attribute Summary collapse
-
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to CyberSource.
-
#solution_id ⇒ String
Identifier for the partner that is integrated to CyberSource.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner16
constructor
A new instance of Partner16.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(developer_id: SKIP, solution_id: SKIP, additional_properties: nil) ⇒ Partner16
Returns a new instance of Partner16.
51 52 53 54 55 56 57 58 59 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 51 def initialize(developer_id: SKIP, solution_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @developer_id = developer_id unless developer_id == SKIP @solution_id = solution_id unless solution_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#developer_id ⇒ String
Identifier for the developer that helped integrate a partner solution to CyberSource. Send this value in all requests that are sent through the partner solutions built by that developer. CyberSource assigns the ID to the developer. Note When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect.
20 21 22 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 20 def developer_id @developer_id end |
#solution_id ⇒ String
Identifier for the partner that is integrated to CyberSource. Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.
28 29 30 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 28 def solution_id @solution_id end |
Class Method Details
.from_element(root) ⇒ Object
82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 82 def self.from_element(root) developer_id = XmlUtilities.from_element(root, 'developerId', String) solution_id = XmlUtilities.from_element(root, 'solutionId', String) new(developer_id: developer_id, solution_id: solution_id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. developer_id = hash.key?('developerId') ? hash['developerId'] : SKIP solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Partner16.new(developer_id: developer_id, solution_id: solution_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['developer_id'] = 'developerId' @_hash['solution_id'] = 'solutionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 39 def self.optionals %w[ developer_id solution_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} developer_id: #{@developer_id.inspect}, solution_id:"\ " #{@solution_id.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} developer_id: #{@developer_id}, solution_id: #{@solution_id},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
91 92 93 94 95 96 97 98 99 100 |
# File 'lib/cyber_source_merged_spec/models/partner16.rb', line 91 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'developerId', developer_id) XmlUtilities.add_as_subelement(doc, root, 'solutionId', solution_id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |