Class: CyberSourceMergedSpec::Partner34
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Partner34
- Defined in:
- lib/cyber_source_merged_spec/models/partner34.rb
Overview
Partner34 Model.
Instance Attribute Summary collapse
-
#solution_id ⇒ String
Identifier for the partner that is integrated to CyberSource.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(solution_id: SKIP, additional_properties: nil) ⇒ Partner34
constructor
A new instance of Partner34.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(solution_id: SKIP, additional_properties: nil) ⇒ Partner34
Returns a new instance of Partner34.
39 40 41 42 43 44 45 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 39 def initialize(solution_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @solution_id = solution_id unless solution_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#solution_id ⇒ String
Identifier for the partner that is integrated to CyberSource. Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner. Note When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 18 def solution_id @solution_id end |
Class Method Details
.from_element(root) ⇒ Object
66 67 68 69 70 71 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 66 def self.from_element(root) solution_id = XmlUtilities.from_element(root, 'solutionId', String) new(solution_id: solution_id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. solution_id = hash.key?('solutionId') ? hash['solutionId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Partner34.new(solution_id: solution_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['solution_id'] = 'solutionId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
28 29 30 31 32 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 28 def self.optionals %w[ solution_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} solution_id: #{@solution_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} solution_id: #{@solution_id}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
73 74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/partner34.rb', line 73 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'solutionId', solution_id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |