Class: CyberSourceMergedSpec::Passenger3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Passenger3
- Defined in:
- lib/cyber_source_merged_spec/models/passenger3.rb
Overview
Passenger3 Model.
Instance Attribute Summary collapse
-
#first_name ⇒ String
First name of the passenger to whom the ticket was issued.
-
#last_name ⇒ String
Last name of the passenger to whom the ticket was issued.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(first_name: SKIP, last_name: SKIP, additional_properties: nil) ⇒ Passenger3
constructor
A new instance of Passenger3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(first_name: SKIP, last_name: SKIP, additional_properties: nil) ⇒ Passenger3
Returns a new instance of Passenger3.
49 50 51 52 53 54 55 56 57 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 49 def initialize(first_name: SKIP, last_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @first_name = first_name unless first_name == SKIP @last_name = last_name unless last_name == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#first_name ⇒ String
First name of the passenger to whom the ticket was issued. If there are multiple passengers, include all listed on the ticket. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Required for American Express SafeKey (U.S.) for travel-related requests.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 18 def first_name @first_name end |
#last_name ⇒ String
Last name of the passenger to whom the ticket was issued. If there are multiple passengers, include all listed on the ticket. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Required for American Express SafeKey (U.S.) for travel-related requests.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 26 def last_name @last_name end |
Class Method Details
.from_element(root) ⇒ Object
80 81 82 83 84 85 86 87 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 80 def self.from_element(root) first_name = XmlUtilities.from_element(root, 'firstName', String) last_name = XmlUtilities.from_element(root, 'lastName', String) new(first_name: first_name, last_name: last_name, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. first_name = hash.key?('firstName') ? hash['firstName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Passenger3.new(first_name: first_name, last_name: last_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['first_name'] = 'firstName' @_hash['last_name'] = 'lastName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
37 38 39 40 41 42 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 37 def self.optionals %w[ first_name last_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 108 def inspect class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 101 def to_s class_name = self.class.name.split('::').last "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/passenger3.rb', line 89 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'firstName', first_name) XmlUtilities.add_as_subelement(doc, root, 'lastName', last_name) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |