Class: CyberSourceMergedSpec::PaymentAccountInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentAccountInformation
- Defined in:
- lib/cyber_source_merged_spec/models/payment_account_information.rb
Overview
PaymentAccountInformation Model.
Instance Attribute Summary collapse
-
#card ⇒ Card1
TODO: Write general description for this method.
-
#tokenized_card ⇒ TokenizedCard1
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(card: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ PaymentAccountInformation
constructor
A new instance of PaymentAccountInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(card: SKIP, tokenized_card: SKIP, additional_properties: nil) ⇒ PaymentAccountInformation
Returns a new instance of PaymentAccountInformation.
41 42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 41 def initialize(card: SKIP, tokenized_card: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @card = card unless card == SKIP @tokenized_card = tokenized_card unless tokenized_card == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#card ⇒ Card1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 14 def card @card end |
#tokenized_card ⇒ TokenizedCard1
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 18 def tokenized_card @tokenized_card end |
Class Method Details
.from_element(root) ⇒ Object
71 72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 71 def self.from_element(root) card = XmlUtilities.from_element(root, 'Card1', Card1) tokenized_card = XmlUtilities.from_element(root, 'TokenizedCard1', TokenizedCard1) new(card: card, tokenized_card: tokenized_card, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. card = Card1.from_hash(hash['card']) if hash['card'] tokenized_card = TokenizedCard1.from_hash(hash['tokenizedCard']) if hash['tokenizedCard'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentAccountInformation.new(card: card, tokenized_card: tokenized_card, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['card'] = 'card' @_hash['tokenized_card'] = 'tokenizedCard' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 29 def self.optionals %w[ card tokenized_card ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} card: #{@card.inspect}, tokenized_card: #{@tokenized_card.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} card: #{@card}, tokenized_card: #{@tokenized_card}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/payment_account_information.rb', line 81 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Card1', card) XmlUtilities.add_as_subelement(doc, root, 'TokenizedCard1', tokenized_card) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |