Class: CyberSourceMergedSpec::PaymentInformation14
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentInformation14
- Defined in:
- lib/cyber_source_merged_spec/models/payment_information14.rb
Overview
PaymentInformation14 Model.
Instance Attribute Summary collapse
-
#customer ⇒ Customer10
TODO: Write general description for this method.
-
#payment_type ⇒ PaymentType11
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(customer: SKIP, payment_type: SKIP, additional_properties: nil) ⇒ PaymentInformation14
constructor
A new instance of PaymentInformation14.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(customer: SKIP, payment_type: SKIP, additional_properties: nil) ⇒ PaymentInformation14
Returns a new instance of PaymentInformation14.
41 42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 41 def initialize(customer: SKIP, payment_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @customer = customer unless customer == SKIP @payment_type = payment_type unless payment_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#customer ⇒ Customer10
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 14 def customer @customer end |
#payment_type ⇒ PaymentType11
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 18 def payment_type @payment_type end |
Class Method Details
.from_element(root) ⇒ Object
72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 72 def self.from_element(root) customer = XmlUtilities.from_element(root, 'Customer10', Customer10) payment_type = XmlUtilities.from_element(root, 'PaymentType11', PaymentType11) new(customer: customer, payment_type: payment_type, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. customer = Customer10.from_hash(hash['customer']) if hash['customer'] payment_type = PaymentType11.from_hash(hash['paymentType']) if hash['paymentType'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInformation14.new(customer: customer, payment_type: payment_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['customer'] = 'customer' @_hash['payment_type'] = 'paymentType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 29 def self.optionals %w[ customer payment_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} customer: #{@customer.inspect}, payment_type: #{@payment_type.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} customer: #{@customer}, payment_type: #{@payment_type},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/cyber_source_merged_spec/models/payment_information14.rb', line 82 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Customer10', customer) XmlUtilities.add_as_subelement(doc, root, 'PaymentType11', payment_type) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |