Class: CyberSourceMergedSpec::PaymentInformation16
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentInformation16
- Defined in:
- lib/cyber_source_merged_spec/models/payment_information16.rb
Overview
PaymentInformation16 Model.
Instance Attribute Summary collapse
-
#bank ⇒ Bank7
TODO: Write general description for this method.
-
#card ⇒ Card8
TODO: Write general description for this method.
-
#payment_type ⇒ PaymentType13
TODO: Write general description for this method.
-
#tokenized_card ⇒ TokenizedCard6
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(card: SKIP, tokenized_card: SKIP, payment_type: SKIP, bank: SKIP, additional_properties: nil) ⇒ PaymentInformation16
constructor
A new instance of PaymentInformation16.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(card: SKIP, tokenized_card: SKIP, payment_type: SKIP, bank: SKIP, additional_properties: nil) ⇒ PaymentInformation16
Returns a new instance of PaymentInformation16.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 53 def initialize(card: SKIP, tokenized_card: SKIP, payment_type: SKIP, bank: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @card = card unless card == SKIP @tokenized_card = tokenized_card unless tokenized_card == SKIP @payment_type = payment_type unless payment_type == SKIP @bank = bank unless bank == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#bank ⇒ Bank7
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 26 def bank @bank end |
#card ⇒ Card8
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 14 def card @card end |
#payment_type ⇒ PaymentType13
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 22 def payment_type @payment_type end |
#tokenized_card ⇒ TokenizedCard6
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 18 def tokenized_card @tokenized_card end |
Class Method Details
.from_element(root) ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 90 def self.from_element(root) card = XmlUtilities.from_element(root, 'Card8', Card8) tokenized_card = XmlUtilities.from_element(root, 'TokenizedCard6', TokenizedCard6) payment_type = XmlUtilities.from_element(root, 'PaymentType13', PaymentType13) bank = XmlUtilities.from_element(root, 'Bank7', Bank7) new(card: card, tokenized_card: tokenized_card, payment_type: payment_type, bank: bank, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 66 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. card = Card8.from_hash(hash['card']) if hash['card'] tokenized_card = TokenizedCard6.from_hash(hash['tokenizedCard']) if hash['tokenizedCard'] payment_type = PaymentType13.from_hash(hash['paymentType']) if hash['paymentType'] bank = Bank7.from_hash(hash['bank']) if hash['bank'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInformation16.new(card: card, tokenized_card: tokenized_card, payment_type: payment_type, bank: bank, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['card'] = 'card' @_hash['tokenized_card'] = 'tokenizedCard' @_hash['payment_type'] = 'paymentType' @_hash['bank'] = 'bank' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 39 def self.optionals %w[ card tokenized_card payment_type bank ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
127 128 129 130 131 132 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 127 def inspect class_name = self.class.name.split('::').last "<#{class_name} card: #{@card.inspect}, tokenized_card: #{@tokenized_card.inspect},"\ " payment_type: #{@payment_type.inspect}, bank: #{@bank.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
120 121 122 123 124 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 120 def to_s class_name = self.class.name.split('::').last "<#{class_name} card: #{@card}, tokenized_card: #{@tokenized_card}, payment_type:"\ " #{@payment_type}, bank: #{@bank}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/cyber_source_merged_spec/models/payment_information16.rb', line 105 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Card8', card) XmlUtilities.add_as_subelement(doc, root, 'TokenizedCard6', tokenized_card) XmlUtilities.add_as_subelement(doc, root, 'PaymentType13', payment_type) XmlUtilities.add_as_subelement(doc, root, 'Bank7', bank) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |