Class: CyberSourceMergedSpec::PaymentInformation30
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentInformation30
- Defined in:
- lib/cyber_source_merged_spec/models/payment_information30.rb
Overview
PaymentInformation30 Model.
Instance Attribute Summary collapse
-
#e_wallet ⇒ EWallet13
TODO: Write general description for this method.
-
#tokenized_payment_method ⇒ TokenizedPaymentMethod4
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tokenized_payment_method: SKIP, e_wallet: SKIP, additional_properties: nil) ⇒ PaymentInformation30
constructor
A new instance of PaymentInformation30.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tokenized_payment_method: SKIP, e_wallet: SKIP, additional_properties: nil) ⇒ PaymentInformation30
Returns a new instance of PaymentInformation30.
41 42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 41 def initialize(tokenized_payment_method: SKIP, e_wallet: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @tokenized_payment_method = tokenized_payment_method unless tokenized_payment_method == SKIP @e_wallet = e_wallet unless e_wallet == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#e_wallet ⇒ EWallet13
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 18 def e_wallet @e_wallet end |
#tokenized_payment_method ⇒ TokenizedPaymentMethod4
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 14 def tokenized_payment_method @tokenized_payment_method end |
Class Method Details
.from_element(root) ⇒ Object
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 74 def self.from_element(root) tokenized_payment_method = XmlUtilities.from_element( root, 'TokenizedPaymentMethod4', TokenizedPaymentMethod4 ) e_wallet = XmlUtilities.from_element(root, 'EWallet13', EWallet13) new(tokenized_payment_method: tokenized_payment_method, e_wallet: e_wallet, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['tokenizedPaymentMethod'] tokenized_payment_method = TokenizedPaymentMethod4.from_hash(hash['tokenizedPaymentMethod']) end e_wallet = EWallet13.from_hash(hash['eWallet']) if hash['eWallet'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentInformation30.new(tokenized_payment_method: tokenized_payment_method, e_wallet: e_wallet, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['tokenized_payment_method'] = 'tokenizedPaymentMethod' @_hash['e_wallet'] = 'eWallet' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 29 def self.optionals %w[ tokenized_payment_method e_wallet ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 105 def inspect class_name = self.class.name.split('::').last "<#{class_name} tokenized_payment_method: #{@tokenized_payment_method.inspect}, e_wallet:"\ " #{@e_wallet.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
98 99 100 101 102 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 98 def to_s class_name = self.class.name.split('::').last "<#{class_name} tokenized_payment_method: #{@tokenized_payment_method}, e_wallet:"\ " #{@e_wallet}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/cyber_source_merged_spec/models/payment_information30.rb', line 85 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'TokenizedPaymentMethod4', tokenized_payment_method) XmlUtilities.add_as_subelement(doc, root, 'EWallet13', e_wallet) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |