Class: CyberSourceMergedSpec::PaymentType22
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentType22
- Defined in:
- lib/cyber_source_merged_spec/models/payment_type22.rb
Overview
PaymentType22 Model.
Instance Attribute Summary collapse
-
#method ⇒ String
Indicates the payment method used in this payment transaction.
-
#name ⇒ String
A Payment Type is an agreed means for a payee to receive legal tender from a payer.
-
#type ⇒ String
Indicates the payment type used in this payment transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name: SKIP, type: SKIP, method: SKIP, additional_properties: nil) ⇒ PaymentType22
constructor
A new instance of PaymentType22.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name: SKIP, type: SKIP, method: SKIP, additional_properties: nil) ⇒ PaymentType22
Returns a new instance of PaymentType22.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 58 def initialize(name: SKIP, type: SKIP, method: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @name = name unless name == SKIP @type = type unless type == SKIP @method = method unless method == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#method ⇒ String
Indicates the payment method used in this payment transaction.
33 34 35 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 33 def method @method end |
#name ⇒ String
A Payment Type is an agreed means for a payee to receive legal tender from a payer. The way one pays for a commercial financial transaction. Examples: Card, Bank Transfer, Digital, Direct Debit. Possible values:
CARD(use this for a PIN debit transaction)CHECK(use this for all eCheck payment transactions - ECP Debit, ECP Follow-on Credit, ECP StandAlone Credit)bankTransfer(use for Online Bank Transafer for methods such as P24, iDeal, Estonia Bank, KCP)localCard(KCP Local card via Altpay)carrierBilling(KCP Carrier Billing via Altpay)
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 24 def name @name end |
#type ⇒ String
Indicates the payment type used in this payment transaction. Example: credit card, check
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 29 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 92 def self.from_element(root) name = XmlUtilities.from_element(root, 'name', String) type = XmlUtilities.from_element(root, 'type', String) method = XmlUtilities.from_element(root, 'method', String) new(name: name, type: type, method: method, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP method = hash.key?('method') ? hash['method'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentType22.new(name: name, type: type, method: method, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
36 37 38 39 40 41 42 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 36 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['type'] = 'type' @_hash['method'] = 'method' @_hash end |
.nullables ⇒ Object
An array for nullable fields
54 55 56 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 54 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 45 def self.optionals %w[ name type method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, type: #{@type.inspect}, method: #{@method.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, type: #{@type}, method: #{@method}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/cyber_source_merged_spec/models/payment_type22.rb', line 103 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'name', name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'method', method) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |