Class: CyberSourceMergedSpec::PaymentType23
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentType23
- Defined in:
- lib/cyber_source_merged_spec/models/payment_type23.rb
Overview
PaymentType23 Model.
Instance Attribute Summary collapse
-
#method ⇒ String
Indicates the payment method used in this payment transaction.
-
#type ⇒ String
Indicates the payment type used in this payment transaction.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(type: SKIP, method: SKIP, additional_properties: nil) ⇒ PaymentType23
constructor
A new instance of PaymentType23.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(type: SKIP, method: SKIP, additional_properties: nil) ⇒ PaymentType23
Returns a new instance of PaymentType23.
42 43 44 45 46 47 48 49 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 42 def initialize(type: SKIP, method: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @type = type unless type == SKIP @method = method unless method == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#method ⇒ String
Indicates the payment method used in this payment transaction.
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 19 def method @method end |
#type ⇒ String
Indicates the payment type used in this payment transaction. Example: credit card, check
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 15 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
72 73 74 75 76 77 78 79 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 72 def self.from_element(root) type = XmlUtilities.from_element(root, 'type', String) method = XmlUtilities.from_element(root, 'method', String) new(type: type, method: method, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. type = hash.key?('type') ? hash['type'] : SKIP method = hash.key?('method') ? hash['method'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentType23.new(type: type, method: method, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['type'] = 'type' @_hash['method'] = 'method' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 30 def self.optionals %w[ type method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} type: #{@type.inspect}, method: #{@method.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} type: #{@type}, method: #{@method}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cyber_source_merged_spec/models/payment_type23.rb', line 81 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'method', method) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |