Class: CyberSourceMergedSpec::PaymentsStrongAuthIssuerInformation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PaymentsStrongAuthIssuerInformation
- Defined in:
- lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb
Overview
PaymentsStrongAuthIssuerInformation Model.
Instance Attribute Summary collapse
-
#delegated_authentication_result ⇒ String
This will be the value returned by Visanet when delegated authentication has been requested.
-
#low_value_exemption_result ⇒ String
This will be the value returned by Visanet when low value exemption has been requested.
-
#risk_analysis_exemption_result ⇒ String
Possible values: Visa Platform Connect -
8401Merchant not participating in Visa Trusted Listing Program. -
#secure_corporate_payment_result ⇒ String
This will be the value returned by Visanet when secure corporate payment (scp) exemption has been requested.
-
#transaction_risk_analysis_exemption_result ⇒ String
This will be the value returned by Visanet when transaction risk analysis (TRA) exemption has been requested.
-
#trusted_merchant_exemption_result ⇒ String
Possible values: Visa Platform Connect -
2Trusted merchant exemption validated/honored.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(risk_analysis_exemption_result: SKIP, trusted_merchant_exemption_result: SKIP, low_value_exemption_result: SKIP, secure_corporate_payment_result: SKIP, transaction_risk_analysis_exemption_result: SKIP, delegated_authentication_result: SKIP, additional_properties: nil) ⇒ PaymentsStrongAuthIssuerInformation
constructor
A new instance of PaymentsStrongAuthIssuerInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(risk_analysis_exemption_result: SKIP, trusted_merchant_exemption_result: SKIP, low_value_exemption_result: SKIP, secure_corporate_payment_result: SKIP, transaction_risk_analysis_exemption_result: SKIP, delegated_authentication_result: SKIP, additional_properties: nil) ⇒ PaymentsStrongAuthIssuerInformation
Returns a new instance of PaymentsStrongAuthIssuerInformation.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 92 def initialize(risk_analysis_exemption_result: SKIP, trusted_merchant_exemption_result: SKIP, low_value_exemption_result: SKIP, secure_corporate_payment_result: SKIP, transaction_risk_analysis_exemption_result: SKIP, delegated_authentication_result: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? unless risk_analysis_exemption_result == SKIP @risk_analysis_exemption_result = risk_analysis_exemption_result end unless trusted_merchant_exemption_result == SKIP @trusted_merchant_exemption_result = trusted_merchant_exemption_result end unless low_value_exemption_result == SKIP @low_value_exemption_result = low_value_exemption_result end unless secure_corporate_payment_result == SKIP @secure_corporate_payment_result = secure_corporate_payment_result end unless transaction_risk_analysis_exemption_result == SKIP @transaction_risk_analysis_exemption_result = transaction_risk_analysis_exemption_result end unless delegated_authentication_result == SKIP @delegated_authentication_result = delegated_authentication_result end @additional_properties = additional_properties end |
Instance Attribute Details
#delegated_authentication_result ⇒ String
This will be the value returned by Visanet when delegated authentication has been requested.
57 58 59 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 57 def delegated_authentication_result @delegated_authentication_result end |
#low_value_exemption_result ⇒ String
This will be the value returned by Visanet when low value exemption has been requested. Valid values: Visa Platform Connect
2Low value exemption validated/honored3Low value exemption failed validation/not honored
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 35 def low_value_exemption_result @low_value_exemption_result end |
#risk_analysis_exemption_result ⇒ String
Possible values: Visa Platform Connect
8401Merchant not participating in Visa Trusted Listing Program.8402Issuer not participating in Visa Trusted Listing Program.8403Cardholder has not trusted the merchant (supplied by Visa Net).8404Indeterminate or invalid issuer response.8473Cardholder has not trusted the merchant (issuer-supplied).8474Did not meet the exemption criteria (issuer-supplied). Upto 20 Values may be received in a transaction.
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 21 def risk_analysis_exemption_result @risk_analysis_exemption_result end |
#secure_corporate_payment_result ⇒ String
This will be the value returned by Visanet when secure corporate payment (scp) exemption has been requested. Valid values: Visa Platform Connect
2Secure corporate payment exemption validated/honored3Secure corporate payment exemption failed validation/not honored
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 43 def secure_corporate_payment_result @secure_corporate_payment_result end |
#transaction_risk_analysis_exemption_result ⇒ String
This will be the value returned by Visanet when transaction risk analysis (TRA) exemption has been requested. Valid values: Visa Platform Connect
2transaction risk analysis (TRA) exemption validated/honored3transaction risk analysis (TRA) exemption failed validation/not honored
52 53 54 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 52 def transaction_risk_analysis_exemption_result @transaction_risk_analysis_exemption_result end |
#trusted_merchant_exemption_result ⇒ String
Possible values: Visa Platform Connect
2Trusted merchant exemption validated/honored.3Trusted merchant exemption failed validation/not honored.
27 28 29 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 27 def trusted_merchant_exemption_result @trusted_merchant_exemption_result end |
Class Method Details
.from_element(root) ⇒ Object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 164 def self.from_element(root) risk_analysis_exemption_result = XmlUtilities.from_element( root, 'riskAnalysisExemptionResult', String ) trusted_merchant_exemption_result = XmlUtilities.from_element( root, 'trustedMerchantExemptionResult', String ) low_value_exemption_result = XmlUtilities.from_element( root, 'lowValueExemptionResult', String ) secure_corporate_payment_result = XmlUtilities.from_element( root, 'secureCorporatePaymentResult', String ) transaction_risk_analysis_exemption_result = XmlUtilities.from_element( root, 'transactionRiskAnalysisExemptionResult', String ) delegated_authentication_result = XmlUtilities.from_element( root, 'delegatedAuthenticationResult', String ) new(risk_analysis_exemption_result: risk_analysis_exemption_result, trusted_merchant_exemption_result: trusted_merchant_exemption_result, low_value_exemption_result: low_value_exemption_result, secure_corporate_payment_result: secure_corporate_payment_result, transaction_risk_analysis_exemption_result: transaction_risk_analysis_exemption_result, delegated_authentication_result: delegated_authentication_result, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 130 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. risk_analysis_exemption_result = hash.key?('riskAnalysisExemptionResult') ? hash['riskAnalysisExemptionResult'] : SKIP trusted_merchant_exemption_result = hash.key?('trustedMerchantExemptionResult') ? hash['trustedMerchantExemptionResult'] : SKIP low_value_exemption_result = hash.key?('lowValueExemptionResult') ? hash['lowValueExemptionResult'] : SKIP secure_corporate_payment_result = hash.key?('secureCorporatePaymentResult') ? hash['secureCorporatePaymentResult'] : SKIP transaction_risk_analysis_exemption_result = hash.key?('transactionRiskAnalysisExemptionResult') ? hash['transactionRiskAnalysisExemptionResult'] : SKIP delegated_authentication_result = hash.key?('delegatedAuthenticationResult') ? hash['delegatedAuthenticationResult'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PaymentsStrongAuthIssuerInformation.new(risk_analysis_exemption_result: risk_analysis_exemption_result, trusted_merchant_exemption_result: trusted_merchant_exemption_result, low_value_exemption_result: low_value_exemption_result, secure_corporate_payment_result: secure_corporate_payment_result, transaction_risk_analysis_exemption_result: transaction_risk_analysis_exemption_result, delegated_authentication_result: delegated_authentication_result, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 60 def self.names @_hash = {} if @_hash.nil? @_hash['risk_analysis_exemption_result'] = 'riskAnalysisExemptionResult' @_hash['trusted_merchant_exemption_result'] = 'trustedMerchantExemptionResult' @_hash['low_value_exemption_result'] = 'lowValueExemptionResult' @_hash['secure_corporate_payment_result'] = 'secureCorporatePaymentResult' @_hash['transaction_risk_analysis_exemption_result'] = 'transactionRiskAnalysisExemptionResult' @_hash['delegated_authentication_result'] = 'delegatedAuthenticationResult' @_hash end |
.nullables ⇒ Object
An array for nullable fields
88 89 90 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 88 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 76 def self.optionals %w[ risk_analysis_exemption_result trusted_merchant_exemption_result low_value_exemption_result secure_corporate_payment_result transaction_risk_analysis_exemption_result delegated_authentication_result ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 229 def inspect class_name = self.class.name.split('::').last "<#{class_name} risk_analysis_exemption_result: #{@risk_analysis_exemption_result.inspect},"\ " trusted_merchant_exemption_result: #{@trusted_merchant_exemption_result.inspect},"\ " low_value_exemption_result: #{@low_value_exemption_result.inspect},"\ " secure_corporate_payment_result: #{@secure_corporate_payment_result.inspect},"\ ' transaction_risk_analysis_exemption_result:'\ " #{@transaction_risk_analysis_exemption_result.inspect}, delegated_authentication_result:"\ " #{@delegated_authentication_result.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 217 def to_s class_name = self.class.name.split('::').last "<#{class_name} risk_analysis_exemption_result: #{@risk_analysis_exemption_result},"\ " trusted_merchant_exemption_result: #{@trusted_merchant_exemption_result},"\ " low_value_exemption_result: #{@low_value_exemption_result},"\ " secure_corporate_payment_result: #{@secure_corporate_payment_result},"\ ' transaction_risk_analysis_exemption_result:'\ " #{@transaction_risk_analysis_exemption_result}, delegated_authentication_result:"\ " #{@delegated_authentication_result}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/cyber_source_merged_spec/models/payments_strong_auth_issuer_information.rb', line 193 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'riskAnalysisExemptionResult', risk_analysis_exemption_result) XmlUtilities.add_as_subelement(doc, root, 'trustedMerchantExemptionResult', trusted_merchant_exemption_result) XmlUtilities.add_as_subelement(doc, root, 'lowValueExemptionResult', low_value_exemption_result) XmlUtilities.add_as_subelement(doc, root, 'secureCorporatePaymentResult', secure_corporate_payment_result) XmlUtilities.add_as_subelement(doc, root, 'transactionRiskAnalysisExemptionResult', transaction_risk_analysis_exemption_result) XmlUtilities.add_as_subelement(doc, root, 'delegatedAuthenticationResult', delegated_authentication_result) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |