Class: CyberSourceMergedSpec::ProcessorInformation27
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ProcessorInformation27
- Defined in:
- lib/cyber_source_merged_spec/models/processor_information27.rb
Overview
ProcessorInformation27 Model.
Instance Attribute Summary collapse
-
#network_transaction_id ⇒ String
Same value as
processorInformation.transactionId. -
#payment_url ⇒ String
Direct the customer to this URL to complete the payment.
-
#transaction_id ⇒ String
Network transaction identifier (TID).
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(transaction_id: SKIP, network_transaction_id: SKIP, payment_url: SKIP, additional_properties: nil) ⇒ ProcessorInformation27
constructor
A new instance of ProcessorInformation27.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(transaction_id: SKIP, network_transaction_id: SKIP, payment_url: SKIP, additional_properties: nil) ⇒ ProcessorInformation27
Returns a new instance of ProcessorInformation27.
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 83 def initialize(transaction_id: SKIP, network_transaction_id: SKIP, payment_url: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @transaction_id = transaction_id unless transaction_id == SKIP @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP @payment_url = payment_url unless payment_url == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#network_transaction_id ⇒ String
Same value as processorInformation.transactionId
54 55 56 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 54 def network_transaction_id @network_transaction_id end |
#payment_url ⇒ String
Direct the customer to this URL to complete the payment.
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 58 def payment_url @payment_url end |
#transaction_id ⇒ String
Network transaction identifier (TID). You can use this value to identify a specific transaction when you are discussing the transaction with your processor. Not all processors provide this value. Returned by the authorization service.
PIN debit
Transaction identifier generated by the processor. Returned by PIN debit credit.
GPX
Processor transaction ID.
Cielo
For Cielo, this value is the non-sequential unit (NSU) and is supported for all transactions. The value is generated by Cielo or the issuing bank.
Comercio Latino
For Comercio Latino, this value is the proof of sale or non-sequential unit (NSU) number generated by the acquirers Cielo and Rede, or the issuing bank.
CyberSource through VisaNet and GPN
For details about this value for CyberSource through VisaNet and GPN, see "processorInformation.networkTransactionId" in [REST API Fields](https://developer.cybersource.com/content/dam/docs/cybs/en-us/apif ields/reference/all/rest/api-fields.pdf)
Moneris
This value identifies the transaction on a host system. It contains the following information:
- Terminal used to process the transaction
- Shift during which the transaction took place
- Batch number
- Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
- Terminal ID = 66012345
- Shift number = 001
- Batch number = 069
- Transaction number = 003
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 50 def transaction_id @transaction_id end |
Class Method Details
.from_element(root) ⇒ Object
118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 118 def self.from_element(root) transaction_id = XmlUtilities.from_element(root, 'transactionId', String) network_transaction_id = XmlUtilities.from_element(root, 'networkTransactionId', String) payment_url = XmlUtilities.from_element(root, 'paymentUrl', String) new(transaction_id: transaction_id, network_transaction_id: network_transaction_id, payment_url: payment_url, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 95 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP network_transaction_id = hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP payment_url = hash.key?('paymentUrl') ? hash['paymentUrl'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorInformation27.new(transaction_id: transaction_id, network_transaction_id: network_transaction_id, payment_url: payment_url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
61 62 63 64 65 66 67 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 61 def self.names @_hash = {} if @_hash.nil? @_hash['transaction_id'] = 'transactionId' @_hash['network_transaction_id'] = 'networkTransactionId' @_hash['payment_url'] = 'paymentUrl' @_hash end |
.nullables ⇒ Object
An array for nullable fields
79 80 81 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 79 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
70 71 72 73 74 75 76 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 70 def self.optionals %w[ transaction_id network_transaction_id payment_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
153 154 155 156 157 158 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 153 def inspect class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id.inspect}, network_transaction_id:"\ " #{@network_transaction_id.inspect}, payment_url: #{@payment_url.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
145 146 147 148 149 150 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 145 def to_s class_name = self.class.name.split('::').last "<#{class_name} transaction_id: #{@transaction_id}, network_transaction_id:"\ " #{@network_transaction_id}, payment_url: #{@payment_url}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/cyber_source_merged_spec/models/processor_information27.rb', line 131 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'transactionId', transaction_id) XmlUtilities.add_as_subelement(doc, root, 'networkTransactionId', network_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'paymentUrl', payment_url) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |