Class: CyberSourceMergedSpec::ProcessorInformation34
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ProcessorInformation34
- Defined in:
- lib/cyber_source_merged_spec/models/processor_information34.rb
Overview
ProcessorInformation34 Model.
Instance Attribute Summary collapse
-
#ach_verification ⇒ AchVerification
For most processors, this is the error message sent directly from the bank.
-
#approval_code ⇒ String
Authorization code.
-
#avs ⇒ Avs
For most processors, this is the error message sent directly from the bank.
-
#card_verification ⇒ CardVerification2
For most processors, this is the error message sent directly from the bank.
-
#electronic_verification_results ⇒ ElectronicVerificationResults3
For most processors, this is the error message sent directly from the bank.
-
#event_status ⇒ String
The event status.
-
#issuer_information ⇒ IssuerInformation5
For most processors, this is the error message sent directly from the bank.
-
#multi_processor_routing ⇒ Array[MultiProcessorRouting]
An array of object that contains the list of acquirer response codes & reasons if a transaction is routed to multiple acquirers.
-
#network_transaction_id ⇒ String
Same value as
processorInformation.transactionId. -
#payment_account_reference_number ⇒ String
Payment Account Reference (PAR) is a non-financial reference assigned to each unique payment account and used to link a payment account to associated network tokens, i.e.
-
#processor ⇒ Processor
TODO: Write general description for this method.
-
#raw_response ⇒ String
Failure reason returned by the processor.
-
#raw_response_local ⇒ String
Failure reason returned by the processor in the local language of the processor.
-
#response_code ⇒ String
For most processors, this is the error message sent directly from the bank.
-
#response_code_source ⇒ String
Used by Visa only and contains the response source/reason code that identifies the source of the response decision.
-
#response_details ⇒ String
This field might contain information about a decline.
-
#response_id ⇒ String
Response ID sent from the processor.
-
#retrieval_reference_number ⇒ String
Ingenico ePayments Unique number that CyberSource generates to identify the transaction.
-
#routing ⇒ Routing
Failure reason returned by the processor.
-
#system_trace_audit_number ⇒ String
This field is returned only for American Express Direct and CyberSource through VisaNet.
-
#transaction_id ⇒ String
Network transaction identifier (TID).
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(processor: SKIP, multi_processor_routing: SKIP, transaction_id: SKIP, network_transaction_id: SKIP, retrieval_reference_number: SKIP, response_id: SKIP, approval_code: SKIP, response_code: SKIP, avs: SKIP, card_verification: SKIP, ach_verification: SKIP, electronic_verification_results: SKIP, issuer_information: SKIP, event_status: SKIP, system_trace_audit_number: SKIP, response_code_source: SKIP, payment_account_reference_number: SKIP, response_details: SKIP, raw_response_local: SKIP, raw_response: SKIP, routing: SKIP, additional_properties: nil) ⇒ ProcessorInformation34
constructor
A new instance of ProcessorInformation34.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(processor: SKIP, multi_processor_routing: SKIP, transaction_id: SKIP, network_transaction_id: SKIP, retrieval_reference_number: SKIP, response_id: SKIP, approval_code: SKIP, response_code: SKIP, avs: SKIP, card_verification: SKIP, ach_verification: SKIP, electronic_verification_results: SKIP, issuer_information: SKIP, event_status: SKIP, system_trace_audit_number: SKIP, response_code_source: SKIP, payment_account_reference_number: SKIP, response_details: SKIP, raw_response_local: SKIP, raw_response: SKIP, routing: SKIP, additional_properties: nil) ⇒ ProcessorInformation34
Returns a new instance of ProcessorInformation34.
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 414 def initialize(processor: SKIP, multi_processor_routing: SKIP, transaction_id: SKIP, network_transaction_id: SKIP, retrieval_reference_number: SKIP, response_id: SKIP, approval_code: SKIP, response_code: SKIP, avs: SKIP, card_verification: SKIP, ach_verification: SKIP, electronic_verification_results: SKIP, issuer_information: SKIP, event_status: SKIP, system_trace_audit_number: SKIP, response_code_source: SKIP, payment_account_reference_number: SKIP, response_details: SKIP, raw_response_local: SKIP, raw_response: SKIP, routing: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @processor = processor unless processor == SKIP @multi_processor_routing = multi_processor_routing unless multi_processor_routing == SKIP @transaction_id = transaction_id unless transaction_id == SKIP @network_transaction_id = network_transaction_id unless network_transaction_id == SKIP unless retrieval_reference_number == SKIP @retrieval_reference_number = retrieval_reference_number end @response_id = response_id unless response_id == SKIP @approval_code = approval_code unless approval_code == SKIP @response_code = response_code unless response_code == SKIP @avs = avs unless avs == SKIP @card_verification = card_verification unless card_verification == SKIP @ach_verification = ach_verification unless ach_verification == SKIP unless electronic_verification_results == SKIP @electronic_verification_results = electronic_verification_results end @issuer_information = issuer_information unless issuer_information == SKIP @event_status = event_status unless event_status == SKIP unless system_trace_audit_number == SKIP @system_trace_audit_number = system_trace_audit_number end @response_code_source = response_code_source unless response_code_source == SKIP unless payment_account_reference_number == SKIP @payment_account_reference_number = payment_account_reference_number end @response_details = response_details unless response_details == SKIP @raw_response_local = raw_response_local unless raw_response_local == SKIP @raw_response = raw_response unless raw_response == SKIP @routing = routing unless routing == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#ach_verification ⇒ AchVerification
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
222 223 224 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 222 def ach_verification @ach_verification end |
#approval_code ⇒ String
Authorization code. Returned only when the processor returns this value. The length of this value depends on your processor. Returned by authorization service.
PIN debit
Authorization code that is returned by the processor. Returned by PIN debit credit.
Elavon Encrypted Account Number Program
The returned value is OFFLINE.
TSYS Acquiring Solutions
The returned value for a successful zero amount authorization is 000000.
90 91 92 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 90 def approval_code @approval_code end |
#avs ⇒ Avs
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
156 157 158 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 156 def avs @avs end |
#card_verification ⇒ CardVerification2
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
189 190 191 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 189 def card_verification @card_verification end |
#electronic_verification_results ⇒ ElectronicVerificationResults3
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
255 256 257 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 255 def electronic_verification_results @electronic_verification_results end |
#event_status ⇒ String
The event status.
292 293 294 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 292 def event_status @event_status end |
#issuer_information ⇒ IssuerInformation5
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
288 289 290 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 288 def issuer_information @issuer_information end |
#multi_processor_routing ⇒ Array[MultiProcessorRouting]
An array of object that contains the list of acquirer response codes & reasons if a transaction is routed to multiple acquirers.
19 20 21 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 19 def multi_processor_routing @multi_processor_routing end |
#network_transaction_id ⇒ String
Same value as processorInformation.transactionId
63 64 65 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 63 def network_transaction_id @network_transaction_id end |
#payment_account_reference_number ⇒ String
Payment Account Reference (PAR) is a non-financial reference assigned to each unique payment account and used to link a payment account to associated network tokens, i.e. the same PAR is returned for PAN-based and tokenized transactions, such as from digital wallets. PAR can be returned in authorisation responses for requests initiated with both real PANs and tokenized PANs. PAR can be used by merchants for fraud detection and regulatory compliance across different channels and digital wallets. PAR allows all participants in the payments chain to have a single, non-sensitive value assigned to a consumer. This value can be used in place of sensitive card holder identification fields, and transmitted across the payments ecosystem to facilitate card holder identification. Note On CyberSource through VisaNet, the value for this field corresponds to the following data in the TC 33 capture file:
- Record: CP01 TCR8
- Position: 79-110
- Field: Payment Account Reference The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment networks.
334 335 336 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 334 def payment_account_reference_number @payment_account_reference_number end |
#processor ⇒ Processor
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 14 def processor @processor end |
#raw_response ⇒ String
Failure reason returned by the processor.
347 348 349 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 347 def raw_response @raw_response end |
#raw_response_local ⇒ String
Failure reason returned by the processor in the local language of the processor.
343 344 345 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 343 def raw_response_local @raw_response_local end |
#response_code ⇒ String
For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value. Important Do not use this field to evaluate the result of the authorization.
PIN debit
Response value that is returned by the processor or bank. Important Do not use this field to evaluate the results of the transaction request. Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.
AIBMS
If this value is 08, you can accept the transaction if the customer
provides you with identification.
Atos
This value is the response code sent from Atos and it might also include
the response code from the bank.
Format: aa,bb with the two values separated by a comma and where:
aais the two-digit error message from Atos.bbis the optional two-digit error message from the bank.
Comercio Latino
This value is the status code and the error or response code received from
the processor separated by a colon.
Format: [status code]:E[error code] or [status code]:R[response code]
Example 2:R06
JCN Gateway
Processor-defined detail error code. The associated response category code
is in the processorInformation.responseCategoryCode field.
String (3)
paypalgateway
Processor generated ID for the itemized detail.
123 124 125 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 123 def response_code @response_code end |
#response_code_source ⇒ String
Used by Visa only and contains the response source/reason code that identifies the source of the response decision.
309 310 311 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 309 def response_code_source @response_code_source end |
#response_details ⇒ String
This field might contain information about a decline.
338 339 340 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 338 def response_details @response_details end |
#response_id ⇒ String
Response ID sent from the processor.
77 78 79 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 77 def response_id @response_id end |
#retrieval_reference_number ⇒ String
Ingenico ePayments
Unique number that CyberSource generates to identify the transaction. You can use this value to identify transactions in the Ingenico ePayments Collections Report, which provides settlement information. Contact customer support for information about the report.
CyberSource through VisaNet
Retrieval request number.
73 74 75 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 73 def retrieval_reference_number @retrieval_reference_number end |
#routing ⇒ Routing
Failure reason returned by the processor.
351 352 353 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 351 def routing @routing end |
#system_trace_audit_number ⇒ String
This field is returned only for American Express Direct and CyberSource through VisaNet. Returned by authorization and incremental authorization services.
American Express Direct
System trace audit number (STAN). This value identifies the transaction and is useful when investigating a chargeback dispute.
CyberSource through VisaNet
System trace number that must be printed on the customer’s receipt.
304 305 306 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 304 def system_trace_audit_number @system_trace_audit_number end |
#transaction_id ⇒ String
Network transaction identifier (TID). You can use this value to identify a specific transaction when you are discussing the transaction with your processor. Not all processors provide this value. Returned by the authorization service.
PIN debit
Transaction identifier generated by the processor. Returned by PIN debit credit.
GPX
Processor transaction ID.
Cielo
For Cielo, this value is the non-sequential unit (NSU) and is supported for all transactions. The value is generated by Cielo or the issuing bank.
Comercio Latino
For Comercio Latino, this value is the proof of sale or non-sequential unit (NSU) number generated by the acquirers Cielo and Rede, or the issuing bank.
CyberSource through VisaNet and GPN
For details about this value for CyberSource through VisaNet and GPN, see "processorInformation.networkTransactionId" in [REST API Fields](https://developer.cybersource.com/content/dam/docs/cybs/en-us/apif ields/reference/all/rest/api-fields.pdf)
Moneris
This value identifies the transaction on a host system. It contains the following information:
- Terminal used to process the transaction
- Shift during which the transaction took place
- Batch number
- Transaction number within the batch You must store this value. If you give the customer a receipt, display this value on the receipt. Example For the value 66012345001069003:
- Terminal ID = 66012345
- Shift number = 001
- Batch number = 069
- Transaction number = 003
59 60 61 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 59 def transaction_id @transaction_id end |
Class Method Details
.from_element(root) ⇒ Object
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 545 def self.from_element(root) processor = XmlUtilities.from_element(root, 'Processor', Processor) multi_processor_routing = XmlUtilities.from_element_to_array( root, 'MultiProcessorRouting', MultiProcessorRouting ) transaction_id = XmlUtilities.from_element(root, 'transactionId', String) network_transaction_id = XmlUtilities.from_element(root, 'networkTransactionId', String) retrieval_reference_number = XmlUtilities.from_element( root, 'retrievalReferenceNumber', String ) response_id = XmlUtilities.from_element(root, 'responseId', String) approval_code = XmlUtilities.from_element(root, 'approvalCode', String) response_code = XmlUtilities.from_element(root, 'responseCode', String) avs = XmlUtilities.from_element(root, 'Avs', Avs) card_verification = XmlUtilities.from_element(root, 'CardVerification2', CardVerification2) ach_verification = XmlUtilities.from_element(root, 'AchVerification', AchVerification) electronic_verification_results = XmlUtilities.from_element( root, 'ElectronicVerificationResults3', ElectronicVerificationResults3 ) issuer_information = XmlUtilities.from_element(root, 'IssuerInformation5', IssuerInformation5) event_status = XmlUtilities.from_element(root, 'eventStatus', String) system_trace_audit_number = XmlUtilities.from_element( root, 'systemTraceAuditNumber', String ) response_code_source = XmlUtilities.from_element(root, 'responseCodeSource', String) payment_account_reference_number = XmlUtilities.from_element( root, 'paymentAccountReferenceNumber', String ) response_details = XmlUtilities.from_element(root, 'responseDetails', String) raw_response_local = XmlUtilities.from_element(root, 'rawResponseLocal', String) raw_response = XmlUtilities.from_element(root, 'rawResponse', String) routing = XmlUtilities.from_element(root, 'Routing', Routing) new(processor: processor, multi_processor_routing: multi_processor_routing, transaction_id: transaction_id, network_transaction_id: network_transaction_id, retrieval_reference_number: retrieval_reference_number, response_id: response_id, approval_code: approval_code, response_code: response_code, avs: avs, card_verification: card_verification, ach_verification: ach_verification, electronic_verification_results: electronic_verification_results, issuer_information: issuer_information, event_status: event_status, system_trace_audit_number: system_trace_audit_number, response_code_source: response_code_source, payment_account_reference_number: payment_account_reference_number, response_details: response_details, raw_response_local: raw_response_local, raw_response: raw_response, routing: routing, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 466 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. processor = Processor.from_hash(hash['processor']) if hash['processor'] # Parameter is an array, so we need to iterate through it multi_processor_routing = nil unless hash['multiProcessorRouting'].nil? multi_processor_routing = [] hash['multiProcessorRouting'].each do |structure| multi_processor_routing << (MultiProcessorRouting.from_hash(structure) if structure) end end multi_processor_routing = SKIP unless hash.key?('multiProcessorRouting') transaction_id = hash.key?('transactionId') ? hash['transactionId'] : SKIP network_transaction_id = hash.key?('networkTransactionId') ? hash['networkTransactionId'] : SKIP retrieval_reference_number = hash.key?('retrievalReferenceNumber') ? hash['retrievalReferenceNumber'] : SKIP response_id = hash.key?('responseId') ? hash['responseId'] : SKIP approval_code = hash.key?('approvalCode') ? hash['approvalCode'] : SKIP response_code = hash.key?('responseCode') ? hash['responseCode'] : SKIP avs = Avs.from_hash(hash['avs']) if hash['avs'] card_verification = CardVerification2.from_hash(hash['cardVerification']) if hash['cardVerification'] ach_verification = AchVerification.from_hash(hash['achVerification']) if hash['achVerification'] if hash['electronicVerificationResults'] electronic_verification_results = ElectronicVerificationResults3.from_hash(hash['electronicVerificationResults']) end issuer_information = IssuerInformation5.from_hash(hash['issuerInformation']) if hash['issuerInformation'] event_status = hash.key?('eventStatus') ? hash['eventStatus'] : SKIP system_trace_audit_number = hash.key?('systemTraceAuditNumber') ? hash['systemTraceAuditNumber'] : SKIP response_code_source = hash.key?('responseCodeSource') ? hash['responseCodeSource'] : SKIP payment_account_reference_number = hash.key?('paymentAccountReferenceNumber') ? hash['paymentAccountReferenceNumber'] : SKIP response_details = hash.key?('responseDetails') ? hash['responseDetails'] : SKIP raw_response_local = hash.key?('rawResponseLocal') ? hash['rawResponseLocal'] : SKIP raw_response = hash.key?('rawResponse') ? hash['rawResponse'] : SKIP routing = Routing.from_hash(hash['routing']) if hash['routing'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProcessorInformation34.new(processor: processor, multi_processor_routing: multi_processor_routing, transaction_id: transaction_id, network_transaction_id: network_transaction_id, retrieval_reference_number: retrieval_reference_number, response_id: response_id, approval_code: approval_code, response_code: response_code, avs: avs, card_verification: card_verification, ach_verification: ach_verification, electronic_verification_results: electronic_verification_results, issuer_information: issuer_information, event_status: event_status, system_trace_audit_number: system_trace_audit_number, response_code_source: response_code_source, payment_account_reference_number: payment_account_reference_number, response_details: response_details, raw_response_local: raw_response_local, raw_response: raw_response, routing: routing, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 354 def self.names @_hash = {} if @_hash.nil? @_hash['processor'] = 'processor' @_hash['multi_processor_routing'] = 'multiProcessorRouting' @_hash['transaction_id'] = 'transactionId' @_hash['network_transaction_id'] = 'networkTransactionId' @_hash['retrieval_reference_number'] = 'retrievalReferenceNumber' @_hash['response_id'] = 'responseId' @_hash['approval_code'] = 'approvalCode' @_hash['response_code'] = 'responseCode' @_hash['avs'] = 'avs' @_hash['card_verification'] = 'cardVerification' @_hash['ach_verification'] = 'achVerification' @_hash['electronic_verification_results'] = 'electronicVerificationResults' @_hash['issuer_information'] = 'issuerInformation' @_hash['event_status'] = 'eventStatus' @_hash['system_trace_audit_number'] = 'systemTraceAuditNumber' @_hash['response_code_source'] = 'responseCodeSource' @_hash['payment_account_reference_number'] = 'paymentAccountReferenceNumber' @_hash['response_details'] = 'responseDetails' @_hash['raw_response_local'] = 'rawResponseLocal' @_hash['raw_response'] = 'rawResponse' @_hash['routing'] = 'routing' @_hash end |
.nullables ⇒ Object
An array for nullable fields
410 411 412 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 410 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 383 def self.optionals %w[ processor multi_processor_routing transaction_id network_transaction_id retrieval_reference_number response_id approval_code response_code avs card_verification ach_verification electronic_verification_results issuer_information event_status system_trace_audit_number response_code_source payment_account_reference_number response_details raw_response_local raw_response routing ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 673 def inspect class_name = self.class.name.split('::').last "<#{class_name} processor: #{@processor.inspect}, multi_processor_routing:"\ " #{@multi_processor_routing.inspect}, transaction_id: #{@transaction_id.inspect},"\ " network_transaction_id: #{@network_transaction_id.inspect}, retrieval_reference_number:"\ " #{@retrieval_reference_number.inspect}, response_id: #{@response_id.inspect},"\ " approval_code: #{@approval_code.inspect}, response_code: #{@response_code.inspect}, avs:"\ " #{@avs.inspect}, card_verification: #{@card_verification.inspect}, ach_verification:"\ " #{@ach_verification.inspect}, electronic_verification_results:"\ " #{@electronic_verification_results.inspect}, issuer_information:"\ " #{@issuer_information.inspect}, event_status: #{@event_status.inspect},"\ " system_trace_audit_number: #{@system_trace_audit_number.inspect}, response_code_source:"\ " #{@response_code_source.inspect}, payment_account_reference_number:"\ " #{@payment_account_reference_number.inspect}, response_details:"\ " #{@response_details.inspect}, raw_response_local: #{@raw_response_local.inspect},"\ " raw_response: #{@raw_response.inspect}, routing: #{@routing.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 656 def to_s class_name = self.class.name.split('::').last "<#{class_name} processor: #{@processor}, multi_processor_routing:"\ " #{@multi_processor_routing}, transaction_id: #{@transaction_id}, network_transaction_id:"\ " #{@network_transaction_id}, retrieval_reference_number: #{@retrieval_reference_number},"\ " response_id: #{@response_id}, approval_code: #{@approval_code}, response_code:"\ " #{@response_code}, avs: #{@avs}, card_verification: #{@card_verification},"\ " ach_verification: #{@ach_verification}, electronic_verification_results:"\ " #{@electronic_verification_results}, issuer_information: #{@issuer_information},"\ " event_status: #{@event_status}, system_trace_audit_number: #{@system_trace_audit_number},"\ " response_code_source: #{@response_code_source}, payment_account_reference_number:"\ " #{@payment_account_reference_number}, response_details: #{@response_details},"\ " raw_response_local: #{@raw_response_local}, raw_response: #{@raw_response}, routing:"\ " #{@routing}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/cyber_source_merged_spec/models/processor_information34.rb', line 612 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Processor', processor) XmlUtilities.add_array_as_subelement(doc, root, 'MultiProcessorRouting', multi_processor_routing) XmlUtilities.add_as_subelement(doc, root, 'transactionId', transaction_id) XmlUtilities.add_as_subelement(doc, root, 'networkTransactionId', network_transaction_id) XmlUtilities.add_as_subelement(doc, root, 'retrievalReferenceNumber', retrieval_reference_number) XmlUtilities.add_as_subelement(doc, root, 'responseId', response_id) XmlUtilities.add_as_subelement(doc, root, 'approvalCode', approval_code) XmlUtilities.add_as_subelement(doc, root, 'responseCode', response_code) XmlUtilities.add_as_subelement(doc, root, 'Avs', avs) XmlUtilities.add_as_subelement(doc, root, 'CardVerification2', card_verification) XmlUtilities.add_as_subelement(doc, root, 'AchVerification', ach_verification) XmlUtilities.add_as_subelement(doc, root, 'ElectronicVerificationResults3', electronic_verification_results) XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation5', issuer_information) XmlUtilities.add_as_subelement(doc, root, 'eventStatus', event_status) XmlUtilities.add_as_subelement(doc, root, 'systemTraceAuditNumber', system_trace_audit_number) XmlUtilities.add_as_subelement(doc, root, 'responseCodeSource', response_code_source) XmlUtilities.add_as_subelement(doc, root, 'paymentAccountReferenceNumber', payment_account_reference_number) XmlUtilities.add_as_subelement(doc, root, 'responseDetails', response_details) XmlUtilities.add_as_subelement(doc, root, 'rawResponseLocal', raw_response_local) XmlUtilities.add_as_subelement(doc, root, 'rawResponse', raw_response) XmlUtilities.add_as_subelement(doc, root, 'Routing', routing) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |