Class: CyberSourceMergedSpec::PtsV2ModifyBillingAgreementPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2ModifyBillingAgreementPost201Response
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb
Overview
PtsV2ModifyBillingAgreementPost201Response Model.
Instance Attribute Summary collapse
-
#agreement_information ⇒ AgreementInformation9
The status of the billing agreement.
-
#client_reference_information ⇒ ClientReferenceInformation29
The status of the billing agreement.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#installment_information ⇒ InstallmentInformation5
The status of the billing agreement.
-
#links ⇒ Links14
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation22
The status of the billing agreement.
-
#payment_information ⇒ PaymentInformation18
The status of the billing agreement.
-
#processor_information ⇒ ProcessorInformation21
The status of the billing agreement.
-
#risk_information ⇒ RiskInformation2
The status of the billing agreement.
-
#status ⇒ String
The status of the billing agreement.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, processor_information: SKIP, installment_information: SKIP, client_reference_information: SKIP, risk_information: SKIP, agreement_information: SKIP, order_information: SKIP, payment_information: SKIP, additional_properties: nil) ⇒ PtsV2ModifyBillingAgreementPost201Response
constructor
A new instance of PtsV2ModifyBillingAgreementPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, processor_information: SKIP, installment_information: SKIP, client_reference_information: SKIP, risk_information: SKIP, agreement_information: SKIP, order_information: SKIP, payment_information: SKIP, additional_properties: nil) ⇒ PtsV2ModifyBillingAgreementPost201Response
Returns a new instance of PtsV2ModifyBillingAgreementPost201Response.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 159 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, processor_information: SKIP, installment_information: SKIP, client_reference_information: SKIP, risk_information: SKIP, agreement_information: SKIP, order_information: SKIP, payment_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @processor_information = processor_information unless processor_information == SKIP @installment_information = installment_information unless installment_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @risk_information = risk_information unless risk_information == SKIP @agreement_information = agreement_information unless agreement_information == SKIP @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#agreement_information ⇒ AgreementInformation9
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
96 97 98 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 96 def agreement_information @agreement_information end |
#client_reference_information ⇒ ClientReferenceInformation29
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
74 75 76 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 74 def client_reference_information @client_reference_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 22 def id @id end |
#installment_information ⇒ InstallmentInformation5
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
63 64 65 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 63 def installment_information @installment_information end |
#links ⇒ Links14
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 14 def links @links end |
#order_information ⇒ OrderInformation22
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
107 108 109 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 107 def order_information @order_information end |
#payment_information ⇒ PaymentInformation18
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
118 119 120 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 118 def payment_information @payment_information end |
#processor_information ⇒ ProcessorInformation21
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
52 53 54 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 52 def processor_information @processor_information end |
#risk_information ⇒ RiskInformation2
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
85 86 87 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 85 def risk_information @risk_information end |
#status ⇒ String
The status of the billing agreement. Possible value is:
- PENDING
- REVOKED
- ACTIVE
- FAILED
- EXPIRED
- INACTIVE
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 41 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 232 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links14', Links14) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation21', ProcessorInformation21 ) installment_information = XmlUtilities.from_element( root, 'InstallmentInformation5', InstallmentInformation5 ) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation29', ClientReferenceInformation29 ) risk_information = XmlUtilities.from_element(root, 'RiskInformation2', RiskInformation2) agreement_information = XmlUtilities.from_element(root, 'AgreementInformation9', AgreementInformation9) order_information = XmlUtilities.from_element(root, 'OrderInformation22', OrderInformation22) payment_information = XmlUtilities.from_element(root, 'PaymentInformation18', PaymentInformation18) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, processor_information: processor_information, installment_information: installment_information, client_reference_information: client_reference_information, risk_information: risk_information, agreement_information: agreement_information, order_information: order_information, payment_information: payment_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 185 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links14.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP processor_information = ProcessorInformation21.from_hash(hash['processorInformation']) if hash['processorInformation'] installment_information = InstallmentInformation5.from_hash(hash['installmentInformation']) if hash['installmentInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation29.from_hash(hash['clientReferenceInformation']) end risk_information = RiskInformation2.from_hash(hash['riskInformation']) if hash['riskInformation'] agreement_information = AgreementInformation9.from_hash(hash['agreementInformation']) if hash['agreementInformation'] order_information = OrderInformation22.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation18.from_hash(hash['paymentInformation']) if hash['paymentInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2ModifyBillingAgreementPost201Response.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, processor_information: processor_information, installment_information: installment_information, client_reference_information: client_reference_information, risk_information: risk_information, agreement_information: agreement_information, order_information: order_information, payment_information: payment_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 121 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['processor_information'] = 'processorInformation' @_hash['installment_information'] = 'installmentInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['risk_information'] = 'riskInformation' @_hash['agreement_information'] = 'agreementInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
155 156 157 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 155 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 138 def self.optionals %w[ links id submit_time_utc status processor_information installment_information client_reference_information risk_information agreement_information order_information payment_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 313 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, processor_information:"\ " #{@processor_information.inspect}, installment_information:"\ " #{@installment_information.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, risk_information: #{@risk_information.inspect},"\ " agreement_information: #{@agreement_information.inspect}, order_information:"\ " #{@order_information.inspect}, payment_information: #{@payment_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 301 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, processor_information: #{@processor_information}, installment_information:"\ " #{@installment_information}, client_reference_information:"\ " #{@client_reference_information}, risk_information: #{@risk_information},"\ " agreement_information: #{@agreement_information}, order_information:"\ " #{@order_information}, payment_information: #{@payment_information},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_modify_billing_agreement_post201_response.rb', line 272 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links14', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation21', processor_information) XmlUtilities.add_as_subelement(doc, root, 'InstallmentInformation5', installment_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation29', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'RiskInformation2', risk_information) XmlUtilities.add_as_subelement(doc, root, 'AgreementInformation9', agreement_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation22', order_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation18', payment_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |