Class: CyberSourceMergedSpec::PtsV2PaymentsOrderPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2PaymentsOrderPost201Response
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb
Overview
PtsV2PaymentsOrderPost201Response Model.
Instance Attribute Summary collapse
-
#buyer_information ⇒ BuyerInformation8
An unique identification number generated by Cybersource to identify the submitted request.
-
#client_reference_information ⇒ ClientReferenceInformation3
An unique identification number generated by Cybersource to identify the submitted request.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#order_information ⇒ OrderInformation25
An unique identification number generated by Cybersource to identify the submitted request.
-
#payment_information ⇒ PaymentInformation21
An unique identification number generated by Cybersource to identify the submitted request.
-
#processing_information ⇒ ProcessingInformation22
An unique identification number generated by Cybersource to identify the submitted request.
-
#processor_information ⇒ ProcessorInformation24
An unique identification number generated by Cybersource to identify the submitted request.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#risk_information ⇒ RiskInformation4
Reference number for the transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, client_reference_information: SKIP, processor_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, risk_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsOrderPost201Response
constructor
A new instance of PtsV2PaymentsOrderPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, client_reference_information: SKIP, processor_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, risk_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsOrderPost201Response
Returns a new instance of PtsV2PaymentsOrderPost201Response.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 142 def initialize(id: SKIP, client_reference_information: SKIP, processor_information: SKIP, order_information: SKIP, payment_information: SKIP, processing_information: SKIP, buyer_information: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, risk_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @processor_information = processor_information unless processor_information == SKIP @order_information = order_information unless order_information == SKIP @payment_information = payment_information unless payment_information == SKIP @processing_information = processing_information unless processing_information == SKIP @buyer_information = buyer_information unless buyer_information == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @risk_information = risk_information unless risk_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#buyer_information ⇒ BuyerInformation8
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
66 67 68 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 66 def buyer_information @buyer_information end |
#client_reference_information ⇒ ClientReferenceInformation3
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 26 def client_reference_information @client_reference_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 18 def id @id end |
#order_information ⇒ OrderInformation25
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 42 def order_information @order_information end |
#payment_information ⇒ PaymentInformation21
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 50 def payment_information @payment_information end |
#processing_information ⇒ ProcessingInformation22
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 58 def processing_information @processing_information end |
#processor_information ⇒ ProcessorInformation24
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
34 35 36 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 34 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
93 94 95 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 93 def reconciliation_id @reconciliation_id end |
#risk_information ⇒ RiskInformation4
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
101 102 103 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 101 def risk_information @risk_information end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- CREATED
- SAVED
- APPROVED
- VOIDED
- COMPLETED
- PAYER_ACTION_REQUIRED
85 86 87 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 85 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
74 75 76 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 74 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 217 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation3', ClientReferenceInformation3 ) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation24', ProcessorInformation24 ) order_information = XmlUtilities.from_element(root, 'OrderInformation25', OrderInformation25) payment_information = XmlUtilities.from_element(root, 'PaymentInformation21', PaymentInformation21) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation22', ProcessingInformation22 ) buyer_information = XmlUtilities.from_element(root, 'BuyerInformation8', BuyerInformation8) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) risk_information = XmlUtilities.from_element(root, 'RiskInformation4', RiskInformation4) new(id: id, client_reference_information: client_reference_information, processor_information: processor_information, order_information: order_information, payment_information: payment_information, processing_information: processing_information, buyer_information: buyer_information, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, risk_information: risk_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 169 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end processor_information = ProcessorInformation24.from_hash(hash['processorInformation']) if hash['processorInformation'] order_information = OrderInformation25.from_hash(hash['orderInformation']) if hash['orderInformation'] payment_information = PaymentInformation21.from_hash(hash['paymentInformation']) if hash['paymentInformation'] processing_information = ProcessingInformation22.from_hash(hash['processingInformation']) if hash['processingInformation'] buyer_information = BuyerInformation8.from_hash(hash['buyerInformation']) if hash['buyerInformation'] submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP risk_information = RiskInformation4.from_hash(hash['riskInformation']) if hash['riskInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PaymentsOrderPost201Response.new(id: id, client_reference_information: client_reference_information, processor_information: processor_information, order_information: order_information, payment_information: payment_information, processing_information: processing_information, buyer_information: buyer_information, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, risk_information: risk_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 104 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['processor_information'] = 'processorInformation' @_hash['order_information'] = 'orderInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['processing_information'] = 'processingInformation' @_hash['buyer_information'] = 'buyerInformation' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['risk_information'] = 'riskInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
138 139 140 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 138 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 121 def self.optionals %w[ id client_reference_information processor_information order_information payment_information processing_information buyer_information submit_time_utc status reconciliation_id risk_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 299 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, processor_information:"\ " #{@processor_information.inspect}, order_information: #{@order_information.inspect},"\ " payment_information: #{@payment_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, buyer_information: #{@buyer_information.inspect},"\ " submit_time_utc: #{@submit_time_utc.inspect}, status: #{@status.inspect},"\ " reconciliation_id: #{@reconciliation_id.inspect}, risk_information:"\ " #{@risk_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
287 288 289 290 291 292 293 294 295 296 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 287 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, client_reference_information: #{@client_reference_information},"\ " processor_information: #{@processor_information}, order_information:"\ " #{@order_information}, payment_information: #{@payment_information},"\ " processing_information: #{@processing_information}, buyer_information:"\ " #{@buyer_information}, submit_time_utc: #{@submit_time_utc}, status: #{@status},"\ " reconciliation_id: #{@reconciliation_id}, risk_information: #{@risk_information},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_order_post201_response.rb', line 257 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation3', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation24', processor_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation25', order_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation21', payment_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation22', processing_information) XmlUtilities.add_as_subelement(doc, root, 'BuyerInformation8', buyer_information) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'RiskInformation4', risk_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |