Class: CyberSourceMergedSpec::PtsV2PaymentsPost201Response1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2PaymentsPost201Response1
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb
Overview
PtsV2PaymentsPost201Response1 Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation3
Reference number for the transaction.
-
#error_information ⇒ ErrorInformation5
Reference number for the transaction.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#issuer_information ⇒ IssuerInformation5
Reference number for the transaction.
-
#order_information ⇒ OrderInformation19
Reference number for the transaction.
-
#payment_information ⇒ PaymentInformation15
Reference number for the transaction.
-
#processor_information ⇒ ProcessorInformation20
Time of request in UTC.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, status: SKIP, submit_time_utc: SKIP, processor_information: SKIP, reconciliation_id: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, issuer_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response1
constructor
A new instance of PtsV2PaymentsPost201Response1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, status: SKIP, submit_time_utc: SKIP, processor_information: SKIP, reconciliation_id: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, issuer_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response1
Returns a new instance of PtsV2PaymentsPost201Response1.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 134 def initialize(id: SKIP, status: SKIP, submit_time_utc: SKIP, processor_information: SKIP, reconciliation_id: SKIP, payment_information: SKIP, order_information: SKIP, client_reference_information: SKIP, issuer_information: SKIP, error_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @status = status unless status == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @processor_information = processor_information unless processor_information == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @issuer_information = issuer_information unless issuer_information == SKIP @error_information = error_information unless error_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation3
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
79 80 81 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 79 def client_reference_information @client_reference_information end |
#error_information ⇒ ErrorInformation5
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
95 96 97 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 95 def error_information @error_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 18 def id @id end |
#issuer_information ⇒ IssuerInformation5
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
87 88 89 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 87 def issuer_information @issuer_information end |
#order_information ⇒ OrderInformation19
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
71 72 73 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 71 def order_information @order_information end |
#payment_information ⇒ PaymentInformation15
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
63 64 65 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 63 def payment_information @payment_information end |
#processor_information ⇒ ProcessorInformation20
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
47 48 49 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 47 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 55 def reconciliation_id @reconciliation_id end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- AUTHORIZED
- PARTIAL_AUTHORIZED
- AUTHORIZED_PENDING_REVIEW
- AUTHORIZED_RISK_DECLINED
- PENDING_AUTHENTICATION
- PENDING_REVIEW
- DECLINED
- INVALID_REQUEST
31 32 33 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 31 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
39 40 41 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 39 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 204 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) status = XmlUtilities.from_element(root, 'status', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation20', ProcessorInformation20 ) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) payment_information = XmlUtilities.from_element(root, 'PaymentInformation15', PaymentInformation15) order_information = XmlUtilities.from_element(root, 'OrderInformation19', OrderInformation19) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation3', ClientReferenceInformation3 ) issuer_information = XmlUtilities.from_element(root, 'IssuerInformation5', IssuerInformation5) error_information = XmlUtilities.from_element(root, 'ErrorInformation5', ErrorInformation5) new(id: id, status: status, submit_time_utc: submit_time_utc, processor_information: processor_information, reconciliation_id: reconciliation_id, payment_information: payment_information, order_information: order_information, client_reference_information: client_reference_information, issuer_information: issuer_information, error_information: error_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 159 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP processor_information = ProcessorInformation20.from_hash(hash['processorInformation']) if hash['processorInformation'] reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP payment_information = PaymentInformation15.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation19.from_hash(hash['orderInformation']) if hash['orderInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end issuer_information = IssuerInformation5.from_hash(hash['issuerInformation']) if hash['issuerInformation'] error_information = ErrorInformation5.from_hash(hash['errorInformation']) if hash['errorInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PaymentsPost201Response1.new(id: id, status: status, submit_time_utc: submit_time_utc, processor_information: processor_information, reconciliation_id: reconciliation_id, payment_information: payment_information, order_information: order_information, client_reference_information: client_reference_information, issuer_information: issuer_information, error_information: error_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 98 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['status'] = 'status' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['processor_information'] = 'processorInformation' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash['error_information'] = 'errorInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
130 131 132 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 130 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 114 def self.optionals %w[ id status submit_time_utc processor_information reconciliation_id payment_information order_information client_reference_information issuer_information error_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 279 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, status: #{@status.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, processor_information: #{@processor_information.inspect},"\ " reconciliation_id: #{@reconciliation_id.inspect}, payment_information:"\ " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " issuer_information: #{@issuer_information.inspect}, error_information:"\ " #{@error_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
268 269 270 271 272 273 274 275 276 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 268 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, status: #{@status}, submit_time_utc: #{@submit_time_utc},"\ " processor_information: #{@processor_information}, reconciliation_id:"\ " #{@reconciliation_id}, payment_information: #{@payment_information}, order_information:"\ " #{@order_information}, client_reference_information: #{@client_reference_information},"\ " issuer_information: #{@issuer_information}, error_information: #{@error_information},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response1.rb', line 240 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation20', processor_information) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation15', payment_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation19', order_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation3', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation5', issuer_information) XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation5', error_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |