Class: CyberSourceMergedSpec::PtsV2PaymentsPost201Response2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2PaymentsPost201Response2
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb
Overview
PtsV2PaymentsPost201Response2 Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation1
Reference number for the transaction.
-
#error_information ⇒ ErrorInformation
Reference number for the transaction.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#links ⇒ Links
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation27
Reference number for the transaction.
-
#payment_information ⇒ PaymentInformation23
Reference number for the transaction.
-
#processor_information ⇒ ProcessorInformation25
Reference number for the transaction.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#status ⇒ String
Status of the sessions request.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response2
constructor
A new instance of PtsV2PaymentsPost201Response2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsPost201Response2
Returns a new instance of PtsV2PaymentsPost201Response2.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 124 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, processor_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @error_information = error_information unless error_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @processor_information = processor_information unless processor_information == SKIP @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation1
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
61 62 63 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 61 def client_reference_information @client_reference_information end |
#error_information ⇒ ErrorInformation
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
53 54 55 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 53 def error_information @error_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 22 def id @id end |
#links ⇒ Links
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 14 def links @links end |
#order_information ⇒ OrderInformation27
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
85 86 87 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 85 def order_information @order_information end |
#payment_information ⇒ PaymentInformation23
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
77 78 79 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 77 def payment_information @payment_information end |
#processor_information ⇒ ProcessorInformation25
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
69 70 71 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 69 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
45 46 47 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 45 def reconciliation_id @reconciliation_id end |
#status ⇒ String
Status of the sessions request. Possible values: Created Failed
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 37 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 193 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links', Links) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) error_information = XmlUtilities.from_element(root, 'ErrorInformation', ErrorInformation) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation1', ClientReferenceInformation1 ) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation25', ProcessorInformation25 ) payment_information = XmlUtilities.from_element(root, 'PaymentInformation23', PaymentInformation23) order_information = XmlUtilities.from_element(root, 'OrderInformation27', OrderInformation27) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, error_information: error_information, client_reference_information: client_reference_information, processor_information: processor_information, payment_information: payment_information, order_information: order_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 149 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP error_information = ErrorInformation.from_hash(hash['errorInformation']) if hash['errorInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation1.from_hash(hash['clientReferenceInformation']) end processor_information = ProcessorInformation25.from_hash(hash['processorInformation']) if hash['processorInformation'] payment_information = PaymentInformation23.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation27.from_hash(hash['orderInformation']) if hash['orderInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PaymentsPost201Response2.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, error_information: error_information, client_reference_information: client_reference_information, processor_information: processor_information, payment_information: payment_information, order_information: order_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 88 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['error_information'] = 'errorInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['processor_information'] = 'processorInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
120 121 122 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 120 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 104 def self.optionals %w[ links id submit_time_utc status reconciliation_id error_information client_reference_information processor_information payment_information order_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 266 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\ " #{@reconciliation_id.inspect}, error_information: #{@error_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " processor_information: #{@processor_information.inspect}, payment_information:"\ " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
255 256 257 258 259 260 261 262 263 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 255 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, reconciliation_id: #{@reconciliation_id}, error_information:"\ " #{@error_information}, client_reference_information: #{@client_reference_information},"\ " processor_information: #{@processor_information}, payment_information:"\ " #{@payment_information}, order_information: #{@order_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_post201_response2.rb', line 228 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation', error_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation1', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation25', processor_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation23', payment_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation27', order_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |