Class: CyberSourceMergedSpec::PtsV2PaymentsReversalsPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2PaymentsReversalsPost201Response
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb
Overview
PtsV2PaymentsReversalsPost201Response Model.
Instance Attribute Summary collapse
-
#authorization_information ⇒ AuthorizationInformation
Reference number for the transaction.
-
#client_reference_information ⇒ ClientReferenceInformation1
Reference number for the transaction.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#issuer_information ⇒ IssuerInformation3
Reference number for the transaction.
-
#links ⇒ Links1
TODO: Write general description for this method.
-
#point_of_sale_information ⇒ PointOfSaleInformation2
Reference number for the transaction.
-
#processor_information ⇒ ProcessorInformation4
Reference number for the transaction.
-
#reconciliation_id ⇒ String
Reference number for the transaction.
-
#reversal_amount_details ⇒ ReversalAmountDetails
Reference number for the transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, reversal_amount_details: SKIP, processor_information: SKIP, issuer_information: SKIP, authorization_information: SKIP, point_of_sale_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsReversalsPost201Response
constructor
A new instance of PtsV2PaymentsReversalsPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, reversal_amount_details: SKIP, processor_information: SKIP, issuer_information: SKIP, authorization_information: SKIP, point_of_sale_information: SKIP, additional_properties: nil) ⇒ PtsV2PaymentsReversalsPost201Response
Returns a new instance of PtsV2PaymentsReversalsPost201Response.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 133 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, client_reference_information: SKIP, reversal_amount_details: SKIP, processor_information: SKIP, issuer_information: SKIP, authorization_information: SKIP, point_of_sale_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @reversal_amount_details = reversal_amount_details unless reversal_amount_details == SKIP @processor_information = processor_information unless processor_information == SKIP @issuer_information = issuer_information unless issuer_information == SKIP unless == SKIP @authorization_information = end unless point_of_sale_information == SKIP @point_of_sale_information = point_of_sale_information end @additional_properties = additional_properties end |
Instance Attribute Details
#authorization_information ⇒ AuthorizationInformation
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
84 85 86 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 84 def @authorization_information end |
#client_reference_information ⇒ ClientReferenceInformation1
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
52 53 54 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 52 def client_reference_information @client_reference_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 22 def id @id end |
#issuer_information ⇒ IssuerInformation3
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
76 77 78 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 76 def issuer_information @issuer_information end |
#links ⇒ Links1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 14 def links @links end |
#point_of_sale_information ⇒ PointOfSaleInformation2
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
92 93 94 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 92 def point_of_sale_information @point_of_sale_information end |
#processor_information ⇒ ProcessorInformation4
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
68 69 70 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 68 def processor_information @processor_information end |
#reconciliation_id ⇒ String
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
44 45 46 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 44 def reconciliation_id @reconciliation_id end |
#reversal_amount_details ⇒ ReversalAmountDetails
Reference number for the transaction. Depending on how your Cybersource account is configured, this value could either be provided in the API request or generated by CyberSource. The actual value used in the request to the processor is provided back to you by Cybersource in the response.
60 61 62 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 60 def reversal_amount_details @reversal_amount_details end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- REVERSED
36 37 38 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 36 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 214 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links1', Links1) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation1', ClientReferenceInformation1 ) reversal_amount_details = XmlUtilities.from_element( root, 'ReversalAmountDetails', ReversalAmountDetails ) processor_information = XmlUtilities.from_element(root, 'ProcessorInformation4', ProcessorInformation4) issuer_information = XmlUtilities.from_element(root, 'IssuerInformation3', IssuerInformation3) = XmlUtilities.from_element( root, 'AuthorizationInformation', AuthorizationInformation ) point_of_sale_information = XmlUtilities.from_element( root, 'PointOfSaleInformation2', PointOfSaleInformation2 ) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, client_reference_information: client_reference_information, reversal_amount_details: reversal_amount_details, processor_information: processor_information, issuer_information: issuer_information, authorization_information: , point_of_sale_information: point_of_sale_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 165 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links1.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation1.from_hash(hash['clientReferenceInformation']) end reversal_amount_details = ReversalAmountDetails.from_hash(hash['reversalAmountDetails']) if hash['reversalAmountDetails'] processor_information = ProcessorInformation4.from_hash(hash['processorInformation']) if hash['processorInformation'] issuer_information = IssuerInformation3.from_hash(hash['issuerInformation']) if hash['issuerInformation'] if hash['authorizationInformation'] = AuthorizationInformation.from_hash(hash['authorizationInformation']) end if hash['pointOfSaleInformation'] point_of_sale_information = PointOfSaleInformation2.from_hash(hash['pointOfSaleInformation']) end # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PaymentsReversalsPost201Response.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, client_reference_information: client_reference_information, reversal_amount_details: reversal_amount_details, processor_information: processor_information, issuer_information: issuer_information, authorization_information: , point_of_sale_information: point_of_sale_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 95 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['reversal_amount_details'] = 'reversalAmountDetails' @_hash['processor_information'] = 'processorInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash['authorization_information'] = 'authorizationInformation' @_hash['point_of_sale_information'] = 'pointOfSaleInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
129 130 131 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 129 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 112 def self.optionals %w[ links id submit_time_utc status reconciliation_id client_reference_information reversal_amount_details processor_information issuer_information authorization_information point_of_sale_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 295 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\ " #{@reconciliation_id.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, reversal_amount_details:"\ " #{@reversal_amount_details.inspect}, processor_information:"\ " #{@processor_information.inspect}, issuer_information: #{@issuer_information.inspect},"\ " authorization_information: #{@authorization_information.inspect},"\ " point_of_sale_information: #{@point_of_sale_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
283 284 285 286 287 288 289 290 291 292 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 283 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, reconciliation_id: #{@reconciliation_id}, client_reference_information:"\ " #{@client_reference_information}, reversal_amount_details: #{@reversal_amount_details},"\ " processor_information: #{@processor_information}, issuer_information:"\ " #{@issuer_information}, authorization_information: #{@authorization_information},"\ " point_of_sale_information: #{@point_of_sale_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payments_reversals_post201_response.rb', line 254 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links1', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation1', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'ReversalAmountDetails', reversal_amount_details) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation4', processor_information) XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation3', issuer_information) XmlUtilities.add_as_subelement(doc, root, 'AuthorizationInformation', ) XmlUtilities.add_as_subelement(doc, root, 'PointOfSaleInformation2', point_of_sale_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |