Class: CyberSourceMergedSpec::PtsV2PayoutsPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PtsV2PayoutsPost201Response
- Defined in:
- lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb
Overview
PtsV2PayoutsPost201Response Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation1
Cybersource or merchant generated transaction reference number.
-
#error_information ⇒ ErrorInformation29
Cybersource or merchant generated transaction reference number.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#issuer_information ⇒ IssuerInformation33
Cybersource or merchant generated transaction reference number.
-
#links ⇒ Links1
TODO: Write general description for this method.
-
#merchant_information ⇒ MerchantInformation22
Cybersource or merchant generated transaction reference number.
-
#order_information ⇒ OrderInformation44
Cybersource or merchant generated transaction reference number.
-
#processing_information ⇒ ProcessingInformation62
Cybersource or merchant generated transaction reference number.
-
#processor_information ⇒ ProcessorInformation30
Cybersource or merchant generated transaction reference number.
-
#recipient_information ⇒ RecipientInformation4
Cybersource or merchant generated transaction reference number.
-
#reconciliation_id ⇒ String
Cybersource or merchant generated transaction reference number.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
-
#token_information ⇒ TokenInformation1
Cybersource or merchant generated transaction reference number.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, merchant_information: SKIP, order_information: SKIP, processor_information: SKIP, recipient_information: SKIP, issuer_information: SKIP, token_information: SKIP, processing_information: SKIP, additional_properties: nil) ⇒ PtsV2PayoutsPost201Response
constructor
A new instance of PtsV2PayoutsPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, merchant_information: SKIP, order_information: SKIP, processor_information: SKIP, recipient_information: SKIP, issuer_information: SKIP, token_information: SKIP, processing_information: SKIP, additional_properties: nil) ⇒ PtsV2PayoutsPost201Response
Returns a new instance of PtsV2PayoutsPost201Response.
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 154 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, reconciliation_id: SKIP, error_information: SKIP, client_reference_information: SKIP, merchant_information: SKIP, order_information: SKIP, processor_information: SKIP, recipient_information: SKIP, issuer_information: SKIP, token_information: SKIP, processing_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @reconciliation_id = reconciliation_id unless reconciliation_id == SKIP @error_information = error_information unless error_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @merchant_information = merchant_information unless merchant_information == SKIP @order_information = order_information unless order_information == SKIP @processor_information = processor_information unless processor_information == SKIP @recipient_information = recipient_information unless recipient_information == SKIP @issuer_information = issuer_information unless issuer_information == SKIP @token_information = token_information unless token_information == SKIP @processing_information = processing_information unless processing_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation1
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 58 def client_reference_information @client_reference_information end |
#error_information ⇒ ErrorInformation29
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
51 52 53 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 51 def error_information @error_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 22 def id @id end |
#issuer_information ⇒ IssuerInformation33
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
93 94 95 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 93 def issuer_information @issuer_information end |
#links ⇒ Links1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 14 def links @links end |
#merchant_information ⇒ MerchantInformation22
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
65 66 67 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 65 def merchant_information @merchant_information end |
#order_information ⇒ OrderInformation44
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
72 73 74 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 72 def order_information @order_information end |
#processing_information ⇒ ProcessingInformation62
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
107 108 109 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 107 def processing_information @processing_information end |
#processor_information ⇒ ProcessorInformation30
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
79 80 81 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 79 def processor_information @processor_information end |
#recipient_information ⇒ RecipientInformation4
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
86 87 88 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 86 def recipient_information @recipient_information end |
#reconciliation_id ⇒ String
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
44 45 46 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 44 def reconciliation_id @reconciliation_id end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- ACCEPTED
- DECLINED
- INVALID_REQUEST
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 37 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57
p.m.). The T separates the date and the
time. The Z indicates UTC.
29 30 31 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 29 def submit_time_utc @submit_time_utc end |
#token_information ⇒ TokenInformation1
Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes.
100 101 102 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 100 def token_information @token_information end |
Class Method Details
.from_element(root) ⇒ Object
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 241 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links1', Links1) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) reconciliation_id = XmlUtilities.from_element(root, 'reconciliationId', String) error_information = XmlUtilities.from_element(root, 'ErrorInformation29', ErrorInformation29) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation1', ClientReferenceInformation1 ) merchant_information = XmlUtilities.from_element(root, 'MerchantInformation22', MerchantInformation22) order_information = XmlUtilities.from_element(root, 'OrderInformation44', OrderInformation44) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation30', ProcessorInformation30 ) recipient_information = XmlUtilities.from_element(root, 'RecipientInformation4', RecipientInformation4) issuer_information = XmlUtilities.from_element(root, 'IssuerInformation33', IssuerInformation33) token_information = XmlUtilities.from_element(root, 'TokenInformation1', TokenInformation1) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation62', ProcessingInformation62 ) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, error_information: error_information, client_reference_information: client_reference_information, merchant_information: merchant_information, order_information: order_information, processor_information: processor_information, recipient_information: recipient_information, issuer_information: issuer_information, token_information: token_information, processing_information: processing_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 185 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links1.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reconciliation_id = hash.key?('reconciliationId') ? hash['reconciliationId'] : SKIP error_information = ErrorInformation29.from_hash(hash['errorInformation']) if hash['errorInformation'] if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation1.from_hash(hash['clientReferenceInformation']) end merchant_information = MerchantInformation22.from_hash(hash['merchantInformation']) if hash['merchantInformation'] order_information = OrderInformation44.from_hash(hash['orderInformation']) if hash['orderInformation'] processor_information = ProcessorInformation30.from_hash(hash['processorInformation']) if hash['processorInformation'] recipient_information = RecipientInformation4.from_hash(hash['recipientInformation']) if hash['recipientInformation'] issuer_information = IssuerInformation33.from_hash(hash['issuerInformation']) if hash['issuerInformation'] token_information = TokenInformation1.from_hash(hash['tokenInformation']) if hash['tokenInformation'] processing_information = ProcessingInformation62.from_hash(hash['processingInformation']) if hash['processingInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PtsV2PayoutsPost201Response.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, reconciliation_id: reconciliation_id, error_information: error_information, client_reference_information: client_reference_information, merchant_information: merchant_information, order_information: order_information, processor_information: processor_information, recipient_information: recipient_information, issuer_information: issuer_information, token_information: token_information, processing_information: processing_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 110 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['reconciliation_id'] = 'reconciliationId' @_hash['error_information'] = 'errorInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['merchant_information'] = 'merchantInformation' @_hash['order_information'] = 'orderInformation' @_hash['processor_information'] = 'processorInformation' @_hash['recipient_information'] = 'recipientInformation' @_hash['issuer_information'] = 'issuerInformation' @_hash['token_information'] = 'tokenInformation' @_hash['processing_information'] = 'processingInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
150 151 152 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 150 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 130 def self.optionals %w[ links id submit_time_utc status reconciliation_id error_information client_reference_information merchant_information order_information processor_information recipient_information issuer_information token_information processing_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 339 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, reconciliation_id:"\ " #{@reconciliation_id.inspect}, error_information: #{@error_information.inspect},"\ " client_reference_information: #{@client_reference_information.inspect},"\ " merchant_information: #{@merchant_information.inspect}, order_information:"\ " #{@order_information.inspect}, processor_information: #{@processor_information.inspect},"\ " recipient_information: #{@recipient_information.inspect}, issuer_information:"\ " #{@issuer_information.inspect}, token_information: #{@token_information.inspect},"\ " processing_information: #{@processing_information.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 326 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, reconciliation_id: #{@reconciliation_id}, error_information:"\ " #{@error_information}, client_reference_information: #{@client_reference_information},"\ " merchant_information: #{@merchant_information}, order_information: #{@order_information},"\ " processor_information: #{@processor_information}, recipient_information:"\ " #{@recipient_information}, issuer_information: #{@issuer_information}, token_information:"\ " #{@token_information}, processing_information: #{@processing_information},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/cyber_source_merged_spec/models/pts_v2_payouts_post201_response.rb', line 291 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links1', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'reconciliationId', reconciliation_id) XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation29', error_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation1', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'MerchantInformation22', merchant_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation44', order_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation30', processor_information) XmlUtilities.add_as_subelement(doc, root, 'RecipientInformation4', recipient_information) XmlUtilities.add_as_subelement(doc, root, 'IssuerInformation33', issuer_information) XmlUtilities.add_as_subelement(doc, root, 'TokenInformation1', token_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation62', processing_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |