Class: CyberSourceMergedSpec::PullFunds201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::PullFunds201Response
- Defined in:
- lib/cyber_source_merged_spec/models/pull_funds201_response.rb
Overview
PullFunds201Response Model.
Instance Attribute Summary collapse
-
#error_information ⇒ ErrorInformation30
The status of the submitted transaction.
-
#id ⇒ String
A unique identification number to identify the submitted request.
-
#links ⇒ Links223
The status of the submitted transaction.
-
#order_information ⇒ OrderInformation46
Time of request in UTC.
-
#processor_information ⇒ ProcessorInformation31
The status of the submitted transaction.
-
#status ⇒ String
The status of the submitted transaction.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id: SKIP, submit_time_utc: SKIP, order_information: SKIP, status: SKIP, error_information: SKIP, processor_information: SKIP, links: SKIP, additional_properties: nil) ⇒ PullFunds201Response
constructor
A new instance of PullFunds201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id: SKIP, submit_time_utc: SKIP, order_information: SKIP, status: SKIP, error_information: SKIP, processor_information: SKIP, links: SKIP, additional_properties: nil) ⇒ PullFunds201Response
Returns a new instance of PullFunds201Response.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 108 def initialize(id: SKIP, submit_time_utc: SKIP, order_information: SKIP, status: SKIP, error_information: SKIP, processor_information: SKIP, links: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @order_information = order_information unless order_information == SKIP @status = status unless status == SKIP @error_information = error_information unless error_information == SKIP @processor_information = processor_information unless processor_information == SKIP @links = links unless links == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#error_information ⇒ ErrorInformation30
The status of the submitted transaction. Possible values:
- AUTHORIZED
- DECLINED
- SERVER_ERROR
- INVALID_REQUEST
- PARTIAL_AUTHORIZED
55 56 57 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 55 def error_information @error_information end |
#id ⇒ String
A unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 15 def id @id end |
#links ⇒ Links223
The status of the submitted transaction. Possible values:
- AUTHORIZED
- DECLINED
- SERVER_ERROR
- INVALID_REQUEST
- PARTIAL_AUTHORIZED
75 76 77 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 75 def links @links end |
#order_information ⇒ OrderInformation46
Time of request in UTC.
Format: YYYY-MM-DDThh:mm:ssZ
Example
2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57
p.m.).
The T separates the date and the time.
The Z indicates UTC.
35 36 37 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 35 def order_information @order_information end |
#processor_information ⇒ ProcessorInformation31
The status of the submitted transaction. Possible values:
- AUTHORIZED
- DECLINED
- SERVER_ERROR
- INVALID_REQUEST
- PARTIAL_AUTHORIZED
65 66 67 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 65 def processor_information @processor_information end |
#status ⇒ String
The status of the submitted transaction. Possible values:
- AUTHORIZED
- DECLINED
- SERVER_ERROR
- INVALID_REQUEST
- PARTIAL_AUTHORIZED
45 46 47 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 45 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC.
Format: YYYY-MM-DDThh:mm:ssZ
Example
2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57
p.m.).
The T separates the date and the time.
The Z indicates UTC.
25 26 27 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 25 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 160 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) order_information = XmlUtilities.from_element(root, 'OrderInformation46', OrderInformation46) status = XmlUtilities.from_element(root, 'status', String) error_information = XmlUtilities.from_element(root, 'ErrorInformation30', ErrorInformation30) processor_information = XmlUtilities.from_element( root, 'ProcessorInformation31', ProcessorInformation31 ) links = XmlUtilities.from_element(root, 'Links223', Links223) new(id: id, submit_time_utc: submit_time_utc, order_information: order_information, status: status, error_information: error_information, processor_information: processor_information, links: links, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 126 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP order_information = OrderInformation46.from_hash(hash['orderInformation']) if hash['orderInformation'] status = hash.key?('status') ? hash['status'] : SKIP error_information = ErrorInformation30.from_hash(hash['errorInformation']) if hash['errorInformation'] processor_information = ProcessorInformation31.from_hash(hash['processorInformation']) if hash['processorInformation'] links = Links223.from_hash(hash['_links']) if hash['_links'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. PullFunds201Response.new(id: id, submit_time_utc: submit_time_utc, order_information: order_information, status: status, error_information: error_information, processor_information: processor_information, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 78 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['order_information'] = 'orderInformation' @_hash['status'] = 'status' @_hash['error_information'] = 'errorInformation' @_hash['processor_information'] = 'processorInformation' @_hash['links'] = '_links' @_hash end |
.nullables ⇒ Object
An array for nullable fields
104 105 106 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 104 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 91 def self.optionals %w[ id submit_time_utc order_information status error_information processor_information links ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
213 214 215 216 217 218 219 220 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 213 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, submit_time_utc: #{@submit_time_utc.inspect},"\ " order_information: #{@order_information.inspect}, status: #{@status.inspect},"\ " error_information: #{@error_information.inspect}, processor_information:"\ " #{@processor_information.inspect}, links: #{@links.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
204 205 206 207 208 209 210 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 204 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, submit_time_utc: #{@submit_time_utc}, order_information:"\ " #{@order_information}, status: #{@status}, error_information: #{@error_information},"\ " processor_information: #{@processor_information}, links: #{@links}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/cyber_source_merged_spec/models/pull_funds201_response.rb', line 183 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation46', order_information) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation30', error_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessorInformation31', processor_information) XmlUtilities.add_as_subelement(doc, root, 'Links223', links) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |