Class: CyberSourceMergedSpec::RefundOptions2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::RefundOptions2
- Defined in:
- lib/cyber_source_merged_spec/models/refund_options2.rb
Overview
RefundOptions2 Model.
Instance Attribute Summary collapse
-
#reason ⇒ String
Must be set to
powfor Mastercard Gaming Payment of Winnings tranactions. -
#reconciliation_id_alternate ⇒ String
Alternative reference number that can be up to 12 characters in length.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reason: SKIP, reconciliation_id_alternate: SKIP, additional_properties: nil) ⇒ RefundOptions2
constructor
A new instance of RefundOptions2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reason: SKIP, reconciliation_id_alternate: SKIP, additional_properties: nil) ⇒ RefundOptions2
Returns a new instance of RefundOptions2.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 45 def initialize(reason: SKIP, reconciliation_id_alternate: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @reason = reason unless reason == SKIP unless reconciliation_id_alternate == SKIP @reconciliation_id_alternate = reconciliation_id_alternate end @additional_properties = additional_properties end |
Instance Attribute Details
#reason ⇒ String
Must be set to pow for Mastercard Gaming Payment of Winnings
tranactions.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 15 def reason @reason end |
#reconciliation_id_alternate ⇒ String
Alternative reference number that can be up to 12 characters in length. If this field is used, it overrides any data added to the ccCaptureService_reconciliationID field. You can use this value to reconcile Cybersource reports with processor reports.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 22 def reconciliation_id_alternate @reconciliation_id_alternate end |
Class Method Details
.from_element(root) ⇒ Object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 80 def self.from_element(root) reason = XmlUtilities.from_element(root, 'reason', String) reconciliation_id_alternate = XmlUtilities.from_element( root, 'reconciliationIdAlternate', String ) new(reason: reason, reconciliation_id_alternate: reconciliation_id_alternate, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reason = hash.key?('reason') ? hash['reason'] : SKIP reconciliation_id_alternate = hash.key?('reconciliationIdAlternate') ? hash['reconciliationIdAlternate'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RefundOptions2.new(reason: reason, reconciliation_id_alternate: reconciliation_id_alternate, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['reason'] = 'reason' @_hash['reconciliation_id_alternate'] = 'reconciliationIdAlternate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
33 34 35 36 37 38 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 33 def self.optionals %w[ reason reconciliation_id_alternate ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
111 112 113 114 115 116 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 111 def inspect class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason.inspect}, reconciliation_id_alternate:"\ " #{@reconciliation_id_alternate.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
104 105 106 107 108 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 104 def to_s class_name = self.class.name.split('::').last "<#{class_name} reason: #{@reason}, reconciliation_id_alternate:"\ " #{@reconciliation_id_alternate}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/cyber_source_merged_spec/models/refund_options2.rb', line 91 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'reason', reason) XmlUtilities.add_as_subelement(doc, root, 'reconciliationIdAlternate', reconciliation_id_alternate) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |