Class: CyberSourceMergedSpec::RiskV1AuthenticationsPost201Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::RiskV1AuthenticationsPost201Response
- Defined in:
- lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb
Overview
RiskV1AuthenticationsPost201Response Model.
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation49
The message describing the reason of the status.
-
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation5
The message describing the reason of the status.
-
#error_information ⇒ ErrorInformation25
The message describing the reason of the status.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#links ⇒ Links1
TODO: Write general description for this method.
-
#message ⇒ String
The message describing the reason of the status.
-
#order_information ⇒ OrderInformation36
The message describing the reason of the status.
-
#status ⇒ String
The status for payerAuthentication 201 enroll and validate calls.
-
#submit_time_utc ⇒ String
Time of request in UTC.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, message: SKIP, client_reference_information: SKIP, order_information: SKIP, consumer_authentication_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ RiskV1AuthenticationsPost201Response
constructor
A new instance of RiskV1AuthenticationsPost201Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, message: SKIP, client_reference_information: SKIP, order_information: SKIP, consumer_authentication_information: SKIP, error_information: SKIP, additional_properties: nil) ⇒ RiskV1AuthenticationsPost201Response
Returns a new instance of RiskV1AuthenticationsPost201Response.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 106 def initialize(links: SKIP, id: SKIP, submit_time_utc: SKIP, status: SKIP, message: SKIP, client_reference_information: SKIP, order_information: SKIP, consumer_authentication_information: SKIP, error_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @submit_time_utc = submit_time_utc unless submit_time_utc == SKIP @status = status unless status == SKIP @message = unless == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @order_information = order_information unless order_information == SKIP unless consumer_authentication_information == SKIP @consumer_authentication_information = consumer_authentication_information end @error_information = error_information unless error_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation49
The message describing the reason of the status. Value is:
- The cardholder is enrolled in Payer Authentication. Please authenticate the cardholder before continuing with the transaction.
50 51 52 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 50 def client_reference_information @client_reference_information end |
#consumer_authentication_information ⇒ ConsumerAuthenticationInformation5
The message describing the reason of the status. Value is:
- The cardholder is enrolled in Payer Authentication. Please authenticate the cardholder before continuing with the transaction.
62 63 64 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 62 def consumer_authentication_information @consumer_authentication_information end |
#error_information ⇒ ErrorInformation25
The message describing the reason of the status. Value is:
- The cardholder is enrolled in Payer Authentication. Please authenticate the cardholder before continuing with the transaction.
68 69 70 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 68 def error_information @error_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 22 def id @id end |
#links ⇒ Links1
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 14 def links @links end |
#message ⇒ String
The message describing the reason of the status. Value is:
- The cardholder is enrolled in Payer Authentication. Please authenticate the cardholder before continuing with the transaction.
44 45 46 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 44 def @message end |
#order_information ⇒ OrderInformation36
The message describing the reason of the status. Value is:
- The cardholder is enrolled in Payer Authentication. Please authenticate the cardholder before continuing with the transaction.
56 57 58 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 56 def order_information @order_information end |
#status ⇒ String
The status for payerAuthentication 201 enroll and validate calls. Possible values are:
AUTHENTICATION_SUCCESSFULPENDING_AUTHENTICATIONAUTHENTICATION_FAILED
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 38 def status @status end |
#submit_time_utc ⇒ String
Time of request in UTC. Format: YYYY-MM-DDThh:mm:ssZ
Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57
(10:47:57 p.m.).
The T separates the date and the time. The Z indicates UTC.
Returned by Cybersource for all services.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 30 def submit_time_utc @submit_time_utc end |
Class Method Details
.from_element(root) ⇒ Object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 174 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links1', Links1) id = XmlUtilities.from_element(root, 'id', String) submit_time_utc = XmlUtilities.from_element(root, 'submitTimeUtc', String) status = XmlUtilities.from_element(root, 'status', String) = XmlUtilities.from_element(root, 'message', String) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation49', ClientReferenceInformation49 ) order_information = XmlUtilities.from_element(root, 'OrderInformation36', OrderInformation36) consumer_authentication_information = XmlUtilities.from_element( root, 'ConsumerAuthenticationInformation5', ConsumerAuthenticationInformation5 ) error_information = XmlUtilities.from_element(root, 'ErrorInformation25', ErrorInformation25) new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, message: , client_reference_information: client_reference_information, order_information: order_information, consumer_authentication_information: consumer_authentication_information, error_information: error_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 133 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links1.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP submit_time_utc = hash.key?('submitTimeUtc') ? hash['submitTimeUtc'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP = hash.key?('message') ? hash['message'] : SKIP if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation49.from_hash(hash['clientReferenceInformation']) end order_information = OrderInformation36.from_hash(hash['orderInformation']) if hash['orderInformation'] if hash['consumerAuthenticationInformation'] consumer_authentication_information = ConsumerAuthenticationInformation5.from_hash(hash['consumerAuthenticationInformation']) end error_information = ErrorInformation25.from_hash(hash['errorInformation']) if hash['errorInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RiskV1AuthenticationsPost201Response.new(links: links, id: id, submit_time_utc: submit_time_utc, status: status, message: , client_reference_information: client_reference_information, order_information: order_information, consumer_authentication_information: consumer_authentication_information, error_information: error_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 71 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['submit_time_utc'] = 'submitTimeUtc' @_hash['status'] = 'status' @_hash['message'] = 'message' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['order_information'] = 'orderInformation' @_hash['consumer_authentication_information'] = 'consumerAuthenticationInformation' @_hash['error_information'] = 'errorInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
102 103 104 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 102 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 87 def self.optionals %w[ links id submit_time_utc status message client_reference_information order_information consumer_authentication_information error_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
241 242 243 244 245 246 247 248 249 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 241 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, submit_time_utc:"\ " #{@submit_time_utc.inspect}, status: #{@status.inspect}, message: #{@message.inspect},"\ " client_reference_information: #{@client_reference_information.inspect}, order_information:"\ " #{@order_information.inspect}, consumer_authentication_information:"\ " #{@consumer_authentication_information.inspect}, error_information:"\ " #{@error_information.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
230 231 232 233 234 235 236 237 238 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 230 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, submit_time_utc: #{@submit_time_utc}, status:"\ " #{@status}, message: #{@message}, client_reference_information:"\ " #{@client_reference_information}, order_information: #{@order_information},"\ " consumer_authentication_information: #{@consumer_authentication_information},"\ " error_information: #{@error_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/cyber_source_merged_spec/models/risk_v1_authentications_post201_response.rb', line 205 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links1', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'submitTimeUtc', submit_time_utc) XmlUtilities.add_as_subelement(doc, root, 'status', status) XmlUtilities.add_as_subelement(doc, root, 'message', ) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation49', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation36', order_information) XmlUtilities.add_as_subelement(doc, root, 'ConsumerAuthenticationInformation5', consumer_authentication_information) XmlUtilities.add_as_subelement(doc, root, 'ErrorInformation25', error_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |