Class: CyberSourceMergedSpec::SenderInformation4
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::SenderInformation4
- Defined in:
- lib/cyber_source_merged_spec/models/sender_information4.rb
Overview
SenderInformation4 Model.
Instance Attribute Summary collapse
-
#account ⇒ Account17
Visa Direct(16 characters) If the transaction is a money transfer, pre-paid load, or credit card bill pay, and if the sender intends to fund the transaction with a non-financial instrument (for example, cash), a reference number unique to the sender is required.
-
#address1 ⇒ String
Street address of sender.
-
#address2 ⇒ String
Second line of the sender's address.
-
#administrative_area ⇒ String
Sender’s state.
-
#alias_name ⇒ String
Sender's alias name.
-
#consumer_authentication ⇒ ConsumerAuthentication1
Country of sender.
-
#country ⇒ String
Country of sender.
-
#country_of_birth ⇒ String
Account Owner Country of Birth.
-
#date_of_birth ⇒ String
Sender’s date of birth.
-
#email ⇒ String
Account Owner email address.
-
#first_name ⇒ String
First name of sender.
-
#last_name ⇒ String
Last name of sender.
-
#locality ⇒ String
City of sender.
-
#middle_initial ⇒ String
Middle Initial of sender.
-
#middle_name ⇒ String
This field contains the middle name of the entity funding the transaction.
-
#name ⇒ String
Name of sender.
-
#nationality ⇒ String
Account Owner Nationality.
-
#occupation ⇒ String
Account Owner Occupation.
-
#payment_information ⇒ PaymentInformation38
Country of sender.
-
#personal_identification ⇒ PersonalIdentification32
Country of sender.
-
#phone_number ⇒ String
Sender’s phone number.
-
#postal_code ⇒ String
Sender’s postal code.
-
#reference_number ⇒ String
Visa Direct(16 characters) If the transaction is a money transfer, pre-paid load, or credit card bill pay, and if the sender intends to fund the transaction with a non-financial instrument (for example, cash), a reference number unique to the sender is required.
-
#type ⇒ String
This field identifies if the sender is a business or an individual.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(postal_code: SKIP, first_name: SKIP, middle_initial: SKIP, middle_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, country: SKIP, payment_information: SKIP, consumer_authentication: SKIP, personal_identification: SKIP, reference_number: SKIP, account: SKIP, alias_name: SKIP, country_of_birth: SKIP, date_of_birth: SKIP, email: SKIP, name: SKIP, nationality: SKIP, occupation: SKIP, phone_number: SKIP, type: SKIP, additional_properties: nil) ⇒ SenderInformation4
constructor
A new instance of SenderInformation4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(postal_code: SKIP, first_name: SKIP, middle_initial: SKIP, middle_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, country: SKIP, payment_information: SKIP, consumer_authentication: SKIP, personal_identification: SKIP, reference_number: SKIP, account: SKIP, alias_name: SKIP, country_of_birth: SKIP, date_of_birth: SKIP, email: SKIP, name: SKIP, nationality: SKIP, occupation: SKIP, phone_number: SKIP, type: SKIP, additional_properties: nil) ⇒ SenderInformation4
Returns a new instance of SenderInformation4.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 206 def initialize(postal_code: SKIP, first_name: SKIP, middle_initial: SKIP, middle_name: SKIP, last_name: SKIP, address1: SKIP, address2: SKIP, locality: SKIP, administrative_area: SKIP, country: SKIP, payment_information: SKIP, consumer_authentication: SKIP, personal_identification: SKIP, reference_number: SKIP, account: SKIP, alias_name: SKIP, country_of_birth: SKIP, date_of_birth: SKIP, email: SKIP, name: SKIP, nationality: SKIP, occupation: SKIP, phone_number: SKIP, type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @postal_code = postal_code unless postal_code == SKIP @first_name = first_name unless first_name == SKIP @middle_initial = middle_initial unless middle_initial == SKIP @middle_name = middle_name unless middle_name == SKIP @last_name = last_name unless last_name == SKIP @address1 = address1 unless address1 == SKIP @address2 = address2 unless address2 == SKIP @locality = locality unless locality == SKIP @administrative_area = administrative_area unless administrative_area == SKIP @country = country unless country == SKIP @payment_information = payment_information unless payment_information == SKIP @consumer_authentication = consumer_authentication unless consumer_authentication == SKIP @personal_identification = personal_identification unless personal_identification == SKIP @reference_number = reference_number unless reference_number == SKIP @account = account unless account == SKIP @alias_name = alias_name unless alias_name == SKIP @country_of_birth = country_of_birth unless country_of_birth == SKIP @date_of_birth = date_of_birth unless date_of_birth == SKIP @email = email unless email == SKIP @name = name unless name == SKIP @nationality = nationality unless nationality == SKIP @occupation = occupation unless occupation == SKIP @phone_number = phone_number unless phone_number == SKIP @type = type unless type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account ⇒ Account17
Visa Direct(16 characters)
If the transaction is a money transfer, pre-paid load, or credit card bill
pay, and if the sender intends to fund the transaction with a
non-financial instrument (for example, cash), a reference number unique to
the sender is required.
If the transaction is a funds disbursement, the field is required.
100 101 102 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 100 def account @account end |
#address1 ⇒ String
Street address of sender. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 38 def address1 @address1 end |
#address2 ⇒ String
Second line of the sender's address.
42 43 44 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 42 def address2 @address2 end |
#administrative_area ⇒ String
Sender’s state. Use the State, Province, and Territory Codes for the United States and Canada. This field is conditional: it is required if in the United States or Canada, and transaction is using neither a Customer nor Payment Instrument token. Value must be an ISO Standard State Code: [https://developer.cybersource.com/library/documentation/sbc/quickref/stat es_and_provinces.pdf](https://developer.cybersource.com/library/documentat ion/sbc/quickref/states_and_provinces.pdf)
58 59 60 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 58 def administrative_area @administrative_area end |
#alias_name ⇒ String
Sender's alias name.
104 105 106 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 104 def alias_name @alias_name end |
#consumer_authentication ⇒ ConsumerAuthentication1
Country of sender. Check that this field contains 2 character alpha ISO 3166-1 standard values. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
76 77 78 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 76 def consumer_authentication @consumer_authentication end |
#country ⇒ String
Country of sender. Check that this field contains 2 character alpha ISO 3166-1 standard values. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
64 65 66 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 64 def country @country end |
#country_of_birth ⇒ String
Account Owner Country of Birth.
108 109 110 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 108 def country_of_birth @country_of_birth end |
#date_of_birth ⇒ String
Sender’s date of birth. Format: YYYYMMDD.
112 113 114 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 112 def date_of_birth @date_of_birth end |
#email ⇒ String
Account Owner email address
116 117 118 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 116 def email @email end |
#first_name ⇒ String
First name of sender. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
20 21 22 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 20 def first_name @first_name end |
#last_name ⇒ String
Last name of sender. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
33 34 35 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 33 def last_name @last_name end |
#locality ⇒ String
City of sender. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
47 48 49 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 47 def locality @locality end |
#middle_initial ⇒ String
Middle Initial of sender
24 25 26 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 24 def middle_initial @middle_initial end |
#middle_name ⇒ String
This field contains the middle name of the entity funding the transaction.
28 29 30 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 28 def middle_name @middle_name end |
#name ⇒ String
Name of sender. Use this field if the sender is a business.
120 121 122 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 120 def name @name end |
#nationality ⇒ String
Account Owner Nationality
124 125 126 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 124 def nationality @nationality end |
#occupation ⇒ String
Account Owner Occupation.
128 129 130 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 128 def occupation @occupation end |
#payment_information ⇒ PaymentInformation38
Country of sender. Check that this field contains 2 character alpha ISO 3166-1 standard values. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
70 71 72 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 70 def payment_information @payment_information end |
#personal_identification ⇒ PersonalIdentification32
Country of sender. Check that this field contains 2 character alpha ISO 3166-1 standard values. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
82 83 84 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 82 def personal_identification @personal_identification end |
#phone_number ⇒ String
Sender’s phone number.
132 133 134 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 132 def phone_number @phone_number end |
#postal_code ⇒ String
Sender’s postal code. This field is conditional: it is required if using neither a Customer nor Payment Instrument token.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 15 def postal_code @postal_code end |
#reference_number ⇒ String
Visa Direct(16 characters)
If the transaction is a money transfer, pre-paid load, or credit card bill
pay, and if the sender intends to fund the transaction with a
non-financial instrument (for example, cash), a reference number unique to
the sender is required.
If the transaction is a funds disbursement, the field is required.
91 92 93 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 91 def reference_number @reference_number end |
#type ⇒ String
This field identifies if the sender is a business or an individual.
The valid values are:
• B (Business)
• I (Individual)
139 140 141 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 139 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 317 def self.from_element(root) postal_code = XmlUtilities.from_element(root, 'postalCode', String) first_name = XmlUtilities.from_element(root, 'firstName', String) middle_initial = XmlUtilities.from_element(root, 'middleInitial', String) middle_name = XmlUtilities.from_element(root, 'middleName', String) last_name = XmlUtilities.from_element(root, 'lastName', String) address1 = XmlUtilities.from_element(root, 'address1', String) address2 = XmlUtilities.from_element(root, 'address2', String) locality = XmlUtilities.from_element(root, 'locality', String) administrative_area = XmlUtilities.from_element(root, 'administrativeArea', String) country = XmlUtilities.from_element(root, 'country', String) payment_information = XmlUtilities.from_element(root, 'PaymentInformation38', PaymentInformation38) consumer_authentication = XmlUtilities.from_element( root, 'ConsumerAuthentication1', ConsumerAuthentication1 ) personal_identification = XmlUtilities.from_element( root, 'PersonalIdentification32', PersonalIdentification32 ) reference_number = XmlUtilities.from_element(root, 'referenceNumber', String) account = XmlUtilities.from_element(root, 'Account17', Account17) alias_name = XmlUtilities.from_element(root, 'aliasName', String) country_of_birth = XmlUtilities.from_element(root, 'countryOfBirth', String) date_of_birth = XmlUtilities.from_element(root, 'dateOfBirth', String) email = XmlUtilities.from_element(root, 'email', String) name = XmlUtilities.from_element(root, 'name', String) nationality = XmlUtilities.from_element(root, 'nationality', String) occupation = XmlUtilities.from_element(root, 'occupation', String) phone_number = XmlUtilities.from_element(root, 'phoneNumber', String) type = XmlUtilities.from_element(root, 'type', String) new(postal_code: postal_code, first_name: first_name, middle_initial: middle_initial, middle_name: middle_name, last_name: last_name, address1: address1, address2: address2, locality: locality, administrative_area: administrative_area, country: country, payment_information: payment_information, consumer_authentication: consumer_authentication, personal_identification: personal_identification, reference_number: reference_number, account: account, alias_name: alias_name, country_of_birth: country_of_birth, date_of_birth: date_of_birth, email: email, name: name, nationality: nationality, occupation: occupation, phone_number: phone_number, type: type, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 246 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. postal_code = hash.key?('postalCode') ? hash['postalCode'] : SKIP first_name = hash.key?('firstName') ? hash['firstName'] : SKIP middle_initial = hash.key?('middleInitial') ? hash['middleInitial'] : SKIP middle_name = hash.key?('middleName') ? hash['middleName'] : SKIP last_name = hash.key?('lastName') ? hash['lastName'] : SKIP address1 = hash.key?('address1') ? hash['address1'] : SKIP address2 = hash.key?('address2') ? hash['address2'] : SKIP locality = hash.key?('locality') ? hash['locality'] : SKIP administrative_area = hash.key?('administrativeArea') ? hash['administrativeArea'] : SKIP country = hash.key?('country') ? hash['country'] : SKIP payment_information = PaymentInformation38.from_hash(hash['paymentInformation']) if hash['paymentInformation'] consumer_authentication = ConsumerAuthentication1.from_hash(hash['consumerAuthentication']) if hash['consumerAuthentication'] if hash['personalIdentification'] personal_identification = PersonalIdentification32.from_hash(hash['personalIdentification']) end reference_number = hash.key?('referenceNumber') ? hash['referenceNumber'] : SKIP account = Account17.from_hash(hash['account']) if hash['account'] alias_name = hash.key?('aliasName') ? hash['aliasName'] : SKIP country_of_birth = hash.key?('countryOfBirth') ? hash['countryOfBirth'] : SKIP date_of_birth = hash.key?('dateOfBirth') ? hash['dateOfBirth'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP nationality = hash.key?('nationality') ? hash['nationality'] : SKIP occupation = hash.key?('occupation') ? hash['occupation'] : SKIP phone_number = hash.key?('phoneNumber') ? hash['phoneNumber'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. SenderInformation4.new(postal_code: postal_code, first_name: first_name, middle_initial: middle_initial, middle_name: middle_name, last_name: last_name, address1: address1, address2: address2, locality: locality, administrative_area: administrative_area, country: country, payment_information: payment_information, consumer_authentication: consumer_authentication, personal_identification: personal_identification, reference_number: reference_number, account: account, alias_name: alias_name, country_of_birth: country_of_birth, date_of_birth: date_of_birth, email: email, name: name, nationality: nationality, occupation: occupation, phone_number: phone_number, type: type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 142 def self.names @_hash = {} if @_hash.nil? @_hash['postal_code'] = 'postalCode' @_hash['first_name'] = 'firstName' @_hash['middle_initial'] = 'middleInitial' @_hash['middle_name'] = 'middleName' @_hash['last_name'] = 'lastName' @_hash['address1'] = 'address1' @_hash['address2'] = 'address2' @_hash['locality'] = 'locality' @_hash['administrative_area'] = 'administrativeArea' @_hash['country'] = 'country' @_hash['payment_information'] = 'paymentInformation' @_hash['consumer_authentication'] = 'consumerAuthentication' @_hash['personal_identification'] = 'personalIdentification' @_hash['reference_number'] = 'referenceNumber' @_hash['account'] = 'account' @_hash['alias_name'] = 'aliasName' @_hash['country_of_birth'] = 'countryOfBirth' @_hash['date_of_birth'] = 'dateOfBirth' @_hash['email'] = 'email' @_hash['name'] = 'name' @_hash['nationality'] = 'nationality' @_hash['occupation'] = 'occupation' @_hash['phone_number'] = 'phoneNumber' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
202 203 204 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 202 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 172 def self.optionals %w[ postal_code first_name middle_initial middle_name last_name address1 address2 locality administrative_area country payment_information consumer_authentication personal_identification reference_number account alias_name country_of_birth date_of_birth email name nationality occupation phone_number type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 435 def inspect class_name = self.class.name.split('::').last "<#{class_name} postal_code: #{@postal_code.inspect}, first_name: #{@first_name.inspect},"\ " middle_initial: #{@middle_initial.inspect}, middle_name: #{@middle_name.inspect},"\ " last_name: #{@last_name.inspect}, address1: #{@address1.inspect}, address2:"\ " #{@address2.inspect}, locality: #{@locality.inspect}, administrative_area:"\ " #{@administrative_area.inspect}, country: #{@country.inspect}, payment_information:"\ " #{@payment_information.inspect}, consumer_authentication:"\ " #{@consumer_authentication.inspect}, personal_identification:"\ " #{@personal_identification.inspect}, reference_number: #{@reference_number.inspect},"\ " account: #{@account.inspect}, alias_name: #{@alias_name.inspect}, country_of_birth:"\ " #{@country_of_birth.inspect}, date_of_birth: #{@date_of_birth.inspect}, email:"\ " #{@email.inspect}, name: #{@name.inspect}, nationality: #{@nationality.inspect},"\ " occupation: #{@occupation.inspect}, phone_number: #{@phone_number.inspect}, type:"\ " #{@type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 420 def to_s class_name = self.class.name.split('::').last "<#{class_name} postal_code: #{@postal_code}, first_name: #{@first_name}, middle_initial:"\ " #{@middle_initial}, middle_name: #{@middle_name}, last_name: #{@last_name}, address1:"\ " #{@address1}, address2: #{@address2}, locality: #{@locality}, administrative_area:"\ " #{@administrative_area}, country: #{@country}, payment_information:"\ " #{@payment_information}, consumer_authentication: #{@consumer_authentication},"\ " personal_identification: #{@personal_identification}, reference_number:"\ " #{@reference_number}, account: #{@account}, alias_name: #{@alias_name}, country_of_birth:"\ " #{@country_of_birth}, date_of_birth: #{@date_of_birth}, email: #{@email}, name: #{@name},"\ " nationality: #{@nationality}, occupation: #{@occupation}, phone_number: #{@phone_number},"\ " type: #{@type}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/cyber_source_merged_spec/models/sender_information4.rb', line 380 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'postalCode', postal_code) XmlUtilities.add_as_subelement(doc, root, 'firstName', first_name) XmlUtilities.add_as_subelement(doc, root, 'middleInitial', middle_initial) XmlUtilities.add_as_subelement(doc, root, 'middleName', middle_name) XmlUtilities.add_as_subelement(doc, root, 'lastName', last_name) XmlUtilities.add_as_subelement(doc, root, 'address1', address1) XmlUtilities.add_as_subelement(doc, root, 'address2', address2) XmlUtilities.add_as_subelement(doc, root, 'locality', locality) XmlUtilities.add_as_subelement(doc, root, 'administrativeArea', administrative_area) XmlUtilities.add_as_subelement(doc, root, 'country', country) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation38', payment_information) XmlUtilities.add_as_subelement(doc, root, 'ConsumerAuthentication1', consumer_authentication) XmlUtilities.add_as_subelement(doc, root, 'PersonalIdentification32', personal_identification) XmlUtilities.add_as_subelement(doc, root, 'referenceNumber', reference_number) XmlUtilities.add_as_subelement(doc, root, 'Account17', account) XmlUtilities.add_as_subelement(doc, root, 'aliasName', alias_name) XmlUtilities.add_as_subelement(doc, root, 'countryOfBirth', country_of_birth) XmlUtilities.add_as_subelement(doc, root, 'dateOfBirth', date_of_birth) XmlUtilities.add_as_subelement(doc, root, 'email', email) XmlUtilities.add_as_subelement(doc, root, 'name', name) XmlUtilities.add_as_subelement(doc, root, 'nationality', nationality) XmlUtilities.add_as_subelement(doc, root, 'occupation', occupation) XmlUtilities.add_as_subelement(doc, root, 'phoneNumber', phone_number) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |