Class: CyberSourceMergedSpec::Subscription
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::Subscription
- Defined in:
- lib/cyber_source_merged_spec/models/subscription.rb
Overview
Subscription list
Instance Attribute Summary collapse
-
#client_reference_information ⇒ ClientReferenceInformation3
An unique identification number generated by Cybersource to identify the submitted request.
-
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request.
-
#links ⇒ Links235
TODO: Write general description for this method.
-
#order_information ⇒ OrderInformation53
An unique identification number generated by Cybersource to identify the submitted request.
-
#payment_information ⇒ PaymentInformation40
An unique identification number generated by Cybersource to identify the submitted request.
-
#plan_information ⇒ PlanInformation9
An unique identification number generated by Cybersource to identify the submitted request.
-
#subscription_information ⇒ SubscriptionInformation2
An unique identification number generated by Cybersource to identify the submitted request.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(links: SKIP, id: SKIP, plan_information: SKIP, subscription_information: SKIP, client_reference_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ Subscription
constructor
A new instance of Subscription.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(links: SKIP, id: SKIP, plan_information: SKIP, subscription_information: SKIP, client_reference_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ Subscription
Returns a new instance of Subscription.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 95 def initialize(links: SKIP, id: SKIP, plan_information: SKIP, subscription_information: SKIP, client_reference_information: SKIP, payment_information: SKIP, order_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @links = links unless links == SKIP @id = id unless id == SKIP @plan_information = plan_information unless plan_information == SKIP @subscription_information = subscription_information unless subscription_information == SKIP unless client_reference_information == SKIP @client_reference_information = client_reference_information end @payment_information = payment_information unless payment_information == SKIP @order_information = order_information unless order_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#client_reference_information ⇒ ClientReferenceInformation3
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
46 47 48 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 46 def client_reference_information @client_reference_information end |
#id ⇒ String
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 22 def id @id end |
#links ⇒ Links235
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 14 def links @links end |
#order_information ⇒ OrderInformation53
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
62 63 64 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 62 def order_information @order_information end |
#payment_information ⇒ PaymentInformation40
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
54 55 56 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 54 def payment_information @payment_information end |
#plan_information ⇒ PlanInformation9
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
30 31 32 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 30 def plan_information @plan_information end |
#subscription_information ⇒ SubscriptionInformation2
An unique identification number generated by Cybersource to identify the submitted request. Returned by all services. It is also appended to the endpoint of the resource. On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.
38 39 40 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 38 def subscription_information @subscription_information end |
Class Method Details
.from_element(root) ⇒ Object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 154 def self.from_element(root) links = XmlUtilities.from_element(root, 'Links235', Links235) id = XmlUtilities.from_element(root, 'id', String) plan_information = XmlUtilities.from_element(root, 'PlanInformation9', PlanInformation9) subscription_information = XmlUtilities.from_element( root, 'SubscriptionInformation2', SubscriptionInformation2 ) client_reference_information = XmlUtilities.from_element( root, 'ClientReferenceInformation3', ClientReferenceInformation3 ) payment_information = XmlUtilities.from_element(root, 'PaymentInformation40', PaymentInformation40) order_information = XmlUtilities.from_element(root, 'OrderInformation53', OrderInformation53) new(links: links, id: id, plan_information: plan_information, subscription_information: subscription_information, client_reference_information: client_reference_information, payment_information: payment_information, order_information: order_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 117 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. links = Links235.from_hash(hash['_links']) if hash['_links'] id = hash.key?('id') ? hash['id'] : SKIP plan_information = PlanInformation9.from_hash(hash['planInformation']) if hash['planInformation'] if hash['subscriptionInformation'] subscription_information = SubscriptionInformation2.from_hash(hash['subscriptionInformation']) end if hash['clientReferenceInformation'] client_reference_information = ClientReferenceInformation3.from_hash(hash['clientReferenceInformation']) end payment_information = PaymentInformation40.from_hash(hash['paymentInformation']) if hash['paymentInformation'] order_information = OrderInformation53.from_hash(hash['orderInformation']) if hash['orderInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Subscription.new(links: links, id: id, plan_information: plan_information, subscription_information: subscription_information, client_reference_information: client_reference_information, payment_information: payment_information, order_information: order_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 65 def self.names @_hash = {} if @_hash.nil? @_hash['links'] = '_links' @_hash['id'] = 'id' @_hash['plan_information'] = 'planInformation' @_hash['subscription_information'] = 'subscriptionInformation' @_hash['client_reference_information'] = 'clientReferenceInformation' @_hash['payment_information'] = 'paymentInformation' @_hash['order_information'] = 'orderInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
91 92 93 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 91 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 78 def self.optionals %w[ links id plan_information subscription_information client_reference_information payment_information order_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
214 215 216 217 218 219 220 221 222 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 214 def inspect class_name = self.class.name.split('::').last "<#{class_name} links: #{@links.inspect}, id: #{@id.inspect}, plan_information:"\ " #{@plan_information.inspect}, subscription_information:"\ " #{@subscription_information.inspect}, client_reference_information:"\ " #{@client_reference_information.inspect}, payment_information:"\ " #{@payment_information.inspect}, order_information: #{@order_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
204 205 206 207 208 209 210 211 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 204 def to_s class_name = self.class.name.split('::').last "<#{class_name} links: #{@links}, id: #{@id}, plan_information: #{@plan_information},"\ " subscription_information: #{@subscription_information}, client_reference_information:"\ " #{@client_reference_information}, payment_information: #{@payment_information},"\ " order_information: #{@order_information}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/cyber_source_merged_spec/models/subscription.rb', line 182 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Links235', links) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'PlanInformation9', plan_information) XmlUtilities.add_as_subelement(doc, root, 'SubscriptionInformation2', subscription_information) XmlUtilities.add_as_subelement(doc, root, 'ClientReferenceInformation3', client_reference_information) XmlUtilities.add_as_subelement(doc, root, 'PaymentInformation40', payment_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation53', order_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |