Class: CyberSourceMergedSpec::ThirdPartyToken1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::ThirdPartyToken1
- Defined in:
- lib/cyber_source_merged_spec/models/third_party_token1.rb
Overview
ThirdPartyToken1 Model.
Instance Attribute Summary collapse
-
#id ⇒ String
When a third party is being used for tokenization, this field contains the token ID.
-
#source ⇒ String
This field identifies the third party that provided the Third Party Token identification value.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(source: SKIP, id: SKIP, additional_properties: nil) ⇒ ThirdPartyToken1
constructor
A new instance of ThirdPartyToken1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(source: SKIP, id: SKIP, additional_properties: nil) ⇒ ThirdPartyToken1
Returns a new instance of ThirdPartyToken1.
44 45 46 47 48 49 50 51 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 44 def initialize(source: SKIP, id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @source = source unless source == SKIP @id = id unless id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#id ⇒ String
When a third party is being used for tokenization, this field contains the token ID. See tokenInformation.thirdPartyToken.source to identify the provider.
21 22 23 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 21 def id @id end |
#source ⇒ String
This field identifies the third party that provided the Third Party Token identification value.
15 16 17 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 15 def source @source end |
Class Method Details
.from_element(root) ⇒ Object
74 75 76 77 78 79 80 81 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 74 def self.from_element(root) source = XmlUtilities.from_element(root, 'source', String) id = XmlUtilities.from_element(root, 'id', String) new(source: source, id: id, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. source = hash.key?('source') ? hash['source'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ThirdPartyToken1.new(source: source, id: id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['source'] = 'source' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 35 36 37 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 32 def self.optionals %w[ source id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 102 def inspect class_name = self.class.name.split('::').last "<#{class_name} source: #{@source.inspect}, id: #{@id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} source: #{@source}, id: #{@id}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/third_party_token1.rb', line 83 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'source', source) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |