Class: CyberSourceMergedSpec::Travel
- Defined in:
- lib/cyber_source_merged_spec/models/travel.rb
Overview
Travel Model.
Instance Attribute Summary collapse
-
#actual_final_destination ⇒ ActualFinalDestination
TODO: Write general description for this method.
-
#first_departure ⇒ FirstDeparture
TODO: Write general description for this method.
-
#first_destination ⇒ FirstDestination
TODO: Write general description for this method.
-
#last_destination ⇒ LastDestination
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(actual_final_destination: SKIP, first_departure: SKIP, first_destination: SKIP, last_destination: SKIP, additional_properties: nil) ⇒ Travel
constructor
A new instance of Travel.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(actual_final_destination: SKIP, first_departure: SKIP, first_destination: SKIP, last_destination: SKIP, additional_properties: nil) ⇒ Travel
Returns a new instance of Travel.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 53 def initialize(actual_final_destination: SKIP, first_departure: SKIP, first_destination: SKIP, last_destination: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @actual_final_destination = actual_final_destination unless actual_final_destination == SKIP @first_departure = first_departure unless first_departure == SKIP @first_destination = first_destination unless first_destination == SKIP @last_destination = last_destination unless last_destination == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#actual_final_destination ⇒ ActualFinalDestination
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 14 def actual_final_destination @actual_final_destination end |
#first_departure ⇒ FirstDeparture
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 18 def first_departure @first_departure end |
#first_destination ⇒ FirstDestination
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 22 def first_destination @first_destination end |
#last_destination ⇒ LastDestination
TODO: Write general description for this method
26 27 28 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 26 def last_destination @last_destination end |
Class Method Details
.from_element(root) ⇒ Object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 94 def self.from_element(root) actual_final_destination = XmlUtilities.from_element( root, 'ActualFinalDestination', ActualFinalDestination ) first_departure = XmlUtilities.from_element(root, 'FirstDeparture', FirstDeparture) first_destination = XmlUtilities.from_element(root, 'FirstDestination', FirstDestination) last_destination = XmlUtilities.from_element(root, 'LastDestination', LastDestination) new(actual_final_destination: actual_final_destination, first_departure: first_departure, first_destination: first_destination, last_destination: last_destination, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. actual_final_destination = ActualFinalDestination.from_hash(hash['actualFinalDestination']) if hash['actualFinalDestination'] first_departure = FirstDeparture.from_hash(hash['firstDeparture']) if hash['firstDeparture'] first_destination = FirstDestination.from_hash(hash['firstDestination']) if hash['firstDestination'] last_destination = LastDestination.from_hash(hash['lastDestination']) if hash['lastDestination'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Travel.new(actual_final_destination: actual_final_destination, first_departure: first_departure, first_destination: first_destination, last_destination: last_destination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['actual_final_destination'] = 'actualFinalDestination' @_hash['first_departure'] = 'firstDeparture' @_hash['first_destination'] = 'firstDestination' @_hash['last_destination'] = 'lastDestination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 46 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 39 def self.optionals %w[ actual_final_destination first_departure first_destination last_destination ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
138 139 140 141 142 143 144 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 138 def inspect class_name = self.class.name.split('::').last "<#{class_name} actual_final_destination: #{@actual_final_destination.inspect},"\ " first_departure: #{@first_departure.inspect}, first_destination:"\ " #{@first_destination.inspect}, last_destination: #{@last_destination.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
130 131 132 133 134 135 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 130 def to_s class_name = self.class.name.split('::').last "<#{class_name} actual_final_destination: #{@actual_final_destination}, first_departure:"\ " #{@first_departure}, first_destination: #{@first_destination}, last_destination:"\ " #{@last_destination}, additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/cyber_source_merged_spec/models/travel.rb', line 112 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'ActualFinalDestination', actual_final_destination) XmlUtilities.add_as_subelement(doc, root, 'FirstDeparture', first_departure) XmlUtilities.add_as_subelement(doc, root, 'FirstDestination', first_destination) XmlUtilities.add_as_subelement(doc, root, 'LastDestination', last_destination) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |