Class: CyberSourceMergedSpec::TravelInformation8
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::TravelInformation8
- Defined in:
- lib/cyber_source_merged_spec/models/travel_information8.rb
Overview
TravelInformation8 Model.
Instance Attribute Summary collapse
-
#actual_final_destination ⇒ String
The actual final destination of the travel.
-
#agency ⇒ Agency5
TODO: Write general description for this method.
-
#journey_type ⇒ String
The type of journey.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(agency: SKIP, journey_type: SKIP, actual_final_destination: SKIP, additional_properties: nil) ⇒ TravelInformation8
constructor
A new instance of TravelInformation8.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(agency: SKIP, journey_type: SKIP, actual_final_destination: SKIP, additional_properties: nil) ⇒ TravelInformation8
Returns a new instance of TravelInformation8.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 47 def initialize(agency: SKIP, journey_type: SKIP, actual_final_destination: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @agency = agency unless agency == SKIP @journey_type = journey_type unless journey_type == SKIP @actual_final_destination = actual_final_destination unless actual_final_destination == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#actual_final_destination ⇒ String
The actual final destination of the travel.
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 22 def actual_final_destination @actual_final_destination end |
#agency ⇒ Agency5
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 14 def agency @agency end |
#journey_type ⇒ String
The type of journey.
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 18 def journey_type @journey_type end |
Class Method Details
.from_element(root) ⇒ Object
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 82 def self.from_element(root) agency = XmlUtilities.from_element(root, 'Agency5', Agency5) journey_type = XmlUtilities.from_element(root, 'journeyType', String) actual_final_destination = XmlUtilities.from_element( root, 'actualFinalDestination', String ) new(agency: agency, journey_type: journey_type, actual_final_destination: actual_final_destination, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. agency = Agency5.from_hash(hash['agency']) if hash['agency'] journey_type = hash.key?('journeyType') ? hash['journeyType'] : SKIP actual_final_destination = hash.key?('actualFinalDestination') ? hash['actualFinalDestination'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TravelInformation8.new(agency: agency, journey_type: journey_type, actual_final_destination: actual_final_destination, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['agency'] = 'agency' @_hash['journey_type'] = 'journeyType' @_hash['actual_final_destination'] = 'actualFinalDestination' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 34 def self.optionals %w[ agency journey_type actual_final_destination ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} agency: #{@agency.inspect}, journey_type: #{@journey_type.inspect},"\ " actual_final_destination: #{@actual_final_destination.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} agency: #{@agency}, journey_type: #{@journey_type},"\ " actual_final_destination: #{@actual_final_destination}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/cyber_source_merged_spec/models/travel_information8.rb', line 95 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'Agency5', agency) XmlUtilities.add_as_subelement(doc, root, 'journeyType', journey_type) XmlUtilities.add_as_subelement(doc, root, 'actualFinalDestination', actual_final_destination) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |