Class: CyberSourceMergedSpec::UpdatePlanRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::UpdatePlanRequest
- Defined in:
- lib/cyber_source_merged_spec/models/update_plan_request.rb
Overview
UpdatePlanRequest Model.
Instance Attribute Summary collapse
-
#order_information ⇒ OrderInformation49
TODO: Write general description for this method.
-
#plan_information ⇒ PlanInformation4
TODO: Write general description for this method.
-
#processing_information ⇒ ProcessingInformation64
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(plan_information: SKIP, processing_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ UpdatePlanRequest
constructor
A new instance of UpdatePlanRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(plan_information: SKIP, processing_information: SKIP, order_information: SKIP, additional_properties: nil) ⇒ UpdatePlanRequest
Returns a new instance of UpdatePlanRequest.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 47 def initialize(plan_information: SKIP, processing_information: SKIP, order_information: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @plan_information = plan_information unless plan_information == SKIP @processing_information = processing_information unless processing_information == SKIP @order_information = order_information unless order_information == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#order_information ⇒ OrderInformation49
TODO: Write general description for this method
22 23 24 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 22 def order_information @order_information end |
#plan_information ⇒ PlanInformation4
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 14 def plan_information @plan_information end |
#processing_information ⇒ ProcessingInformation64
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 18 def processing_information @processing_information end |
Class Method Details
.from_element(root) ⇒ Object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 84 def self.from_element(root) plan_information = XmlUtilities.from_element(root, 'PlanInformation4', PlanInformation4) processing_information = XmlUtilities.from_element( root, 'ProcessingInformation64', ProcessingInformation64 ) order_information = XmlUtilities.from_element(root, 'OrderInformation49', OrderInformation49) new(plan_information: plan_information, processing_information: processing_information, order_information: order_information, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. plan_information = PlanInformation4.from_hash(hash['planInformation']) if hash['planInformation'] processing_information = ProcessingInformation64.from_hash(hash['processingInformation']) if hash['processingInformation'] order_information = OrderInformation49.from_hash(hash['orderInformation']) if hash['orderInformation'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UpdatePlanRequest.new(plan_information: plan_information, processing_information: processing_information, order_information: order_information, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['plan_information'] = 'planInformation' @_hash['processing_information'] = 'processingInformation' @_hash['order_information'] = 'orderInformation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 34 def self.optionals %w[ plan_information processing_information order_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
123 124 125 126 127 128 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 123 def inspect class_name = self.class.name.split('::').last "<#{class_name} plan_information: #{@plan_information.inspect}, processing_information:"\ " #{@processing_information.inspect}, order_information: #{@order_information.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
115 116 117 118 119 120 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 115 def to_s class_name = self.class.name.split('::').last "<#{class_name} plan_information: #{@plan_information}, processing_information:"\ " #{@processing_information}, order_information: #{@order_information},"\ " additional_properties: #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/cyber_source_merged_spec/models/update_plan_request.rb', line 99 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'PlanInformation4', plan_information) XmlUtilities.add_as_subelement(doc, root, 'ProcessingInformation64', processing_information) XmlUtilities.add_as_subelement(doc, root, 'OrderInformation49', order_information) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |