Class: CyberSourceMergedSpec::V1FileDetailsGet200Response
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- CyberSourceMergedSpec::V1FileDetailsGet200Response
- Defined in:
- lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb
Overview
V1FileDetailsGet200Response Model.
Instance Attribute Summary collapse
-
#file_details ⇒ Array[FileDetail]
TODO: Write general description for this method.
-
#links ⇒ Links250
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(file_details: SKIP, links: SKIP, additional_properties: nil) ⇒ V1FileDetailsGet200Response
constructor
A new instance of V1FileDetailsGet200Response.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(file_details: SKIP, links: SKIP, additional_properties: nil) ⇒ V1FileDetailsGet200Response
Returns a new instance of V1FileDetailsGet200Response.
41 42 43 44 45 46 47 48 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 41 def initialize(file_details: SKIP, links: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @file_details = file_details unless file_details == SKIP @links = links unless links == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#file_details ⇒ Array[FileDetail]
TODO: Write general description for this method
14 15 16 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 14 def file_details @file_details end |
#links ⇒ Links250
TODO: Write general description for this method
18 19 20 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 18 def links @links end |
Class Method Details
.from_element(root) ⇒ Object
80 81 82 83 84 85 86 87 88 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 80 def self.from_element(root) file_details = XmlUtilities.from_element_to_array(root, 'FileDetail', FileDetail) links = XmlUtilities.from_element(root, 'Links250', Links250) new(file_details: file_details, links: links, additional_properties: additional_properties) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it file_details = nil unless hash['fileDetails'].nil? file_details = [] hash['fileDetails'].each do |structure| file_details << (FileDetail.from_hash(structure) if structure) end end file_details = SKIP unless hash.key?('fileDetails') links = Links250.from_hash(hash['_links']) if hash['_links'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. V1FileDetailsGet200Response.new(file_details: file_details, links: links, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['file_details'] = 'fileDetails' @_hash['links'] = '_links' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 29 def self.optionals %w[ file_details links ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
110 111 112 113 114 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 110 def inspect class_name = self.class.name.split('::').last "<#{class_name} file_details: #{@file_details.inspect}, links: #{@links.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
103 104 105 106 107 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 103 def to_s class_name = self.class.name.split('::').last "<#{class_name} file_details: #{@file_details}, links: #{@links}, additional_properties:"\ " #{@additional_properties}>" end |
#to_xml_element(doc, root_name) ⇒ Object
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/cyber_source_merged_spec/models/v1_file_details_get200_response.rb', line 90 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_array_as_subelement(doc, root, 'FileDetail', file_details) XmlUtilities.add_as_subelement(doc, root, 'Links250', links) XmlUtilities.add_as_subelement(doc, root, 'additional_properties', additional_properties) root end |